/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_f0gd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (f0|gd) integrals */

void d12hrr_order_f0gd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][6][11] = int_stack + 0;
 Libderiv->deriv_classes[3][6][10] = int_stack + 280;
 Libderiv->deriv_classes[3][6][9] = int_stack + 560;
 Libderiv->deriv_classes[3][6][8] = int_stack + 840;
 Libderiv->deriv_classes[3][6][7] = int_stack + 1120;
 Libderiv->dvrr_classes[3][5] = int_stack + 1400;
 Libderiv->deriv_classes[3][6][6] = int_stack + 1610;
 Libderiv->deriv_classes[3][6][2] = int_stack + 1890;
 Libderiv->deriv_classes[3][6][1] = int_stack + 2170;
 Libderiv->deriv_classes[3][6][0] = int_stack + 2450;
 Libderiv->deriv2_classes[3][4][143] = int_stack + 2730;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 2880;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 3090;
 Libderiv->deriv2_classes[3][4][131] = int_stack + 3370;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 3520;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 3730;
 Libderiv->deriv2_classes[3][4][130] = int_stack + 4010;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 4160;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 4370;
 Libderiv->deriv2_classes[3][4][119] = int_stack + 4650;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 4800;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 5010;
 Libderiv->deriv2_classes[3][4][118] = int_stack + 5290;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 5440;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 5650;
 Libderiv->deriv2_classes[3][4][117] = int_stack + 5930;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 6080;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 6290;
 Libderiv->deriv2_classes[3][4][107] = int_stack + 6570;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 6720;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 6930;
 Libderiv->deriv2_classes[3][4][106] = int_stack + 7210;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 7360;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 7570;
 Libderiv->deriv2_classes[3][4][105] = int_stack + 7850;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 8000;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 8210;
 Libderiv->deriv2_classes[3][4][104] = int_stack + 8490;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 8640;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 8850;
 Libderiv->deriv2_classes[3][4][95] = int_stack + 9130;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 9280;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 9490;
 Libderiv->deriv2_classes[3][4][94] = int_stack + 9770;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 9920;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 10130;
 Libderiv->deriv2_classes[3][4][93] = int_stack + 10410;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 10560;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 10770;
 Libderiv->deriv2_classes[3][4][92] = int_stack + 11050;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 11200;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 11410;
 Libderiv->deriv2_classes[3][4][91] = int_stack + 11690;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 11840;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 12050;
 Libderiv->deriv_classes[3][4][11] = int_stack + 12330;
 Libderiv->deriv2_classes[3][4][83] = int_stack + 12480;
 Libderiv->deriv_classes[3][5][11] = int_stack + 12630;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 12840;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 13050;
 Libderiv->deriv_classes[3][4][10] = int_stack + 13330;
 Libderiv->deriv2_classes[3][4][82] = int_stack + 13480;
 Libderiv->deriv_classes[3][5][10] = int_stack + 13630;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 13840;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 14050;
 Libderiv->deriv_classes[3][4][9] = int_stack + 14330;
 Libderiv->deriv2_classes[3][4][81] = int_stack + 14480;
 Libderiv->deriv_classes[3][5][9] = int_stack + 14630;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 14840;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 15050;
 Libderiv->deriv_classes[3][4][8] = int_stack + 15330;
 Libderiv->deriv2_classes[3][4][80] = int_stack + 15480;
 Libderiv->deriv_classes[3][5][8] = int_stack + 15630;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 15840;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 16050;
 Libderiv->deriv_classes[3][4][7] = int_stack + 16330;
 Libderiv->deriv2_classes[3][4][79] = int_stack + 16480;
 Libderiv->deriv_classes[3][5][7] = int_stack + 16630;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 16840;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 17050;
 Libderiv->dvrr_classes[3][4] = int_stack + 17330;
 Libderiv->deriv_classes[3][4][6] = int_stack + 17480;
 Libderiv->deriv2_classes[3][4][78] = int_stack + 17630;
 Libderiv->deriv_classes[3][5][6] = int_stack + 17780;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 17990;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 18200;
 Libderiv->deriv2_classes[3][4][35] = int_stack + 18480;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 18630;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 18840;
 Libderiv->deriv2_classes[3][4][34] = int_stack + 19120;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 19270;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 19480;
 Libderiv->deriv2_classes[3][4][33] = int_stack + 19760;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 19910;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 20120;
 Libderiv->deriv2_classes[3][4][32] = int_stack + 20400;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 20550;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 20760;
 Libderiv->deriv2_classes[3][4][31] = int_stack + 21040;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 21190;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 21400;
 Libderiv->deriv_classes[3][4][2] = int_stack + 21680;
 Libderiv->deriv2_classes[3][4][30] = int_stack + 21830;
 Libderiv->deriv_classes[3][5][2] = int_stack + 21980;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 22190;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 22400;
 Libderiv->deriv2_classes[3][4][26] = int_stack + 22680;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 22830;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 23040;
 Libderiv->deriv2_classes[3][4][23] = int_stack + 23320;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 23470;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 23680;
 Libderiv->deriv2_classes[3][4][22] = int_stack + 23960;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 24110;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 24320;
 Libderiv->deriv2_classes[3][4][21] = int_stack + 24600;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 24750;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 24960;
 Libderiv->deriv2_classes[3][4][20] = int_stack + 25240;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 25390;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 25600;
 Libderiv->deriv2_classes[3][4][19] = int_stack + 25880;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 26030;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 26240;
 Libderiv->deriv_classes[3][4][1] = int_stack + 26520;
 Libderiv->deriv2_classes[3][4][18] = int_stack + 26670;
 Libderiv->deriv_classes[3][5][1] = int_stack + 26820;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 27030;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 27240;
 Libderiv->deriv2_classes[3][4][14] = int_stack + 27520;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 27670;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 27880;
 Libderiv->deriv2_classes[3][4][13] = int_stack + 28160;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 28310;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 28520;
 Libderiv->deriv2_classes[3][4][11] = int_stack + 28800;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 28950;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 29160;
 Libderiv->deriv2_classes[3][4][10] = int_stack + 29440;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 29590;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 29800;
 Libderiv->deriv2_classes[3][4][9] = int_stack + 30080;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 30230;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 30440;
 Libderiv->deriv2_classes[3][4][8] = int_stack + 30720;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 30870;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 31080;
 Libderiv->deriv2_classes[3][4][7] = int_stack + 31360;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 31510;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 31720;
 Libderiv->deriv_classes[3][4][0] = int_stack + 32000;
 Libderiv->deriv2_classes[3][4][6] = int_stack + 32150;
 Libderiv->deriv_classes[3][5][0] = int_stack + 32300;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 32510;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 32720;
 Libderiv->deriv2_classes[3][4][2] = int_stack + 33000;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 33150;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 33360;
 Libderiv->deriv2_classes[3][4][1] = int_stack + 33640;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 33790;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 34000;
 Libderiv->deriv2_classes[3][4][0] = int_stack + 34280;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 34430;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 34640;
 memset(int_stack,0,279360);

 Libderiv->dvrr_stack = int_stack + 64350;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_f0gd(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+34920,int_stack+1400,int_stack+17330,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+35370,int_stack+12630,int_stack+12330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17330,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+35820,int_stack+0,int_stack+12630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+36450,int_stack+13630,int_stack+13330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17330, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36900,int_stack+280,int_stack+13630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+14630,int_stack+14330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17330, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+37530,int_stack+560,int_stack+14630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+38160,int_stack+15630,int_stack+15330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38610,int_stack+840,int_stack+15630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+450,int_stack+16630,int_stack+16330, 0.0, zero_stack, 1.0, int_stack+17330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39240,int_stack+1120,int_stack+16630, 0.0, zero_stack, 1.0, int_stack+1400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+900,int_stack+17780,int_stack+17480, 1.0, int_stack+17330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39870,int_stack+1610,int_stack+17780, 1.0, int_stack+1400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1350,int_stack+21980,int_stack+21680,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+40500,int_stack+1890,int_stack+21980,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+41130,int_stack+26820,int_stack+26520,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+41580,int_stack+2170,int_stack+26820,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1800,int_stack+32300,int_stack+32000,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+42210,int_stack+2450,int_stack+32300,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2250,int_stack+2880,int_stack+2730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+12330,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+42840,int_stack+3090,int_stack+2880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+12630,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2700,int_stack+3520,int_stack+3370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12330, 1.0, int_stack+13330,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+43470,int_stack+3730,int_stack+3520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12630, 1.0, int_stack+13630,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+3150,int_stack+4160,int_stack+4010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+13330, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+44100,int_stack+4370,int_stack+4160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+13630, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+3600,int_stack+4800,int_stack+4650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12330, 0.0, zero_stack, 1.0, int_stack+14330,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4050,int_stack+5010,int_stack+4800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12630, 0.0, zero_stack, 1.0, int_stack+14630,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+4680,int_stack+5440,int_stack+5290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13330, 1.0, int_stack+14330, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+44730,int_stack+5650,int_stack+5440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13630, 1.0, int_stack+14630, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+5130,int_stack+6080,int_stack+5930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+14330, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45360,int_stack+6290,int_stack+6080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+14630, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+5580,int_stack+6720,int_stack+6570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15330,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6030,int_stack+6930,int_stack+6720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+15630,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+6660,int_stack+7360,int_stack+7210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13330, 0.0, zero_stack, 1.0, int_stack+15330, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45990,int_stack+7570,int_stack+7360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+13630, 0.0, zero_stack, 1.0, int_stack+15630, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+7110,int_stack+8000,int_stack+7850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14330, 1.0, int_stack+15330, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46620,int_stack+8210,int_stack+8000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14630, 1.0, int_stack+15630, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+7560,int_stack+8640,int_stack+8490, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+15330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8010,int_stack+8850,int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+15630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+8640,int_stack+9280,int_stack+9130, 0.0, zero_stack, 1.0, int_stack+12330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16330,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47250,int_stack+9490,int_stack+9280, 0.0, zero_stack, 1.0, int_stack+12630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16630,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9090,int_stack+9920,int_stack+9770, 0.0, zero_stack, 1.0, int_stack+13330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16330, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47880,int_stack+10130,int_stack+9920, 0.0, zero_stack, 1.0, int_stack+13630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16630, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9540,int_stack+10560,int_stack+10410, 0.0, zero_stack, 1.0, int_stack+14330, 0.0, zero_stack, 1.0, int_stack+16330, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48510,int_stack+10770,int_stack+10560, 0.0, zero_stack, 1.0, int_stack+14630, 0.0, zero_stack, 1.0, int_stack+16630, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+9990,int_stack+11200,int_stack+11050, 0.0, zero_stack, 1.0, int_stack+15330, 1.0, int_stack+16330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10440,int_stack+11410,int_stack+11200, 0.0, zero_stack, 1.0, int_stack+15630, 1.0, int_stack+16630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+11070,int_stack+11840,int_stack+11690, 0.0, zero_stack, 2.0, int_stack+16330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49140,int_stack+12050,int_stack+11840, 0.0, zero_stack, 2.0, int_stack+16630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+11520,int_stack+12840,int_stack+12480, 1.0, int_stack+12330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17480,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11970,int_stack+13050,int_stack+12840, 1.0, int_stack+12630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17780,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+12600,int_stack+13840,int_stack+13480, 1.0, int_stack+13330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17480, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49770,int_stack+14050,int_stack+13840, 1.0, int_stack+13630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17780, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+13050,int_stack+14840,int_stack+14480, 1.0, int_stack+14330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17480, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13500,int_stack+15050,int_stack+14840, 1.0, int_stack+14630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17780, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14130,int_stack+15840,int_stack+15480, 1.0, int_stack+15330, 0.0, zero_stack, 1.0, int_stack+17480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14580,int_stack+16050,int_stack+15840, 1.0, int_stack+15630, 0.0, zero_stack, 1.0, int_stack+17780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+15210,int_stack+16840,int_stack+16480, 1.0, int_stack+16330, 1.0, int_stack+17480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15660,int_stack+17050,int_stack+16840, 1.0, int_stack+16630, 1.0, int_stack+17780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+16290,int_stack+17990,int_stack+17630, 2.0, int_stack+17480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16740,int_stack+18200,int_stack+17990, 2.0, int_stack+17780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+17370,int_stack+18630,int_stack+18480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21680,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17820,int_stack+18840,int_stack+18630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21980,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+18450,int_stack+19270,int_stack+19120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21680, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+50400,int_stack+19480,int_stack+19270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21980, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+18900,int_stack+19910,int_stack+19760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21680, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+51030,int_stack+20120,int_stack+19910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21980, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+19350,int_stack+20550,int_stack+20400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19800,int_stack+20760,int_stack+20550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+20430,int_stack+21190,int_stack+21040, 0.0, zero_stack, 1.0, int_stack+21680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+51660,int_stack+21400,int_stack+21190, 0.0, zero_stack, 1.0, int_stack+21980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+20880,int_stack+22190,int_stack+21830, 1.0, int_stack+21680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21330,int_stack+22400,int_stack+22190, 1.0, int_stack+21980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+21960,int_stack+22830,int_stack+22680,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+52290,int_stack+23040,int_stack+22830,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+22410,int_stack+23470,int_stack+23320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26520,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+52920,int_stack+23680,int_stack+23470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26820,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+22860,int_stack+24110,int_stack+23960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26520, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23310,int_stack+24320,int_stack+24110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26820, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+23940,int_stack+24750,int_stack+24600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26520, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53550,int_stack+24960,int_stack+24750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26820, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+24390,int_stack+25390,int_stack+25240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+54180,int_stack+25600,int_stack+25390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+26820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+24840,int_stack+26030,int_stack+25880, 0.0, zero_stack, 1.0, int_stack+26520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+25290,int_stack+26240,int_stack+26030, 0.0, zero_stack, 1.0, int_stack+26820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+25920,int_stack+27030,int_stack+26670, 1.0, int_stack+26520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+54810,int_stack+27240,int_stack+27030, 1.0, int_stack+26820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+26370,int_stack+27670,int_stack+27520,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+26820,int_stack+27880,int_stack+27670,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+27450,int_stack+28310,int_stack+28160,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+55440,int_stack+28520,int_stack+28310,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+27900,int_stack+28950,int_stack+28800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32000,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56070,int_stack+29160,int_stack+28950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32300,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+28350,int_stack+29590,int_stack+29440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32000, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28800,int_stack+29800,int_stack+29590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32300, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+29430,int_stack+30230,int_stack+30080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32000, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56700,int_stack+30440,int_stack+30230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32300, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+29880,int_stack+30870,int_stack+30720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+57330,int_stack+31080,int_stack+30870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+32300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+30330,int_stack+31510,int_stack+31360, 0.0, zero_stack, 1.0, int_stack+32000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30780,int_stack+31720,int_stack+31510, 0.0, zero_stack, 1.0, int_stack+32300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+31410,int_stack+32510,int_stack+32150, 1.0, int_stack+32000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+57960,int_stack+32720,int_stack+32510, 1.0, int_stack+32300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+31860,int_stack+33150,int_stack+33000,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+32310,int_stack+33360,int_stack+33150,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+32940,int_stack+33790,int_stack+33640,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+58590,int_stack+34000,int_stack+33790,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+33390,int_stack+34430,int_stack+34280,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+59220,int_stack+34640,int_stack+34430,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+33840,int_stack+35820,int_stack+35370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34920,10);
     Libderiv->ABCD[11] = int_stack + 33840;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+59850,int_stack+36900,int_stack+36450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34920, 0.0, zero_stack,10);
     Libderiv->ABCD[10] = int_stack + 59850;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+60750,int_stack+37530,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34920, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[9] = int_stack + 60750;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+36900,int_stack+38610,int_stack+38160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+34920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[8] = int_stack + 36900;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+61650,int_stack+39240,int_stack+450, 0.0, zero_stack, 1.0, int_stack+34920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[7] = int_stack + 61650;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+38610,int_stack+39870,int_stack+900, 1.0, int_stack+34920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[6] = int_stack + 38610;
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+39510,int_stack+40500,int_stack+1350,10);
     Libderiv->ABCD[2] = int_stack + 39510;
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+62550,int_stack+41580,int_stack+41130,10);
     Libderiv->ABCD[1] = int_stack + 62550;
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+63450,int_stack+42210,int_stack+1800,10);
     Libderiv->ABCD[0] = int_stack + 63450;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+41580,int_stack+42840,int_stack+2250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+35370,10);
     Libderiv->ABCD[155] = int_stack + 41580;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+42480,int_stack+43470,int_stack+2700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35370, 1.0, int_stack+36450,10);
     Libderiv->ABCD[143] = int_stack + 42480;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+2250,int_stack+44100,int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+36450, 0.0, zero_stack,10);
     Libderiv->ABCD[142] = int_stack + 2250;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+43380,int_stack+4050,int_stack+3600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35370, 0.0, zero_stack, 1.0, int_stack+0,10);
     Libderiv->ABCD[131] = int_stack + 43380;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+3150,int_stack+44730,int_stack+4680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36450, 1.0, int_stack+0, 0.0, zero_stack,10);
     Libderiv->ABCD[130] = int_stack + 3150;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+4050,int_stack+45360,int_stack+5130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[129] = int_stack + 4050;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+44280,int_stack+6030,int_stack+5580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38160,10);
     Libderiv->ABCD[119] = int_stack + 44280;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+4950,int_stack+45990,int_stack+6660, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36450, 0.0, zero_stack, 1.0, int_stack+38160, 0.0, zero_stack,10);
     Libderiv->ABCD[118] = int_stack + 4950;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+5850,int_stack+46620,int_stack+7110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+38160, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[117] = int_stack + 5850;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+45180,int_stack+8010,int_stack+7560, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+38160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[116] = int_stack + 45180;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+6750,int_stack+47250,int_stack+8640, 0.0, zero_stack, 1.0, int_stack+35370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450,10);
     Libderiv->ABCD[107] = int_stack + 6750;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+7650,int_stack+47880,int_stack+9090, 0.0, zero_stack, 1.0, int_stack+36450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450, 0.0, zero_stack,10);
     Libderiv->ABCD[106] = int_stack + 7650;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+8550,int_stack+48510,int_stack+9540, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+450, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[105] = int_stack + 8550;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+46080,int_stack+10440,int_stack+9990, 0.0, zero_stack, 1.0, int_stack+38160, 1.0, int_stack+450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[104] = int_stack + 46080;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+9450,int_stack+49140,int_stack+11070, 0.0, zero_stack, 2.0, int_stack+450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[103] = int_stack + 9450;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+10350,int_stack+11970,int_stack+11520, 1.0, int_stack+35370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+900,10);
     Libderiv->ABCD[95] = int_stack + 10350;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+11250,int_stack+49770,int_stack+12600, 1.0, int_stack+36450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+900, 0.0, zero_stack,10);
     Libderiv->ABCD[94] = int_stack + 11250;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12150,int_stack+13500,int_stack+13050, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+900, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[93] = int_stack + 12150;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+13050,int_stack+14580,int_stack+14130, 1.0, int_stack+38160, 0.0, zero_stack, 1.0, int_stack+900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[92] = int_stack + 13050;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+13950,int_stack+15660,int_stack+15210, 1.0, int_stack+450, 1.0, int_stack+900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[91] = int_stack + 13950;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+16740,int_stack+16290, 2.0, int_stack+900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[90] = int_stack + 0;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14850,int_stack+17820,int_stack+17370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350,10);
     Libderiv->ABCD[47] = int_stack + 14850;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+15750,int_stack+50400,int_stack+18450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack,10);
     Libderiv->ABCD[46] = int_stack + 15750;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+16650,int_stack+51030,int_stack+18900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[45] = int_stack + 16650;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+17550,int_stack+19800,int_stack+19350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[44] = int_stack + 17550;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+18450,int_stack+51660,int_stack+20430, 0.0, zero_stack, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[43] = int_stack + 18450;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+19350,int_stack+21330,int_stack+20880, 1.0, int_stack+1350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[42] = int_stack + 19350;
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+900,int_stack+52290,int_stack+21960,10);
     Libderiv->ABCD[38] = int_stack + 900;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+20250,int_stack+52920,int_stack+22410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41130,10);
     Libderiv->ABCD[35] = int_stack + 20250;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+21150,int_stack+23310,int_stack+22860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41130, 0.0, zero_stack,10);
     Libderiv->ABCD[34] = int_stack + 21150;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+22050,int_stack+53550,int_stack+23940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41130, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[33] = int_stack + 22050;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+22950,int_stack+54180,int_stack+24390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+41130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[32] = int_stack + 22950;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+23850,int_stack+25290,int_stack+24840, 0.0, zero_stack, 1.0, int_stack+41130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[31] = int_stack + 23850;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+24750,int_stack+54810,int_stack+25920, 1.0, int_stack+41130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[30] = int_stack + 24750;
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+46980,int_stack+26820,int_stack+26370,10);
     Libderiv->ABCD[26] = int_stack + 46980;
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+25650,int_stack+55440,int_stack+27450,10);
     Libderiv->ABCD[25] = int_stack + 25650;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+26550,int_stack+56070,int_stack+27900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800,10);
     Libderiv->ABCD[23] = int_stack + 26550;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+27450,int_stack+28800,int_stack+28350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack,10);
     Libderiv->ABCD[22] = int_stack + 27450;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+28350,int_stack+56700,int_stack+29430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[21] = int_stack + 28350;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+47880,int_stack+57330,int_stack+29880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[20] = int_stack + 47880;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29250,int_stack+30780,int_stack+30330, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[19] = int_stack + 29250;
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+30150,int_stack+57960,int_stack+31410, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[18] = int_stack + 30150;
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+48780,int_stack+32310,int_stack+31860,10);
     Libderiv->ABCD[14] = int_stack + 48780;
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+31050,int_stack+58590,int_stack+32940,10);
     Libderiv->ABCD[13] = int_stack + 31050;
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+31950,int_stack+59220,int_stack+33390,10);
     Libderiv->ABCD[12] = int_stack + 31950;

}
