/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_fpgd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (fp|gd) integrals */

void d12hrr_order_fpgd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][10] = int_stack + 420;
 Libderiv->deriv_classes[4][6][9] = int_stack + 840;
 Libderiv->deriv_classes[4][6][8] = int_stack + 1260;
 Libderiv->deriv_classes[4][6][7] = int_stack + 1680;
 Libderiv->dvrr_classes[4][5] = int_stack + 2100;
 Libderiv->deriv_classes[4][6][6] = int_stack + 2415;
 Libderiv->deriv_classes[4][6][2] = int_stack + 2835;
 Libderiv->deriv_classes[4][6][1] = int_stack + 3255;
 Libderiv->dvrr_classes[3][6] = int_stack + 3675;
 Libderiv->deriv_classes[4][6][0] = int_stack + 3955;
 Libderiv->deriv2_classes[3][4][143] = int_stack + 4375;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 4525;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 4735;
 Libderiv->deriv2_classes[4][4][143] = int_stack + 5015;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 5240;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 5555;
 Libderiv->deriv2_classes[3][4][131] = int_stack + 5975;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 6125;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 6335;
 Libderiv->deriv2_classes[4][4][131] = int_stack + 6615;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 6840;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 7155;
 Libderiv->deriv2_classes[3][4][130] = int_stack + 7575;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 7725;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 7935;
 Libderiv->deriv2_classes[4][4][130] = int_stack + 8215;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 8440;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 8755;
 Libderiv->deriv2_classes[3][4][119] = int_stack + 9175;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 9325;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 9535;
 Libderiv->deriv2_classes[4][4][119] = int_stack + 9815;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 10040;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 10355;
 Libderiv->deriv2_classes[3][4][118] = int_stack + 10775;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 10925;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 11135;
 Libderiv->deriv2_classes[4][4][118] = int_stack + 11415;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 11640;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 11955;
 Libderiv->deriv2_classes[3][4][117] = int_stack + 12375;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 12525;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 12735;
 Libderiv->deriv2_classes[4][4][117] = int_stack + 13015;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 13240;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 13555;
 Libderiv->deriv2_classes[3][4][107] = int_stack + 13975;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 14125;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 14335;
 Libderiv->deriv2_classes[4][4][107] = int_stack + 14615;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 14840;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 15155;
 Libderiv->deriv2_classes[3][4][106] = int_stack + 15575;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 15725;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 15935;
 Libderiv->deriv2_classes[4][4][106] = int_stack + 16215;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 16440;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 16755;
 Libderiv->deriv2_classes[3][4][105] = int_stack + 17175;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 17325;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 17535;
 Libderiv->deriv2_classes[4][4][105] = int_stack + 17815;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 18040;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 18355;
 Libderiv->deriv2_classes[3][4][104] = int_stack + 18775;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 18925;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 19135;
 Libderiv->deriv2_classes[4][4][104] = int_stack + 19415;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 19640;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 19955;
 Libderiv->deriv2_classes[3][4][95] = int_stack + 20375;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 20525;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 20735;
 Libderiv->deriv2_classes[4][4][95] = int_stack + 21015;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 21240;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 21555;
 Libderiv->deriv2_classes[3][4][94] = int_stack + 21975;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 22125;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 22335;
 Libderiv->deriv2_classes[4][4][94] = int_stack + 22615;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 22840;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 23155;
 Libderiv->deriv2_classes[3][4][93] = int_stack + 23575;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 23725;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 23935;
 Libderiv->deriv2_classes[4][4][93] = int_stack + 24215;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 24440;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 24755;
 Libderiv->deriv2_classes[3][4][92] = int_stack + 25175;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 25325;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 25535;
 Libderiv->deriv2_classes[4][4][92] = int_stack + 25815;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 26040;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 26355;
 Libderiv->deriv2_classes[3][4][91] = int_stack + 26775;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 26925;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 27135;
 Libderiv->deriv2_classes[4][4][91] = int_stack + 27415;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 27640;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 27955;
 Libderiv->deriv2_classes[3][4][83] = int_stack + 28375;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 28525;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 28735;
 Libderiv->deriv_classes[4][4][11] = int_stack + 29015;
 Libderiv->deriv2_classes[4][4][83] = int_stack + 29240;
 Libderiv->deriv_classes[4][5][11] = int_stack + 29465;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 29780;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 30095;
 Libderiv->deriv2_classes[3][4][82] = int_stack + 30515;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 30665;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 30875;
 Libderiv->deriv_classes[4][4][10] = int_stack + 31155;
 Libderiv->deriv2_classes[4][4][82] = int_stack + 31380;
 Libderiv->deriv_classes[4][5][10] = int_stack + 31605;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 31920;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 32235;
 Libderiv->deriv2_classes[3][4][81] = int_stack + 32655;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 32805;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 33015;
 Libderiv->deriv_classes[4][4][9] = int_stack + 33295;
 Libderiv->deriv2_classes[4][4][81] = int_stack + 33520;
 Libderiv->deriv_classes[4][5][9] = int_stack + 33745;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 34060;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 34375;
 Libderiv->deriv2_classes[3][4][80] = int_stack + 34795;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 34945;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 35155;
 Libderiv->deriv_classes[4][4][8] = int_stack + 35435;
 Libderiv->deriv2_classes[4][4][80] = int_stack + 35660;
 Libderiv->deriv_classes[4][5][8] = int_stack + 35885;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 36200;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 36515;
 Libderiv->deriv2_classes[3][4][79] = int_stack + 36935;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 37085;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 37295;
 Libderiv->deriv_classes[4][4][7] = int_stack + 37575;
 Libderiv->deriv2_classes[4][4][79] = int_stack + 37800;
 Libderiv->deriv_classes[4][5][7] = int_stack + 38025;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 38340;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 38655;
 Libderiv->deriv2_classes[3][4][78] = int_stack + 39075;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 39225;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 39435;
 Libderiv->dvrr_classes[4][4] = int_stack + 39715;
 Libderiv->deriv_classes[4][4][6] = int_stack + 39940;
 Libderiv->deriv2_classes[4][4][78] = int_stack + 40165;
 Libderiv->deriv_classes[4][5][6] = int_stack + 40390;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 40705;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 41020;
 Libderiv->deriv2_classes[3][4][35] = int_stack + 41440;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 41590;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 41800;
 Libderiv->deriv2_classes[4][4][35] = int_stack + 42080;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 42305;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 42620;
 Libderiv->deriv2_classes[3][4][34] = int_stack + 43040;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 43190;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 43400;
 Libderiv->deriv2_classes[4][4][34] = int_stack + 43680;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 43905;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 44220;
 Libderiv->deriv2_classes[3][4][33] = int_stack + 44640;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 44790;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 45000;
 Libderiv->deriv2_classes[4][4][33] = int_stack + 45280;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 45505;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 45820;
 Libderiv->deriv2_classes[3][4][32] = int_stack + 46240;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 46390;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 46600;
 Libderiv->deriv2_classes[4][4][32] = int_stack + 46880;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 47105;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 47420;
 Libderiv->deriv2_classes[3][4][31] = int_stack + 47840;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 47990;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 48200;
 Libderiv->deriv2_classes[4][4][31] = int_stack + 48480;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 48705;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 49020;
 Libderiv->deriv2_classes[3][4][30] = int_stack + 49440;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 49590;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 49800;
 Libderiv->deriv_classes[4][4][2] = int_stack + 50080;
 Libderiv->deriv2_classes[4][4][30] = int_stack + 50305;
 Libderiv->deriv_classes[4][5][2] = int_stack + 50530;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 50845;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 51160;
 Libderiv->deriv2_classes[3][4][26] = int_stack + 51580;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 51730;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 51940;
 Libderiv->deriv2_classes[4][4][26] = int_stack + 52220;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 52445;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 52760;
 Libderiv->deriv2_classes[3][4][23] = int_stack + 53180;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 53330;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 53540;
 Libderiv->deriv2_classes[4][4][23] = int_stack + 53820;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 54045;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 54360;
 Libderiv->deriv2_classes[3][4][22] = int_stack + 54780;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 54930;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 55140;
 Libderiv->deriv2_classes[4][4][22] = int_stack + 55420;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 55645;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 55960;
 Libderiv->deriv2_classes[3][4][21] = int_stack + 56380;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 56530;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 56740;
 Libderiv->deriv2_classes[4][4][21] = int_stack + 57020;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 57245;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 57560;
 Libderiv->deriv2_classes[3][4][20] = int_stack + 57980;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 58130;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 58340;
 Libderiv->deriv2_classes[4][4][20] = int_stack + 58620;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 58845;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 59160;
 Libderiv->deriv2_classes[3][4][19] = int_stack + 59580;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 59730;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 59940;
 Libderiv->deriv2_classes[4][4][19] = int_stack + 60220;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 60445;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 60760;
 Libderiv->deriv2_classes[3][4][18] = int_stack + 61180;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 61330;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 61540;
 Libderiv->deriv_classes[4][4][1] = int_stack + 61820;
 Libderiv->deriv2_classes[4][4][18] = int_stack + 62045;
 Libderiv->deriv_classes[4][5][1] = int_stack + 62270;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 62585;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 62900;
 Libderiv->deriv2_classes[3][4][14] = int_stack + 63320;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 63470;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 63680;
 Libderiv->deriv2_classes[4][4][14] = int_stack + 63960;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 64185;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 64500;
 Libderiv->deriv2_classes[3][4][13] = int_stack + 64920;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 65070;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 65280;
 Libderiv->deriv2_classes[4][4][13] = int_stack + 65560;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 65785;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 66100;
 Libderiv->deriv_classes[3][4][11] = int_stack + 66520;
 Libderiv->deriv_classes[3][5][11] = int_stack + 66670;
 Libderiv->deriv_classes[3][6][11] = int_stack + 66880;
 Libderiv->deriv2_classes[3][4][11] = int_stack + 67160;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 67310;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 67520;
 Libderiv->deriv2_classes[4][4][11] = int_stack + 67800;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 68025;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 68340;
 Libderiv->deriv_classes[3][4][10] = int_stack + 68760;
 Libderiv->deriv_classes[3][5][10] = int_stack + 68910;
 Libderiv->deriv_classes[3][6][10] = int_stack + 69120;
 Libderiv->deriv2_classes[3][4][10] = int_stack + 69400;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 69550;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 69760;
 Libderiv->deriv2_classes[4][4][10] = int_stack + 70040;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 70265;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 70580;
 Libderiv->deriv_classes[3][4][9] = int_stack + 71000;
 Libderiv->deriv_classes[3][5][9] = int_stack + 71150;
 Libderiv->deriv_classes[3][6][9] = int_stack + 71360;
 Libderiv->deriv2_classes[3][4][9] = int_stack + 71640;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 71790;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 72000;
 Libderiv->deriv2_classes[4][4][9] = int_stack + 72280;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 72505;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 72820;
 Libderiv->deriv_classes[3][4][8] = int_stack + 73240;
 Libderiv->deriv_classes[3][5][8] = int_stack + 73390;
 Libderiv->deriv_classes[3][6][8] = int_stack + 73600;
 Libderiv->deriv2_classes[3][4][8] = int_stack + 73880;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 74030;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 74240;
 Libderiv->deriv2_classes[4][4][8] = int_stack + 74520;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 74745;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 75060;
 Libderiv->deriv_classes[3][4][7] = int_stack + 75480;
 Libderiv->deriv_classes[3][5][7] = int_stack + 75630;
 Libderiv->deriv_classes[3][6][7] = int_stack + 75840;
 Libderiv->deriv2_classes[3][4][7] = int_stack + 76120;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 76270;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 76480;
 Libderiv->deriv2_classes[4][4][7] = int_stack + 76760;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 76985;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 77300;
 Libderiv->dvrr_classes[3][4] = int_stack + 77720;
 Libderiv->deriv_classes[3][4][6] = int_stack + 77870;
 Libderiv->dvrr_classes[3][5] = int_stack + 78020;
 Libderiv->deriv_classes[3][5][6] = int_stack + 78230;
 Libderiv->deriv_classes[3][6][6] = int_stack + 78440;
 Libderiv->deriv2_classes[3][4][6] = int_stack + 78720;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 78870;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 79080;
 Libderiv->deriv_classes[4][4][0] = int_stack + 79360;
 Libderiv->deriv2_classes[4][4][6] = int_stack + 79585;
 Libderiv->deriv_classes[4][5][0] = int_stack + 79810;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 80125;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 80440;
 Libderiv->deriv_classes[3][4][2] = int_stack + 80860;
 Libderiv->deriv_classes[3][5][2] = int_stack + 81010;
 Libderiv->deriv_classes[3][6][2] = int_stack + 81220;
 Libderiv->deriv2_classes[3][4][2] = int_stack + 81500;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 81650;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 81860;
 Libderiv->deriv2_classes[4][4][2] = int_stack + 82140;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 82365;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 82680;
 Libderiv->deriv_classes[3][4][1] = int_stack + 83100;
 Libderiv->deriv_classes[3][5][1] = int_stack + 83250;
 Libderiv->deriv_classes[3][6][1] = int_stack + 83460;
 Libderiv->deriv2_classes[3][4][1] = int_stack + 83740;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 83890;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 84100;
 Libderiv->deriv2_classes[4][4][1] = int_stack + 84380;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 84605;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 84920;
 Libderiv->deriv_classes[3][4][0] = int_stack + 85340;
 Libderiv->deriv_classes[3][5][0] = int_stack + 85490;
 Libderiv->deriv_classes[3][6][0] = int_stack + 85700;
 Libderiv->deriv2_classes[3][4][0] = int_stack + 85980;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 86130;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 86340;
 Libderiv->deriv2_classes[4][4][0] = int_stack + 86620;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 86845;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 87160;
 memset(int_stack,0,700640);

 Libderiv->dvrr_stack = int_stack + 169660;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_fpgd(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+78020,int_stack+77720,10);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+88030,int_stack+66670,int_stack+66520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77720,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+66880,int_stack+66670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78020,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+89110,int_stack+88480,int_stack+88030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87580,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+90010,int_stack+2100,int_stack+39715,15);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90685,int_stack+29465,int_stack+29015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39715,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+91360,int_stack+0,int_stack+29465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+92305,int_stack+91360,int_stack+90685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90010,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+91360,int_stack+68910,int_stack+68760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77720, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+69120,int_stack+68910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78020, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+93655,int_stack+88480,int_stack+91360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87580, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+94555,int_stack+31605,int_stack+31155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39715, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+95230,int_stack+420,int_stack+31605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+96175,int_stack+95230,int_stack+94555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90010, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+95230,int_stack+71150,int_stack+71000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77720, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+71360,int_stack+71150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78020, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+97525,int_stack+88480,int_stack+95230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87580, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+33745,int_stack+33295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39715, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+98425,int_stack+840,int_stack+33745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+99370,int_stack+98425,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90010, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+98425,int_stack+73390,int_stack+73240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+73600,int_stack+73390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+100720,int_stack+88480,int_stack+98425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+101620,int_stack+35885,int_stack+35435, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+102295,int_stack+1260,int_stack+35885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+103240,int_stack+102295,int_stack+101620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+102295,int_stack+75630,int_stack+75480, 0.0, zero_stack, 1.0, int_stack+77720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+75840,int_stack+75630, 0.0, zero_stack, 1.0, int_stack+78020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+675,int_stack+88480,int_stack+102295, 0.0, zero_stack, 1.0, int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+104590,int_stack+38025,int_stack+37575, 0.0, zero_stack, 1.0, int_stack+39715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+105265,int_stack+1680,int_stack+38025, 0.0, zero_stack, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+106210,int_stack+105265,int_stack+104590, 0.0, zero_stack, 1.0, int_stack+90010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+105265,int_stack+78230,int_stack+77870, 1.0, int_stack+77720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+78440,int_stack+78230, 1.0, int_stack+78020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+107560,int_stack+88480,int_stack+105265, 1.0, int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+40390,int_stack+39940, 1.0, int_stack+39715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+109135,int_stack+2415,int_stack+40390, 1.0, int_stack+2100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+110080,int_stack+109135,int_stack+108460, 1.0, int_stack+90010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+3675,int_stack+78020,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+109135,int_stack+88480,int_stack+87580,10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+81010,int_stack+80860,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+81220,int_stack+81010,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1575,int_stack+88480,int_stack+87580,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+90010,int_stack+50530,int_stack+50080,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+111430,int_stack+2835,int_stack+50530,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+112375,int_stack+111430,int_stack+90010,15);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+111430,int_stack+83250,int_stack+83100,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+83460,int_stack+83250,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+113725,int_stack+88480,int_stack+111430,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2475,int_stack+62270,int_stack+61820,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+114625,int_stack+3255,int_stack+62270,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+115570,int_stack+114625,int_stack+2475,15);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+114625,int_stack+85490,int_stack+85340,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+85700,int_stack+85490,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+116920,int_stack+88480,int_stack+114625,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+3150,int_stack+79810,int_stack+79360,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+117820,int_stack+3955,int_stack+79810,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+118765,int_stack+117820,int_stack+3150,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+4525,int_stack+4375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+66520,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+4735,int_stack+4525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+66670,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+3825,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+88030,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+5240,int_stack+5015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+29015,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+120115,int_stack+5555,int_stack+5240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+29465,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+121060,int_stack+120115,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+90685,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+6125,int_stack+5975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66520, 1.0, int_stack+68760,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+6335,int_stack+6125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66670, 1.0, int_stack+68910,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+120115,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88030, 1.0, int_stack+91360,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+6840,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29015, 1.0, int_stack+31155,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4725,int_stack+7155,int_stack+6840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29465, 1.0, int_stack+31605,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+5670,int_stack+4725,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90685, 1.0, int_stack+94555,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+7725,int_stack+7575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+68760, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+7935,int_stack+7725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+68910, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+4725,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+91360, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+8440,int_stack+8215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+31155, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7020,int_stack+8755,int_stack+8440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+31605, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+122410,int_stack+7020,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+94555, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+9325,int_stack+9175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66520, 0.0, zero_stack, 1.0, int_stack+71000,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+9535,int_stack+9325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66670, 0.0, zero_stack, 1.0, int_stack+71150,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+7020,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88030, 0.0, zero_stack, 1.0, int_stack+95230,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+10040,int_stack+9815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29015, 0.0, zero_stack, 1.0, int_stack+33295,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7920,int_stack+10355,int_stack+10040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29465, 0.0, zero_stack, 1.0, int_stack+33745,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+8865,int_stack+7920,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90685, 0.0, zero_stack, 1.0, int_stack+0,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+10925,int_stack+10775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68760, 1.0, int_stack+71000, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+11135,int_stack+10925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68910, 1.0, int_stack+71150, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+7920,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91360, 1.0, int_stack+95230, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+11640,int_stack+11415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31155, 1.0, int_stack+33295, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+10215,int_stack+11955,int_stack+11640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31605, 1.0, int_stack+33745, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+123760,int_stack+10215,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94555, 1.0, int_stack+0, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+12525,int_stack+12375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+71000, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+12735,int_stack+12525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+71150, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+10215,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+95230, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+13240,int_stack+13015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+33295, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11115,int_stack+13555,int_stack+13240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+33745, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+12060,int_stack+11115,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+14125,int_stack+13975, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73240,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+14335,int_stack+14125, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+73390,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+11115,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98425,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+14840,int_stack+14615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35435,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13410,int_stack+15155,int_stack+14840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35885,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+125110,int_stack+13410,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101620,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+15725,int_stack+15575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68760, 0.0, zero_stack, 1.0, int_stack+73240, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+15935,int_stack+15725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68910, 0.0, zero_stack, 1.0, int_stack+73390, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+13410,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+91360, 0.0, zero_stack, 1.0, int_stack+98425, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+16440,int_stack+16215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31155, 0.0, zero_stack, 1.0, int_stack+35435, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14310,int_stack+16755,int_stack+16440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+31605, 0.0, zero_stack, 1.0, int_stack+35885, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+15255,int_stack+14310,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94555, 0.0, zero_stack, 1.0, int_stack+101620, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+17325,int_stack+17175, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71000, 1.0, int_stack+73240, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+17535,int_stack+17325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71150, 1.0, int_stack+73390, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+14310,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95230, 1.0, int_stack+98425, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+18040,int_stack+17815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33295, 1.0, int_stack+35435, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+16605,int_stack+18355,int_stack+18040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+33745, 1.0, int_stack+35885, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+126460,int_stack+16605,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+101620, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+18925,int_stack+18775, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+73240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+19135,int_stack+18925, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+73390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+16605,int_stack+88480,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+98425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+19640,int_stack+19415, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+35435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17505,int_stack+19955,int_stack+19640, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+35885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+18450,int_stack+17505,int_stack+117820, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+101620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+20525,int_stack+20375, 0.0, zero_stack, 1.0, int_stack+66520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75480,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+20735,int_stack+20525, 0.0, zero_stack, 1.0, int_stack+66670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75630,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+17505,int_stack+88480,int_stack+117820, 0.0, zero_stack, 1.0, int_stack+88030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102295,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+21240,int_stack+21015, 0.0, zero_stack, 1.0, int_stack+29015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37575,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+19800,int_stack+21555,int_stack+21240, 0.0, zero_stack, 1.0, int_stack+29465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38025,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+127810,int_stack+19800,int_stack+117820, 0.0, zero_stack, 1.0, int_stack+90685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104590,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+22125,int_stack+21975, 0.0, zero_stack, 1.0, int_stack+68760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75480, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+22335,int_stack+22125, 0.0, zero_stack, 1.0, int_stack+68910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75630, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+19800,int_stack+88480,int_stack+117820, 0.0, zero_stack, 1.0, int_stack+91360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102295, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+22840,int_stack+22615, 0.0, zero_stack, 1.0, int_stack+31155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37575, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+20700,int_stack+23155,int_stack+22840, 0.0, zero_stack, 1.0, int_stack+31605, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38025, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+21645,int_stack+20700,int_stack+117820, 0.0, zero_stack, 1.0, int_stack+94555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+104590, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+23725,int_stack+23575, 0.0, zero_stack, 1.0, int_stack+71000, 0.0, zero_stack, 1.0, int_stack+75480, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+23935,int_stack+23725, 0.0, zero_stack, 1.0, int_stack+71150, 0.0, zero_stack, 1.0, int_stack+75630, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+20700,int_stack+88480,int_stack+117820, 0.0, zero_stack, 1.0, int_stack+95230, 0.0, zero_stack, 1.0, int_stack+102295, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+24440,int_stack+24215, 0.0, zero_stack, 1.0, int_stack+33295, 0.0, zero_stack, 1.0, int_stack+37575, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+22995,int_stack+24755,int_stack+24440, 0.0, zero_stack, 1.0, int_stack+33745, 0.0, zero_stack, 1.0, int_stack+38025, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+129160,int_stack+22995,int_stack+117820, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+104590, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+25325,int_stack+25175, 0.0, zero_stack, 1.0, int_stack+73240, 1.0, int_stack+75480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+25535,int_stack+25325, 0.0, zero_stack, 1.0, int_stack+73390, 1.0, int_stack+75630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+22995,int_stack+88480,int_stack+117820, 0.0, zero_stack, 1.0, int_stack+98425, 1.0, int_stack+102295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+26040,int_stack+25815, 0.0, zero_stack, 1.0, int_stack+35435, 1.0, int_stack+37575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23895,int_stack+26355,int_stack+26040, 0.0, zero_stack, 1.0, int_stack+35885, 1.0, int_stack+38025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+24840,int_stack+23895,int_stack+117820, 0.0, zero_stack, 1.0, int_stack+101620, 1.0, int_stack+104590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+26925,int_stack+26775, 0.0, zero_stack, 2.0, int_stack+75480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+27135,int_stack+26925, 0.0, zero_stack, 2.0, int_stack+75630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+23895,int_stack+88480,int_stack+117820, 0.0, zero_stack, 2.0, int_stack+102295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+27640,int_stack+27415, 0.0, zero_stack, 2.0, int_stack+37575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26190,int_stack+27955,int_stack+27640, 0.0, zero_stack, 2.0, int_stack+38025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+130510,int_stack+26190,int_stack+117820, 0.0, zero_stack, 2.0, int_stack+104590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+117820,int_stack+28525,int_stack+28375, 1.0, int_stack+66520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77870,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88480,int_stack+28735,int_stack+28525, 1.0, int_stack+66670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78230,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+26190,int_stack+88480,int_stack+117820, 1.0, int_stack+88030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105265,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+88030,int_stack+29780,int_stack+29240, 1.0, int_stack+29015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39940,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+117820,int_stack+30095,int_stack+29780, 1.0, int_stack+29465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40390,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+27090,int_stack+117820,int_stack+88030, 1.0, int_stack+90685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108460,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90685,int_stack+30665,int_stack+30515, 1.0, int_stack+68760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77870, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88030,int_stack+30875,int_stack+30665, 1.0, int_stack+68910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78230, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+117820,int_stack+88030,int_stack+90685, 1.0, int_stack+91360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105265, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+90685,int_stack+31920,int_stack+31380, 1.0, int_stack+31155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39940, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+91360,int_stack+32235,int_stack+31920, 1.0, int_stack+31605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40390, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+28440,int_stack+91360,int_stack+90685, 1.0, int_stack+94555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108460, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+94555,int_stack+32805,int_stack+32655, 1.0, int_stack+71000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77870, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+33015,int_stack+32805, 1.0, int_stack+71150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+78230, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+91315,int_stack+90685,int_stack+94555, 1.0, int_stack+95230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+105265, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+94555,int_stack+34060,int_stack+33520, 1.0, int_stack+33295, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39940, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+95230,int_stack+34375,int_stack+34060, 1.0, int_stack+33745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40390, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+29790,int_stack+95230,int_stack+94555, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108460, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+34945,int_stack+34795, 1.0, int_stack+73240, 0.0, zero_stack, 1.0, int_stack+77870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+35155,int_stack+34945, 1.0, int_stack+73390, 0.0, zero_stack, 1.0, int_stack+78230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+94555,int_stack+90685,int_stack+0, 1.0, int_stack+98425, 0.0, zero_stack, 1.0, int_stack+105265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+36200,int_stack+35660, 1.0, int_stack+35435, 0.0, zero_stack, 1.0, int_stack+39940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+98425,int_stack+36515,int_stack+36200, 1.0, int_stack+35885, 0.0, zero_stack, 1.0, int_stack+40390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+31140,int_stack+98425,int_stack+0, 1.0, int_stack+101620, 0.0, zero_stack, 1.0, int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+101620,int_stack+37085,int_stack+36935, 1.0, int_stack+75480, 1.0, int_stack+77870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+37295,int_stack+37085, 1.0, int_stack+75630, 1.0, int_stack+78230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98425,int_stack+90685,int_stack+101620, 1.0, int_stack+102295, 1.0, int_stack+105265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+38340,int_stack+37800, 1.0, int_stack+37575, 1.0, int_stack+39940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+101620,int_stack+38655,int_stack+38340, 1.0, int_stack+38025, 1.0, int_stack+40390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+32490,int_stack+101620,int_stack+0, 1.0, int_stack+104590, 1.0, int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+104590,int_stack+39225,int_stack+39075, 2.0, int_stack+77870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+39435,int_stack+39225, 2.0, int_stack+78230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+101620,int_stack+90685,int_stack+104590, 2.0, int_stack+105265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+40705,int_stack+40165, 2.0, int_stack+39940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+104590,int_stack+41020,int_stack+40705, 2.0, int_stack+40390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+33840,int_stack+104590,int_stack+0, 2.0, int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+41590,int_stack+41440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80860,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+41800,int_stack+41590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81010,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+104590,int_stack+90685,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87580,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+42305,int_stack+42080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50080,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+88030,int_stack+42620,int_stack+42305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50530,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+35190,int_stack+88030,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90010,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+43190,int_stack+43040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80860, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+43400,int_stack+43190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81010, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+88030,int_stack+90685,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87580, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+43905,int_stack+43680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50080, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36540,int_stack+44220,int_stack+43905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50530, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+37485,int_stack+36540,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90010, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+44790,int_stack+44640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80860, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+45000,int_stack+44790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81010, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+36540,int_stack+90685,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87580, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+45505,int_stack+45280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50080, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38835,int_stack+45820,int_stack+45505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50530, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+39780,int_stack+38835,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90010, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+46390,int_stack+46240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+46600,int_stack+46390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+38835,int_stack+90685,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+47105,int_stack+46880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+41130,int_stack+47420,int_stack+47105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+42075,int_stack+41130,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+90010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+47990,int_stack+47840, 0.0, zero_stack, 1.0, int_stack+80860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+48200,int_stack+47990, 0.0, zero_stack, 1.0, int_stack+81010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+41130,int_stack+90685,int_stack+108460, 0.0, zero_stack, 1.0, int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+48705,int_stack+48480, 0.0, zero_stack, 1.0, int_stack+50080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+43425,int_stack+49020,int_stack+48705, 0.0, zero_stack, 1.0, int_stack+50530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+44370,int_stack+43425,int_stack+108460, 0.0, zero_stack, 1.0, int_stack+90010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+49590,int_stack+49440, 1.0, int_stack+80860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+90685,int_stack+49800,int_stack+49590, 1.0, int_stack+81010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+43425,int_stack+90685,int_stack+108460, 1.0, int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+50845,int_stack+50305, 1.0, int_stack+50080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45720,int_stack+51160,int_stack+50845, 1.0, int_stack+50530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+46665,int_stack+45720,int_stack+108460, 1.0, int_stack+90010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+51730,int_stack+51580,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+90010,int_stack+51940,int_stack+51730,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+45720,int_stack+90010,int_stack+87580,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+52445,int_stack+52220,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+90010,int_stack+52760,int_stack+52445,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+48015,int_stack+90010,int_stack+108460,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+53330,int_stack+53180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83100,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+108460,int_stack+53540,int_stack+53330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83250,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+90010,int_stack+108460,int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111430,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+54045,int_stack+53820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61820,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+49365,int_stack+54360,int_stack+54045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62270,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+50310,int_stack+49365,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2475,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+54930,int_stack+54780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83100, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+108460,int_stack+55140,int_stack+54930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83250, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+49365,int_stack+108460,int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111430, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+55645,int_stack+55420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61820, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+51660,int_stack+55960,int_stack+55645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62270, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+52605,int_stack+51660,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2475, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+56530,int_stack+56380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83100, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+108460,int_stack+56740,int_stack+56530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83250, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+51660,int_stack+108460,int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111430, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+57245,int_stack+57020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61820, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53955,int_stack+57560,int_stack+57245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62270, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+54900,int_stack+53955,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2475, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+58130,int_stack+57980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+108460,int_stack+58340,int_stack+58130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+83250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+53955,int_stack+108460,int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+58845,int_stack+58620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+56250,int_stack+59160,int_stack+58845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+62270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+57195,int_stack+56250,int_stack+108460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+59730,int_stack+59580, 0.0, zero_stack, 1.0, int_stack+83100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+108460,int_stack+59940,int_stack+59730, 0.0, zero_stack, 1.0, int_stack+83250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+56250,int_stack+108460,int_stack+87580, 0.0, zero_stack, 1.0, int_stack+111430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+60445,int_stack+60220, 0.0, zero_stack, 1.0, int_stack+61820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+58545,int_stack+60760,int_stack+60445, 0.0, zero_stack, 1.0, int_stack+62270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+59490,int_stack+58545,int_stack+108460, 0.0, zero_stack, 1.0, int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+61330,int_stack+61180, 1.0, int_stack+83100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+108460,int_stack+61540,int_stack+61330, 1.0, int_stack+83250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+58545,int_stack+108460,int_stack+87580, 1.0, int_stack+111430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+62585,int_stack+62045, 1.0, int_stack+61820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+111430,int_stack+62900,int_stack+62585, 1.0, int_stack+62270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+60840,int_stack+111430,int_stack+108460, 1.0, int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+63470,int_stack+63320,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+63680,int_stack+63470,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+111430,int_stack+2475,int_stack+87580,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2475,int_stack+64185,int_stack+63960,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+62190,int_stack+64500,int_stack+64185,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+63135,int_stack+62190,int_stack+2475,15);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+65070,int_stack+64920,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+65280,int_stack+65070,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+62190,int_stack+2475,int_stack+87580,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+2475,int_stack+65785,int_stack+65560,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+64485,int_stack+66100,int_stack+65785,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+65430,int_stack+64485,int_stack+2475,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+67310,int_stack+67160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85340,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+67520,int_stack+67310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85490,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+64485,int_stack+2475,int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114625,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2475,int_stack+68025,int_stack+67800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79360,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+66780,int_stack+68340,int_stack+68025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79810,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+67725,int_stack+66780,int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3150,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+69550,int_stack+69400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85340, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+69760,int_stack+69550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85490, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+66780,int_stack+2475,int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114625, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2475,int_stack+70265,int_stack+70040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79360, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+69075,int_stack+70580,int_stack+70265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79810, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+70020,int_stack+69075,int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3150, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+71790,int_stack+71640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85340, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+72000,int_stack+71790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85490, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+69075,int_stack+2475,int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114625, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2475,int_stack+72505,int_stack+72280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79360, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71370,int_stack+72820,int_stack+72505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79810, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+72315,int_stack+71370,int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+74030,int_stack+73880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+74240,int_stack+74030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+85490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+71370,int_stack+2475,int_stack+87580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2475,int_stack+74745,int_stack+74520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+73665,int_stack+75060,int_stack+74745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+79810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+74610,int_stack+73665,int_stack+2475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+76270,int_stack+76120, 0.0, zero_stack, 1.0, int_stack+85340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+76480,int_stack+76270, 0.0, zero_stack, 1.0, int_stack+85490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+73665,int_stack+2475,int_stack+87580, 0.0, zero_stack, 1.0, int_stack+114625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2475,int_stack+76985,int_stack+76760, 0.0, zero_stack, 1.0, int_stack+79360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+75960,int_stack+77300,int_stack+76985, 0.0, zero_stack, 1.0, int_stack+79810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+76905,int_stack+75960,int_stack+2475, 0.0, zero_stack, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+78870,int_stack+78720, 1.0, int_stack+85340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+79080,int_stack+78870, 1.0, int_stack+85490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+75960,int_stack+2475,int_stack+87580, 1.0, int_stack+114625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (g0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+2475,int_stack+80125,int_stack+79585, 1.0, int_stack+79360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+114625,int_stack+80440,int_stack+80125, 1.0, int_stack+79810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+78255,int_stack+114625,int_stack+2475, 1.0, int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+81650,int_stack+81500,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+81860,int_stack+81650,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+114625,int_stack+2475,int_stack+87580,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+82365,int_stack+82140,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2475,int_stack+82680,int_stack+82365,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+79605,int_stack+2475,int_stack+108460,15);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+83890,int_stack+83740,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+108460,int_stack+84100,int_stack+83890,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+2475,int_stack+108460,int_stack+87580,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+84605,int_stack+84380,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+80955,int_stack+84920,int_stack+84605,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+81900,int_stack+80955,int_stack+108460,15);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+87580,int_stack+86130,int_stack+85980,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+108460,int_stack+86340,int_stack+86130,10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+80955,int_stack+108460,int_stack+87580,10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+108460,int_stack+86845,int_stack+86620,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+83250,int_stack+87160,int_stack+86845,15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+84195,int_stack+83250,int_stack+108460,15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+131860,int_stack+92305,int_stack+89110,90);
     Libderiv->ABCD[11] = int_stack + 131860;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+134560,int_stack+96175,int_stack+93655,90);
     Libderiv->ABCD[10] = int_stack + 134560;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+137260,int_stack+99370,int_stack+97525,90);
     Libderiv->ABCD[9] = int_stack + 137260;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+139960,int_stack+103240,int_stack+100720,90);
     Libderiv->ABCD[8] = int_stack + 139960;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+142660,int_stack+106210,int_stack+675,90);
     Libderiv->ABCD[7] = int_stack + 142660;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+145360,int_stack+110080,int_stack+107560,90);
     Libderiv->ABCD[6] = int_stack + 145360;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+148060,int_stack+112375,int_stack+1575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+109135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[2] = int_stack + 148060;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+150760,int_stack+115570,int_stack+113725, 0.0, zero_stack, 1.0, int_stack+109135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[1] = int_stack + 150760;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+153460,int_stack+118765,int_stack+116920, 1.0, int_stack+109135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[0] = int_stack + 153460;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+108460,int_stack+121060,int_stack+3825,90);
     Libderiv->ABCD[155] = int_stack + 108460;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+156160,int_stack+5670,int_stack+120115,90);
     Libderiv->ABCD[143] = int_stack + 156160;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+118720,int_stack+122410,int_stack+4725,90);
     Libderiv->ABCD[142] = int_stack + 118720;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+3375,int_stack+8865,int_stack+7020,90);
     Libderiv->ABCD[131] = int_stack + 3375;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+158860,int_stack+123760,int_stack+7920,90);
     Libderiv->ABCD[130] = int_stack + 158860;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+6075,int_stack+12060,int_stack+10215,90);
     Libderiv->ABCD[129] = int_stack + 6075;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+121420,int_stack+125110,int_stack+11115,90);
     Libderiv->ABCD[119] = int_stack + 121420;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+8775,int_stack+15255,int_stack+13410,90);
     Libderiv->ABCD[118] = int_stack + 8775;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+11475,int_stack+126460,int_stack+14310,90);
     Libderiv->ABCD[117] = int_stack + 11475;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+124120,int_stack+18450,int_stack+16605,90);
     Libderiv->ABCD[116] = int_stack + 124120;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+14175,int_stack+127810,int_stack+17505,90);
     Libderiv->ABCD[107] = int_stack + 14175;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+16875,int_stack+21645,int_stack+19800,90);
     Libderiv->ABCD[106] = int_stack + 16875;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+161560,int_stack+129160,int_stack+20700,90);
     Libderiv->ABCD[105] = int_stack + 161560;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+19575,int_stack+24840,int_stack+22995,90);
     Libderiv->ABCD[104] = int_stack + 19575;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+126820,int_stack+130510,int_stack+23895,90);
     Libderiv->ABCD[103] = int_stack + 126820;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+22275,int_stack+27090,int_stack+26190,90);
     Libderiv->ABCD[95] = int_stack + 22275;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+24975,int_stack+28440,int_stack+117820,90);
     Libderiv->ABCD[94] = int_stack + 24975;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+164260,int_stack+29790,int_stack+91315,90);
     Libderiv->ABCD[93] = int_stack + 164260;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+27675,int_stack+31140,int_stack+94555,90);
     Libderiv->ABCD[92] = int_stack + 27675;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+94555,int_stack+32490,int_stack+98425,90);
     Libderiv->ABCD[91] = int_stack + 94555;
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libderiv->AB,int_stack+30375,int_stack+33840,int_stack+101620,90);
     Libderiv->ABCD[90] = int_stack + 30375;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+101620,int_stack+35190,int_stack+104590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+89110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[47] = int_stack + 101620;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+104320,int_stack+37485,int_stack+88030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[46] = int_stack + 104320;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+33075,int_stack+39780,int_stack+36540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[45] = int_stack + 33075;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+35775,int_stack+42075,int_stack+38835, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[44] = int_stack + 35775;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+90910,int_stack+44370,int_stack+41130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[43] = int_stack + 90910;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+38475,int_stack+46665,int_stack+43425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[42] = int_stack + 38475;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+41175,int_stack+48015,int_stack+45720, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[38] = int_stack + 41175;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+43875,int_stack+50310,int_stack+90010, 0.0, zero_stack, 1.0, int_stack+89110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[35] = int_stack + 43875;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+46575,int_stack+52605,int_stack+49365, 0.0, zero_stack, 1.0, int_stack+93655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[34] = int_stack + 46575;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+85545,int_stack+54900,int_stack+51660, 0.0, zero_stack, 1.0, int_stack+97525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[33] = int_stack + 85545;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+49275,int_stack+57195,int_stack+53955, 0.0, zero_stack, 1.0, int_stack+100720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[32] = int_stack + 49275;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+51975,int_stack+59490,int_stack+56250, 0.0, zero_stack, 1.0, int_stack+675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[31] = int_stack + 51975;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+54675,int_stack+60840,int_stack+58545, 0.0, zero_stack, 1.0, int_stack+107560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[30] = int_stack + 54675;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+57375,int_stack+63135,int_stack+111430, 0.0, zero_stack, 1.0, int_stack+1575, 1.0, int_stack+113725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[26] = int_stack + 57375;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+166960,int_stack+65430,int_stack+62190, 0.0, zero_stack, 2.0, int_stack+113725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[25] = int_stack + 166960;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+60075,int_stack+67725,int_stack+64485, 1.0, int_stack+89110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[23] = int_stack + 60075;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+62775,int_stack+70020,int_stack+66780, 1.0, int_stack+93655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[22] = int_stack + 62775;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+65475,int_stack+72315,int_stack+69075, 1.0, int_stack+97525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[21] = int_stack + 65475;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+97255,int_stack+74610,int_stack+71370, 1.0, int_stack+100720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[20] = int_stack + 97255;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+68175,int_stack+76905,int_stack+73665, 1.0, int_stack+675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[19] = int_stack + 68175;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+70875,int_stack+78255,int_stack+75960, 1.0, int_stack+107560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[18] = int_stack + 70875;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+73575,int_stack+79605,int_stack+114625, 1.0, int_stack+1575, 0.0, zero_stack, 1.0, int_stack+116920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[14] = int_stack + 73575;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+76275,int_stack+81900,int_stack+2475, 1.0, int_stack+113725, 1.0, int_stack+116920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[13] = int_stack + 76275;
 /*--- compute (fp|gd) ---*/
   d1hrr1_build_fp(Libderiv->AB,int_stack+111160,int_stack+84195,int_stack+80955, 2.0, int_stack+116920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,90);
     Libderiv->ABCD[12] = int_stack + 111160;

}
