/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_g0hf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (g0|hf) integrals */

void d12hrr_order_g0hf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][8][11] = int_stack + 0;
 Libderiv->deriv_classes[4][8][10] = int_stack + 675;
 Libderiv->deriv_classes[4][8][9] = int_stack + 1350;
 Libderiv->deriv_classes[4][8][8] = int_stack + 2025;
 Libderiv->deriv_classes[4][8][7] = int_stack + 2700;
 Libderiv->dvrr_classes[4][7] = int_stack + 3375;
 Libderiv->deriv_classes[4][8][6] = int_stack + 3915;
 Libderiv->deriv_classes[4][8][2] = int_stack + 4590;
 Libderiv->deriv_classes[4][8][1] = int_stack + 5265;
 Libderiv->deriv_classes[4][8][0] = int_stack + 5940;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 6615;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 6930;
 Libderiv->deriv2_classes[4][7][143] = int_stack + 7350;
 Libderiv->deriv2_classes[4][8][143] = int_stack + 7890;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 8565;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 8880;
 Libderiv->deriv2_classes[4][7][131] = int_stack + 9300;
 Libderiv->deriv2_classes[4][8][131] = int_stack + 9840;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 10515;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 10830;
 Libderiv->deriv2_classes[4][7][130] = int_stack + 11250;
 Libderiv->deriv2_classes[4][8][130] = int_stack + 11790;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 12465;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 12780;
 Libderiv->deriv2_classes[4][7][119] = int_stack + 13200;
 Libderiv->deriv2_classes[4][8][119] = int_stack + 13740;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 14415;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 14730;
 Libderiv->deriv2_classes[4][7][118] = int_stack + 15150;
 Libderiv->deriv2_classes[4][8][118] = int_stack + 15690;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 16365;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 16680;
 Libderiv->deriv2_classes[4][7][117] = int_stack + 17100;
 Libderiv->deriv2_classes[4][8][117] = int_stack + 17640;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 18315;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 18630;
 Libderiv->deriv2_classes[4][7][107] = int_stack + 19050;
 Libderiv->deriv2_classes[4][8][107] = int_stack + 19590;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 20265;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 20580;
 Libderiv->deriv2_classes[4][7][106] = int_stack + 21000;
 Libderiv->deriv2_classes[4][8][106] = int_stack + 21540;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 22215;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 22530;
 Libderiv->deriv2_classes[4][7][105] = int_stack + 22950;
 Libderiv->deriv2_classes[4][8][105] = int_stack + 23490;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 24165;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 24480;
 Libderiv->deriv2_classes[4][7][104] = int_stack + 24900;
 Libderiv->deriv2_classes[4][8][104] = int_stack + 25440;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 26115;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 26430;
 Libderiv->deriv2_classes[4][7][95] = int_stack + 26850;
 Libderiv->deriv2_classes[4][8][95] = int_stack + 27390;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 28065;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 28380;
 Libderiv->deriv2_classes[4][7][94] = int_stack + 28800;
 Libderiv->deriv2_classes[4][8][94] = int_stack + 29340;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 30015;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 30330;
 Libderiv->deriv2_classes[4][7][93] = int_stack + 30750;
 Libderiv->deriv2_classes[4][8][93] = int_stack + 31290;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 31965;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 32280;
 Libderiv->deriv2_classes[4][7][92] = int_stack + 32700;
 Libderiv->deriv2_classes[4][8][92] = int_stack + 33240;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 33915;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 34230;
 Libderiv->deriv2_classes[4][7][91] = int_stack + 34650;
 Libderiv->deriv2_classes[4][8][91] = int_stack + 35190;
 Libderiv->deriv_classes[4][5][11] = int_stack + 35865;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 36180;
 Libderiv->deriv_classes[4][6][11] = int_stack + 36495;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 36915;
 Libderiv->deriv_classes[4][7][11] = int_stack + 37335;
 Libderiv->deriv2_classes[4][7][83] = int_stack + 37875;
 Libderiv->deriv2_classes[4][8][83] = int_stack + 38415;
 Libderiv->deriv_classes[4][5][10] = int_stack + 39090;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 39405;
 Libderiv->deriv_classes[4][6][10] = int_stack + 39720;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 40140;
 Libderiv->deriv_classes[4][7][10] = int_stack + 40560;
 Libderiv->deriv2_classes[4][7][82] = int_stack + 41100;
 Libderiv->deriv2_classes[4][8][82] = int_stack + 41640;
 Libderiv->deriv_classes[4][5][9] = int_stack + 42315;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 42630;
 Libderiv->deriv_classes[4][6][9] = int_stack + 42945;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 43365;
 Libderiv->deriv_classes[4][7][9] = int_stack + 43785;
 Libderiv->deriv2_classes[4][7][81] = int_stack + 44325;
 Libderiv->deriv2_classes[4][8][81] = int_stack + 44865;
 Libderiv->deriv_classes[4][5][8] = int_stack + 45540;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 45855;
 Libderiv->deriv_classes[4][6][8] = int_stack + 46170;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 46590;
 Libderiv->deriv_classes[4][7][8] = int_stack + 47010;
 Libderiv->deriv2_classes[4][7][80] = int_stack + 47550;
 Libderiv->deriv2_classes[4][8][80] = int_stack + 48090;
 Libderiv->deriv_classes[4][5][7] = int_stack + 48765;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 49080;
 Libderiv->deriv_classes[4][6][7] = int_stack + 49395;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 49815;
 Libderiv->deriv_classes[4][7][7] = int_stack + 50235;
 Libderiv->deriv2_classes[4][7][79] = int_stack + 50775;
 Libderiv->deriv2_classes[4][8][79] = int_stack + 51315;
 Libderiv->dvrr_classes[4][5] = int_stack + 51990;
 Libderiv->deriv_classes[4][5][6] = int_stack + 52305;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 52620;
 Libderiv->dvrr_classes[4][6] = int_stack + 52935;
 Libderiv->deriv_classes[4][6][6] = int_stack + 53355;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 53775;
 Libderiv->deriv_classes[4][7][6] = int_stack + 54195;
 Libderiv->deriv2_classes[4][7][78] = int_stack + 54735;
 Libderiv->deriv2_classes[4][8][78] = int_stack + 55275;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 55950;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 56265;
 Libderiv->deriv2_classes[4][7][35] = int_stack + 56685;
 Libderiv->deriv2_classes[4][8][35] = int_stack + 57225;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 57900;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 58215;
 Libderiv->deriv2_classes[4][7][34] = int_stack + 58635;
 Libderiv->deriv2_classes[4][8][34] = int_stack + 59175;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 59850;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 60165;
 Libderiv->deriv2_classes[4][7][33] = int_stack + 60585;
 Libderiv->deriv2_classes[4][8][33] = int_stack + 61125;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 61800;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 62115;
 Libderiv->deriv2_classes[4][7][32] = int_stack + 62535;
 Libderiv->deriv2_classes[4][8][32] = int_stack + 63075;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 63750;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 64065;
 Libderiv->deriv2_classes[4][7][31] = int_stack + 64485;
 Libderiv->deriv2_classes[4][8][31] = int_stack + 65025;
 Libderiv->deriv_classes[4][5][2] = int_stack + 65700;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 66015;
 Libderiv->deriv_classes[4][6][2] = int_stack + 66330;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 66750;
 Libderiv->deriv_classes[4][7][2] = int_stack + 67170;
 Libderiv->deriv2_classes[4][7][30] = int_stack + 67710;
 Libderiv->deriv2_classes[4][8][30] = int_stack + 68250;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 68925;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 69240;
 Libderiv->deriv2_classes[4][7][26] = int_stack + 69660;
 Libderiv->deriv2_classes[4][8][26] = int_stack + 70200;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 70875;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 71190;
 Libderiv->deriv2_classes[4][7][23] = int_stack + 71610;
 Libderiv->deriv2_classes[4][8][23] = int_stack + 72150;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 72825;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 73140;
 Libderiv->deriv2_classes[4][7][22] = int_stack + 73560;
 Libderiv->deriv2_classes[4][8][22] = int_stack + 74100;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 74775;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 75090;
 Libderiv->deriv2_classes[4][7][21] = int_stack + 75510;
 Libderiv->deriv2_classes[4][8][21] = int_stack + 76050;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 76725;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 77040;
 Libderiv->deriv2_classes[4][7][20] = int_stack + 77460;
 Libderiv->deriv2_classes[4][8][20] = int_stack + 78000;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 78675;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 78990;
 Libderiv->deriv2_classes[4][7][19] = int_stack + 79410;
 Libderiv->deriv2_classes[4][8][19] = int_stack + 79950;
 Libderiv->deriv_classes[4][5][1] = int_stack + 80625;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 80940;
 Libderiv->deriv_classes[4][6][1] = int_stack + 81255;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 81675;
 Libderiv->deriv_classes[4][7][1] = int_stack + 82095;
 Libderiv->deriv2_classes[4][7][18] = int_stack + 82635;
 Libderiv->deriv2_classes[4][8][18] = int_stack + 83175;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 83850;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 84165;
 Libderiv->deriv2_classes[4][7][14] = int_stack + 84585;
 Libderiv->deriv2_classes[4][8][14] = int_stack + 85125;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 85800;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 86115;
 Libderiv->deriv2_classes[4][7][13] = int_stack + 86535;
 Libderiv->deriv2_classes[4][8][13] = int_stack + 87075;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 87750;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 88065;
 Libderiv->deriv2_classes[4][7][11] = int_stack + 88485;
 Libderiv->deriv2_classes[4][8][11] = int_stack + 89025;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 89700;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 90015;
 Libderiv->deriv2_classes[4][7][10] = int_stack + 90435;
 Libderiv->deriv2_classes[4][8][10] = int_stack + 90975;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 91650;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 91965;
 Libderiv->deriv2_classes[4][7][9] = int_stack + 92385;
 Libderiv->deriv2_classes[4][8][9] = int_stack + 92925;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 93600;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 93915;
 Libderiv->deriv2_classes[4][7][8] = int_stack + 94335;
 Libderiv->deriv2_classes[4][8][8] = int_stack + 94875;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 95550;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 95865;
 Libderiv->deriv2_classes[4][7][7] = int_stack + 96285;
 Libderiv->deriv2_classes[4][8][7] = int_stack + 96825;
 Libderiv->deriv_classes[4][5][0] = int_stack + 97500;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 97815;
 Libderiv->deriv_classes[4][6][0] = int_stack + 98130;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 98550;
 Libderiv->deriv_classes[4][7][0] = int_stack + 98970;
 Libderiv->deriv2_classes[4][7][6] = int_stack + 99510;
 Libderiv->deriv2_classes[4][8][6] = int_stack + 100050;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 100725;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 101040;
 Libderiv->deriv2_classes[4][7][2] = int_stack + 101460;
 Libderiv->deriv2_classes[4][8][2] = int_stack + 102000;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 102675;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 102990;
 Libderiv->deriv2_classes[4][7][1] = int_stack + 103410;
 Libderiv->deriv2_classes[4][8][1] = int_stack + 103950;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 104625;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 104940;
 Libderiv->deriv2_classes[4][7][0] = int_stack + 105360;
 Libderiv->deriv2_classes[4][8][0] = int_stack + 105900;
 memset(int_stack,0,852600);

 Libderiv->dvrr_stack = int_stack + 265785;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_g0hf(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+106575,int_stack+52935,int_stack+51990,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+107520,int_stack+3375,int_stack+52935,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+108780,int_stack+107520,int_stack+106575,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+110670,int_stack+36495,int_stack+35865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51990,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+111615,int_stack+37335,int_stack+36495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52935,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+112875,int_stack+111615,int_stack+110670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106575,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+114765,int_stack+0,int_stack+37335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3375,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+116385,int_stack+114765,int_stack+111615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107520,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+114765,int_stack+39720,int_stack+39090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51990, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+118905,int_stack+40560,int_stack+39720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52935, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+120165,int_stack+118905,int_stack+114765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106575, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+122055,int_stack+675,int_stack+40560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3375, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+123675,int_stack+122055,int_stack+118905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107520, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+122055,int_stack+42945,int_stack+42315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51990, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+43785,int_stack+42945, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52935, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+126195,int_stack+0,int_stack+122055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106575, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+128085,int_stack+1350,int_stack+43785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3375, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+129705,int_stack+128085,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107520, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+128085,int_stack+46170,int_stack+45540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+51990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+47010,int_stack+46170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+133485,int_stack+132225,int_stack+128085, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+135375,int_stack+2025,int_stack+47010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+136995,int_stack+135375,int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+135375,int_stack+49395,int_stack+48765, 0.0, zero_stack, 1.0, int_stack+51990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1260,int_stack+50235,int_stack+49395, 0.0, zero_stack, 1.0, int_stack+52935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+139515,int_stack+1260,int_stack+135375, 0.0, zero_stack, 1.0, int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+141405,int_stack+2700,int_stack+50235, 0.0, zero_stack, 1.0, int_stack+3375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+143025,int_stack+141405,int_stack+1260, 0.0, zero_stack, 1.0, int_stack+107520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+141405,int_stack+53355,int_stack+52305, 1.0, int_stack+51990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+54195,int_stack+53355, 1.0, int_stack+52935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+146805,int_stack+145545,int_stack+141405, 1.0, int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148695,int_stack+3915,int_stack+54195, 1.0, int_stack+3375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+150315,int_stack+148695,int_stack+145545, 1.0, int_stack+107520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+148695,int_stack+66330,int_stack+65700,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+106575,int_stack+67170,int_stack+66330,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2520,int_stack+106575,int_stack+148695,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+152835,int_stack+4590,int_stack+67170,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+154455,int_stack+152835,int_stack+106575,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+107835,int_stack+81255,int_stack+80625,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+152835,int_stack+82095,int_stack+81255,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+156975,int_stack+152835,int_stack+107835,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+158865,int_stack+5265,int_stack+82095,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+160485,int_stack+158865,int_stack+152835,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+158865,int_stack+98130,int_stack+97500,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+4410,int_stack+98970,int_stack+98130,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+163005,int_stack+4410,int_stack+158865,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+164895,int_stack+5940,int_stack+98970,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+166515,int_stack+164895,int_stack+4410,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+6930,int_stack+6615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+35865,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164895,int_stack+7350,int_stack+6930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+36495,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+169035,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+110670,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+5670,int_stack+7890,int_stack+7350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+37335,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+170925,int_stack+5670,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+111615,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+164895,int_stack+8880,int_stack+8565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35865, 1.0, int_stack+39090,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+9300,int_stack+8880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36495, 1.0, int_stack+39720,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6930,int_stack+5670,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110670, 1.0, int_stack+114765,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164895,int_stack+9840,int_stack+9300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37335, 1.0, int_stack+40560,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+173445,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111615, 1.0, int_stack+118905,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+10830,int_stack+10515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+39090, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164895,int_stack+11250,int_stack+10830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+39720, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8820,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+114765, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+175965,int_stack+11790,int_stack+11250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+40560, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+177585,int_stack+175965,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+118905, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+164895,int_stack+12780,int_stack+12465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35865, 0.0, zero_stack, 1.0, int_stack+42315,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+13200,int_stack+12780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36495, 0.0, zero_stack, 1.0, int_stack+42945,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10710,int_stack+5670,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110670, 0.0, zero_stack, 1.0, int_stack+122055,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164895,int_stack+13740,int_stack+13200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37335, 0.0, zero_stack, 1.0, int_stack+43785,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+180105,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111615, 0.0, zero_stack, 1.0, int_stack+0,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+14730,int_stack+14415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39090, 1.0, int_stack+42315, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164895,int_stack+15150,int_stack+14730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39720, 1.0, int_stack+42945, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114765, 1.0, int_stack+122055, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+175965,int_stack+15690,int_stack+15150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40560, 1.0, int_stack+43785, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+182625,int_stack+175965,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118905, 1.0, int_stack+0, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+164895,int_stack+16680,int_stack+16365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+42315, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+17100,int_stack+16680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+42945, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+14490,int_stack+5670,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+122055, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164895,int_stack+17640,int_stack+17100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+43785, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+185145,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+18630,int_stack+18315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+45540,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164895,int_stack+19050,int_stack+18630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+36495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46170,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16380,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+128085,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+175965,int_stack+19590,int_stack+19050, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+37335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47010,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+187665,int_stack+175965,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+111615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+132225,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+164895,int_stack+20580,int_stack+20265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39090, 0.0, zero_stack, 1.0, int_stack+45540, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+21000,int_stack+20580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39720, 0.0, zero_stack, 1.0, int_stack+46170, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18270,int_stack+5670,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+114765, 0.0, zero_stack, 1.0, int_stack+128085, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164895,int_stack+21540,int_stack+21000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40560, 0.0, zero_stack, 1.0, int_stack+47010, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+190185,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+118905, 0.0, zero_stack, 1.0, int_stack+132225, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+22530,int_stack+22215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42315, 1.0, int_stack+45540, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164895,int_stack+22950,int_stack+22530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42945, 1.0, int_stack+46170, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20160,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122055, 1.0, int_stack+128085, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+175965,int_stack+23490,int_stack+22950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43785, 1.0, int_stack+47010, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+192705,int_stack+175965,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+132225, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+164895,int_stack+24480,int_stack+24165, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+45540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+24900,int_stack+24480, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+46170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22050,int_stack+5670,int_stack+164895, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+128085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164895,int_stack+25440,int_stack+24900, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+47010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+195225,int_stack+164895,int_stack+5670, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+26430,int_stack+26115, 0.0, zero_stack, 1.0, int_stack+35865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48765,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164895,int_stack+26850,int_stack+26430, 0.0, zero_stack, 1.0, int_stack+36495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49395,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+23940,int_stack+164895,int_stack+5670, 0.0, zero_stack, 1.0, int_stack+110670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135375,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+175965,int_stack+27390,int_stack+26850, 0.0, zero_stack, 1.0, int_stack+37335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50235,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+197745,int_stack+175965,int_stack+164895, 0.0, zero_stack, 1.0, int_stack+111615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+164895,int_stack+28380,int_stack+28065, 0.0, zero_stack, 1.0, int_stack+39090, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48765, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+28800,int_stack+28380, 0.0, zero_stack, 1.0, int_stack+39720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+49395, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+25830,int_stack+5670,int_stack+164895, 0.0, zero_stack, 1.0, int_stack+114765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135375, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164895,int_stack+29340,int_stack+28800, 0.0, zero_stack, 1.0, int_stack+40560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50235, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+200265,int_stack+164895,int_stack+5670, 0.0, zero_stack, 1.0, int_stack+118905, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+30330,int_stack+30015, 0.0, zero_stack, 1.0, int_stack+42315, 0.0, zero_stack, 1.0, int_stack+48765, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164895,int_stack+30750,int_stack+30330, 0.0, zero_stack, 1.0, int_stack+42945, 0.0, zero_stack, 1.0, int_stack+49395, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+27720,int_stack+164895,int_stack+5670, 0.0, zero_stack, 1.0, int_stack+122055, 0.0, zero_stack, 1.0, int_stack+135375, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+175965,int_stack+31290,int_stack+30750, 0.0, zero_stack, 1.0, int_stack+43785, 0.0, zero_stack, 1.0, int_stack+50235, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202785,int_stack+175965,int_stack+164895, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+164895,int_stack+32280,int_stack+31965, 0.0, zero_stack, 1.0, int_stack+45540, 1.0, int_stack+48765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+32700,int_stack+32280, 0.0, zero_stack, 1.0, int_stack+46170, 1.0, int_stack+49395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29610,int_stack+5670,int_stack+164895, 0.0, zero_stack, 1.0, int_stack+128085, 1.0, int_stack+135375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164895,int_stack+33240,int_stack+32700, 0.0, zero_stack, 1.0, int_stack+47010, 1.0, int_stack+50235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+205305,int_stack+164895,int_stack+5670, 0.0, zero_stack, 1.0, int_stack+132225, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+34230,int_stack+33915, 0.0, zero_stack, 2.0, int_stack+48765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164895,int_stack+34650,int_stack+34230, 0.0, zero_stack, 2.0, int_stack+49395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+31500,int_stack+164895,int_stack+5670, 0.0, zero_stack, 2.0, int_stack+135375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+175965,int_stack+35190,int_stack+34650, 0.0, zero_stack, 2.0, int_stack+50235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+207825,int_stack+175965,int_stack+164895, 0.0, zero_stack, 2.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+164895,int_stack+36915,int_stack+36180, 1.0, int_stack+35865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52305,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+37875,int_stack+36915, 1.0, int_stack+36495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53355,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+33390,int_stack+5670,int_stack+164895, 1.0, int_stack+110670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141405,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+164895,int_stack+38415,int_stack+37875, 1.0, int_stack+37335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54195,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+35280,int_stack+164895,int_stack+5670, 1.0, int_stack+111615, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145545,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+40140,int_stack+39405, 1.0, int_stack+39090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52305, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+164895,int_stack+41100,int_stack+40140, 1.0, int_stack+39720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53355, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+110670,int_stack+164895,int_stack+5670, 1.0, int_stack+114765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141405, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+114765,int_stack+41640,int_stack+41100, 1.0, int_stack+40560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54195, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+37800,int_stack+114765,int_stack+164895, 1.0, int_stack+118905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145545, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+118905,int_stack+43365,int_stack+42630, 1.0, int_stack+42315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+52305, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+44325,int_stack+43365, 1.0, int_stack+42945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53355, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+40320,int_stack+5670,int_stack+118905, 1.0, int_stack+122055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141405, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+122055,int_stack+44865,int_stack+44325, 1.0, int_stack+43785, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+54195, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+42210,int_stack+122055,int_stack+5670, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145545, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+46590,int_stack+45855, 1.0, int_stack+45540, 0.0, zero_stack, 1.0, int_stack+52305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+47550,int_stack+46590, 1.0, int_stack+46170, 0.0, zero_stack, 1.0, int_stack+53355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+44730,int_stack+5670,int_stack+0, 1.0, int_stack+128085, 0.0, zero_stack, 1.0, int_stack+141405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+128085,int_stack+48090,int_stack+47550, 1.0, int_stack+47010, 0.0, zero_stack, 1.0, int_stack+54195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+210345,int_stack+128085,int_stack+5670, 1.0, int_stack+132225, 0.0, zero_stack, 1.0, int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+132225,int_stack+49815,int_stack+49080, 1.0, int_stack+48765, 1.0, int_stack+52305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5670,int_stack+50775,int_stack+49815, 1.0, int_stack+49395, 1.0, int_stack+53355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+46620,int_stack+5670,int_stack+132225, 1.0, int_stack+135375, 1.0, int_stack+141405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+135375,int_stack+51315,int_stack+50775, 1.0, int_stack+50235, 1.0, int_stack+54195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+48510,int_stack+135375,int_stack+5670, 1.0, int_stack+1260, 1.0, int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5670,int_stack+53775,int_stack+52620, 2.0, int_stack+52305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+54735,int_stack+53775, 2.0, int_stack+53355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+132225,int_stack+5670, 2.0, int_stack+141405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+141405,int_stack+55275,int_stack+54735, 2.0, int_stack+54195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+51030,int_stack+141405,int_stack+132225, 2.0, int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+56265,int_stack+55950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65700,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+56685,int_stack+56265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66330,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+53550,int_stack+132225,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148695,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+141405,int_stack+57225,int_stack+56685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67170,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+212865,int_stack+141405,int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106575,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+132225,int_stack+58215,int_stack+57900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65700, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+58635,int_stack+58215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66330, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+55440,int_stack+145545,int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148695, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+141405,int_stack+59175,int_stack+58635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67170, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+57330,int_stack+141405,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106575, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+60165,int_stack+59850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65700, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+60585,int_stack+60165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66330, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+215385,int_stack+132225,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148695, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+141405,int_stack+61125,int_stack+60585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67170, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+217275,int_stack+141405,int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106575, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+132225,int_stack+62115,int_stack+61800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+65700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+62535,int_stack+62115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+59850,int_stack+145545,int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+148695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+141405,int_stack+63075,int_stack+62535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+67170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+219795,int_stack+141405,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+64065,int_stack+63750, 0.0, zero_stack, 1.0, int_stack+65700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+64485,int_stack+64065, 0.0, zero_stack, 1.0, int_stack+66330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+61740,int_stack+132225,int_stack+145545, 0.0, zero_stack, 1.0, int_stack+148695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+141405,int_stack+65025,int_stack+64485, 0.0, zero_stack, 1.0, int_stack+67170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+222315,int_stack+141405,int_stack+132225, 0.0, zero_stack, 1.0, int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+132225,int_stack+66750,int_stack+66015, 1.0, int_stack+65700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+67710,int_stack+66750, 1.0, int_stack+66330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+63630,int_stack+145545,int_stack+132225, 1.0, int_stack+148695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148695,int_stack+68250,int_stack+67710, 1.0, int_stack+67170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+65520,int_stack+148695,int_stack+145545, 1.0, int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+106575,int_stack+69240,int_stack+68925,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+69660,int_stack+69240,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+224835,int_stack+145545,int_stack+106575,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+148695,int_stack+70200,int_stack+69660,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+68040,int_stack+148695,int_stack+145545,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+71190,int_stack+70875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80625,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+106575,int_stack+71610,int_stack+71190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81255,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+226725,int_stack+106575,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107835,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148695,int_stack+72150,int_stack+71610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82095,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+228615,int_stack+148695,int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152835,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+106575,int_stack+73140,int_stack+72825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80625, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+73560,int_stack+73140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81255, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+70560,int_stack+145545,int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107835, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148695,int_stack+74100,int_stack+73560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82095, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+231135,int_stack+148695,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152835, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+75090,int_stack+74775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80625, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+106575,int_stack+75510,int_stack+75090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81255, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+72450,int_stack+106575,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107835, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148695,int_stack+76050,int_stack+75510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82095, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+233655,int_stack+148695,int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152835, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+106575,int_stack+77040,int_stack+76725, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+77460,int_stack+77040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+74340,int_stack+145545,int_stack+106575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+107835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148695,int_stack+78000,int_stack+77460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+236175,int_stack+148695,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+152835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+78990,int_stack+78675, 0.0, zero_stack, 1.0, int_stack+80625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+106575,int_stack+79410,int_stack+78990, 0.0, zero_stack, 1.0, int_stack+81255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+76230,int_stack+106575,int_stack+145545, 0.0, zero_stack, 1.0, int_stack+107835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148695,int_stack+79950,int_stack+79410, 0.0, zero_stack, 1.0, int_stack+82095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+238695,int_stack+148695,int_stack+106575, 0.0, zero_stack, 1.0, int_stack+152835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+106575,int_stack+81675,int_stack+80940, 1.0, int_stack+80625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+82635,int_stack+81675, 1.0, int_stack+81255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+78120,int_stack+145545,int_stack+106575, 1.0, int_stack+107835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+148695,int_stack+83175,int_stack+82635, 1.0, int_stack+82095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+80010,int_stack+148695,int_stack+145545, 1.0, int_stack+152835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+152835,int_stack+84165,int_stack+83850,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+84585,int_stack+84165,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+106575,int_stack+145545,int_stack+152835,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+152835,int_stack+85125,int_stack+84585,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+82530,int_stack+152835,int_stack+145545,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+86115,int_stack+85800,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+86535,int_stack+86115,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+241215,int_stack+132225,int_stack+145545,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+152835,int_stack+87075,int_stack+86535,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+85050,int_stack+152835,int_stack+132225,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+132225,int_stack+88065,int_stack+87750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97500,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+88485,int_stack+88065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98130,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+243105,int_stack+145545,int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158865,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+152835,int_stack+89025,int_stack+88485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98970,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+244995,int_stack+152835,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4410,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+90015,int_stack+89700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97500, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+90435,int_stack+90015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98130, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+87570,int_stack+132225,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158865, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+152835,int_stack+90975,int_stack+90435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98970, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+247515,int_stack+152835,int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4410, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+132225,int_stack+91965,int_stack+91650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97500, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+92385,int_stack+91965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98130, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+89460,int_stack+145545,int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158865, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+152835,int_stack+92925,int_stack+92385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98970, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+250035,int_stack+152835,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4410, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+93915,int_stack+93600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+94335,int_stack+93915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+91350,int_stack+132225,int_stack+145545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+158865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+152835,int_stack+94875,int_stack+94335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+252555,int_stack+152835,int_stack+132225, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+132225,int_stack+95865,int_stack+95550, 0.0, zero_stack, 1.0, int_stack+97500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+96285,int_stack+95865, 0.0, zero_stack, 1.0, int_stack+98130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+93240,int_stack+145545,int_stack+132225, 0.0, zero_stack, 1.0, int_stack+158865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+152835,int_stack+96825,int_stack+96285, 0.0, zero_stack, 1.0, int_stack+98970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+255075,int_stack+152835,int_stack+145545, 0.0, zero_stack, 1.0, int_stack+4410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+98550,int_stack+97815, 1.0, int_stack+97500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+99510,int_stack+98550, 1.0, int_stack+98130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+95130,int_stack+132225,int_stack+145545, 1.0, int_stack+158865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+158865,int_stack+100050,int_stack+99510, 1.0, int_stack+98970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+97020,int_stack+158865,int_stack+132225, 1.0, int_stack+4410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+4410,int_stack+101040,int_stack+100725,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+101460,int_stack+101040,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+99540,int_stack+132225,int_stack+4410,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+158865,int_stack+102000,int_stack+101460,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+4410,int_stack+158865,int_stack+132225,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+132225,int_stack+102990,int_stack+102675,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+145545,int_stack+103410,int_stack+102990,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+101430,int_stack+145545,int_stack+132225,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+158865,int_stack+103950,int_stack+103410,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+257595,int_stack+158865,int_stack+145545,15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+145545,int_stack+104940,int_stack+104625,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+132225,int_stack+105360,int_stack+104940,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+103320,int_stack+132225,int_stack+145545,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+158865,int_stack+105900,int_stack+105360,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+260115,int_stack+158865,int_stack+132225,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+262635,int_stack+116385,int_stack+112875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108780,15);
     Libderiv->ABCD[11] = int_stack + 262635;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+114765,int_stack+123675,int_stack+120165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108780, 0.0, zero_stack,15);
     Libderiv->ABCD[10] = int_stack + 114765;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+122055,int_stack+129705,int_stack+126195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108780, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[9] = int_stack + 122055;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+128085,int_stack+136995,int_stack+133485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[8] = int_stack + 128085;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+135375,int_stack+143025,int_stack+139515, 0.0, zero_stack, 1.0, int_stack+108780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[7] = int_stack + 135375;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+141405,int_stack+150315,int_stack+146805, 1.0, int_stack+108780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[6] = int_stack + 141405;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+148695,int_stack+154455,int_stack+2520,15);
     Libderiv->ABCD[2] = int_stack + 148695;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+151845,int_stack+160485,int_stack+156975,15);
     Libderiv->ABCD[1] = int_stack + 151845;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+158865,int_stack+166515,int_stack+163005,15);
     Libderiv->ABCD[0] = int_stack + 158865;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+164895,int_stack+170925,int_stack+169035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+112875,15);
     Libderiv->ABCD[155] = int_stack + 164895;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+168045,int_stack+173445,int_stack+6930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112875, 1.0, int_stack+120165,15);
     Libderiv->ABCD[143] = int_stack + 168045;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+171195,int_stack+177585,int_stack+8820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+120165, 0.0, zero_stack,15);
     Libderiv->ABCD[142] = int_stack + 171195;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+6930,int_stack+180105,int_stack+10710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112875, 0.0, zero_stack, 1.0, int_stack+126195,15);
     Libderiv->ABCD[131] = int_stack + 6930;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+174345,int_stack+182625,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120165, 1.0, int_stack+126195, 0.0, zero_stack,15);
     Libderiv->ABCD[130] = int_stack + 174345;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+10080,int_stack+185145,int_stack+14490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+126195, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[129] = int_stack + 10080;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13230,int_stack+187665,int_stack+16380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+112875, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+133485,15);
     Libderiv->ABCD[119] = int_stack + 13230;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+177495,int_stack+190185,int_stack+18270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+120165, 0.0, zero_stack, 1.0, int_stack+133485, 0.0, zero_stack,15);
     Libderiv->ABCD[118] = int_stack + 177495;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+16380,int_stack+192705,int_stack+20160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126195, 1.0, int_stack+133485, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[117] = int_stack + 16380;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+180645,int_stack+195225,int_stack+22050, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+133485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[116] = int_stack + 180645;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+19530,int_stack+197745,int_stack+23940, 0.0, zero_stack, 1.0, int_stack+112875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139515,15);
     Libderiv->ABCD[107] = int_stack + 19530;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+22680,int_stack+200265,int_stack+25830, 0.0, zero_stack, 1.0, int_stack+120165, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+139515, 0.0, zero_stack,15);
     Libderiv->ABCD[106] = int_stack + 22680;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+183795,int_stack+202785,int_stack+27720, 0.0, zero_stack, 1.0, int_stack+126195, 0.0, zero_stack, 1.0, int_stack+139515, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[105] = int_stack + 183795;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+25830,int_stack+205305,int_stack+29610, 0.0, zero_stack, 1.0, int_stack+133485, 1.0, int_stack+139515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[104] = int_stack + 25830;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+186945,int_stack+207825,int_stack+31500, 0.0, zero_stack, 2.0, int_stack+139515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[103] = int_stack + 186945;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28980,int_stack+35280,int_stack+33390, 1.0, int_stack+112875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146805,15);
     Libderiv->ABCD[95] = int_stack + 28980;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+32130,int_stack+37800,int_stack+110670, 1.0, int_stack+120165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146805, 0.0, zero_stack,15);
     Libderiv->ABCD[94] = int_stack + 32130;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+35280,int_stack+42210,int_stack+40320, 1.0, int_stack+126195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+146805, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[93] = int_stack + 35280;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+38430,int_stack+210345,int_stack+44730, 1.0, int_stack+133485, 0.0, zero_stack, 1.0, int_stack+146805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[92] = int_stack + 38430;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+41580,int_stack+48510,int_stack+46620, 1.0, int_stack+139515, 1.0, int_stack+146805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[91] = int_stack + 41580;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+44730,int_stack+51030,int_stack+0, 2.0, int_stack+146805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[90] = int_stack + 44730;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+47880,int_stack+212865,int_stack+53550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520,15);
     Libderiv->ABCD[47] = int_stack + 47880;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+51030,int_stack+57330,int_stack+55440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack,15);
     Libderiv->ABCD[46] = int_stack + 51030;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+54180,int_stack+217275,int_stack+215385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[45] = int_stack + 54180;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+108465,int_stack+219795,int_stack+59850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[44] = int_stack + 108465;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+111615,int_stack+222315,int_stack+61740, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[43] = int_stack + 111615;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+57330,int_stack+65520,int_stack+63630, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[42] = int_stack + 57330;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+68040,int_stack+224835,15);
     Libderiv->ABCD[38] = int_stack + 0;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+60480,int_stack+228615,int_stack+226725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156975,15);
     Libderiv->ABCD[35] = int_stack + 60480;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+63630,int_stack+231135,int_stack+70560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156975, 0.0, zero_stack,15);
     Libderiv->ABCD[34] = int_stack + 63630;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+66780,int_stack+233655,int_stack+72450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156975, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[33] = int_stack + 66780;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+69930,int_stack+236175,int_stack+74340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[32] = int_stack + 69930;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+73080,int_stack+238695,int_stack+76230, 0.0, zero_stack, 1.0, int_stack+156975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[31] = int_stack + 73080;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+144555,int_stack+80010,int_stack+78120, 1.0, int_stack+156975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[30] = int_stack + 144555;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+76230,int_stack+82530,int_stack+106575,15);
     Libderiv->ABCD[26] = int_stack + 76230;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+79380,int_stack+85050,int_stack+241215,15);
     Libderiv->ABCD[25] = int_stack + 79380;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+82530,int_stack+244995,int_stack+243105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163005,15);
     Libderiv->ABCD[23] = int_stack + 82530;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+154995,int_stack+247515,int_stack+87570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163005, 0.0, zero_stack,15);
     Libderiv->ABCD[22] = int_stack + 154995;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+85680,int_stack+250035,int_stack+89460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163005, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[21] = int_stack + 85680;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+105210,int_stack+252555,int_stack+91350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[20] = int_stack + 105210;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+88830,int_stack+255075,int_stack+93240, 0.0, zero_stack, 1.0, int_stack+163005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[19] = int_stack + 88830;
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+91980,int_stack+97020,int_stack+95130, 1.0, int_stack+163005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
     Libderiv->ABCD[18] = int_stack + 91980;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+95130,int_stack+4410,int_stack+99540,15);
     Libderiv->ABCD[14] = int_stack + 95130;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+98280,int_stack+257595,int_stack+101430,15);
     Libderiv->ABCD[13] = int_stack + 98280;
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3150,int_stack+260115,int_stack+103320,15);
     Libderiv->ABCD[12] = int_stack + 3150;

}
