/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_f0ii(Libderiv_t *, prim_data *);

  /* Computes derivatives of (f0|ii) integrals */

void d1hrr_order_f0ii(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][6][11] = int_stack + 0;
 Libderiv->deriv_classes[3][7][11] = int_stack + 280;
 Libderiv->deriv_classes[3][8][11] = int_stack + 640;
 Libderiv->deriv_classes[3][9][11] = int_stack + 1090;
 Libderiv->deriv_classes[3][10][11] = int_stack + 1640;
 Libderiv->deriv_classes[3][11][11] = int_stack + 2300;
 Libderiv->deriv_classes[3][12][11] = int_stack + 3080;
 Libderiv->deriv_classes[3][6][10] = int_stack + 3990;
 Libderiv->deriv_classes[3][7][10] = int_stack + 4270;
 Libderiv->deriv_classes[3][8][10] = int_stack + 4630;
 Libderiv->deriv_classes[3][9][10] = int_stack + 5080;
 Libderiv->deriv_classes[3][10][10] = int_stack + 5630;
 Libderiv->deriv_classes[3][11][10] = int_stack + 6290;
 Libderiv->deriv_classes[3][12][10] = int_stack + 7070;
 Libderiv->deriv_classes[3][6][9] = int_stack + 7980;
 Libderiv->deriv_classes[3][7][9] = int_stack + 8260;
 Libderiv->deriv_classes[3][8][9] = int_stack + 8620;
 Libderiv->deriv_classes[3][9][9] = int_stack + 9070;
 Libderiv->deriv_classes[3][10][9] = int_stack + 9620;
 Libderiv->deriv_classes[3][11][9] = int_stack + 10280;
 Libderiv->deriv_classes[3][12][9] = int_stack + 11060;
 Libderiv->deriv_classes[3][6][8] = int_stack + 11970;
 Libderiv->deriv_classes[3][7][8] = int_stack + 12250;
 Libderiv->deriv_classes[3][8][8] = int_stack + 12610;
 Libderiv->deriv_classes[3][9][8] = int_stack + 13060;
 Libderiv->deriv_classes[3][10][8] = int_stack + 13610;
 Libderiv->deriv_classes[3][11][8] = int_stack + 14270;
 Libderiv->deriv_classes[3][12][8] = int_stack + 15050;
 Libderiv->deriv_classes[3][6][7] = int_stack + 15960;
 Libderiv->deriv_classes[3][7][7] = int_stack + 16240;
 Libderiv->deriv_classes[3][8][7] = int_stack + 16600;
 Libderiv->deriv_classes[3][9][7] = int_stack + 17050;
 Libderiv->deriv_classes[3][10][7] = int_stack + 17600;
 Libderiv->deriv_classes[3][11][7] = int_stack + 18260;
 Libderiv->deriv_classes[3][12][7] = int_stack + 19040;
 Libderiv->dvrr_classes[3][6] = int_stack + 19950;
 Libderiv->deriv_classes[3][6][6] = int_stack + 20230;
 Libderiv->dvrr_classes[3][7] = int_stack + 20510;
 Libderiv->deriv_classes[3][7][6] = int_stack + 20870;
 Libderiv->dvrr_classes[3][8] = int_stack + 21230;
 Libderiv->deriv_classes[3][8][6] = int_stack + 21680;
 Libderiv->dvrr_classes[3][9] = int_stack + 22130;
 Libderiv->deriv_classes[3][9][6] = int_stack + 22680;
 Libderiv->dvrr_classes[3][10] = int_stack + 23230;
 Libderiv->deriv_classes[3][10][6] = int_stack + 23890;
 Libderiv->dvrr_classes[3][11] = int_stack + 24550;
 Libderiv->deriv_classes[3][11][6] = int_stack + 25330;
 Libderiv->deriv_classes[3][12][6] = int_stack + 26110;
 Libderiv->deriv_classes[3][6][2] = int_stack + 27020;
 Libderiv->deriv_classes[3][7][2] = int_stack + 27300;
 Libderiv->deriv_classes[3][8][2] = int_stack + 27660;
 Libderiv->deriv_classes[3][9][2] = int_stack + 28110;
 Libderiv->deriv_classes[3][10][2] = int_stack + 28660;
 Libderiv->deriv_classes[3][11][2] = int_stack + 29320;
 Libderiv->deriv_classes[3][12][2] = int_stack + 30100;
 Libderiv->deriv_classes[3][6][1] = int_stack + 31010;
 Libderiv->deriv_classes[3][7][1] = int_stack + 31290;
 Libderiv->deriv_classes[3][8][1] = int_stack + 31650;
 Libderiv->deriv_classes[3][9][1] = int_stack + 32100;
 Libderiv->deriv_classes[3][10][1] = int_stack + 32650;
 Libderiv->deriv_classes[3][11][1] = int_stack + 33310;
 Libderiv->deriv_classes[3][12][1] = int_stack + 34090;
 Libderiv->deriv_classes[3][6][0] = int_stack + 35000;
 Libderiv->deriv_classes[3][7][0] = int_stack + 35280;
 Libderiv->deriv_classes[3][8][0] = int_stack + 35640;
 Libderiv->deriv_classes[3][9][0] = int_stack + 36090;
 Libderiv->deriv_classes[3][10][0] = int_stack + 36640;
 Libderiv->deriv_classes[3][11][0] = int_stack + 37300;
 Libderiv->deriv_classes[3][12][0] = int_stack + 38080;
 memset(int_stack,0,311920);

 Libderiv->dvrr_stack = int_stack + 162970;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_f0ii(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+38990,int_stack+20510,int_stack+19950,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+39830,int_stack+21230,int_stack+20510,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+40910,int_stack+39830,int_stack+38990,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+42590,int_stack+22130,int_stack+21230,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+43940,int_stack+42590,int_stack+39830,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+46100,int_stack+43940,int_stack+40910,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+48900,int_stack+23230,int_stack+22130,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+50550,int_stack+48900,int_stack+42590,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+53250,int_stack+50550,int_stack+43940,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+56850,int_stack+53250,int_stack+46100,10);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+61050,int_stack+24550,int_stack+23230,10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+63030,int_stack+61050,int_stack+48900,10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+66330,int_stack+63030,int_stack+50550,10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+70830,int_stack+66330,int_stack+53250,10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+76230,int_stack+70830,int_stack+56850,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+82110,int_stack+280,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19950,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+82950,int_stack+640,int_stack+280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20510,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+84030,int_stack+82950,int_stack+82110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38990,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+85710,int_stack+1090,int_stack+640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21230,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+87060,int_stack+85710,int_stack+82950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39830,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+89220,int_stack+87060,int_stack+84030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40910,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+82110,int_stack+1640,int_stack+1090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22130,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+92020,int_stack+82110,int_stack+85710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42590,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+94720,int_stack+92020,int_stack+87060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43940,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+83760,int_stack+94720,int_stack+89220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46100,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+87960,int_stack+2300,int_stack+1640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23230,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+98320,int_stack+87960,int_stack+82110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48900,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+101620,int_stack+98320,int_stack+92020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50550,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+106120,int_stack+101620,int_stack+94720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53250,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+89940,int_stack+106120,int_stack+83760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56850,10);
 /*--- compute (f0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+82110,int_stack+3080,int_stack+2300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24550,10);
 /*--- compute (f0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+82110,int_stack+87960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61050,10);
 /*--- compute (f0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+82110,int_stack+0,int_stack+98320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63030,10);
 /*--- compute (f0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+111520,int_stack+82110,int_stack+101620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66330,10);
 /*--- compute (f0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+82110,int_stack+111520,int_stack+106120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70830,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+4270,int_stack+3990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19950, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+840,int_stack+4630,int_stack+4270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20510, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1920,int_stack+840,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38990, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+95820,int_stack+5080,int_stack+4630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21230, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+97170,int_stack+95820,int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39830, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+99330,int_stack+97170,int_stack+1920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40910, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+5630,int_stack+5080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22130, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1650,int_stack+0,int_stack+95820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42590, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+102130,int_stack+1650,int_stack+97170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43940, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+105730,int_stack+102130,int_stack+99330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46100, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+95820,int_stack+6290,int_stack+5630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23230, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+97800,int_stack+95820,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48900, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+109930,int_stack+97800,int_stack+1650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50550, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+109930,int_stack+102130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53250, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+114430,int_stack+0,int_stack+105730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56850, 0.0, zero_stack,10);
 /*--- compute (f0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+101100,int_stack+7070,int_stack+6290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24550, 0.0, zero_stack,10);
 /*--- compute (f0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+103440,int_stack+101100,int_stack+95820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61050, 0.0, zero_stack,10);
 /*--- compute (f0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+120310,int_stack+103440,int_stack+97800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63030, 0.0, zero_stack,10);
 /*--- compute (f0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+95820,int_stack+120310,int_stack+109930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66330, 0.0, zero_stack,10);
 /*--- compute (f0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+102570,int_stack+95820,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70830, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+8260,int_stack+7980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19950, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+840,int_stack+8620,int_stack+8260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20510, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1920,int_stack+840,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38990, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3600,int_stack+9070,int_stack+8620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21230, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4950,int_stack+3600,int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39830, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+95820,int_stack+4950,int_stack+1920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40910, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+9620,int_stack+9070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22130, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+98620,int_stack+0,int_stack+3600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42590, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+120310,int_stack+98620,int_stack+4950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43940, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1650,int_stack+120310,int_stack+95820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46100, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+95820,int_stack+10280,int_stack+9620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23230, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+5850,int_stack+95820,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48900, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+123910,int_stack+5850,int_stack+98620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50550, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+128410,int_stack+123910,int_stack+120310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53250, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+133810,int_stack+128410,int_stack+1650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56850, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+120310,int_stack+11060,int_stack+10280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24550, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+0,int_stack+120310,int_stack+95820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61050, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+95820,int_stack+0,int_stack+5850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63030, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+0,int_stack+95820,int_stack+123910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66330, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+120310,int_stack+0,int_stack+128410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70830, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+12250,int_stack+11970, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+840,int_stack+12610,int_stack+12250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1920,int_stack+840,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+38990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3600,int_stack+13060,int_stack+12610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+4950,int_stack+3600,int_stack+840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+39830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+7110,int_stack+4950,int_stack+1920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+40910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+13610,int_stack+13060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+9910,int_stack+0,int_stack+3600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+95820,int_stack+9910,int_stack+4950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+43940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1650,int_stack+95820,int_stack+7110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+5850,int_stack+14270,int_stack+13610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+127870,int_stack+5850,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+139690,int_stack+127870,int_stack+9910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+7830,int_stack+139690,int_stack+95820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+95820,int_stack+7830,int_stack+1650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+56850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+0,int_stack+15050,int_stack+14270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+24550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+110130,int_stack+0,int_stack+5850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+61050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+0,int_stack+110130,int_stack+127870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+63030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+144190,int_stack+0,int_stack+139690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+66330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+0,int_stack+144190,int_stack+7830, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+139690,int_stack+16240,int_stack+15960, 0.0, zero_stack, 1.0, int_stack+19950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+140530,int_stack+16600,int_stack+16240, 0.0, zero_stack, 1.0, int_stack+20510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+141610,int_stack+140530,int_stack+139690, 0.0, zero_stack, 1.0, int_stack+38990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+143290,int_stack+17050,int_stack+16600, 0.0, zero_stack, 1.0, int_stack+21230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+144640,int_stack+143290,int_stack+140530, 0.0, zero_stack, 1.0, int_stack+39830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+146800,int_stack+144640,int_stack+141610, 0.0, zero_stack, 1.0, int_stack+40910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+139690,int_stack+17600,int_stack+17050, 0.0, zero_stack, 1.0, int_stack+22130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7560,int_stack+139690,int_stack+143290, 0.0, zero_stack, 1.0, int_stack+42590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+10260,int_stack+7560,int_stack+144640, 0.0, zero_stack, 1.0, int_stack+43940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+141340,int_stack+10260,int_stack+146800, 0.0, zero_stack, 1.0, int_stack+46100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+145540,int_stack+18260,int_stack+17600, 0.0, zero_stack, 1.0, int_stack+23230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+147520,int_stack+145540,int_stack+139690, 0.0, zero_stack, 1.0, int_stack+48900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+127870,int_stack+147520,int_stack+7560, 0.0, zero_stack, 1.0, int_stack+50550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+150820,int_stack+127870,int_stack+10260, 0.0, zero_stack, 1.0, int_stack+53250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+7560,int_stack+150820,int_stack+141340, 0.0, zero_stack, 1.0, int_stack+56850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+13440,int_stack+19040,int_stack+18260, 0.0, zero_stack, 1.0, int_stack+24550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+15780,int_stack+13440,int_stack+145540, 0.0, zero_stack, 1.0, int_stack+61050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+139690,int_stack+15780,int_stack+147520, 0.0, zero_stack, 1.0, int_stack+63030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+156220,int_stack+139690,int_stack+127870, 0.0, zero_stack, 1.0, int_stack+66330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+139690,int_stack+156220,int_stack+150820, 0.0, zero_stack, 1.0, int_stack+70830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+127870,int_stack+20870,int_stack+20230, 1.0, int_stack+19950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+128710,int_stack+21680,int_stack+20870, 1.0, int_stack+20510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+129790,int_stack+128710,int_stack+127870, 1.0, int_stack+38990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+131470,int_stack+22680,int_stack+21680, 1.0, int_stack+21230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+147250,int_stack+131470,int_stack+128710, 1.0, int_stack+39830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+149410,int_stack+147250,int_stack+129790, 1.0, int_stack+40910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+38990,int_stack+23890,int_stack+22680, 1.0, int_stack+22130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+127870,int_stack+38990,int_stack+131470, 1.0, int_stack+42590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+152210,int_stack+127870,int_stack+147250, 1.0, int_stack+43940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+40640,int_stack+152210,int_stack+149410, 1.0, int_stack+46100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+147250,int_stack+25330,int_stack+23890, 1.0, int_stack+23230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+44840,int_stack+147250,int_stack+38990, 1.0, int_stack+48900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+155810,int_stack+44840,int_stack+127870, 1.0, int_stack+50550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+127870,int_stack+155810,int_stack+152210, 1.0, int_stack+53250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+149230,int_stack+127870,int_stack+40640, 1.0, int_stack+56850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|op) ---*/
   d1hrr3_build_op(Libderiv->CD,int_stack+38990,int_stack+26110,int_stack+25330, 1.0, int_stack+24550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|nd) ---*/
   d1hrr3_build_nd(Libderiv->CD,int_stack+48140,int_stack+38990,int_stack+147250, 1.0, int_stack+61050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mf) ---*/
   d1hrr3_build_mf(Libderiv->CD,int_stack+38990,int_stack+48140,int_stack+44840, 1.0, int_stack+63030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lg) ---*/
   d1hrr3_build_lg(Libderiv->CD,int_stack+44490,int_stack+38990,int_stack+155810, 1.0, int_stack+66330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kh) ---*/
   d1hrr3_build_kh(Libderiv->CD,int_stack+51240,int_stack+44490,int_stack+127870, 1.0, int_stack+70830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+127870,int_stack+27300,int_stack+27020,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+128710,int_stack+27660,int_stack+27300,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+129790,int_stack+128710,int_stack+127870,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+131470,int_stack+28110,int_stack+27660,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+38990,int_stack+131470,int_stack+128710,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+41150,int_stack+38990,int_stack+129790,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+127870,int_stack+28660,int_stack+28110,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+43950,int_stack+127870,int_stack+131470,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+129520,int_stack+43950,int_stack+38990,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+46650,int_stack+129520,int_stack+41150,10);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+147250,int_stack+29320,int_stack+28660,10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+38990,int_stack+147250,int_stack+127870,10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+58800,int_stack+38990,int_stack+43950,10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+63300,int_stack+58800,int_stack+129520,10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+127870,int_stack+63300,int_stack+46650,10);
 /*--- compute (f0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+42290,int_stack+30100,int_stack+29320,10);
 /*--- compute (f0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+44630,int_stack+42290,int_stack+147250,10);
 /*--- compute (f0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+68700,int_stack+44630,int_stack+38990,10);
 /*--- compute (f0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+38990,int_stack+68700,int_stack+58800,10);
 /*--- compute (f0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+155110,int_stack+38990,int_stack+63300,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+38990,int_stack+31290,int_stack+31010,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+39830,int_stack+31650,int_stack+31290,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+40910,int_stack+39830,int_stack+38990,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+42590,int_stack+32100,int_stack+31650,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+43940,int_stack+42590,int_stack+39830,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+46100,int_stack+43940,int_stack+40910,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+38990,int_stack+32650,int_stack+32100,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+58800,int_stack+38990,int_stack+42590,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+61500,int_stack+58800,int_stack+43940,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+40640,int_stack+61500,int_stack+46100,10);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+147250,int_stack+33310,int_stack+32650,10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+44840,int_stack+147250,int_stack+38990,10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+65100,int_stack+44840,int_stack+58800,10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+69600,int_stack+65100,int_stack+61500,10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+58800,int_stack+69600,int_stack+40640,10);
 /*--- compute (f0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+38990,int_stack+34090,int_stack+33310,10);
 /*--- compute (f0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+13440,int_stack+38990,int_stack+147250,10);
 /*--- compute (f0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+38990,int_stack+13440,int_stack+44840,10);
 /*--- compute (f0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+44490,int_stack+38990,int_stack+65100,10);
 /*--- compute (f0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+13440,int_stack+44490,int_stack+69600,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+38990,int_stack+35280,int_stack+35000,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+39830,int_stack+35640,int_stack+35280,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+40910,int_stack+39830,int_stack+38990,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+42590,int_stack+36090,int_stack+35640,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+43940,int_stack+42590,int_stack+39830,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+46100,int_stack+43940,int_stack+40910,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+38990,int_stack+36640,int_stack+36090,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+21000,int_stack+38990,int_stack+42590,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+23700,int_stack+21000,int_stack+43940,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+40640,int_stack+23700,int_stack+46100,10);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+147250,int_stack+37300,int_stack+36640,10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+44840,int_stack+147250,int_stack+38990,10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+27300,int_stack+44840,int_stack+21000,10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+31800,int_stack+27300,int_stack+23700,10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+21000,int_stack+31800,int_stack+40640,10);
 /*--- compute (f0|op) ---*/
   hrr3_build_op(Libderiv->CD,int_stack+38990,int_stack+38080,int_stack+37300,10);
 /*--- compute (f0|nd) ---*/
   hrr3_build_nd(Libderiv->CD,int_stack+64680,int_stack+38990,int_stack+147250,10);
 /*--- compute (f0|mf) ---*/
   hrr3_build_mf(Libderiv->CD,int_stack+37200,int_stack+64680,int_stack+44840,10);
 /*--- compute (f0|lg) ---*/
   hrr3_build_lg(Libderiv->CD,int_stack+64680,int_stack+37200,int_stack+27300,10);
 /*--- compute (f0|kh) ---*/
   hrr3_build_kh(Libderiv->CD,int_stack+37200,int_stack+64680,int_stack+31800,10);
 /*--- compute (f0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+64680,int_stack+82110,int_stack+89940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76230,10);
     Libderiv->ABCD[11] = int_stack + 64680;
 /*--- compute (f0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+82110,int_stack+102570,int_stack+114430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76230, 0.0, zero_stack,10);
     Libderiv->ABCD[10] = int_stack + 82110;
 /*--- compute (f0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+26880,int_stack+120310,int_stack+133810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76230, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[9] = int_stack + 26880;
 /*--- compute (f0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+101700,int_stack+0,int_stack+95820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[8] = int_stack + 101700;
 /*--- compute (f0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+89950,int_stack+139690,int_stack+7560, 0.0, zero_stack, 1.0, int_stack+76230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[7] = int_stack + 89950;
 /*--- compute (f0|ii) ---*/
   d1hrr3_build_ii(Libderiv->CD,int_stack+0,int_stack+51240,int_stack+149230, 1.0, int_stack+76230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[6] = int_stack + 0;
 /*--- compute (f0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+72520,int_stack+155110,int_stack+127870,10);
     Libderiv->ABCD[2] = int_stack + 72520;
 /*--- compute (f0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+44760,int_stack+13440,int_stack+58800,10);
     Libderiv->ABCD[1] = int_stack + 44760;
 /*--- compute (f0|ii) ---*/
   hrr3_build_ii(Libderiv->CD,int_stack+7840,int_stack+37200,int_stack+21000,10);
     Libderiv->ABCD[0] = int_stack + 7840;

}
