/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_d0dd(Libr12_t *, prim_data *);

  /* Computes (d0|dd) integrals for linear R12-methods */

void hrr_grt_order_d0dd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[3][2] = int_stack + 0;
 Libr12->t2vrr_classes[2][2] = int_stack + 60;
 Libr12->gvrr_classes[3][3] = int_stack + 96;
 Libr12->t2vrr_classes[2][3] = int_stack + 196;
 Libr12->t2vrr_classes[2][4] = int_stack + 256;
 Libr12->t1vrr_classes[2][2] = int_stack + 346;
 Libr12->t1vrr_classes[2][3] = int_stack + 382;
 Libr12->t1vrr_classes[2][4] = int_stack + 442;
 Libr12->rvrr_classes[2][2] = int_stack + 532;
 Libr12->rvrr_classes[2][3] = int_stack + 568;
 Libr12->rvrr_classes[2][4] = int_stack + 628;
 Libr12->gvrr_classes[2][2] = int_stack + 718;
 Libr12->gvrr_classes[2][3] = int_stack + 754;
 Libr12->gvrr_classes[2][4] = int_stack + 814;
 memset(int_stack,0,904*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 904;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_d0dd(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+904, int_stack+754, int_stack+718, 6);
 /*--- compute (f0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1012, int_stack+96, int_stack+0, 10);
 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1192, int_stack+814, int_stack+754, 6);
 /*--- compute (d0|[r12,T2]|dp) ---*/
   t2hrr3_build_dp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1372, int_stack+196, int_stack+60, int_stack+754, int_stack+0, int_stack+718, 2, 0);
 /*--- compute (d0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1480, int_stack+256, int_stack+196, int_stack+814, int_stack+96, int_stack+754, 2, 0);
 /*--- compute (d0|[r12,T1]|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+718, int_stack+382, int_stack+346, 6);
 /*--- compute (d0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+442, int_stack+382, 6);
 /*--- compute (d0||dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+180, int_stack+568, int_stack+532, 6);
 /*--- compute (d0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+288, int_stack+628, int_stack+568, 6);
 /*--- compute (d0|[r12,T2]|dd) ---*/
   t2hrr3_build_dd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+468, int_stack+1480, int_stack+1372, int_stack+1192, int_stack+1012, int_stack+904, 2, 0);
     Libr12->te_ptr[3] = int_stack + 468;
 /*--- compute (d0|[r12,T1]|dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+1372, int_stack+0, int_stack+718, 6);
     Libr12->te_ptr[2] = int_stack + 1372;
 /*--- compute (d0||dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+1588, int_stack+288, int_stack+180, 6);
     Libr12->te_ptr[1] = int_stack + 1588;
 /*--- compute (d0|dd) ---*/
   hrr3_build_dd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1192, int_stack+904, 6);
     Libr12->te_ptr[0] = int_stack + 0;

}
