/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_d0ff(Libr12_t *, prim_data *);

  /* Computes (d0|ff) integrals for linear R12-methods */

void hrr_grt_order_d0ff(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[3][3] = int_stack + 0;
 Libr12->t2vrr_classes[2][3] = int_stack + 100;
 Libr12->gvrr_classes[3][4] = int_stack + 160;
 Libr12->t2vrr_classes[2][4] = int_stack + 310;
 Libr12->gvrr_classes[3][5] = int_stack + 400;
 Libr12->t2vrr_classes[2][5] = int_stack + 610;
 Libr12->t2vrr_classes[2][6] = int_stack + 736;
 Libr12->t1vrr_classes[2][3] = int_stack + 904;
 Libr12->t1vrr_classes[2][4] = int_stack + 964;
 Libr12->t1vrr_classes[2][5] = int_stack + 1054;
 Libr12->t1vrr_classes[2][6] = int_stack + 1180;
 Libr12->rvrr_classes[2][3] = int_stack + 1348;
 Libr12->rvrr_classes[2][4] = int_stack + 1408;
 Libr12->rvrr_classes[2][5] = int_stack + 1498;
 Libr12->rvrr_classes[2][6] = int_stack + 1624;
 Libr12->gvrr_classes[2][3] = int_stack + 1792;
 Libr12->gvrr_classes[2][4] = int_stack + 1852;
 Libr12->gvrr_classes[2][5] = int_stack + 1942;
 Libr12->gvrr_classes[2][6] = int_stack + 2068;
 memset(int_stack,0,2236*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 2236;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_d0ff(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2236, int_stack+1852, int_stack+1792, 6);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2416, int_stack+1942, int_stack+1852, 6);
 /*--- compute (d0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+2686, int_stack+2416, int_stack+2236, 6);
 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+3046, int_stack+160, int_stack+0, 10);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3346, int_stack+400, int_stack+160, 10);
 /*--- compute (f0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+3796, int_stack+3346, int_stack+3046, 10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4396, int_stack+2068, int_stack+1942, 6);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+4774, int_stack+4396, int_stack+2416, 6);
 /*--- compute (d0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5314, int_stack+310, int_stack+100, int_stack+1852, int_stack+0, int_stack+1792, 2, 0);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5494, int_stack+610, int_stack+310, int_stack+1942, int_stack+160, int_stack+1852, 2, 0);
 /*--- compute (d0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+5494, int_stack+5314, int_stack+2416, int_stack+3046, int_stack+2236, 2, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5764, int_stack+736, int_stack+610, int_stack+2068, int_stack+400, int_stack+1942, 2, 0);
 /*--- compute (d0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1792, int_stack+5764, int_stack+5494, int_stack+4396, int_stack+3346, int_stack+2416, 2, 0);
 /*--- compute (d0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+4396, int_stack+964, int_stack+904, 6);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3046, int_stack+1054, int_stack+964, 6);
 /*--- compute (d0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+3316, int_stack+3046, int_stack+4396, 6);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+4396, int_stack+1180, int_stack+1054, 6);
 /*--- compute (d0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+5314, int_stack+4396, int_stack+3046, 6);
 /*--- compute (d0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+3046, int_stack+1408, int_stack+1348, 6);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4396, int_stack+1498, int_stack+1408, 6);
 /*--- compute (d0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+5854, int_stack+4396, int_stack+3046, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6214, int_stack+1624, int_stack+1498, 6);
 /*--- compute (d0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+360, int_stack+6214, int_stack+4396, 6);
 /*--- compute (d0|[r12,T2]|ff) ---*/
   t2hrr3_build_ff(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6214, int_stack+1792, int_stack+0, int_stack+4774, int_stack+3796, int_stack+2686, 2, 0);
     Libr12->te_ptr[3] = int_stack + 6214;
 /*--- compute (d0|[r12,T1]|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+3676, int_stack+5314, int_stack+3316, 6);
     Libr12->te_ptr[2] = int_stack + 3676;
 /*--- compute (d0||ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+3046, int_stack+360, int_stack+5854, 6);
     Libr12->te_ptr[1] = int_stack + 3046;
 /*--- compute (d0|ff) ---*/
   hrr3_build_ff(Libr12->ShellQuartet.CD,int_stack+5314, int_stack+4774, int_stack+2686, 6);
     Libr12->te_ptr[0] = int_stack + 5314;

}
