/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_f0fd(Libr12_t *, prim_data *);

  /* Computes (f0|fd) integrals for linear R12-methods */

void hrr_grt_order_f0fd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[4][3] = int_stack + 0;
 Libr12->t2vrr_classes[3][3] = int_stack + 150;
 Libr12->gvrr_classes[4][4] = int_stack + 250;
 Libr12->t2vrr_classes[3][4] = int_stack + 475;
 Libr12->t2vrr_classes[3][5] = int_stack + 625;
 Libr12->t1vrr_classes[3][3] = int_stack + 835;
 Libr12->t1vrr_classes[3][4] = int_stack + 935;
 Libr12->t1vrr_classes[3][5] = int_stack + 1085;
 Libr12->rvrr_classes[3][3] = int_stack + 1295;
 Libr12->rvrr_classes[3][4] = int_stack + 1395;
 Libr12->rvrr_classes[3][5] = int_stack + 1545;
 Libr12->gvrr_classes[3][3] = int_stack + 1755;
 Libr12->gvrr_classes[3][4] = int_stack + 1855;
 Libr12->gvrr_classes[3][5] = int_stack + 2005;
 memset(int_stack,0,2215*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 2215;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_f0fd(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2215, int_stack+1855, int_stack+1755, 10);
 /*--- compute (g0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2515, int_stack+250, int_stack+0, 15);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2965, int_stack+2005, int_stack+1855, 10);
 /*--- compute (f0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3415, int_stack+475, int_stack+150, int_stack+1855, int_stack+0, int_stack+1755, 3, 0);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3715, int_stack+625, int_stack+475, int_stack+2005, int_stack+250, int_stack+1855, 3, 0);
 /*--- compute (f0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1755, int_stack+935, int_stack+835, 10);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1085, int_stack+935, 10);
 /*--- compute (f0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+450, int_stack+1395, int_stack+1295, 10);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+750, int_stack+1545, int_stack+1395, 10);
 /*--- compute (f0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4165, int_stack+3715, int_stack+3415, int_stack+2965, int_stack+2515, int_stack+2215, 3, 0);
     Libr12->te_ptr[3] = int_stack + 4165;
 /*--- compute (f0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+3415, int_stack+0, int_stack+1755, 10);
     Libr12->te_ptr[2] = int_stack + 3415;
 /*--- compute (f0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+1200, int_stack+750, int_stack+450, 10);
     Libr12->te_ptr[1] = int_stack + 1200;
 /*--- compute (f0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2965, int_stack+2215, 10);
     Libr12->te_ptr[0] = int_stack + 0;

}
