/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fphh(Libr12_t *, prim_data *);

  /* Computes (fp|hh) integrals for linear R12-methods */

void hrr_grt_order_fphh(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[3][6] = int_stack + 210;
 Libr12->t2vrr_classes[3][7] = int_stack + 490;
 Libr12->t2vrr_classes[3][8] = int_stack + 850;
 Libr12->t2vrr_classes[3][9] = int_stack + 1300;
 Libr12->t2vrr_classes[3][10] = int_stack + 1850;
 Libr12->gvrr_classes[5][5] = int_stack + 2510;
 Libr12->t2vrr_classes[4][5] = int_stack + 2951;
 Libr12->gvrr_classes[5][6] = int_stack + 3266;
 Libr12->t2vrr_classes[4][6] = int_stack + 3854;
 Libr12->gvrr_classes[5][7] = int_stack + 4274;
 Libr12->t2vrr_classes[4][7] = int_stack + 5030;
 Libr12->gvrr_classes[5][8] = int_stack + 5570;
 Libr12->t2vrr_classes[4][8] = int_stack + 6515;
 Libr12->gvrr_classes[5][9] = int_stack + 7190;
 Libr12->t2vrr_classes[4][9] = int_stack + 8345;
 Libr12->t2vrr_classes[4][10] = int_stack + 9170;
 Libr12->gvrr_classes[3][11] = int_stack + 10160;
 Libr12->t1vrr_classes[3][5] = int_stack + 10940;
 Libr12->t1vrr_classes[3][6] = int_stack + 11150;
 Libr12->t1vrr_classes[3][7] = int_stack + 11430;
 Libr12->t1vrr_classes[3][8] = int_stack + 11790;
 Libr12->t1vrr_classes[3][9] = int_stack + 12240;
 Libr12->t1vrr_classes[3][10] = int_stack + 12790;
 Libr12->t1vrr_classes[4][5] = int_stack + 13450;
 Libr12->t1vrr_classes[4][6] = int_stack + 13765;
 Libr12->t1vrr_classes[4][7] = int_stack + 14185;
 Libr12->t1vrr_classes[4][8] = int_stack + 14725;
 Libr12->t1vrr_classes[4][9] = int_stack + 15400;
 Libr12->t1vrr_classes[4][10] = int_stack + 16225;
 Libr12->rvrr_classes[3][5] = int_stack + 17215;
 Libr12->rvrr_classes[3][6] = int_stack + 17425;
 Libr12->rvrr_classes[3][7] = int_stack + 17705;
 Libr12->rvrr_classes[3][8] = int_stack + 18065;
 Libr12->rvrr_classes[3][9] = int_stack + 18515;
 Libr12->rvrr_classes[3][10] = int_stack + 19065;
 Libr12->rvrr_classes[4][5] = int_stack + 19725;
 Libr12->rvrr_classes[4][6] = int_stack + 20040;
 Libr12->rvrr_classes[4][7] = int_stack + 20460;
 Libr12->rvrr_classes[4][8] = int_stack + 21000;
 Libr12->rvrr_classes[4][9] = int_stack + 21675;
 Libr12->rvrr_classes[4][10] = int_stack + 22500;
 Libr12->gvrr_classes[3][5] = int_stack + 23490;
 Libr12->gvrr_classes[3][6] = int_stack + 23700;
 Libr12->gvrr_classes[3][7] = int_stack + 23980;
 Libr12->gvrr_classes[3][8] = int_stack + 24340;
 Libr12->gvrr_classes[3][9] = int_stack + 24790;
 Libr12->gvrr_classes[3][10] = int_stack + 25340;
 Libr12->gvrr_classes[4][5] = int_stack + 26000;
 Libr12->gvrr_classes[4][6] = int_stack + 26315;
 Libr12->gvrr_classes[4][7] = int_stack + 26735;
 Libr12->gvrr_classes[4][8] = int_stack + 27275;
 Libr12->gvrr_classes[4][9] = int_stack + 27950;
 Libr12->gvrr_classes[4][10] = int_stack + 28775;
 memset(int_stack,0,29765*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 29765;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fphh(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+29765, int_stack+23700, int_stack+23490, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+30395, int_stack+23980, int_stack+23700, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+31235, int_stack+30395, int_stack+29765, 10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+32495, int_stack+24340, int_stack+23980, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+33575, int_stack+32495, int_stack+30395, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+35255, int_stack+33575, int_stack+31235, 10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+37355, int_stack+24790, int_stack+24340, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+38705, int_stack+37355, int_stack+32495, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+40865, int_stack+38705, int_stack+33575, 10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+43665, int_stack+40865, int_stack+35255, 10);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+46815, int_stack+26315, int_stack+26000, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+47760, int_stack+26735, int_stack+26315, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+49020, int_stack+47760, int_stack+46815, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+50910, int_stack+27275, int_stack+26735, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+52530, int_stack+50910, int_stack+47760, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+55050, int_stack+52530, int_stack+49020, 15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+58200, int_stack+27950, int_stack+27275, 15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+60225, int_stack+58200, int_stack+50910, 15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+63465, int_stack+60225, int_stack+52530, 15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+67665, int_stack+63465, int_stack+55050, 15);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+72390, int_stack+25340, int_stack+24790, 10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+74040, int_stack+72390, int_stack+37355, 10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+76740, int_stack+74040, int_stack+38705, 10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+80340, int_stack+76740, int_stack+40865, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+84540, int_stack+210, int_stack+0, int_stack+23700, int_stack+26000, int_stack+23490, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+85170, int_stack+490, int_stack+210, int_stack+23980, int_stack+26315, int_stack+23700, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+86010, int_stack+85170, int_stack+84540, int_stack+30395, int_stack+46815, int_stack+29765, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+87270, int_stack+850, int_stack+490, int_stack+24340, int_stack+26735, int_stack+23980, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+88350, int_stack+87270, int_stack+85170, int_stack+32495, int_stack+47760, int_stack+30395, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+90030, int_stack+88350, int_stack+86010, int_stack+33575, int_stack+49020, int_stack+31235, 3, 0);
 /*--- compute (f0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+29765, int_stack+1300, int_stack+850, int_stack+24790, int_stack+27275, int_stack+24340, 3, 0);
 /*--- compute (f0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+84540, int_stack+29765, int_stack+87270, int_stack+37355, int_stack+50910, int_stack+32495, 3, 0);
 /*--- compute (f0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+92130, int_stack+84540, int_stack+88350, int_stack+38705, int_stack+52530, int_stack+33575, 3, 0);
 /*--- compute (f0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+31115, int_stack+92130, int_stack+90030, int_stack+40865, int_stack+55050, int_stack+35255, 3, 0);
 /*--- compute (f0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34265, int_stack+1850, int_stack+1300, int_stack+25340, int_stack+27950, int_stack+24790, 3, 0);
 /*--- compute (f0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+86700, int_stack+34265, int_stack+29765, int_stack+72390, int_stack+58200, int_stack+37355, 3, 0);
 /*--- compute (f0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34265, int_stack+86700, int_stack+84540, int_stack+74040, int_stack+60225, int_stack+38705, 3, 0);
 /*--- compute (f0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+84540, int_stack+34265, int_stack+92130, int_stack+76740, int_stack+63465, int_stack+40865, 3, 0);
 /*--- compute (f0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+34265, int_stack+84540, int_stack+31115, int_stack+80340, int_stack+67665, int_stack+43665, 3, 0);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+84540, int_stack+3266, int_stack+2510, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+85863, int_stack+4274, int_stack+3266, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+87627, int_stack+85863, int_stack+84540, 21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+90273, int_stack+5570, int_stack+4274, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+38675, int_stack+90273, int_stack+85863, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+29765, int_stack+38675, int_stack+87627, 21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+92541, int_stack+7190, int_stack+5570, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+95376, int_stack+92541, int_stack+90273, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+99912, int_stack+95376, int_stack+38675, 21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+105792, int_stack+99912, int_stack+29765, 21);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+28775, int_stack+27950, 15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+112407, int_stack+0, int_stack+58200, 15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+116457, int_stack+112407, int_stack+60225, 15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+121857, int_stack+116457, int_stack+63465, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+42203, int_stack+3854, int_stack+2951, int_stack+26315, int_stack+2510, int_stack+26000, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+23490, int_stack+5030, int_stack+3854, int_stack+26735, int_stack+3266, int_stack+26315, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+128157, int_stack+23490, int_stack+42203, int_stack+47760, int_stack+84540, int_stack+46815, 4, 0);
 /*--- compute (g0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2475, int_stack+6515, int_stack+5030, int_stack+27275, int_stack+4274, int_stack+26735, 4, 0);
 /*--- compute (g0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+130047, int_stack+2475, int_stack+23490, int_stack+50910, int_stack+85863, int_stack+47760, 4, 0);
 /*--- compute (g0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+132567, int_stack+130047, int_stack+128157, int_stack+52530, int_stack+87627, int_stack+49020, 4, 0);
 /*--- compute (g0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+46815, int_stack+8345, int_stack+6515, int_stack+27950, int_stack+5570, int_stack+27275, 4, 0);
 /*--- compute (g0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+84540, int_stack+46815, int_stack+2475, int_stack+58200, int_stack+90273, int_stack+50910, 4, 0);
 /*--- compute (g0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2475, int_stack+84540, int_stack+130047, int_stack+60225, int_stack+38675, int_stack+52530, 4, 0);
 /*--- compute (g0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+38675, int_stack+2475, int_stack+132567, int_stack+63465, int_stack+29765, int_stack+55050, 4, 0);
 /*--- compute (g0|[r12,T2]|mp) ---*/
   t2hrr3_build_mp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+29765, int_stack+9170, int_stack+8345, int_stack+28775, int_stack+7190, int_stack+27950, 4, 0);
 /*--- compute (g0|[r12,T2]|ld) ---*/
   t2hrr3_build_ld(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+128157, int_stack+29765, int_stack+46815, int_stack+0, int_stack+92541, int_stack+58200, 4, 0);
 /*--- compute (g0|[r12,T2]|kf) ---*/
   t2hrr3_build_kf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+46815, int_stack+128157, int_stack+84540, int_stack+112407, int_stack+95376, int_stack+60225, 4, 0);
 /*--- compute (g0|[r12,T2]|ig) ---*/
   t2hrr3_build_ig(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+84540, int_stack+46815, int_stack+2475, int_stack+116457, int_stack+99912, int_stack+63465, 4, 0);
 /*--- compute (g0|[r12,T2]|hh) ---*/
   t2hrr3_build_hh(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+46815, int_stack+84540, int_stack+38675, int_stack+121857, int_stack+105792, int_stack+67665, 4, 0);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+38675, int_stack+80340, int_stack+43665, 10);
 /*--- compute (f0|np) ---*/
   hrr3_build_np(Libr12->ShellQuartet.CD,int_stack+43085, int_stack+10160, int_stack+25340, 10);
 /*--- compute (f0|md) ---*/
   hrr3_build_md(Libr12->ShellQuartet.CD,int_stack+84540, int_stack+43085, int_stack+72390, 10);
 /*--- compute (f0|lf) ---*/
   hrr3_build_lf(Libr12->ShellQuartet.CD,int_stack+87840, int_stack+84540, int_stack+74040, 10);
 /*--- compute (f0|kg) ---*/
   hrr3_build_kg(Libr12->ShellQuartet.CD,int_stack+92340, int_stack+87840, int_stack+76740, 10);
 /*--- compute (f0|ih) ---*/
   hrr3_build_ih(Libr12->ShellQuartet.CD,int_stack+84540, int_stack+92340, int_stack+80340, 10);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+90420, int_stack+121857, int_stack+67665, 15);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+97035, int_stack+11150, int_stack+10940, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+97665, int_stack+11430, int_stack+11150, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+98505, int_stack+97665, int_stack+97035, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+99765, int_stack+11790, int_stack+11430, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+100845, int_stack+99765, int_stack+97665, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+102525, int_stack+100845, int_stack+98505, 10);
 /*--- compute (f0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+97035, int_stack+12240, int_stack+11790, 10);
 /*--- compute (f0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+104625, int_stack+97035, int_stack+99765, 10);
 /*--- compute (f0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+106785, int_stack+104625, int_stack+100845, 10);
 /*--- compute (f0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+98385, int_stack+106785, int_stack+102525, 10);
 /*--- compute (f0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+101535, int_stack+12790, int_stack+12240, 10);
 /*--- compute (f0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+109585, int_stack+101535, int_stack+97035, 10);
 /*--- compute (f0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+112285, int_stack+109585, int_stack+104625, 10);
 /*--- compute (f0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+101535, int_stack+112285, int_stack+106785, 10);
 /*--- compute (f0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+105735, int_stack+101535, int_stack+98385, 10);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+97035, int_stack+13765, int_stack+13450, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+97980, int_stack+14185, int_stack+13765, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+99240, int_stack+97980, int_stack+97035, 15);
 /*--- compute (g0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+101130, int_stack+14725, int_stack+14185, 15);
 /*--- compute (g0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+102750, int_stack+101130, int_stack+97980, 15);
 /*--- compute (g0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+110145, int_stack+102750, int_stack+99240, 15);
 /*--- compute (g0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+97035, int_stack+15400, int_stack+14725, 15);
 /*--- compute (g0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+113295, int_stack+97035, int_stack+101130, 15);
 /*--- compute (g0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+116535, int_stack+113295, int_stack+102750, 15);
 /*--- compute (g0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+99060, int_stack+116535, int_stack+110145, 15);
 /*--- compute (g0|[r12,T1]|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+110145, int_stack+16225, int_stack+15400, 15);
 /*--- compute (g0|[r12,T1]|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+120735, int_stack+110145, int_stack+97035, 15);
 /*--- compute (g0|[r12,T1]|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+124785, int_stack+120735, int_stack+113295, 15);
 /*--- compute (g0|[r12,T1]|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+110145, int_stack+124785, int_stack+116535, 15);
 /*--- compute (g0|[r12,T1]|hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+116445, int_stack+110145, int_stack+99060, 15);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+110145, int_stack+17425, int_stack+17215, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+110775, int_stack+17705, int_stack+17425, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+111615, int_stack+110775, int_stack+110145, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+112875, int_stack+18065, int_stack+17705, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+113955, int_stack+112875, int_stack+110775, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+97035, int_stack+113955, int_stack+111615, 10);
 /*--- compute (f0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+110145, int_stack+18515, int_stack+18065, 10);
 /*--- compute (f0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+99135, int_stack+110145, int_stack+112875, 10);
 /*--- compute (f0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+101295, int_stack+99135, int_stack+113955, 10);
 /*--- compute (f0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+111495, int_stack+101295, int_stack+97035, 10);
 /*--- compute (f0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+97035, int_stack+19065, int_stack+18515, 10);
 /*--- compute (f0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+123060, int_stack+97035, int_stack+110145, 10);
 /*--- compute (f0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+125760, int_stack+123060, int_stack+99135, 10);
 /*--- compute (f0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+97035, int_stack+125760, int_stack+101295, 10);
 /*--- compute (f0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+123060, int_stack+97035, int_stack+111495, 10);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+97035, int_stack+20040, int_stack+19725, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+97980, int_stack+20460, int_stack+20040, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+99240, int_stack+97980, int_stack+97035, 15);
 /*--- compute (g0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+101130, int_stack+21000, int_stack+20460, 15);
 /*--- compute (g0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+102750, int_stack+101130, int_stack+97980, 15);
 /*--- compute (g0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+127470, int_stack+102750, int_stack+99240, 15);
 /*--- compute (g0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+97035, int_stack+21675, int_stack+21000, 15);
 /*--- compute (g0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+130620, int_stack+97035, int_stack+101130, 15);
 /*--- compute (g0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+110145, int_stack+130620, int_stack+102750, 15);
 /*--- compute (g0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+99060, int_stack+110145, int_stack+127470, 15);
 /*--- compute (g0||mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+127470, int_stack+22500, int_stack+21675, 15);
 /*--- compute (g0||ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+53430, int_stack+127470, int_stack+97035, 15);
 /*--- compute (g0||kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+57480, int_stack+53430, int_stack+130620, 15);
 /*--- compute (g0||ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+127470, int_stack+57480, int_stack+110145, 15);
 /*--- compute (g0||hh) ---*/
   hrr3_build_hh(Libr12->ShellQuartet.CD,int_stack+53430, int_stack+127470, int_stack+99060, 15);
 /*--- compute (fp|[r12,T2]|hh) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+60045, int_stack+46815, int_stack+34265, 441);
     Libr12->te_ptr[3] = int_stack + 60045;
 /*--- compute (fp|[r12,T1]|hh) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+0, int_stack+116445, int_stack+105735, int_stack+90420, int_stack+84540, int_stack+38675, 5, 5);
     Libr12->te_ptr[2] = int_stack + 0;
 /*--- compute (fp||hh) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+73275, int_stack+53430, int_stack+123060, 441);
     Libr12->te_ptr[1] = int_stack + 73275;
 /*--- compute (fp|hh) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+97035, int_stack+90420, int_stack+38675, 441);
     Libr12->te_ptr[0] = int_stack + 97035;

}
