/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_g0gd(Libr12_t *, prim_data *);

  /* Computes (g0|gd) integrals for linear R12-methods */

void hrr_grt_order_g0gd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[5][4] = int_stack + 0;
 Libr12->t2vrr_classes[4][4] = int_stack + 315;
 Libr12->gvrr_classes[5][5] = int_stack + 540;
 Libr12->t2vrr_classes[4][5] = int_stack + 981;
 Libr12->t2vrr_classes[4][6] = int_stack + 1296;
 Libr12->t1vrr_classes[4][4] = int_stack + 1716;
 Libr12->t1vrr_classes[4][5] = int_stack + 1941;
 Libr12->t1vrr_classes[4][6] = int_stack + 2256;
 Libr12->rvrr_classes[4][4] = int_stack + 2676;
 Libr12->rvrr_classes[4][5] = int_stack + 2901;
 Libr12->rvrr_classes[4][6] = int_stack + 3216;
 Libr12->gvrr_classes[4][4] = int_stack + 3636;
 Libr12->gvrr_classes[4][5] = int_stack + 3861;
 Libr12->gvrr_classes[4][6] = int_stack + 4176;
 memset(int_stack,0,4596*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 4596;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_g0gd(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4596, int_stack+3861, int_stack+3636, 15);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5271, int_stack+540, int_stack+0, 21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6216, int_stack+4176, int_stack+3861, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7161, int_stack+981, int_stack+315, int_stack+3861, int_stack+0, int_stack+3636, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7836, int_stack+1296, int_stack+981, int_stack+4176, int_stack+540, int_stack+3861, 4, 0);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3636, int_stack+1941, int_stack+1716, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2256, int_stack+1941, 15);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+945, int_stack+2901, int_stack+2676, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+1620, int_stack+3216, int_stack+2901, 15);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8781, int_stack+7836, int_stack+7161, int_stack+6216, int_stack+5271, int_stack+4596, 4, 0);
     Libr12->te_ptr[3] = int_stack + 8781;
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+7161, int_stack+0, int_stack+3636, 15);
     Libr12->te_ptr[2] = int_stack + 7161;
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2565, int_stack+1620, int_stack+945, 15);
     Libr12->te_ptr[1] = int_stack + 2565;
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+6216, int_stack+4596, 15);
     Libr12->te_ptr[0] = int_stack + 0;

}
