/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_gphd(Libr12_t *, prim_data *);

  /* Computes (gp|hd) integrals for linear R12-methods */

void hrr_grt_order_gphd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[4][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][6] = int_stack + 315;
 Libr12->t2vrr_classes[4][7] = int_stack + 735;
 Libr12->gvrr_classes[6][5] = int_stack + 1275;
 Libr12->t2vrr_classes[5][5] = int_stack + 1863;
 Libr12->gvrr_classes[6][6] = int_stack + 2304;
 Libr12->t2vrr_classes[5][6] = int_stack + 3088;
 Libr12->t2vrr_classes[5][7] = int_stack + 3676;
 Libr12->gvrr_classes[4][8] = int_stack + 4432;
 Libr12->t1vrr_classes[4][5] = int_stack + 5107;
 Libr12->t1vrr_classes[4][6] = int_stack + 5422;
 Libr12->t1vrr_classes[4][7] = int_stack + 5842;
 Libr12->t1vrr_classes[5][5] = int_stack + 6382;
 Libr12->t1vrr_classes[5][6] = int_stack + 6823;
 Libr12->t1vrr_classes[5][7] = int_stack + 7411;
 Libr12->rvrr_classes[4][5] = int_stack + 8167;
 Libr12->rvrr_classes[4][6] = int_stack + 8482;
 Libr12->rvrr_classes[4][7] = int_stack + 8902;
 Libr12->rvrr_classes[5][5] = int_stack + 9442;
 Libr12->rvrr_classes[5][6] = int_stack + 9883;
 Libr12->rvrr_classes[5][7] = int_stack + 10471;
 Libr12->gvrr_classes[4][5] = int_stack + 11227;
 Libr12->gvrr_classes[4][6] = int_stack + 11542;
 Libr12->gvrr_classes[4][7] = int_stack + 11962;
 Libr12->gvrr_classes[5][5] = int_stack + 12502;
 Libr12->gvrr_classes[5][6] = int_stack + 12943;
 Libr12->gvrr_classes[5][7] = int_stack + 13531;
 memset(int_stack,0,14287*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 14287;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_gphd(Libr12, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14287, int_stack+11542, int_stack+11227, 15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15232, int_stack+12943, int_stack+12502, 21);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+16555, int_stack+11962, int_stack+11542, 15);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+17815, int_stack+315, int_stack+0, int_stack+11542, int_stack+12502, int_stack+11227, 4, 0);
 /*--- compute (g0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+18760, int_stack+735, int_stack+315, int_stack+11962, int_stack+12943, int_stack+11542, 4, 0);
 /*--- compute (g0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20020, int_stack+18760, int_stack+17815, int_stack+16555, int_stack+15232, int_stack+14287, 4, 0);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+17815, int_stack+2304, int_stack+1275, 28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+21910, int_stack+13531, int_stack+12943, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+23674, int_stack+3088, int_stack+1863, int_stack+12943, int_stack+1275, int_stack+12502, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3676, int_stack+3088, int_stack+13531, int_stack+2304, int_stack+12943, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1764, int_stack+0, int_stack+23674, int_stack+21910, int_stack+17815, int_stack+15232, 5, 0);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+17815, int_stack+16555, int_stack+14287, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+4432, int_stack+11962, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+11227, int_stack+0, int_stack+16555, 15);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+23674, int_stack+21910, int_stack+15232, 21);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+21910, int_stack+5422, int_stack+5107, 15);
 /*--- compute (g0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+5842, int_stack+5422, 15);
 /*--- compute (g0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+13747, int_stack+0, int_stack+21910, 15);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+21910, int_stack+6823, int_stack+6382, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+7411, int_stack+6823, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4410, int_stack+0, int_stack+21910, 21);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+21910, int_stack+8482, int_stack+8167, 15);
 /*--- compute (g0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+8902, int_stack+8482, 15);
 /*--- compute (g0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+15637, int_stack+0, int_stack+21910, 15);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+21910, int_stack+9883, int_stack+9442, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+10471, int_stack+9883, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+7056, int_stack+0, int_stack+21910, 21);
 /*--- compute (gp|[r12,T2]|hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+26320, int_stack+1764, int_stack+20020, 126);
     Libr12->te_ptr[3] = int_stack + 26320;
 /*--- compute (gp|[r12,T1]|hd) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+31990, int_stack+4410, int_stack+13747, int_stack+23674, int_stack+11227, int_stack+17815, 5, 2);
     Libr12->te_ptr[2] = int_stack + 31990;
 /*--- compute (gp||hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+7056, int_stack+15637, 126);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+5670, int_stack+23674, int_stack+17815, 126);
     Libr12->te_ptr[0] = int_stack + 5670;

}
