/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_hfgg(Libr12_t *, prim_data *);

  /* Computes (hf|gg) integrals for linear R12-methods */

void hrr_grt_order_hfgg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[5][4] = int_stack + 0;
 Libr12->t2vrr_classes[5][5] = int_stack + 315;
 Libr12->t2vrr_classes[5][6] = int_stack + 756;
 Libr12->t2vrr_classes[5][7] = int_stack + 1344;
 Libr12->t2vrr_classes[5][8] = int_stack + 2100;
 Libr12->t2vrr_classes[6][4] = int_stack + 3045;
 Libr12->t2vrr_classes[6][5] = int_stack + 3465;
 Libr12->t2vrr_classes[6][6] = int_stack + 4053;
 Libr12->t2vrr_classes[6][7] = int_stack + 4837;
 Libr12->t2vrr_classes[6][8] = int_stack + 5845;
 Libr12->t2vrr_classes[7][4] = int_stack + 7105;
 Libr12->t2vrr_classes[7][5] = int_stack + 7645;
 Libr12->t2vrr_classes[7][6] = int_stack + 8401;
 Libr12->t2vrr_classes[7][7] = int_stack + 9409;
 Libr12->t2vrr_classes[7][8] = int_stack + 10705;
 Libr12->gvrr_classes[9][4] = int_stack + 12325;
 Libr12->t2vrr_classes[8][4] = int_stack + 13150;
 Libr12->gvrr_classes[9][5] = int_stack + 13825;
 Libr12->t2vrr_classes[8][5] = int_stack + 14980;
 Libr12->gvrr_classes[9][6] = int_stack + 15925;
 Libr12->t2vrr_classes[8][6] = int_stack + 17465;
 Libr12->gvrr_classes[9][7] = int_stack + 18725;
 Libr12->t2vrr_classes[8][7] = int_stack + 20705;
 Libr12->t2vrr_classes[8][8] = int_stack + 22325;
 Libr12->gvrr_classes[5][9] = int_stack + 24350;
 Libr12->t1vrr_classes[5][4] = int_stack + 25505;
 Libr12->t1vrr_classes[5][5] = int_stack + 25820;
 Libr12->t1vrr_classes[5][6] = int_stack + 26261;
 Libr12->t1vrr_classes[5][7] = int_stack + 26849;
 Libr12->t1vrr_classes[5][8] = int_stack + 27605;
 Libr12->gvrr_classes[6][9] = int_stack + 28550;
 Libr12->t1vrr_classes[6][4] = int_stack + 30090;
 Libr12->t1vrr_classes[6][5] = int_stack + 30510;
 Libr12->t1vrr_classes[6][6] = int_stack + 31098;
 Libr12->t1vrr_classes[6][7] = int_stack + 31882;
 Libr12->t1vrr_classes[6][8] = int_stack + 32890;
 Libr12->gvrr_classes[7][9] = int_stack + 34150;
 Libr12->t1vrr_classes[7][4] = int_stack + 36130;
 Libr12->t1vrr_classes[7][5] = int_stack + 36670;
 Libr12->t1vrr_classes[7][6] = int_stack + 37426;
 Libr12->t1vrr_classes[7][7] = int_stack + 38434;
 Libr12->t1vrr_classes[7][8] = int_stack + 39730;
 Libr12->t1vrr_classes[8][4] = int_stack + 41350;
 Libr12->t1vrr_classes[8][5] = int_stack + 42025;
 Libr12->t1vrr_classes[8][6] = int_stack + 42970;
 Libr12->t1vrr_classes[8][7] = int_stack + 44230;
 Libr12->t1vrr_classes[8][8] = int_stack + 45850;
 Libr12->rvrr_classes[5][4] = int_stack + 47875;
 Libr12->rvrr_classes[5][5] = int_stack + 48190;
 Libr12->rvrr_classes[5][6] = int_stack + 48631;
 Libr12->rvrr_classes[5][7] = int_stack + 49219;
 Libr12->rvrr_classes[5][8] = int_stack + 49975;
 Libr12->rvrr_classes[6][4] = int_stack + 50920;
 Libr12->rvrr_classes[6][5] = int_stack + 51340;
 Libr12->rvrr_classes[6][6] = int_stack + 51928;
 Libr12->rvrr_classes[6][7] = int_stack + 52712;
 Libr12->rvrr_classes[6][8] = int_stack + 53720;
 Libr12->rvrr_classes[7][4] = int_stack + 54980;
 Libr12->rvrr_classes[7][5] = int_stack + 55520;
 Libr12->rvrr_classes[7][6] = int_stack + 56276;
 Libr12->rvrr_classes[7][7] = int_stack + 57284;
 Libr12->rvrr_classes[7][8] = int_stack + 58580;
 Libr12->rvrr_classes[8][4] = int_stack + 60200;
 Libr12->rvrr_classes[8][5] = int_stack + 60875;
 Libr12->rvrr_classes[8][6] = int_stack + 61820;
 Libr12->rvrr_classes[8][7] = int_stack + 63080;
 Libr12->rvrr_classes[8][8] = int_stack + 64700;
 Libr12->gvrr_classes[5][4] = int_stack + 66725;
 Libr12->gvrr_classes[5][5] = int_stack + 67040;
 Libr12->gvrr_classes[5][6] = int_stack + 67481;
 Libr12->gvrr_classes[5][7] = int_stack + 68069;
 Libr12->gvrr_classes[5][8] = int_stack + 68825;
 Libr12->gvrr_classes[6][4] = int_stack + 69770;
 Libr12->gvrr_classes[6][5] = int_stack + 70190;
 Libr12->gvrr_classes[6][6] = int_stack + 70778;
 Libr12->gvrr_classes[6][7] = int_stack + 71562;
 Libr12->gvrr_classes[6][8] = int_stack + 72570;
 Libr12->gvrr_classes[7][4] = int_stack + 73830;
 Libr12->gvrr_classes[7][5] = int_stack + 74370;
 Libr12->gvrr_classes[7][6] = int_stack + 75126;
 Libr12->gvrr_classes[7][7] = int_stack + 76134;
 Libr12->gvrr_classes[7][8] = int_stack + 77430;
 Libr12->gvrr_classes[8][4] = int_stack + 79050;
 Libr12->gvrr_classes[8][5] = int_stack + 79725;
 Libr12->gvrr_classes[8][6] = int_stack + 80670;
 Libr12->gvrr_classes[8][7] = int_stack + 81930;
 Libr12->gvrr_classes[8][8] = int_stack + 83550;
 memset(int_stack,0,85575*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 85575;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_hfgg(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+85575, int_stack+67040, int_stack+66725, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+86520, int_stack+67481, int_stack+67040, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+87843, int_stack+86520, int_stack+85575, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+89733, int_stack+68069, int_stack+67481, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+91497, int_stack+89733, int_stack+86520, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+94143, int_stack+91497, int_stack+87843, 21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+97293, int_stack+70190, int_stack+69770, 28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+98553, int_stack+70778, int_stack+70190, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+100317, int_stack+98553, int_stack+97293, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+102837, int_stack+71562, int_stack+70778, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+105189, int_stack+102837, int_stack+98553, 28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+108717, int_stack+105189, int_stack+100317, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+112917, int_stack+68825, int_stack+68069, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+115185, int_stack+112917, int_stack+89733, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+118713, int_stack+115185, int_stack+91497, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+123123, int_stack+315, int_stack+0, int_stack+67040, int_stack+69770, int_stack+66725, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+124068, int_stack+756, int_stack+315, int_stack+67481, int_stack+70190, int_stack+67040, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+125391, int_stack+124068, int_stack+123123, int_stack+86520, int_stack+97293, int_stack+85575, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+127281, int_stack+1344, int_stack+756, int_stack+68069, int_stack+70778, int_stack+67481, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+129045, int_stack+127281, int_stack+124068, int_stack+89733, int_stack+98553, int_stack+86520, 5, 0);
 /*--- compute (h0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+131691, int_stack+129045, int_stack+125391, int_stack+91497, int_stack+100317, int_stack+87843, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+85575, int_stack+2100, int_stack+1344, int_stack+68825, int_stack+71562, int_stack+68069, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+123123, int_stack+85575, int_stack+127281, int_stack+112917, int_stack+102837, int_stack+89733, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+85575, int_stack+123123, int_stack+129045, int_stack+115185, int_stack+105189, int_stack+91497, 5, 0);
 /*--- compute (h0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+123123, int_stack+85575, int_stack+131691, int_stack+118713, int_stack+108717, int_stack+94143, 5, 0);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+85575, int_stack+74370, int_stack+73830, 36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+87195, int_stack+75126, int_stack+74370, 36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+89463, int_stack+87195, int_stack+85575, 36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+127848, int_stack+76134, int_stack+75126, 36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+130872, int_stack+127848, int_stack+87195, 36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+135408, int_stack+130872, int_stack+89463, 36);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+72570, int_stack+71562, 28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+140808, int_stack+0, int_stack+102837, 28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+145512, int_stack+140808, int_stack+105189, 28);
 /*--- compute (i0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+92703, int_stack+3465, int_stack+3045, int_stack+70190, int_stack+73830, int_stack+69770, 6, 0);
 /*--- compute (i0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+66725, int_stack+4053, int_stack+3465, int_stack+70778, int_stack+74370, int_stack+70190, 6, 0);
 /*--- compute (i0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+151392, int_stack+66725, int_stack+92703, int_stack+98553, int_stack+85575, int_stack+97293, 6, 0);
 /*--- compute (i0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+153912, int_stack+4837, int_stack+4053, int_stack+71562, int_stack+75126, int_stack+70778, 6, 0);
 /*--- compute (i0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+156264, int_stack+153912, int_stack+66725, int_stack+102837, int_stack+87195, int_stack+98553, 6, 0);
 /*--- compute (i0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+159792, int_stack+156264, int_stack+151392, int_stack+105189, int_stack+89463, int_stack+100317, 6, 0);
 /*--- compute (i0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+97293, int_stack+5845, int_stack+4837, int_stack+72570, int_stack+76134, int_stack+71562, 6, 0);
 /*--- compute (i0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+163992, int_stack+97293, int_stack+153912, int_stack+0, int_stack+127848, int_stack+102837, 6, 0);
 /*--- compute (i0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+97293, int_stack+163992, int_stack+156264, int_stack+140808, int_stack+130872, int_stack+105189, 6, 0);
 /*--- compute (i0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+151392, int_stack+97293, int_stack+159792, int_stack+145512, int_stack+135408, int_stack+108717, 6, 0);
 /*--- compute (hp|[r12,T2]|gg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+157692, int_stack+151392, int_stack+123123, 225);
 /*--- compute (l0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+123123, int_stack+79725, int_stack+79050, 45);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+97293, int_stack+80670, int_stack+79725, 45);
 /*--- compute (l0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+100128, int_stack+97293, int_stack+123123, 45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+104178, int_stack+81930, int_stack+80670, 45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+171867, int_stack+104178, int_stack+97293, 45);
 /*--- compute (l0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+177537, int_stack+171867, int_stack+100128, 45);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+3024, int_stack+77430, int_stack+76134, 36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+184287, int_stack+3024, int_stack+127848, 36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+190335, int_stack+184287, int_stack+130872, 36);
 /*--- compute (k0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+125148, int_stack+7645, int_stack+7105, int_stack+74370, int_stack+79050, int_stack+73830, 7, 0);
 /*--- compute (k0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+69770, int_stack+8401, int_stack+7645, int_stack+75126, int_stack+79725, int_stack+74370, 7, 0);
 /*--- compute (k0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+197895, int_stack+69770, int_stack+125148, int_stack+87195, int_stack+123123, int_stack+85575, 7, 0);
 /*--- compute (k0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+201135, int_stack+9409, int_stack+8401, int_stack+76134, int_stack+80670, int_stack+75126, 7, 0);
 /*--- compute (k0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+204159, int_stack+201135, int_stack+69770, int_stack+127848, int_stack+97293, int_stack+87195, 7, 0);
 /*--- compute (k0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+208695, int_stack+204159, int_stack+197895, int_stack+130872, int_stack+100128, int_stack+89463, 7, 0);
 /*--- compute (k0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+85575, int_stack+10705, int_stack+9409, int_stack+77430, int_stack+81930, int_stack+76134, 7, 0);
 /*--- compute (k0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+214095, int_stack+85575, int_stack+201135, int_stack+3024, int_stack+104178, int_stack+127848, 7, 0);
 /*--- compute (k0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+85575, int_stack+214095, int_stack+204159, int_stack+184287, int_stack+171867, int_stack+130872, 7, 0);
 /*--- compute (k0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+197895, int_stack+85575, int_stack+208695, int_stack+190335, int_stack+177537, int_stack+135408, 7, 0);
 /*--- compute (ip|[r12,T2]|gg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+205995, int_stack+197895, int_stack+151392, 225);
 /*--- compute (hd|[r12,T2]|gg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+224895, int_stack+205995, int_stack+157692, 225);
 /*--- compute (m0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+151392, int_stack+13825, int_stack+12325, 55);
 /*--- compute (m0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+153867, int_stack+15925, int_stack+13825, 55);
 /*--- compute (m0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+157332, int_stack+153867, int_stack+151392, 55);
 /*--- compute (m0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+162282, int_stack+18725, int_stack+15925, 55);
 /*--- compute (m0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+85575, int_stack+162282, int_stack+153867, 55);
 /*--- compute (m0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+125148, int_stack+85575, int_stack+157332, 55);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+166902, int_stack+83550, int_stack+81930, 45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+253245, int_stack+166902, int_stack+104178, 45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+260805, int_stack+253245, int_stack+171867, 45);
 /*--- compute (l0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+69770, int_stack+14980, int_stack+13150, int_stack+79725, int_stack+12325, int_stack+79050, 8, 0);
 /*--- compute (l0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+73830, int_stack+17465, int_stack+14980, int_stack+80670, int_stack+13825, int_stack+79725, 8, 0);
 /*--- compute (l0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6912, int_stack+73830, int_stack+69770, int_stack+97293, int_stack+151392, int_stack+123123, 8, 0);
 /*--- compute (l0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10962, int_stack+20705, int_stack+17465, int_stack+81930, int_stack+15925, int_stack+80670, 8, 0);
 /*--- compute (l0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+270255, int_stack+10962, int_stack+73830, int_stack+104178, int_stack+153867, int_stack+97293, 8, 0);
 /*--- compute (l0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+275925, int_stack+270255, int_stack+6912, int_stack+171867, int_stack+157332, int_stack+100128, 8, 0);
 /*--- compute (l0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+97293, int_stack+22325, int_stack+20705, int_stack+83550, int_stack+18725, int_stack+81930, 8, 0);
 /*--- compute (l0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+151392, int_stack+97293, int_stack+10962, int_stack+166902, int_stack+162282, int_stack+104178, 8, 0);
 /*--- compute (l0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+97293, int_stack+151392, int_stack+270255, int_stack+253245, int_stack+85575, int_stack+171867, 8, 0);
 /*--- compute (l0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+151392, int_stack+97293, int_stack+275925, int_stack+260805, int_stack+125148, int_stack+177537, 8, 0);
 /*--- compute (kp|[r12,T2]|gg) ---*/
   hrr1_build_kp(Libr12->ShellQuartet.AB,int_stack+270255, int_stack+151392, int_stack+197895, 225);
 /*--- compute (id|[r12,T2]|gg) ---*/
   hrr1_build_id(Libr12->ShellQuartet.AB,int_stack+294555, int_stack+270255, int_stack+205995, 225);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+270255, int_stack+118713, int_stack+94143, 21);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+274980, int_stack+145512, int_stack+108717, 28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+197895, int_stack+274980, int_stack+270255, 225);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+281280, int_stack+190335, int_stack+135408, 36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+151392, int_stack+281280, int_stack+274980, 225);
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+79050, int_stack+151392, int_stack+197895, 225);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+289380, int_stack+24350, int_stack+68825, 21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+212070, int_stack+289380, int_stack+112917, 21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+216606, int_stack+212070, int_stack+115185, 21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+170292, int_stack+216606, int_stack+118713, 21);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+212070, int_stack+28550, int_stack+72570, 28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+215850, int_stack+212070, int_stack+0, 28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+6912, int_stack+215850, int_stack+140808, 28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+212070, int_stack+6912, int_stack+145512, 28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+107400, int_stack+212070, int_stack+170292, 315);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+6912, int_stack+34150, int_stack+77430, 36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+11772, int_stack+6912, int_stack+3024, 36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+0, int_stack+11772, int_stack+184287, 36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+10080, int_stack+0, int_stack+190335, 36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+332355, int_stack+10080, int_stack+212070, 315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+358815, int_stack+332355, int_stack+107400, 315);
 /*--- compute (l0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+184287, int_stack+260805, int_stack+177537, 45);
 /*--- compute (kp|gg) ---*/
   hrr1_build_kp(Libr12->ShellQuartet.AB,int_stack+398505, int_stack+184287, int_stack+281280, 225);
 /*--- compute (id|gg) ---*/
   hrr1_build_id(Libr12->ShellQuartet.AB,int_stack+422805, int_stack+398505, int_stack+151392, 225);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+25820, int_stack+25505, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+945, int_stack+26261, int_stack+25820, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2268, int_stack+945, int_stack+0, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+4158, int_stack+26849, int_stack+26261, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+5922, int_stack+4158, int_stack+945, 21);
 /*--- compute (h0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+194412, int_stack+5922, int_stack+2268, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+27605, int_stack+26849, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+21420, int_stack+0, int_stack+4158, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+21420, int_stack+5922, 21);
 /*--- compute (h0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+21420, int_stack+0, int_stack+194412, 21);
 /*--- compute (i0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+194412, int_stack+30510, int_stack+30090, 28);
 /*--- compute (i0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+195672, int_stack+31098, int_stack+30510, 28);
 /*--- compute (i0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+195672, int_stack+194412, 28);
 /*--- compute (i0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+2520, int_stack+31882, int_stack+31098, 28);
 /*--- compute (i0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4872, int_stack+2520, int_stack+195672, 28);
 /*--- compute (i0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+26145, int_stack+4872, int_stack+0, 28);
 /*--- compute (i0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+194412, int_stack+32890, int_stack+31882, 28);
 /*--- compute (i0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+30345, int_stack+194412, int_stack+2520, 28);
 /*--- compute (i0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+176907, int_stack+30345, int_stack+4872, 28);
 /*--- compute (i0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+176907, int_stack+26145, 28);
 /*--- compute (hp|[r12,T1]|gg) ---*/
   t1hrr1_build_hp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+253245, int_stack+0, int_stack+21420, int_stack+274980, int_stack+170292, int_stack+270255, 4, 4);
 /*--- compute (k0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+170292, int_stack+36670, int_stack+36130, 36);
 /*--- compute (k0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+171912, int_stack+37426, int_stack+36670, 36);
 /*--- compute (k0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+174180, int_stack+171912, int_stack+170292, 36);
 /*--- compute (k0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+177420, int_stack+38434, int_stack+37426, 36);
 /*--- compute (k0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+21420, int_stack+177420, int_stack+171912, 36);
 /*--- compute (k0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+25956, int_stack+21420, int_stack+174180, 36);
 /*--- compute (k0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+170292, int_stack+39730, int_stack+38434, 36);
 /*--- compute (k0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+31356, int_stack+170292, int_stack+177420, 36);
 /*--- compute (k0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+267420, int_stack+31356, int_stack+21420, 36);
 /*--- compute (k0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+31356, int_stack+267420, int_stack+25956, 36);
 /*--- compute (ip|[r12,T1]|gg) ---*/
   t1hrr1_build_ip(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+127245, int_stack+31356, int_stack+0, int_stack+281280, int_stack+212070, int_stack+274980, 4, 4);
 /*--- compute (hd|[r12,T1]|gg) ---*/
   t1hrr1_build_hd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+460605, int_stack+127245, int_stack+253245, int_stack+151392, int_stack+107400, int_stack+197895, 4, 4);
 /*--- compute (l0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+107400, int_stack+42025, int_stack+41350, 45);
 /*--- compute (l0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+109425, int_stack+42970, int_stack+42025, 45);
 /*--- compute (l0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+112260, int_stack+109425, int_stack+107400, 45);
 /*--- compute (l0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+116310, int_stack+44230, int_stack+42970, 45);
 /*--- compute (l0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+120090, int_stack+116310, int_stack+109425, 45);
 /*--- compute (l0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+253245, int_stack+120090, int_stack+112260, 45);
 /*--- compute (l0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+107400, int_stack+45850, int_stack+44230, 45);
 /*--- compute (l0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+259995, int_stack+107400, int_stack+116310, 45);
 /*--- compute (l0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+107400, int_stack+259995, int_stack+120090, 45);
 /*--- compute (l0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+259995, int_stack+107400, int_stack+253245, 45);
 /*--- compute (kp|[r12,T1]|gg) ---*/
   t1hrr1_build_kp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+194412, int_stack+259995, int_stack+31356, int_stack+184287, int_stack+10080, int_stack+281280, 4, 4);
 /*--- compute (id|[r12,T1]|gg) ---*/
   t1hrr1_build_id(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+253245, int_stack+194412, int_stack+127245, int_stack+398505, int_stack+332355, int_stack+151392, 4, 4);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+332355, int_stack+48190, int_stack+47875, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+333300, int_stack+48631, int_stack+48190, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+334623, int_stack+333300, int_stack+332355, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+336513, int_stack+49219, int_stack+48631, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+338277, int_stack+336513, int_stack+333300, 21);
 /*--- compute (h0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+340923, int_stack+338277, int_stack+334623, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+332355, int_stack+49975, int_stack+49219, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+344073, int_stack+332355, int_stack+336513, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+332355, int_stack+344073, int_stack+338277, 21);
 /*--- compute (h0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+344073, int_stack+332355, int_stack+340923, 21);
 /*--- compute (i0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+332355, int_stack+51340, int_stack+50920, 28);
 /*--- compute (i0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+333615, int_stack+51928, int_stack+51340, 28);
 /*--- compute (i0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+335379, int_stack+333615, int_stack+332355, 28);
 /*--- compute (i0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+337899, int_stack+52712, int_stack+51928, 28);
 /*--- compute (i0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+340251, int_stack+337899, int_stack+333615, 28);
 /*--- compute (i0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+348798, int_stack+340251, int_stack+335379, 28);
 /*--- compute (i0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+332355, int_stack+53720, int_stack+52712, 28);
 /*--- compute (i0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+352998, int_stack+332355, int_stack+337899, 28);
 /*--- compute (i0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+332355, int_stack+352998, int_stack+340251, 28);
 /*--- compute (i0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+398505, int_stack+332355, int_stack+348798, 28);
 /*--- compute (hp||gg) ---*/
   hrr1_build_hp(Libr12->ShellQuartet.AB,int_stack+404805, int_stack+398505, int_stack+344073, 225);
 /*--- compute (k0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+332355, int_stack+55520, int_stack+54980, 36);
 /*--- compute (k0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+333975, int_stack+56276, int_stack+55520, 36);
 /*--- compute (k0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+336243, int_stack+333975, int_stack+332355, 36);
 /*--- compute (k0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+339483, int_stack+57284, int_stack+56276, 36);
 /*--- compute (k0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+342507, int_stack+339483, int_stack+333975, 36);
 /*--- compute (k0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+347043, int_stack+342507, int_stack+336243, 36);
 /*--- compute (k0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+332355, int_stack+58580, int_stack+57284, 36);
 /*--- compute (k0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+352443, int_stack+332355, int_stack+339483, 36);
 /*--- compute (k0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+332355, int_stack+352443, int_stack+342507, 36);
 /*--- compute (k0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+107400, int_stack+332355, int_stack+347043, 36);
 /*--- compute (ip||gg) ---*/
   hrr1_build_ip(Libr12->ShellQuartet.AB,int_stack+332355, int_stack+107400, int_stack+398505, 225);
 /*--- compute (hd||gg) ---*/
   hrr1_build_hd(Libr12->ShellQuartet.AB,int_stack+115500, int_stack+332355, int_stack+404805, 225);
 /*--- compute (l0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+398505, int_stack+60875, int_stack+60200, 45);
 /*--- compute (l0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+400530, int_stack+61820, int_stack+60875, 45);
 /*--- compute (l0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+403365, int_stack+400530, int_stack+398505, 45);
 /*--- compute (l0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+407415, int_stack+63080, int_stack+61820, 45);
 /*--- compute (l0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+411195, int_stack+407415, int_stack+400530, 45);
 /*--- compute (l0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+351255, int_stack+411195, int_stack+403365, 45);
 /*--- compute (l0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+398505, int_stack+64700, int_stack+63080, 45);
 /*--- compute (l0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+143850, int_stack+398505, int_stack+407415, 45);
 /*--- compute (l0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+398505, int_stack+143850, int_stack+411195, 45);
 /*--- compute (l0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+143850, int_stack+398505, int_stack+351255, 45);
 /*--- compute (kp||gg) ---*/
   hrr1_build_kp(Libr12->ShellQuartet.AB,int_stack+398505, int_stack+143850, int_stack+107400, 225);
 /*--- compute (id||gg) ---*/
   hrr1_build_id(Libr12->ShellQuartet.AB,int_stack+143850, int_stack+398505, int_stack+332355, 225);
 /*--- compute (hf|[r12,T2]|gg) ---*/
   hrr1_build_hf(Libr12->ShellQuartet.AB,int_stack+0, int_stack+294555, int_stack+224895, 225);
     Libr12->te_ptr[3] = int_stack + 0;
 /*--- compute (hf|[r12,T1]|gg) ---*/
   t1hrr1_build_hf(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+181650, int_stack+253245, int_stack+460605, int_stack+422805, int_stack+358815, int_stack+79050, 4, 4);
     Libr12->te_ptr[2] = int_stack + 181650;
 /*--- compute (hf||gg) ---*/
   hrr1_build_hf(Libr12->ShellQuartet.AB,int_stack+228900, int_stack+143850, int_stack+115500, 225);
     Libr12->te_ptr[1] = int_stack + 228900;
 /*--- compute (hf|gg) ---*/
   hrr1_build_hf(Libr12->ShellQuartet.AB,int_stack+107400, int_stack+422805, int_stack+79050, 225);
     Libr12->te_ptr[0] = int_stack + 107400;

}
