/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ppgg(Libr12_t *, prim_data *);

  /* Computes (pp|gg) integrals for linear R12-methods */

void hrr_grt_order_ppgg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[1][4] = int_stack + 0;
 Libr12->t2vrr_classes[1][5] = int_stack + 45;
 Libr12->t2vrr_classes[1][6] = int_stack + 108;
 Libr12->t2vrr_classes[1][7] = int_stack + 192;
 Libr12->t2vrr_classes[1][8] = int_stack + 300;
 Libr12->gvrr_classes[3][4] = int_stack + 435;
 Libr12->t2vrr_classes[2][4] = int_stack + 585;
 Libr12->gvrr_classes[3][5] = int_stack + 675;
 Libr12->t2vrr_classes[2][5] = int_stack + 885;
 Libr12->gvrr_classes[3][6] = int_stack + 1011;
 Libr12->t2vrr_classes[2][6] = int_stack + 1291;
 Libr12->gvrr_classes[3][7] = int_stack + 1459;
 Libr12->t2vrr_classes[2][7] = int_stack + 1819;
 Libr12->t2vrr_classes[2][8] = int_stack + 2035;
 Libr12->gvrr_classes[1][9] = int_stack + 2305;
 Libr12->t1vrr_classes[1][4] = int_stack + 2470;
 Libr12->t1vrr_classes[1][5] = int_stack + 2515;
 Libr12->t1vrr_classes[1][6] = int_stack + 2578;
 Libr12->t1vrr_classes[1][7] = int_stack + 2662;
 Libr12->t1vrr_classes[1][8] = int_stack + 2770;
 Libr12->t1vrr_classes[2][4] = int_stack + 2905;
 Libr12->t1vrr_classes[2][5] = int_stack + 2995;
 Libr12->t1vrr_classes[2][6] = int_stack + 3121;
 Libr12->t1vrr_classes[2][7] = int_stack + 3289;
 Libr12->t1vrr_classes[2][8] = int_stack + 3505;
 Libr12->rvrr_classes[1][4] = int_stack + 3775;
 Libr12->rvrr_classes[1][5] = int_stack + 3820;
 Libr12->rvrr_classes[1][6] = int_stack + 3883;
 Libr12->rvrr_classes[1][7] = int_stack + 3967;
 Libr12->rvrr_classes[1][8] = int_stack + 4075;
 Libr12->rvrr_classes[2][4] = int_stack + 4210;
 Libr12->rvrr_classes[2][5] = int_stack + 4300;
 Libr12->rvrr_classes[2][6] = int_stack + 4426;
 Libr12->rvrr_classes[2][7] = int_stack + 4594;
 Libr12->rvrr_classes[2][8] = int_stack + 4810;
 Libr12->gvrr_classes[1][4] = int_stack + 5080;
 Libr12->gvrr_classes[1][5] = int_stack + 5125;
 Libr12->gvrr_classes[1][6] = int_stack + 5188;
 Libr12->gvrr_classes[1][7] = int_stack + 5272;
 Libr12->gvrr_classes[1][8] = int_stack + 5380;
 Libr12->gvrr_classes[2][4] = int_stack + 5515;
 Libr12->gvrr_classes[2][5] = int_stack + 5605;
 Libr12->gvrr_classes[2][6] = int_stack + 5731;
 Libr12->gvrr_classes[2][7] = int_stack + 5899;
 Libr12->gvrr_classes[2][8] = int_stack + 6115;
 memset(int_stack,0,6385*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 6385;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ppgg(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6385, int_stack+5125, int_stack+5080, 3);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6520, int_stack+5188, int_stack+5125, 3);
 /*--- compute (p0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+6709, int_stack+6520, int_stack+6385, 3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+6979, int_stack+5272, int_stack+5188, 3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+7231, int_stack+6979, int_stack+6520, 3);
 /*--- compute (p0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+7609, int_stack+7231, int_stack+6709, 3);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+8059, int_stack+5605, int_stack+5515, 6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+8329, int_stack+5731, int_stack+5605, 6);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8707, int_stack+8329, int_stack+8059, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9247, int_stack+5899, int_stack+5731, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+9751, int_stack+9247, int_stack+8329, 6);
 /*--- compute (d0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+10507, int_stack+9751, int_stack+8707, 6);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+11407, int_stack+5380, int_stack+5272, 3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+11731, int_stack+11407, int_stack+6979, 3);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+12235, int_stack+11731, int_stack+7231, 3);
 /*--- compute (p0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12865, int_stack+45, int_stack+0, int_stack+5125, int_stack+5515, int_stack+5080, 1, 0);
 /*--- compute (p0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13000, int_stack+108, int_stack+45, int_stack+5188, int_stack+5605, int_stack+5125, 1, 0);
 /*--- compute (p0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13189, int_stack+13000, int_stack+12865, int_stack+6520, int_stack+8059, int_stack+6385, 1, 0);
 /*--- compute (p0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13459, int_stack+192, int_stack+108, int_stack+5272, int_stack+5731, int_stack+5188, 1, 0);
 /*--- compute (p0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13711, int_stack+13459, int_stack+13000, int_stack+6979, int_stack+8329, int_stack+6520, 1, 0);
 /*--- compute (p0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14089, int_stack+13711, int_stack+13189, int_stack+7231, int_stack+8707, int_stack+6709, 1, 0);
 /*--- compute (p0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6385, int_stack+300, int_stack+192, int_stack+5380, int_stack+5899, int_stack+5272, 1, 0);
 /*--- compute (p0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12865, int_stack+6385, int_stack+13459, int_stack+11407, int_stack+9247, int_stack+6979, 1, 0);
 /*--- compute (p0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6385, int_stack+12865, int_stack+13711, int_stack+11731, int_stack+9751, int_stack+7231, 1, 0);
 /*--- compute (p0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12865, int_stack+6385, int_stack+14089, int_stack+12235, int_stack+10507, int_stack+7609, 1, 0);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6385, int_stack+675, int_stack+435, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6835, int_stack+1011, int_stack+675, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+13540, int_stack+6835, int_stack+6385, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+14440, int_stack+1459, int_stack+1011, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+15280, int_stack+14440, int_stack+6835, 10);
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+16540, int_stack+15280, int_stack+13540, 10);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+18040, int_stack+6115, int_stack+5899, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+18688, int_stack+18040, int_stack+9247, 6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+19696, int_stack+18688, int_stack+9751, 6);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5080, int_stack+885, int_stack+585, int_stack+5605, int_stack+435, int_stack+5515, 2, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1291, int_stack+885, int_stack+5731, int_stack+675, int_stack+5605, 2, 0);
 /*--- compute (d0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+378, int_stack+0, int_stack+5080, int_stack+8329, int_stack+6385, int_stack+8059, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+20956, int_stack+1819, int_stack+1291, int_stack+5899, int_stack+1011, int_stack+5731, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+21460, int_stack+20956, int_stack+0, int_stack+9247, int_stack+6835, int_stack+8329, 2, 0);
 /*--- compute (d0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6385, int_stack+21460, int_stack+378, int_stack+9751, int_stack+13540, int_stack+8707, 2, 0);
 /*--- compute (d0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13540, int_stack+2035, int_stack+1819, int_stack+6115, int_stack+1459, int_stack+5899, 2, 0);
 /*--- compute (d0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+13540, int_stack+20956, int_stack+18040, int_stack+14440, int_stack+9247, 2, 0);
 /*--- compute (d0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13540, int_stack+0, int_stack+21460, int_stack+18688, int_stack+15280, int_stack+9751, 2, 0);
 /*--- compute (d0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+13540, int_stack+6385, int_stack+19696, int_stack+16540, int_stack+10507, 2, 0);
 /*--- compute (p0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+13540, int_stack+12235, int_stack+7609, 3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+14215, int_stack+2305, int_stack+5380, 3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+14620, int_stack+14215, int_stack+11407, 3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+15268, int_stack+14620, int_stack+11731, 3);
 /*--- compute (p0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+14215, int_stack+15268, int_stack+12235, 3);
 /*--- compute (d0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+11407, int_stack+19696, int_stack+10507, 6);
 /*--- compute (p0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+15160, int_stack+2515, int_stack+2470, 3);
 /*--- compute (p0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15295, int_stack+2578, int_stack+2515, 3);
 /*--- compute (p0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+15484, int_stack+15295, int_stack+15160, 3);
 /*--- compute (p0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+15754, int_stack+2662, int_stack+2578, 3);
 /*--- compute (p0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+16006, int_stack+15754, int_stack+15295, 3);
 /*--- compute (p0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+16384, int_stack+16006, int_stack+15484, 3);
 /*--- compute (p0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+15160, int_stack+2770, int_stack+2662, 3);
 /*--- compute (p0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+16834, int_stack+15160, int_stack+15754, 3);
 /*--- compute (p0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+15160, int_stack+16834, int_stack+16006, 3);
 /*--- compute (p0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+16834, int_stack+15160, int_stack+16384, 3);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+15160, int_stack+2995, int_stack+2905, 6);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15430, int_stack+3121, int_stack+2995, 6);
 /*--- compute (d0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+15808, int_stack+15430, int_stack+15160, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+17509, int_stack+3289, int_stack+3121, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+18013, int_stack+17509, int_stack+15430, 6);
 /*--- compute (d0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+18769, int_stack+18013, int_stack+15808, 6);
 /*--- compute (d0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+15160, int_stack+3505, int_stack+3289, 6);
 /*--- compute (d0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+15808, int_stack+15160, int_stack+17509, 6);
 /*--- compute (d0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+19669, int_stack+15808, int_stack+18013, 6);
 /*--- compute (d0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+15160, int_stack+19669, int_stack+18769, 6);
 /*--- compute (p0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+17509, int_stack+3820, int_stack+3775, 3);
 /*--- compute (p0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+17644, int_stack+3883, int_stack+3820, 3);
 /*--- compute (p0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+17833, int_stack+17644, int_stack+17509, 3);
 /*--- compute (p0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+18103, int_stack+3967, int_stack+3883, 3);
 /*--- compute (p0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+18355, int_stack+18103, int_stack+17644, 3);
 /*--- compute (p0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+18733, int_stack+18355, int_stack+17833, 3);
 /*--- compute (p0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+16510, int_stack+4075, int_stack+3967, 3);
 /*--- compute (p0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+17509, int_stack+16510, int_stack+18103, 3);
 /*--- compute (p0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+19183, int_stack+17509, int_stack+18355, 3);
 /*--- compute (p0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+17509, int_stack+19183, int_stack+18733, 3);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+18184, int_stack+4300, int_stack+4210, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18454, int_stack+4426, int_stack+4300, 6);
 /*--- compute (d0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+18832, int_stack+18454, int_stack+18184, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19372, int_stack+4594, int_stack+4426, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+19876, int_stack+19372, int_stack+18454, 6);
 /*--- compute (d0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+20632, int_stack+19876, int_stack+18832, 6);
 /*--- compute (d0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+18184, int_stack+4810, int_stack+4594, 6);
 /*--- compute (d0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+21532, int_stack+18184, int_stack+19372, 6);
 /*--- compute (d0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+18184, int_stack+21532, int_stack+19876, 6);
 /*--- compute (d0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+21532, int_stack+18184, int_stack+20632, 6);
 /*--- compute (pp|[r12,T2]|gg) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+18184, int_stack+0, int_stack+12865, 225);
     Libr12->te_ptr[3] = int_stack + 18184;
 /*--- compute (pp|[r12,T1]|gg) ---*/
   t1hrr1_build_pp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+0, int_stack+15160, int_stack+16834, int_stack+11407, int_stack+14215, int_stack+13540, 4, 4);
     Libr12->te_ptr[2] = int_stack + 0;
 /*--- compute (pp||gg) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+14215, int_stack+21532, int_stack+17509, 225);
     Libr12->te_ptr[1] = int_stack + 14215;
 /*--- compute (pp|gg) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+2025, int_stack+11407, int_stack+13540, 225);
     Libr12->te_ptr[0] = int_stack + 2025;

}
