/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_pphf(Libr12_t *, prim_data *);

  /* Computes (pp|hf) integrals for linear R12-methods */

void hrr_grt_order_pphf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[1][5] = int_stack + 0;
 Libr12->t2vrr_classes[1][6] = int_stack + 63;
 Libr12->t2vrr_classes[1][7] = int_stack + 147;
 Libr12->t2vrr_classes[1][8] = int_stack + 255;
 Libr12->gvrr_classes[3][5] = int_stack + 390;
 Libr12->t2vrr_classes[2][5] = int_stack + 600;
 Libr12->gvrr_classes[3][6] = int_stack + 726;
 Libr12->t2vrr_classes[2][6] = int_stack + 1006;
 Libr12->gvrr_classes[3][7] = int_stack + 1174;
 Libr12->t2vrr_classes[2][7] = int_stack + 1534;
 Libr12->t2vrr_classes[2][8] = int_stack + 1750;
 Libr12->gvrr_classes[1][9] = int_stack + 2020;
 Libr12->t1vrr_classes[1][5] = int_stack + 2185;
 Libr12->t1vrr_classes[1][6] = int_stack + 2248;
 Libr12->t1vrr_classes[1][7] = int_stack + 2332;
 Libr12->t1vrr_classes[1][8] = int_stack + 2440;
 Libr12->t1vrr_classes[2][5] = int_stack + 2575;
 Libr12->t1vrr_classes[2][6] = int_stack + 2701;
 Libr12->t1vrr_classes[2][7] = int_stack + 2869;
 Libr12->t1vrr_classes[2][8] = int_stack + 3085;
 Libr12->rvrr_classes[1][5] = int_stack + 3355;
 Libr12->rvrr_classes[1][6] = int_stack + 3418;
 Libr12->rvrr_classes[1][7] = int_stack + 3502;
 Libr12->rvrr_classes[1][8] = int_stack + 3610;
 Libr12->rvrr_classes[2][5] = int_stack + 3745;
 Libr12->rvrr_classes[2][6] = int_stack + 3871;
 Libr12->rvrr_classes[2][7] = int_stack + 4039;
 Libr12->rvrr_classes[2][8] = int_stack + 4255;
 Libr12->gvrr_classes[1][5] = int_stack + 4525;
 Libr12->gvrr_classes[1][6] = int_stack + 4588;
 Libr12->gvrr_classes[1][7] = int_stack + 4672;
 Libr12->gvrr_classes[1][8] = int_stack + 4780;
 Libr12->gvrr_classes[2][5] = int_stack + 4915;
 Libr12->gvrr_classes[2][6] = int_stack + 5041;
 Libr12->gvrr_classes[2][7] = int_stack + 5209;
 Libr12->gvrr_classes[2][8] = int_stack + 5425;
 memset(int_stack,0,5695*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 5695;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_pphf(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+5695, int_stack+4588, int_stack+4525, 3);
 /*--- compute (p0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+5884, int_stack+4672, int_stack+4588, 3);
 /*--- compute (p0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+6136, int_stack+5884, int_stack+5695, 3);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+6514, int_stack+5041, int_stack+4915, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+6892, int_stack+5209, int_stack+5041, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+7396, int_stack+6892, int_stack+6514, 6);
 /*--- compute (p0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+8152, int_stack+4780, int_stack+4672, 3);
 /*--- compute (p0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+8476, int_stack+8152, int_stack+5884, 3);
 /*--- compute (p0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8980, int_stack+63, int_stack+0, int_stack+4588, int_stack+4915, int_stack+4525, 1, 0);
 /*--- compute (p0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9169, int_stack+147, int_stack+63, int_stack+4672, int_stack+5041, int_stack+4588, 1, 0);
 /*--- compute (p0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9421, int_stack+9169, int_stack+8980, int_stack+5884, int_stack+6514, int_stack+5695, 1, 0);
 /*--- compute (p0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+9799, int_stack+255, int_stack+147, int_stack+4780, int_stack+5209, int_stack+4672, 1, 0);
 /*--- compute (p0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10123, int_stack+9799, int_stack+9169, int_stack+8152, int_stack+6892, int_stack+5884, 1, 0);
 /*--- compute (p0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10627, int_stack+10123, int_stack+9421, int_stack+8476, int_stack+7396, int_stack+6136, 1, 0);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+8980, int_stack+726, int_stack+390, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9610, int_stack+1174, int_stack+726, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+11257, int_stack+9610, int_stack+8980, 10);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+12517, int_stack+5425, int_stack+5209, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+13165, int_stack+12517, int_stack+6892, 6);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5695, int_stack+1006, int_stack+600, int_stack+5041, int_stack+390, int_stack+4915, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1534, int_stack+1006, int_stack+5209, int_stack+726, int_stack+5041, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14173, int_stack+0, int_stack+5695, int_stack+6892, int_stack+8980, int_stack+6514, 2, 0);
 /*--- compute (d0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+504, int_stack+1750, int_stack+1534, int_stack+5425, int_stack+1174, int_stack+5209, 2, 0);
 /*--- compute (d0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+4915, int_stack+504, int_stack+0, int_stack+12517, int_stack+9610, int_stack+6892, 2, 0);
 /*--- compute (d0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+4915, int_stack+14173, int_stack+13165, int_stack+11257, int_stack+7396, 2, 0);
 /*--- compute (p0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+11257, int_stack+8476, int_stack+6136, 3);
 /*--- compute (p0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+11887, int_stack+2020, int_stack+4780, 3);
 /*--- compute (p0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+12292, int_stack+11887, int_stack+8152, 3);
 /*--- compute (p0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+1260, int_stack+12292, int_stack+8476, 3);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+8152, int_stack+13165, int_stack+7396, 6);
 /*--- compute (p0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9412, int_stack+2248, int_stack+2185, 3);
 /*--- compute (p0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9601, int_stack+2332, int_stack+2248, 3);
 /*--- compute (p0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+9853, int_stack+9601, int_stack+9412, 3);
 /*--- compute (p0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+10231, int_stack+2440, int_stack+2332, 3);
 /*--- compute (p0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+11887, int_stack+10231, int_stack+9601, 3);
 /*--- compute (p0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+12391, int_stack+11887, int_stack+9853, 3);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11887, int_stack+2701, int_stack+2575, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9412, int_stack+2869, int_stack+2701, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+13021, int_stack+9412, int_stack+11887, 6);
 /*--- compute (d0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+9916, int_stack+3085, int_stack+2869, 6);
 /*--- compute (d0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+13777, int_stack+9916, int_stack+9412, 6);
 /*--- compute (d0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+4525, int_stack+13777, int_stack+13021, 6);
 /*--- compute (p0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+13021, int_stack+3418, int_stack+3355, 3);
 /*--- compute (p0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+13210, int_stack+3502, int_stack+3418, 3);
 /*--- compute (p0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+13462, int_stack+13210, int_stack+13021, 3);
 /*--- compute (p0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+13840, int_stack+3610, int_stack+3502, 3);
 /*--- compute (p0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+11887, int_stack+13840, int_stack+13210, 3);
 /*--- compute (p0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+13840, int_stack+11887, int_stack+13462, 3);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11887, int_stack+3871, int_stack+3745, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+14470, int_stack+4039, int_stack+3871, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+13021, int_stack+14470, int_stack+11887, 6);
 /*--- compute (d0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+9412, int_stack+4255, int_stack+4039, 6);
 /*--- compute (d0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+2100, int_stack+9412, int_stack+14470, 6);
 /*--- compute (d0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+3108, int_stack+2100, int_stack+13021, 6);
 /*--- compute (pp|[r12,T2]|hf) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+5785, int_stack+0, int_stack+10627, 210);
     Libr12->te_ptr[3] = int_stack + 5785;
 /*--- compute (pp|[r12,T1]|hf) ---*/
   t1hrr1_build_pp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+14470, int_stack+4525, int_stack+12391, int_stack+8152, int_stack+1260, int_stack+11257, 5, 3);
     Libr12->te_ptr[2] = int_stack + 14470;
 /*--- compute (pp||hf) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+3108, int_stack+13840, 210);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (pp|hf) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+1890, int_stack+8152, int_stack+11257, 210);
     Libr12->te_ptr[0] = int_stack + 1890;

}
