/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_fphf(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+0, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+6, NULL, NULL, r12vrr_stack+0);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+49, r12vrr_stack+12, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+12, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+68, r12vrr_stack+3, r12vrr_stack+12, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+74, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+84, r12vrr_stack+39, r12vrr_stack+74, NULL, NULL, r12vrr_stack+6);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+114, r12vrr_stack+58, r12vrr_stack+39, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+144, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+21);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+204, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+15, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+219, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+234, r12vrr_stack+219, r12vrr_stack+204, NULL, NULL, r12vrr_stack+39);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+279, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+282, r12vrr_stack+279, r12vrr_stack+49, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+52, r12vrr_stack+279, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+58, r12vrr_stack+282, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+313, r12vrr_stack+298, r12vrr_stack+219, NULL, NULL, r12vrr_stack+58);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+12, r12vrr_stack+49, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+358, r12vrr_stack+68, r12vrr_stack+52, r12vrr_stack+3, r12vrr_stack+12, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+368, r12vrr_stack+74, r12vrr_stack+358, r12vrr_stack+6, r12vrr_stack+68, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+383, r12vrr_stack+204, r12vrr_stack+368, NULL, NULL, r12vrr_stack+74);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+428, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+84);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+518, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+114);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+608, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+144);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+758, r12vrr_stack+0, r12vrr_stack+3, NULL, NULL, Data->F+4);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+767, r12vrr_stack+6, r12vrr_stack+68, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+785, r12vrr_stack+21, r12vrr_stack+767, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+758);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+821, r12vrr_stack+74, r12vrr_stack+358, NULL, NULL, r12vrr_stack+68);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+851, r12vrr_stack+84, r12vrr_stack+821, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+767);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+911, r12vrr_stack+144, r12vrr_stack+851, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+785);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+114, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+114, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+117, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+127, r12vrr_stack+358, r12vrr_stack+117, r12vrr_stack+68, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1011, r12vrr_stack+368, r12vrr_stack+127, NULL, NULL, r12vrr_stack+358);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1056, r12vrr_stack+383, r12vrr_stack+1011, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+821);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1146, r12vrr_stack+428, r12vrr_stack+1056, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+851);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1296, r12vrr_stack+608, r12vrr_stack+1146, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+911);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1521, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+39, r12vrr_stack+74, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1542, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+58, r12vrr_stack+39, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1563, r12vrr_stack+368, r12vrr_stack+127, r12vrr_stack+74, r12vrr_stack+358, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1584, r12vrr_stack+1521, r12vrr_stack+1563, NULL, NULL, r12vrr_stack+368);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1647, r12vrr_stack+1542, r12vrr_stack+1521, NULL, NULL, r12vrr_stack+204);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1710, r12vrr_stack+1647, r12vrr_stack+1584, r12vrr_stack+1542, r12vrr_stack+1521, r12vrr_stack+383);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1836, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+288, r12vrr_stack+58, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1857, r12vrr_stack+1836, r12vrr_stack+1542, NULL, NULL, r12vrr_stack+219);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+1647, r12vrr_stack+1836, r12vrr_stack+1542, r12vrr_stack+234);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+234, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+237, r12vrr_stack+114, r12vrr_stack+234, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+15, r12vrr_stack+237, r12vrr_stack+49, r12vrr_stack+114, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+243, r12vrr_stack+117, r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+258, r12vrr_stack+127, r12vrr_stack+243, r12vrr_stack+358, r12vrr_stack+117, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2046, r12vrr_stack+1563, r12vrr_stack+258, NULL, NULL, r12vrr_stack+127);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2109, r12vrr_stack+1584, r12vrr_stack+2046, r12vrr_stack+1521, r12vrr_stack+1563, r12vrr_stack+1011);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2235, r12vrr_stack+1710, r12vrr_stack+2109, r12vrr_stack+1647, r12vrr_stack+1584, r12vrr_stack+1056);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+1710, r12vrr_stack+1857, r12vrr_stack+1647, r12vrr_stack+428);
 tmp = r12vrr_stack + 2445;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+2235, r12vrr_stack+1920, r12vrr_stack+1710, r12vrr_stack+1146);
 tmp = r12vrr_stack + 2655;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2970, r12vrr_stack+1521, r12vrr_stack+1563, r12vrr_stack+204, r12vrr_stack+368, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2998, r12vrr_stack+1542, r12vrr_stack+1521, r12vrr_stack+219, r12vrr_stack+204, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3026, r12vrr_stack+2998, r12vrr_stack+2970, NULL, NULL, r12vrr_stack+1521);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3110, r12vrr_stack+1836, r12vrr_stack+1542, r12vrr_stack+298, r12vrr_stack+219, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3138, r12vrr_stack+3110, r12vrr_stack+2998, NULL, NULL, r12vrr_stack+1542);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+204, r12vrr_stack+1563, r12vrr_stack+258, r12vrr_stack+368, r12vrr_stack+127, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3222, r12vrr_stack+2970, r12vrr_stack+204, NULL, NULL, r12vrr_stack+1563);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3306, r12vrr_stack+3026, r12vrr_stack+3222, r12vrr_stack+2998, r12vrr_stack+2970, r12vrr_stack+1584);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+3026, r12vrr_stack+3110, r12vrr_stack+2998, r12vrr_stack+1647);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+3306, r12vrr_stack+3138, r12vrr_stack+3026, r12vrr_stack+1710);
 tmp = r12vrr_stack + 3642;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1647, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1650, r12vrr_stack+234, r12vrr_stack+1647, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1656, r12vrr_stack+237, r12vrr_stack+1650, r12vrr_stack+114, r12vrr_stack+234, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1666, r12vrr_stack+58, r12vrr_stack+1656, r12vrr_stack+15, r12vrr_stack+237, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1681, r12vrr_stack+243, r12vrr_stack+1666, r12vrr_stack+117, r12vrr_stack+58, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3922, r12vrr_stack+258, r12vrr_stack+1681, r12vrr_stack+127, r12vrr_stack+243, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3950, r12vrr_stack+204, r12vrr_stack+3922, NULL, NULL, r12vrr_stack+258);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4034, r12vrr_stack+3222, r12vrr_stack+3950, r12vrr_stack+2970, r12vrr_stack+204, r12vrr_stack+2046);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4202, r12vrr_stack+3306, r12vrr_stack+4034, r12vrr_stack+3026, r12vrr_stack+3222, r12vrr_stack+2109);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+4202, r12vrr_stack+3474, r12vrr_stack+3306, r12vrr_stack+2235);
 tmp = r12vrr_stack + 4482;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4902, r12vrr_stack+2970, r12vrr_stack+204, r12vrr_stack+1521, r12vrr_stack+1563, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4938, r12vrr_stack+2998, r12vrr_stack+2970, r12vrr_stack+1542, r12vrr_stack+1521, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4974, r12vrr_stack+4938, r12vrr_stack+4902, NULL, NULL, r12vrr_stack+2970);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5082, r12vrr_stack+3110, r12vrr_stack+2998, r12vrr_stack+1836, r12vrr_stack+1542, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5118, r12vrr_stack+5082, r12vrr_stack+4938, NULL, NULL, r12vrr_stack+2998);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1521, r12vrr_stack+204, r12vrr_stack+3922, r12vrr_stack+1563, r12vrr_stack+258, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5226, r12vrr_stack+4902, r12vrr_stack+1521, NULL, NULL, r12vrr_stack+204);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5334, r12vrr_stack+4974, r12vrr_stack+5226, r12vrr_stack+4938, r12vrr_stack+4902, r12vrr_stack+3222);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5550, r12vrr_stack+5118, r12vrr_stack+4974, r12vrr_stack+5082, r12vrr_stack+4938, r12vrr_stack+3026);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+5334, r12vrr_stack+5118, r12vrr_stack+4974, r12vrr_stack+3306);
 tmp = r12vrr_stack + 5766;
 target_ptr = Libr12->gvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+114, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1557, r12vrr_stack+1647, r12vrr_stack+114, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3026, r12vrr_stack+1650, r12vrr_stack+1557, r12vrr_stack+234, r12vrr_stack+1647, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+3036, r12vrr_stack+1656, r12vrr_stack+3026, r12vrr_stack+237, r12vrr_stack+1650, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3051, r12vrr_stack+1666, r12vrr_stack+3036, r12vrr_stack+58, r12vrr_stack+1656, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3072, r12vrr_stack+1681, r12vrr_stack+3051, r12vrr_stack+243, r12vrr_stack+1666, NULL);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6126, r12vrr_stack+3922, r12vrr_stack+3072, r12vrr_stack+258, r12vrr_stack+1681, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6162, r12vrr_stack+1521, r12vrr_stack+6126, NULL, NULL, r12vrr_stack+3922);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6270, r12vrr_stack+5226, r12vrr_stack+6162, r12vrr_stack+4902, r12vrr_stack+1521, r12vrr_stack+3950);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6486, r12vrr_stack+5334, r12vrr_stack+6270, r12vrr_stack+4974, r12vrr_stack+5226, r12vrr_stack+4034);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6846, r12vrr_stack+5766, r12vrr_stack+6486, r12vrr_stack+5550, r12vrr_stack+5334, r12vrr_stack+4202);
 tmp = r12vrr_stack + 6846;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7386, r12vrr_stack+4902, r12vrr_stack+1521, r12vrr_stack+2970, r12vrr_stack+204, NULL);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7431, r12vrr_stack+4938, r12vrr_stack+4902, r12vrr_stack+2998, r12vrr_stack+2970, NULL);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7476, r12vrr_stack+7431, r12vrr_stack+7386, NULL, NULL, r12vrr_stack+4902);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7611, r12vrr_stack+5082, r12vrr_stack+4938, r12vrr_stack+3110, r12vrr_stack+2998, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7656, r12vrr_stack+7611, r12vrr_stack+7431, NULL, NULL, r12vrr_stack+4938);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2970, r12vrr_stack+1521, r12vrr_stack+6126, r12vrr_stack+204, r12vrr_stack+3922, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7791, r12vrr_stack+7386, r12vrr_stack+2970, NULL, NULL, r12vrr_stack+1521);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7926, r12vrr_stack+7476, r12vrr_stack+7791, r12vrr_stack+7431, r12vrr_stack+7386, r12vrr_stack+5226);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8196, r12vrr_stack+7656, r12vrr_stack+7476, r12vrr_stack+7611, r12vrr_stack+7431, r12vrr_stack+4974);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8466, r12vrr_stack+8196, r12vrr_stack+7926, r12vrr_stack+7656, r12vrr_stack+7476, r12vrr_stack+5334);
 tmp = r12vrr_stack + 8466;
 target_ptr = Libr12->gvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+4974, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+114, r12vrr_stack+4974, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+1557, r12vrr_stack+15, r12vrr_stack+1647, r12vrr_stack+114, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+4977, r12vrr_stack+3026, r12vrr_stack+58, r12vrr_stack+1650, r12vrr_stack+1557, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+4992, r12vrr_stack+3036, r12vrr_stack+4977, r12vrr_stack+1656, r12vrr_stack+3026, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5013, r12vrr_stack+3051, r12vrr_stack+4992, r12vrr_stack+1666, r12vrr_stack+3036, NULL);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5041, r12vrr_stack+3072, r12vrr_stack+5013, r12vrr_stack+1681, r12vrr_stack+3051, NULL);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8916, r12vrr_stack+6126, r12vrr_stack+5041, r12vrr_stack+3922, r12vrr_stack+3072, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8961, r12vrr_stack+2970, r12vrr_stack+8916, NULL, NULL, r12vrr_stack+6126);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9096, r12vrr_stack+7791, r12vrr_stack+8961, r12vrr_stack+7386, r12vrr_stack+2970, r12vrr_stack+6162);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9366, r12vrr_stack+7926, r12vrr_stack+9096, r12vrr_stack+7476, r12vrr_stack+7791, r12vrr_stack+6270);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9816, r12vrr_stack+8466, r12vrr_stack+9366, r12vrr_stack+8196, r12vrr_stack+7926, r12vrr_stack+6486);
 tmp = r12vrr_stack + 9816;
 target_ptr = Libr12->gvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10491, r12vrr_stack+7386, r12vrr_stack+2970, r12vrr_stack+4902, r12vrr_stack+1521, NULL);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10546, r12vrr_stack+7431, r12vrr_stack+7386, r12vrr_stack+4938, r12vrr_stack+4902, NULL);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10601, r12vrr_stack+10546, r12vrr_stack+10491, NULL, NULL, r12vrr_stack+7386);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10766, r12vrr_stack+7611, r12vrr_stack+7431, r12vrr_stack+5082, r12vrr_stack+4938, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10821, r12vrr_stack+10766, r12vrr_stack+10546, NULL, NULL, r12vrr_stack+7431);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+7386, r12vrr_stack+2970, r12vrr_stack+8916, r12vrr_stack+1521, r12vrr_stack+6126, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10986, r12vrr_stack+10491, r12vrr_stack+7386, NULL, NULL, r12vrr_stack+2970);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+11151, r12vrr_stack+10601, r12vrr_stack+10986, r12vrr_stack+10546, r12vrr_stack+10491, r12vrr_stack+7791);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+11481, r12vrr_stack+10821, r12vrr_stack+10601, r12vrr_stack+10766, r12vrr_stack+10546, r12vrr_stack+7476);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+11811, r12vrr_stack+11481, r12vrr_stack+11151, r12vrr_stack+10821, r12vrr_stack+10601, r12vrr_stack+7926);
 tmp = r12vrr_stack + 11811;
 target_ptr = Libr12->gvrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+10546, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+10549, r12vrr_stack+3, r12vrr_stack+12, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+10558, r12vrr_stack+758, r12vrr_stack+10549, r12vrr_stack+0, r12vrr_stack+3, r12vrr_stack+10546);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+10576, r12vrr_stack+68, r12vrr_stack+52, NULL, NULL, r12vrr_stack+12);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+10766, r12vrr_stack+767, r12vrr_stack+10576, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+10549);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+10802, r12vrr_stack+785, r12vrr_stack+10766, r12vrr_stack+21, r12vrr_stack+767, r12vrr_stack+10558);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+10546, r12vrr_stack+358, r12vrr_stack+117, NULL, NULL, r12vrr_stack+52);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+758, r12vrr_stack+821, r12vrr_stack+10546, r12vrr_stack+74, r12vrr_stack+358, r12vrr_stack+10576);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+10862, r12vrr_stack+851, r12vrr_stack+758, r12vrr_stack+84, r12vrr_stack+821, r12vrr_stack+10766);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+7441, r12vrr_stack+911, r12vrr_stack+10862, r12vrr_stack+144, r12vrr_stack+851, r12vrr_stack+10802);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+10766, r12vrr_stack+127, r12vrr_stack+243, NULL, NULL, r12vrr_stack+117);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+818, r12vrr_stack+1011, r12vrr_stack+10766, r12vrr_stack+368, r12vrr_stack+127, r12vrr_stack+10546);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+12361, r12vrr_stack+1056, r12vrr_stack+818, r12vrr_stack+383, r12vrr_stack+1011, r12vrr_stack+758);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+12511, r12vrr_stack+1146, r12vrr_stack+12361, r12vrr_stack+428, r12vrr_stack+1056, r12vrr_stack+10862);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+12736, r12vrr_stack+1296, r12vrr_stack+12511, r12vrr_stack+608, r12vrr_stack+1146, r12vrr_stack+7441);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+7441, r12vrr_stack+258, r12vrr_stack+1681, NULL, NULL, r12vrr_stack+243);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+10811, r12vrr_stack+2046, r12vrr_stack+7441, r12vrr_stack+1563, r12vrr_stack+258, r12vrr_stack+10766);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+908, r12vrr_stack+2109, r12vrr_stack+10811, r12vrr_stack+1584, r12vrr_stack+2046, r12vrr_stack+818);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+13051, r12vrr_stack+2235, r12vrr_stack+908, r12vrr_stack+1710, r12vrr_stack+2109, r12vrr_stack+12361);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+13366, r12vrr_stack+2655, r12vrr_stack+13051, r12vrr_stack+2445, r12vrr_stack+2235, r12vrr_stack+12511);
 tmp = r12vrr_stack + 13366;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+12361, r12vrr_stack+3922, r12vrr_stack+3072, NULL, NULL, r12vrr_stack+1681);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+12445, r12vrr_stack+3950, r12vrr_stack+12361, r12vrr_stack+204, r12vrr_stack+3922, r12vrr_stack+7441);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2046, r12vrr_stack+4034, r12vrr_stack+12445, r12vrr_stack+3222, r12vrr_stack+3950, r12vrr_stack+10811);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+13807, r12vrr_stack+4202, r12vrr_stack+2046, r12vrr_stack+3306, r12vrr_stack+4034, r12vrr_stack+908);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+14227, r12vrr_stack+4482, r12vrr_stack+13807, r12vrr_stack+3642, r12vrr_stack+4202, r12vrr_stack+13051);
 tmp = r12vrr_stack + 14227;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+13051, r12vrr_stack+6126, r12vrr_stack+5041, NULL, NULL, r12vrr_stack+3072);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3222, r12vrr_stack+6162, r12vrr_stack+13051, r12vrr_stack+1521, r12vrr_stack+6126, r12vrr_stack+12361);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3922, r12vrr_stack+6270, r12vrr_stack+3222, r12vrr_stack+5226, r12vrr_stack+6162, r12vrr_stack+12445);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+14815, r12vrr_stack+6486, r12vrr_stack+3922, r12vrr_stack+5334, r12vrr_stack+6270, r12vrr_stack+2046);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+15355, r12vrr_stack+6846, r12vrr_stack+14815, r12vrr_stack+5766, r12vrr_stack+6486, r12vrr_stack+13807);
 tmp = r12vrr_stack + 15355;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+13807, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+13810, r12vrr_stack+4974, r12vrr_stack+13807, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3100, r12vrr_stack+15, r12vrr_stack+13810, r12vrr_stack+114, r12vrr_stack+4974, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+58, r12vrr_stack+3100, r12vrr_stack+1557, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+15, r12vrr_stack+4977, r12vrr_stack+0, r12vrr_stack+3026, r12vrr_stack+58, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+36, r12vrr_stack+4992, r12vrr_stack+15, r12vrr_stack+3036, r12vrr_stack+4977, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+0, r12vrr_stack+5013, r12vrr_stack+36, r12vrr_stack+3051, r12vrr_stack+4992, NULL);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+36, r12vrr_stack+5041, r12vrr_stack+0, r12vrr_stack+3072, r12vrr_stack+5013, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+81, r12vrr_stack+8916, r12vrr_stack+36, NULL, NULL, r12vrr_stack+5041);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13807, r12vrr_stack+8961, r12vrr_stack+81, r12vrr_stack+2970, r12vrr_stack+8916, r12vrr_stack+13051);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6162, r12vrr_stack+9096, r12vrr_stack+13807, r12vrr_stack+7791, r12vrr_stack+8961, r12vrr_stack+3222);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16111, r12vrr_stack+9366, r12vrr_stack+6162, r12vrr_stack+7926, r12vrr_stack+9096, r12vrr_stack+3922);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+16786, r12vrr_stack+9816, r12vrr_stack+16111, r12vrr_stack+8466, r12vrr_stack+9366, r12vrr_stack+14815);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10546, r12vrr_stack+8916, r12vrr_stack+36, r12vrr_stack+6126, r12vrr_stack+5041, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+6126, r12vrr_stack+7386, r12vrr_stack+10546, NULL, NULL, r12vrr_stack+8916);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+6291, r12vrr_stack+10986, r12vrr_stack+6126, r12vrr_stack+10491, r12vrr_stack+7386, r12vrr_stack+8961);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+16111, r12vrr_stack+11151, r12vrr_stack+6291, r12vrr_stack+10601, r12vrr_stack+10986, r12vrr_stack+9096);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+17731, r12vrr_stack+11811, r12vrr_stack+16111, r12vrr_stack+11481, r12vrr_stack+11151, r12vrr_stack+9366);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+16111, &(Data->ss_r12_ss), NULL, r12vrr_stack+279, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+16114, r12vrr_stack+16111, &(Data->ss_r12_ss), r12vrr_stack+282, r12vrr_stack+279, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+16120, r12vrr_stack+16114, r12vrr_stack+16111, r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+279, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+16130, r12vrr_stack+16120, r12vrr_stack+16114, r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+282, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+16145, r12vrr_stack+16130, r12vrr_stack+16120, r12vrr_stack+1836, r12vrr_stack+298, r12vrr_stack+288, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+16166, r12vrr_stack+16145, NULL, r12vrr_stack+1857, r12vrr_stack+1836, NULL, r12vrr_stack+298);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+16229, r12vrr_stack+16166, r12vrr_stack+16145, r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+1836, r12vrr_stack+313);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+16355, r12vrr_stack+16229, r12vrr_stack+16166, r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+518);
 tmp = r12vrr_stack + 16355;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+16166, r12vrr_stack+16145, r12vrr_stack+16130, r12vrr_stack+3110, r12vrr_stack+1836, r12vrr_stack+298, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+16565, r12vrr_stack+16166, NULL, r12vrr_stack+3138, r12vrr_stack+3110, NULL, r12vrr_stack+1836);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+7386, r12vrr_stack+16565, r12vrr_stack+16166, r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+3110, r12vrr_stack+1857);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+10491, r12vrr_stack+7386, r12vrr_stack+16565, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+1920);
 tmp = r12vrr_stack + 10491;
 target_ptr = Libr12->rvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+16565, r12vrr_stack+16166, r12vrr_stack+16145, r12vrr_stack+5082, r12vrr_stack+3110, r12vrr_stack+1836, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+16601, r12vrr_stack+16565, NULL, r12vrr_stack+5118, r12vrr_stack+5082, NULL, r12vrr_stack+3110);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+10771, r12vrr_stack+16601, r12vrr_stack+16565, r12vrr_stack+5550, r12vrr_stack+5118, r12vrr_stack+5082, r12vrr_stack+3138);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+10987, r12vrr_stack+10771, r12vrr_stack+16601, r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+5118, r12vrr_stack+3474);
 tmp = r12vrr_stack + 10987;
 target_ptr = Libr12->rvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+16601, r12vrr_stack+16565, r12vrr_stack+16166, r12vrr_stack+7611, r12vrr_stack+5082, r12vrr_stack+3110, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+16646, r12vrr_stack+16601, NULL, r12vrr_stack+7656, r12vrr_stack+7611, NULL, r12vrr_stack+5082);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+6126, r12vrr_stack+16646, r12vrr_stack+16601, r12vrr_stack+8196, r12vrr_stack+7656, r12vrr_stack+7611, r12vrr_stack+5118);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+6396, r12vrr_stack+6126, r12vrr_stack+16646, r12vrr_stack+8466, r12vrr_stack+8196, r12vrr_stack+7656, r12vrr_stack+5550);
 tmp = r12vrr_stack + 6396;
 target_ptr = Libr12->rvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+16565, r12vrr_stack+2445, r12vrr_stack+3642, r12vrr_stack+2655, r12vrr_stack+1296, r12vrr_stack+608);
 tmp = r12vrr_stack + 16565;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7554, r12vrr_stack+3642, r12vrr_stack+5766, r12vrr_stack+4482, r12vrr_stack+2655, r12vrr_stack+2445);
 tmp = r12vrr_stack + 7554;
 target_ptr = Libr12->t2vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_f0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+7834, r12vrr_stack+5766, r12vrr_stack+8466, r12vrr_stack+6846, r12vrr_stack+4482, r12vrr_stack+3642);
 tmp = r12vrr_stack + 7834;
 target_ptr = Libr12->t2vrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_f0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8916, r12vrr_stack+8466, r12vrr_stack+11811, r12vrr_stack+9816, r12vrr_stack+6846, r12vrr_stack+5766);
 tmp = r12vrr_stack + 8916;
 target_ptr = Libr12->t2vrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+13051, r12vrr_stack+2655, r12vrr_stack+4482, r12vrr_stack+13366, r12vrr_stack+12736, r12vrr_stack+1296);
 tmp = r12vrr_stack + 13051;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+13807, r12vrr_stack+4482, r12vrr_stack+6846, r12vrr_stack+14227, r12vrr_stack+13366, r12vrr_stack+2655);
 tmp = r12vrr_stack + 13807;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14815, r12vrr_stack+6846, r12vrr_stack+9816, r12vrr_stack+15355, r12vrr_stack+14227, r12vrr_stack+4482);
 tmp = r12vrr_stack + 14815;
 target_ptr = Libr12->t2vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+12361, r12vrr_stack+9816, r12vrr_stack+17731, r12vrr_stack+16786, r12vrr_stack+15355, r12vrr_stack+6846);
 tmp = r12vrr_stack + 12361;
 target_ptr = Libr12->t2vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9366, r12vrr_stack+2445, r12vrr_stack+2655, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+1920);
 tmp = r12vrr_stack + 9366;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3922, r12vrr_stack+3642, r12vrr_stack+4482, r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+3474);
 tmp = r12vrr_stack + 3922;
 target_ptr = Libr12->t1vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_f0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2970, r12vrr_stack+5766, r12vrr_stack+6846, r12vrr_stack+8466, r12vrr_stack+8196, r12vrr_stack+5550);
 tmp = r12vrr_stack + 2970;
 target_ptr = Libr12->t1vrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_f0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+8466, r12vrr_stack+9816, r12vrr_stack+11811, r12vrr_stack+11481, r12vrr_stack+8196);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t1vrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+11347, r12vrr_stack+2655, r12vrr_stack+13366, r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+2445);
 tmp = r12vrr_stack + 11347;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+13366, r12vrr_stack+4482, r12vrr_stack+14227, r12vrr_stack+6846, r12vrr_stack+5766, r12vrr_stack+3642);
 tmp = r12vrr_stack + 13366;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14227, r12vrr_stack+6846, r12vrr_stack+15355, r12vrr_stack+9816, r12vrr_stack+8466, r12vrr_stack+5766);
 tmp = r12vrr_stack + 14227;
 target_ptr = Libr12->t1vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+15355, r12vrr_stack+9816, r12vrr_stack+16786, r12vrr_stack+17731, r12vrr_stack+11811, r12vrr_stack+8466);
 tmp = r12vrr_stack + 15355;
 target_ptr = Libr12->t1vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+16775, r12vrr_stack+16355, r12vrr_stack+16229, r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+608);
 tmp = r12vrr_stack + 16775;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+16030, r12vrr_stack+10491, r12vrr_stack+7386, r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+2445);
 tmp = r12vrr_stack + 16030;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+17090, r12vrr_stack+10987, r12vrr_stack+10771, r12vrr_stack+6846, r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+3642);
 tmp = r12vrr_stack + 17090;
 target_ptr = Libr12->rvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+6846, r12vrr_stack+6396, r12vrr_stack+6126, r12vrr_stack+9816, r12vrr_stack+8466, r12vrr_stack+8196, r12vrr_stack+5766);
 tmp = r12vrr_stack + 6846;
 target_ptr = Libr12->rvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];


}

