/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_g0fd(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (p0|00)^2 ---*/
 _BUILD_p000(Data,r12vrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (d0|00)^2 ---*/
 _BUILD_d000(Data,r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+15, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+18, r12vrr_stack+15, r12vrr_stack+12, NULL, NULL, Data->F+3);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+27, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (p0|p0)^1 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+30, r12vrr_stack+27, r12vrr_stack+15, NULL, NULL, Data->F+2);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+39, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+42, r12vrr_stack+12, r12vrr_stack+39, NULL, NULL, Data->F+4);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+51, r12vrr_stack+18, r12vrr_stack+42, r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0);

 /*--- compute (d0|p0)^1 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+69, r12vrr_stack+30, r12vrr_stack+18, r12vrr_stack+27, r12vrr_stack+15, r12vrr_stack+3);

 /*--- compute (f0|p0)^1 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+87, r12vrr_stack+69, r12vrr_stack+51, r12vrr_stack+30, r12vrr_stack+18, r12vrr_stack+6);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+117, r12vrr_stack+15, r12vrr_stack+12, Data->F+2, Data->F+3, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+123, r12vrr_stack+27, r12vrr_stack+15, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+129, r12vrr_stack+12, r12vrr_stack+39, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+135, r12vrr_stack+117, r12vrr_stack+129, NULL, NULL, r12vrr_stack+12);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+153, r12vrr_stack+123, r12vrr_stack+117, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+171, r12vrr_stack+153, r12vrr_stack+135, r12vrr_stack+123, r12vrr_stack+117, r12vrr_stack+18);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+207, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+210, r12vrr_stack+207, r12vrr_stack+27, Data->F+0, Data->F+1, NULL);

 /*--- compute (p0|d0)^0 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+216, r12vrr_stack+210, r12vrr_stack+123, NULL, NULL, r12vrr_stack+27);

 /*--- compute (d0|d0)^0 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+234, r12vrr_stack+216, r12vrr_stack+153, r12vrr_stack+210, r12vrr_stack+123, r12vrr_stack+30);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+30, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+33, r12vrr_stack+39, r12vrr_stack+30, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+270, r12vrr_stack+129, r12vrr_stack+33, NULL, NULL, r12vrr_stack+39);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+288, r12vrr_stack+135, r12vrr_stack+270, r12vrr_stack+117, r12vrr_stack+129, r12vrr_stack+42);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+324, r12vrr_stack+171, r12vrr_stack+288, r12vrr_stack+153, r12vrr_stack+135, r12vrr_stack+51);

 /*--- compute (f0|d0)^0 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+384, r12vrr_stack+234, r12vrr_stack+171, r12vrr_stack+216, r12vrr_stack+153, r12vrr_stack+69);

 /*--- compute (g0|d0)^0 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+444, r12vrr_stack+384, r12vrr_stack+324, r12vrr_stack+234, r12vrr_stack+171, r12vrr_stack+87);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+534, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (d0|00)^3 ---*/
 _BUILD_d000(Data,r12vrr_stack+537, r12vrr_stack+0, r12vrr_stack+534, Data->F+3, Data->F+4, NULL);

 /*--- compute (f0|00)^2 ---*/
 _BUILD_f000(Data,r12vrr_stack+543, r12vrr_stack+6, r12vrr_stack+537, r12vrr_stack+3, r12vrr_stack+0, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+0, r12vrr_stack+39, r12vrr_stack+30, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+553, r12vrr_stack+42, r12vrr_stack+0, r12vrr_stack+12, r12vrr_stack+39, r12vrr_stack+534);

 /*--- compute (f0|p0)^2 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+571, r12vrr_stack+51, r12vrr_stack+553, r12vrr_stack+18, r12vrr_stack+42, r12vrr_stack+537);

 /*--- compute (g0|p0)^1 ---*/
 _BUILD_g0p0(Data,r12vrr_stack+601, r12vrr_stack+87, r12vrr_stack+571, r12vrr_stack+69, r12vrr_stack+51, r12vrr_stack+543);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+42, r12vrr_stack+30, r12vrr_stack+9, Data->F+5, Data->F+6, NULL);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+48, r12vrr_stack+33, r12vrr_stack+42, NULL, NULL, r12vrr_stack+30);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+66, r12vrr_stack+270, r12vrr_stack+48, r12vrr_stack+129, r12vrr_stack+33, r12vrr_stack+0);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+646, r12vrr_stack+288, r12vrr_stack+66, r12vrr_stack+135, r12vrr_stack+270, r12vrr_stack+553);

 /*--- compute (g0|d0)^1 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+706, r12vrr_stack+324, r12vrr_stack+646, r12vrr_stack+171, r12vrr_stack+288, r12vrr_stack+571);

 /*--- compute (h0|d0)^0 ---*/
 _BUILD_h0d0(Data,r12vrr_stack+796, r12vrr_stack+444, r12vrr_stack+706, r12vrr_stack+384, r12vrr_stack+324, r12vrr_stack+601);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+102, r12vrr_stack+129, r12vrr_stack+33, r12vrr_stack+12, r12vrr_stack+39, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+534, r12vrr_stack+117, r12vrr_stack+129, r12vrr_stack+15, r12vrr_stack+12, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+544, r12vrr_stack+534, r12vrr_stack+102, NULL, NULL, r12vrr_stack+129);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+574, r12vrr_stack+123, r12vrr_stack+117, r12vrr_stack+27, r12vrr_stack+15, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+584, r12vrr_stack+574, r12vrr_stack+534, NULL, NULL, r12vrr_stack+117);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+12, r12vrr_stack+33, r12vrr_stack+42, r12vrr_stack+39, r12vrr_stack+30, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+614, r12vrr_stack+102, r12vrr_stack+12, NULL, NULL, r12vrr_stack+33);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+922, r12vrr_stack+544, r12vrr_stack+614, r12vrr_stack+534, r12vrr_stack+102, r12vrr_stack+270);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+982, r12vrr_stack+584, r12vrr_stack+544, r12vrr_stack+574, r12vrr_stack+534, r12vrr_stack+135);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1042, r12vrr_stack+982, r12vrr_stack+922, r12vrr_stack+584, r12vrr_stack+544, r12vrr_stack+288);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+135, r12vrr_stack+210, r12vrr_stack+123, r12vrr_stack+207, r12vrr_stack+27, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+270, r12vrr_stack+135, r12vrr_stack+574, NULL, NULL, r12vrr_stack+123);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1142, r12vrr_stack+270, r12vrr_stack+584, r12vrr_stack+135, r12vrr_stack+574, r12vrr_stack+153);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1202, r12vrr_stack+1142, r12vrr_stack+982, r12vrr_stack+270, r12vrr_stack+584, r12vrr_stack+171);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+39, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+145, r12vrr_stack+9, r12vrr_stack+39, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+151, r12vrr_stack+42, r12vrr_stack+145, r12vrr_stack+30, r12vrr_stack+9, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+161, r12vrr_stack+12, r12vrr_stack+151, NULL, NULL, r12vrr_stack+42);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+1302, r12vrr_stack+614, r12vrr_stack+161, r12vrr_stack+102, r12vrr_stack+12, r12vrr_stack+48);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1362, r12vrr_stack+922, r12vrr_stack+1302, r12vrr_stack+544, r12vrr_stack+614, r12vrr_stack+66);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1462, r12vrr_stack+1042, r12vrr_stack+1362, r12vrr_stack+982, r12vrr_stack+922, r12vrr_stack+646);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1612, r12vrr_stack+1202, r12vrr_stack+1042, r12vrr_stack+1142, r12vrr_stack+982, r12vrr_stack+324);
 tmp = r12vrr_stack + 1612;
 target_ptr = Libr12->gvrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|f0)^0 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+1762, r12vrr_stack+1612, r12vrr_stack+1462, r12vrr_stack+1202, r12vrr_stack+1042, r12vrr_stack+706);
 tmp = r12vrr_stack + 1762;
 target_ptr = Libr12->gvrr_classes[5][3];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+48, r12vrr_stack+534, r12vrr_stack+102, r12vrr_stack+117, r12vrr_stack+129, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+63, r12vrr_stack+574, r12vrr_stack+534, r12vrr_stack+123, r12vrr_stack+117, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+78, r12vrr_stack+102, r12vrr_stack+12, r12vrr_stack+129, r12vrr_stack+33, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+300, r12vrr_stack+48, r12vrr_stack+78, NULL, NULL, r12vrr_stack+102);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+644, r12vrr_stack+63, r12vrr_stack+48, NULL, NULL, r12vrr_stack+534);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+689, r12vrr_stack+644, r12vrr_stack+300, r12vrr_stack+63, r12vrr_stack+48, r12vrr_stack+544);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+544, r12vrr_stack+135, r12vrr_stack+574, r12vrr_stack+210, r12vrr_stack+123, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1972, r12vrr_stack+544, r12vrr_stack+63, NULL, NULL, r12vrr_stack+574);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2017, r12vrr_stack+1972, r12vrr_stack+644, r12vrr_stack+544, r12vrr_stack+63, r12vrr_stack+584);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+559, r12vrr_stack+12, r12vrr_stack+151, r12vrr_stack+33, r12vrr_stack+42, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+2107, r12vrr_stack+78, r12vrr_stack+559, NULL, NULL, r12vrr_stack+12);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2152, r12vrr_stack+300, r12vrr_stack+2107, r12vrr_stack+48, r12vrr_stack+78, r12vrr_stack+614);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2242, r12vrr_stack+689, r12vrr_stack+2152, r12vrr_stack+644, r12vrr_stack+300, r12vrr_stack+922);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2392, r12vrr_stack+2017, r12vrr_stack+689, r12vrr_stack+1972, r12vrr_stack+644, r12vrr_stack+982);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2542, r12vrr_stack+2392, r12vrr_stack+2242, r12vrr_stack+2017, r12vrr_stack+689, r12vrr_stack+1042);
 tmp = r12vrr_stack + 2542;
 target_ptr = Libr12->gvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+922, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+925, r12vrr_stack+39, r12vrr_stack+922, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+931, r12vrr_stack+145, r12vrr_stack+925, r12vrr_stack+9, r12vrr_stack+39, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+941, r12vrr_stack+151, r12vrr_stack+931, r12vrr_stack+42, r12vrr_stack+145, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+956, r12vrr_stack+559, r12vrr_stack+941, NULL, NULL, r12vrr_stack+151);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1001, r12vrr_stack+2107, r12vrr_stack+956, r12vrr_stack+78, r12vrr_stack+559, r12vrr_stack+161);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2767, r12vrr_stack+2152, r12vrr_stack+1001, r12vrr_stack+300, r12vrr_stack+2107, r12vrr_stack+1302);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2917, r12vrr_stack+2242, r12vrr_stack+2767, r12vrr_stack+689, r12vrr_stack+2152, r12vrr_stack+1362);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+3142, r12vrr_stack+2542, r12vrr_stack+2917, r12vrr_stack+2392, r12vrr_stack+2242, r12vrr_stack+1462);
 tmp = r12vrr_stack + 3142;
 target_ptr = Libr12->gvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1302, r12vrr_stack+48, r12vrr_stack+78, r12vrr_stack+534, r12vrr_stack+102, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1323, r12vrr_stack+63, r12vrr_stack+48, r12vrr_stack+574, r12vrr_stack+534, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1344, r12vrr_stack+78, r12vrr_stack+559, r12vrr_stack+102, r12vrr_stack+12, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1365, r12vrr_stack+1302, r12vrr_stack+1344, NULL, NULL, r12vrr_stack+78);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1428, r12vrr_stack+1323, r12vrr_stack+1302, NULL, NULL, r12vrr_stack+48);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3457, r12vrr_stack+1428, r12vrr_stack+1365, r12vrr_stack+1323, r12vrr_stack+1302, r12vrr_stack+300);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+300, r12vrr_stack+544, r12vrr_stack+63, r12vrr_stack+135, r12vrr_stack+574, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+321, r12vrr_stack+300, r12vrr_stack+1323, NULL, NULL, r12vrr_stack+63);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3583, r12vrr_stack+321, r12vrr_stack+1428, r12vrr_stack+300, r12vrr_stack+1323, r12vrr_stack+644);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+574, r12vrr_stack+559, r12vrr_stack+941, r12vrr_stack+12, r12vrr_stack+151, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+595, r12vrr_stack+1344, r12vrr_stack+574, NULL, NULL, r12vrr_stack+559);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3709, r12vrr_stack+1365, r12vrr_stack+595, r12vrr_stack+1302, r12vrr_stack+1344, r12vrr_stack+2107);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3835, r12vrr_stack+3457, r12vrr_stack+3709, r12vrr_stack+1428, r12vrr_stack+1365, r12vrr_stack+2152);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4045, r12vrr_stack+3583, r12vrr_stack+3457, r12vrr_stack+321, r12vrr_stack+1428, r12vrr_stack+689);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4255, r12vrr_stack+4045, r12vrr_stack+3835, r12vrr_stack+3583, r12vrr_stack+3457, r12vrr_stack+2242);
 tmp = r12vrr_stack + 4255;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+2107, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+42, r12vrr_stack+922, r12vrr_stack+2107, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+534, r12vrr_stack+925, r12vrr_stack+42, r12vrr_stack+39, r12vrr_stack+922, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+2107, r12vrr_stack+931, r12vrr_stack+534, r12vrr_stack+145, r12vrr_stack+925, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+2122, r12vrr_stack+941, r12vrr_stack+2107, r12vrr_stack+151, r12vrr_stack+931, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2143, r12vrr_stack+574, r12vrr_stack+2122, NULL, NULL, r12vrr_stack+941);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2206, r12vrr_stack+595, r12vrr_stack+2143, r12vrr_stack+1344, r12vrr_stack+574, r12vrr_stack+956);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4570, r12vrr_stack+3709, r12vrr_stack+2206, r12vrr_stack+1365, r12vrr_stack+595, r12vrr_stack+1001);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4780, r12vrr_stack+3835, r12vrr_stack+4570, r12vrr_stack+3457, r12vrr_stack+3709, r12vrr_stack+2767);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+5095, r12vrr_stack+4255, r12vrr_stack+4780, r12vrr_stack+4045, r12vrr_stack+3835, r12vrr_stack+2917);

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2767, r12vrr_stack+1302, r12vrr_stack+1344, r12vrr_stack+48, r12vrr_stack+78, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2795, r12vrr_stack+1323, r12vrr_stack+1302, r12vrr_stack+63, r12vrr_stack+48, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2823, r12vrr_stack+1344, r12vrr_stack+574, r12vrr_stack+78, r12vrr_stack+559, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2851, r12vrr_stack+2767, r12vrr_stack+2823, NULL, NULL, r12vrr_stack+1344);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2935, r12vrr_stack+2795, r12vrr_stack+2767, NULL, NULL, r12vrr_stack+1302);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4570, r12vrr_stack+2935, r12vrr_stack+2851, r12vrr_stack+2795, r12vrr_stack+2767, r12vrr_stack+1365);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1344, r12vrr_stack+300, r12vrr_stack+1323, r12vrr_stack+544, r12vrr_stack+63, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3019, r12vrr_stack+1344, r12vrr_stack+2795, NULL, NULL, r12vrr_stack+1323);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4738, r12vrr_stack+3019, r12vrr_stack+2935, r12vrr_stack+1344, r12vrr_stack+2795, r12vrr_stack+1428);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2795, r12vrr_stack+574, r12vrr_stack+2122, r12vrr_stack+559, r12vrr_stack+941, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1302, r12vrr_stack+2823, r12vrr_stack+2795, NULL, NULL, r12vrr_stack+574);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+1386, r12vrr_stack+2851, r12vrr_stack+1302, r12vrr_stack+2767, r12vrr_stack+2823, r12vrr_stack+595);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+2107, r12vrr_stack+4570, r12vrr_stack+1386, r12vrr_stack+2935, r12vrr_stack+2851, r12vrr_stack+3709);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+1302, r12vrr_stack+4738, r12vrr_stack+4570, r12vrr_stack+3019, r12vrr_stack+2935, r12vrr_stack+3457);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+5536, r12vrr_stack+1302, r12vrr_stack+2107, r12vrr_stack+4738, r12vrr_stack+4570, r12vrr_stack+3835);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+4570, &(Data->ss_r12_ss), NULL, r12vrr_stack+207, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+4573, r12vrr_stack+4570, &(Data->ss_r12_ss), r12vrr_stack+210, r12vrr_stack+207, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+534, r12vrr_stack+4573, r12vrr_stack+4570, r12vrr_stack+135, r12vrr_stack+210, r12vrr_stack+207, NULL);

 /*--- compute (p0||f0)^0 ---*/
 _R_BUILD_p0f0(Data,r12vrr_stack+1582, r12vrr_stack+534, NULL, r12vrr_stack+270, r12vrr_stack+135, NULL, r12vrr_stack+210);

 /*--- compute (d0||f0)^0 ---*/
 _R_BUILD_d0f0(Data,r12vrr_stack+4579, r12vrr_stack+1582, r12vrr_stack+534, r12vrr_stack+1142, r12vrr_stack+270, r12vrr_stack+135, r12vrr_stack+216);

 /*--- compute (f0||f0)^0 ---*/
 _R_BUILD_f0f0(Data,r12vrr_stack+4639, r12vrr_stack+4579, r12vrr_stack+1582, r12vrr_stack+1202, r12vrr_stack+1142, r12vrr_stack+270, r12vrr_stack+234);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+1582, r12vrr_stack+534, r12vrr_stack+4573, r12vrr_stack+544, r12vrr_stack+135, r12vrr_stack+210, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+5956, r12vrr_stack+1582, NULL, r12vrr_stack+1972, r12vrr_stack+544, NULL, r12vrr_stack+135);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+4739, r12vrr_stack+5956, r12vrr_stack+1582, r12vrr_stack+2017, r12vrr_stack+1972, r12vrr_stack+544, r12vrr_stack+270);

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+4829, r12vrr_stack+4739, r12vrr_stack+5956, r12vrr_stack+2392, r12vrr_stack+2017, r12vrr_stack+1972, r12vrr_stack+1142);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+5956, r12vrr_stack+1582, r12vrr_stack+534, r12vrr_stack+300, r12vrr_stack+544, r12vrr_stack+135, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+5977, r12vrr_stack+5956, NULL, r12vrr_stack+321, r12vrr_stack+300, NULL, r12vrr_stack+544);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+3457, r12vrr_stack+5977, r12vrr_stack+5956, r12vrr_stack+3583, r12vrr_stack+321, r12vrr_stack+300, r12vrr_stack+1972);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+534, r12vrr_stack+3457, r12vrr_stack+5977, r12vrr_stack+4045, r12vrr_stack+3583, r12vrr_stack+321, r12vrr_stack+2017);

 /*--- compute (g0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_g0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+5956, r12vrr_stack+1612, r12vrr_stack+2542, r12vrr_stack+1762, r12vrr_stack+796, r12vrr_stack+444);
 tmp = r12vrr_stack + 5956;
 target_ptr = Libr12->t2vrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6106, r12vrr_stack+2542, r12vrr_stack+4255, r12vrr_stack+3142, r12vrr_stack+1762, r12vrr_stack+1612);
 tmp = r12vrr_stack + 6106;
 target_ptr = Libr12->t2vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+744, r12vrr_stack+4255, r12vrr_stack+5536, r12vrr_stack+5095, r12vrr_stack+3142, r12vrr_stack+2542);
 tmp = r12vrr_stack + 744;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_g0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6331, r12vrr_stack+1612, r12vrr_stack+1762, r12vrr_stack+2542, r12vrr_stack+2392, r12vrr_stack+1202);
 tmp = r12vrr_stack + 6331;
 target_ptr = Libr12->t1vrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1762, r12vrr_stack+2542, r12vrr_stack+3142, r12vrr_stack+4255, r12vrr_stack+4045, r12vrr_stack+2392);
 tmp = r12vrr_stack + 1762;
 target_ptr = Libr12->t1vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+3709, r12vrr_stack+4255, r12vrr_stack+5095, r12vrr_stack+5536, r12vrr_stack+1302, r12vrr_stack+4045);
 tmp = r12vrr_stack + 3709;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||f0)^0 ---*/
 _R_BUILD_g0f0(Data,r12vrr_stack+1302, r12vrr_stack+4639, r12vrr_stack+4579, r12vrr_stack+1612, r12vrr_stack+1202, r12vrr_stack+1142, r12vrr_stack+384);
 tmp = r12vrr_stack + 1302;
 target_ptr = Libr12->rvrr_classes[4][3];
 for(i=0;i<150;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||g0)^0 ---*/
 _R_BUILD_g0g0(Data,r12vrr_stack+1452, r12vrr_stack+4829, r12vrr_stack+4739, r12vrr_stack+2542, r12vrr_stack+2392, r12vrr_stack+2017, r12vrr_stack+1202);
 tmp = r12vrr_stack + 1452;
 target_ptr = Libr12->rvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+2542, r12vrr_stack+534, r12vrr_stack+3457, r12vrr_stack+4255, r12vrr_stack+4045, r12vrr_stack+3583, r12vrr_stack+2392);
 tmp = r12vrr_stack + 2542;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];


}

