/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_g0gg(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (p0|00)^3 ---*/
 _BUILD_p000(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+12, r12vrr_stack+3, r12vrr_stack+9, NULL, NULL, Data->F+4);

 /*--- compute (p0|p0)^2 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+21, r12vrr_stack+6, r12vrr_stack+3, NULL, NULL, Data->F+3);

 /*--- compute (d0|p0)^2 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+30, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+6, r12vrr_stack+3, r12vrr_stack+0);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+48, r12vrr_stack+3, r12vrr_stack+9, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+54, r12vrr_stack+6, r12vrr_stack+3, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+60, r12vrr_stack+54, r12vrr_stack+48, NULL, NULL, r12vrr_stack+3);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+81, r12vrr_stack+78, r12vrr_stack+6, Data->F+1, Data->F+2, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+87, r12vrr_stack+81, r12vrr_stack+54, NULL, NULL, r12vrr_stack+6);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+105, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+108, r12vrr_stack+9, r12vrr_stack+105, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+114, r12vrr_stack+48, r12vrr_stack+108, NULL, NULL, r12vrr_stack+9);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+132, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+12);

 /*--- compute (d0|d0)^1 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+168, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+21);

 /*--- compute (f0|d0)^1 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+204, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+87, r12vrr_stack+60, r12vrr_stack+30);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+264, r12vrr_stack+54, r12vrr_stack+48, r12vrr_stack+6, r12vrr_stack+3, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+274, r12vrr_stack+81, r12vrr_stack+54, r12vrr_stack+78, r12vrr_stack+6, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+284, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+3, r12vrr_stack+9, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+294, r12vrr_stack+264, r12vrr_stack+284, NULL, NULL, r12vrr_stack+48);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+324, r12vrr_stack+274, r12vrr_stack+264, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+354, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+60);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+6, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+414, r12vrr_stack+6, r12vrr_stack+78, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+81, r12vrr_stack+6, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+430, r12vrr_stack+420, r12vrr_stack+274, NULL, NULL, r12vrr_stack+81);

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+460, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+87);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+78, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+87, r12vrr_stack+105, r12vrr_stack+78, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+93, r12vrr_stack+108, r12vrr_stack+87, r12vrr_stack+9, r12vrr_stack+105, NULL);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+520, r12vrr_stack+284, r12vrr_stack+93, NULL, NULL, r12vrr_stack+108);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+550, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+114);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+610, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+324, r12vrr_stack+294, r12vrr_stack+132);

 /*--- compute (f0|f0)^0 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+710, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+430, r12vrr_stack+324, r12vrr_stack+168);

 /*--- compute (g0|f0)^0 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+810, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+460, r12vrr_stack+354, r12vrr_stack+204);

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+960, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (d0|00)^3 ---*/
 _BUILD_d000(Data,r12vrr_stack+963, r12vrr_stack+0, r12vrr_stack+960, Data->F+3, Data->F+4, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+969, r12vrr_stack+9, r12vrr_stack+105, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+978, r12vrr_stack+12, r12vrr_stack+969, r12vrr_stack+3, r12vrr_stack+9, r12vrr_stack+960);

 /*--- compute (f0|p0)^2 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+996, r12vrr_stack+30, r12vrr_stack+978, r12vrr_stack+21, r12vrr_stack+12, r12vrr_stack+963);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+9, r12vrr_stack+108, r12vrr_stack+87, NULL, NULL, r12vrr_stack+105);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1026, r12vrr_stack+114, r12vrr_stack+9, r12vrr_stack+48, r12vrr_stack+108, r12vrr_stack+969);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1062, r12vrr_stack+132, r12vrr_stack+1026, r12vrr_stack+60, r12vrr_stack+114, r12vrr_stack+978);

 /*--- compute (g0|d0)^1 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+1122, r12vrr_stack+204, r12vrr_stack+1062, r12vrr_stack+168, r12vrr_stack+132, r12vrr_stack+996);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+114, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+0, r12vrr_stack+78, r12vrr_stack+114, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+117, r12vrr_stack+87, r12vrr_stack+0, r12vrr_stack+105, r12vrr_stack+78, NULL);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+127, r12vrr_stack+93, r12vrr_stack+117, NULL, NULL, r12vrr_stack+87);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+157, r12vrr_stack+520, r12vrr_stack+127, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+9);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+1212, r12vrr_stack+550, r12vrr_stack+157, r12vrr_stack+294, r12vrr_stack+520, r12vrr_stack+1026);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+1312, r12vrr_stack+610, r12vrr_stack+1212, r12vrr_stack+354, r12vrr_stack+550, r12vrr_stack+1062);

 /*--- compute (h0|f0)^0 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+1462, r12vrr_stack+810, r12vrr_stack+1312, r12vrr_stack+710, r12vrr_stack+610, r12vrr_stack+1122);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+9, r12vrr_stack+284, r12vrr_stack+93, r12vrr_stack+48, r12vrr_stack+108, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+24, r12vrr_stack+264, r12vrr_stack+284, r12vrr_stack+54, r12vrr_stack+48, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+217, r12vrr_stack+24, r12vrr_stack+9, NULL, NULL, r12vrr_stack+284);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+39, r12vrr_stack+274, r12vrr_stack+264, r12vrr_stack+81, r12vrr_stack+54, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+960, r12vrr_stack+39, r12vrr_stack+24, NULL, NULL, r12vrr_stack+264);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+54, r12vrr_stack+93, r12vrr_stack+117, r12vrr_stack+108, r12vrr_stack+87, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1005, r12vrr_stack+9, r12vrr_stack+54, NULL, NULL, r12vrr_stack+93);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1050, r12vrr_stack+217, r12vrr_stack+1005, r12vrr_stack+24, r12vrr_stack+9, r12vrr_stack+520);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1672, r12vrr_stack+960, r12vrr_stack+217, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+294);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1762, r12vrr_stack+1672, r12vrr_stack+1050, r12vrr_stack+960, r12vrr_stack+217, r12vrr_stack+550);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+294, r12vrr_stack+420, r12vrr_stack+274, r12vrr_stack+414, r12vrr_stack+81, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+520, r12vrr_stack+294, r12vrr_stack+39, NULL, NULL, r12vrr_stack+274);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1912, r12vrr_stack+520, r12vrr_stack+960, r12vrr_stack+294, r12vrr_stack+39, r12vrr_stack+324);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2002, r12vrr_stack+1912, r12vrr_stack+1672, r12vrr_stack+520, r12vrr_stack+960, r12vrr_stack+354);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+81, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+309, r12vrr_stack+114, r12vrr_stack+81, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+315, r12vrr_stack+0, r12vrr_stack+309, r12vrr_stack+78, r12vrr_stack+114, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+325, r12vrr_stack+117, r12vrr_stack+315, r12vrr_stack+87, r12vrr_stack+0, NULL);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+565, r12vrr_stack+54, r12vrr_stack+325, NULL, NULL, r12vrr_stack+117);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+2152, r12vrr_stack+1005, r12vrr_stack+565, r12vrr_stack+9, r12vrr_stack+54, r12vrr_stack+127);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+2242, r12vrr_stack+1050, r12vrr_stack+2152, r12vrr_stack+217, r12vrr_stack+1005, r12vrr_stack+157);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2392, r12vrr_stack+1762, r12vrr_stack+2242, r12vrr_stack+1672, r12vrr_stack+1050, r12vrr_stack+1212);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+2617, r12vrr_stack+2002, r12vrr_stack+1762, r12vrr_stack+1912, r12vrr_stack+1672, r12vrr_stack+610);
 tmp = r12vrr_stack + 2617;
 target_ptr = Libr12->gvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+2842, r12vrr_stack+2617, r12vrr_stack+2392, r12vrr_stack+2002, r12vrr_stack+1762, r12vrr_stack+1312);
 tmp = r12vrr_stack + 2842;
 target_ptr = Libr12->gvrr_classes[5][4];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+610, r12vrr_stack+24, r12vrr_stack+9, r12vrr_stack+264, r12vrr_stack+284, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+631, r12vrr_stack+39, r12vrr_stack+24, r12vrr_stack+274, r12vrr_stack+264, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+652, r12vrr_stack+9, r12vrr_stack+54, r12vrr_stack+284, r12vrr_stack+93, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+127, r12vrr_stack+610, r12vrr_stack+652, NULL, NULL, r12vrr_stack+9);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+340, r12vrr_stack+631, r12vrr_stack+610, NULL, NULL, r12vrr_stack+24);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1140, r12vrr_stack+340, r12vrr_stack+127, r12vrr_stack+631, r12vrr_stack+610, r12vrr_stack+217);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+673, r12vrr_stack+294, r12vrr_stack+39, r12vrr_stack+420, r12vrr_stack+274, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+190, r12vrr_stack+673, r12vrr_stack+631, NULL, NULL, r12vrr_stack+39);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1266, r12vrr_stack+190, r12vrr_stack+340, r12vrr_stack+673, r12vrr_stack+631, r12vrr_stack+960);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+960, r12vrr_stack+54, r12vrr_stack+325, r12vrr_stack+93, r12vrr_stack+117, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1392, r12vrr_stack+652, r12vrr_stack+960, NULL, NULL, r12vrr_stack+54);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+3157, r12vrr_stack+127, r12vrr_stack+1392, r12vrr_stack+610, r12vrr_stack+652, r12vrr_stack+1005);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3283, r12vrr_stack+1140, r12vrr_stack+3157, r12vrr_stack+340, r12vrr_stack+127, r12vrr_stack+1050);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+3493, r12vrr_stack+1266, r12vrr_stack+1140, r12vrr_stack+190, r12vrr_stack+340, r12vrr_stack+1672);

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+3703, r12vrr_stack+3493, r12vrr_stack+3283, r12vrr_stack+1266, r12vrr_stack+1140, r12vrr_stack+1762);
 tmp = r12vrr_stack + 3703;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1672, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1675, r12vrr_stack+81, r12vrr_stack+1672, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1681, r12vrr_stack+309, r12vrr_stack+1675, r12vrr_stack+114, r12vrr_stack+81, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1691, r12vrr_stack+315, r12vrr_stack+1681, r12vrr_stack+0, r12vrr_stack+309, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1706, r12vrr_stack+325, r12vrr_stack+1691, r12vrr_stack+117, r12vrr_stack+315, NULL);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1727, r12vrr_stack+960, r12vrr_stack+1706, NULL, NULL, r12vrr_stack+325);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+981, r12vrr_stack+1392, r12vrr_stack+1727, r12vrr_stack+652, r12vrr_stack+960, r12vrr_stack+565);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+4018, r12vrr_stack+3157, r12vrr_stack+981, r12vrr_stack+127, r12vrr_stack+1392, r12vrr_stack+2152);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+4228, r12vrr_stack+3283, r12vrr_stack+4018, r12vrr_stack+1140, r12vrr_stack+3157, r12vrr_stack+2242);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+4543, r12vrr_stack+3703, r12vrr_stack+4228, r12vrr_stack+3493, r12vrr_stack+3283, r12vrr_stack+2392);
 tmp = r12vrr_stack + 4543;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2152, r12vrr_stack+610, r12vrr_stack+652, r12vrr_stack+24, r12vrr_stack+9, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2180, r12vrr_stack+631, r12vrr_stack+610, r12vrr_stack+39, r12vrr_stack+24, NULL);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2208, r12vrr_stack+652, r12vrr_stack+960, r12vrr_stack+9, r12vrr_stack+54, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2236, r12vrr_stack+2152, r12vrr_stack+2208, NULL, NULL, r12vrr_stack+652);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+2320, r12vrr_stack+2180, r12vrr_stack+2152, NULL, NULL, r12vrr_stack+610);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+2404, r12vrr_stack+2320, r12vrr_stack+2236, r12vrr_stack+2180, r12vrr_stack+2152, r12vrr_stack+127);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+9, r12vrr_stack+673, r12vrr_stack+631, r12vrr_stack+294, r12vrr_stack+39, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1790, r12vrr_stack+9, r12vrr_stack+2180, NULL, NULL, r12vrr_stack+631);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4984, r12vrr_stack+1790, r12vrr_stack+2320, r12vrr_stack+9, r12vrr_stack+2180, r12vrr_stack+340);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+340, r12vrr_stack+960, r12vrr_stack+1706, r12vrr_stack+54, r12vrr_stack+325, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+84, r12vrr_stack+2208, r12vrr_stack+340, NULL, NULL, r12vrr_stack+960);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+5152, r12vrr_stack+2236, r12vrr_stack+84, r12vrr_stack+2152, r12vrr_stack+2208, r12vrr_stack+1392);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+5320, r12vrr_stack+2404, r12vrr_stack+5152, r12vrr_stack+2320, r12vrr_stack+2236, r12vrr_stack+3157);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+5600, r12vrr_stack+4984, r12vrr_stack+2404, r12vrr_stack+1790, r12vrr_stack+2320, r12vrr_stack+1140);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+5880, r12vrr_stack+5600, r12vrr_stack+5320, r12vrr_stack+4984, r12vrr_stack+2404, r12vrr_stack+3283);
 tmp = r12vrr_stack + 5880;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3157, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+0, r12vrr_stack+1672, r12vrr_stack+3157, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3160, r12vrr_stack+1675, r12vrr_stack+0, r12vrr_stack+81, r12vrr_stack+1672, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+3170, r12vrr_stack+1681, r12vrr_stack+3160, r12vrr_stack+309, r12vrr_stack+1675, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3185, r12vrr_stack+1691, r12vrr_stack+3170, r12vrr_stack+315, r12vrr_stack+1681, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3206, r12vrr_stack+1706, r12vrr_stack+3185, r12vrr_stack+325, r12vrr_stack+1691, NULL);

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3234, r12vrr_stack+340, r12vrr_stack+3206, NULL, NULL, r12vrr_stack+1706);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3318, r12vrr_stack+84, r12vrr_stack+3234, r12vrr_stack+2208, r12vrr_stack+340, r12vrr_stack+1727);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+6300, r12vrr_stack+5152, r12vrr_stack+3318, r12vrr_stack+2236, r12vrr_stack+84, r12vrr_stack+981);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+6580, r12vrr_stack+5320, r12vrr_stack+6300, r12vrr_stack+2404, r12vrr_stack+5152, r12vrr_stack+4018);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+7000, r12vrr_stack+5880, r12vrr_stack+6580, r12vrr_stack+5600, r12vrr_stack+5320, r12vrr_stack+4228);
 tmp = r12vrr_stack + 7000;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4018, r12vrr_stack+2152, r12vrr_stack+2208, r12vrr_stack+610, r12vrr_stack+652, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4054, r12vrr_stack+2180, r12vrr_stack+2152, r12vrr_stack+631, r12vrr_stack+610, NULL);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4090, r12vrr_stack+2208, r12vrr_stack+340, r12vrr_stack+652, r12vrr_stack+960, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4126, r12vrr_stack+4018, r12vrr_stack+4090, NULL, NULL, r12vrr_stack+2208);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4234, r12vrr_stack+4054, r12vrr_stack+4018, NULL, NULL, r12vrr_stack+2152);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+981, r12vrr_stack+4234, r12vrr_stack+4126, r12vrr_stack+4054, r12vrr_stack+4018, r12vrr_stack+2236);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2236, r12vrr_stack+9, r12vrr_stack+2180, r12vrr_stack+673, r12vrr_stack+631, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+565, r12vrr_stack+2236, r12vrr_stack+4054, NULL, NULL, r12vrr_stack+2180);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7588, r12vrr_stack+565, r12vrr_stack+4234, r12vrr_stack+2236, r12vrr_stack+4054, r12vrr_stack+2320);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+2272, r12vrr_stack+340, r12vrr_stack+3206, r12vrr_stack+960, r12vrr_stack+1706, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4342, r12vrr_stack+4090, r12vrr_stack+2272, NULL, NULL, r12vrr_stack+340);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+7804, r12vrr_stack+4126, r12vrr_stack+4342, r12vrr_stack+4018, r12vrr_stack+4090, r12vrr_stack+84);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8020, r12vrr_stack+981, r12vrr_stack+7804, r12vrr_stack+4234, r12vrr_stack+4126, r12vrr_stack+5152);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8380, r12vrr_stack+7588, r12vrr_stack+981, r12vrr_stack+565, r12vrr_stack+4234, r12vrr_stack+2404);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8740, r12vrr_stack+8380, r12vrr_stack+8020, r12vrr_stack+7588, r12vrr_stack+981, r12vrr_stack+5320);
 tmp = r12vrr_stack + 8740;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+5152, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+5155, r12vrr_stack+3157, r12vrr_stack+5152, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+5161, r12vrr_stack+0, r12vrr_stack+5155, r12vrr_stack+1672, r12vrr_stack+3157, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+5171, r12vrr_stack+3160, r12vrr_stack+5161, r12vrr_stack+1675, r12vrr_stack+0, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+960, r12vrr_stack+3170, r12vrr_stack+5171, r12vrr_stack+1681, r12vrr_stack+3160, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5186, r12vrr_stack+3185, r12vrr_stack+960, r12vrr_stack+1691, r12vrr_stack+3170, NULL);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5214, r12vrr_stack+3206, r12vrr_stack+5186, r12vrr_stack+1706, r12vrr_stack+3185, NULL);

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1672, r12vrr_stack+2272, r12vrr_stack+5214, NULL, NULL, r12vrr_stack+3206);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5250, r12vrr_stack+4342, r12vrr_stack+1672, r12vrr_stack+4090, r12vrr_stack+2272, r12vrr_stack+3234);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9280, r12vrr_stack+7804, r12vrr_stack+5250, r12vrr_stack+4126, r12vrr_stack+4342, r12vrr_stack+3318);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+9640, r12vrr_stack+8020, r12vrr_stack+9280, r12vrr_stack+981, r12vrr_stack+7804, r12vrr_stack+6300);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10180, r12vrr_stack+8740, r12vrr_stack+9640, r12vrr_stack+8380, r12vrr_stack+8020, r12vrr_stack+6580);
 tmp = r12vrr_stack + 10180;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6300, r12vrr_stack+4018, r12vrr_stack+4090, r12vrr_stack+2152, r12vrr_stack+2208, NULL);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6345, r12vrr_stack+4054, r12vrr_stack+4018, r12vrr_stack+2180, r12vrr_stack+2152, NULL);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6390, r12vrr_stack+4090, r12vrr_stack+2272, r12vrr_stack+2208, r12vrr_stack+340, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6435, r12vrr_stack+6300, r12vrr_stack+6390, NULL, NULL, r12vrr_stack+4090);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6570, r12vrr_stack+6345, r12vrr_stack+6300, NULL, NULL, r12vrr_stack+4018);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+6705, r12vrr_stack+6570, r12vrr_stack+6435, r12vrr_stack+6345, r12vrr_stack+6300, r12vrr_stack+4126);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+4126, r12vrr_stack+2236, r12vrr_stack+4054, r12vrr_stack+9, r12vrr_stack+2180, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+3234, r12vrr_stack+4126, r12vrr_stack+6345, NULL, NULL, r12vrr_stack+4054);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2308, r12vrr_stack+3234, r12vrr_stack+6570, r12vrr_stack+4126, r12vrr_stack+6345, r12vrr_stack+4234);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+4171, r12vrr_stack+2272, r12vrr_stack+5214, r12vrr_stack+340, r12vrr_stack+3206, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+37, r12vrr_stack+6390, r12vrr_stack+4171, NULL, NULL, r12vrr_stack+2272);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10936, r12vrr_stack+6435, r12vrr_stack+37, r12vrr_stack+6300, r12vrr_stack+6390, r12vrr_stack+4342);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+11206, r12vrr_stack+6705, r12vrr_stack+10936, r12vrr_stack+6570, r12vrr_stack+6435, r12vrr_stack+7804);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+11656, r12vrr_stack+2308, r12vrr_stack+6705, r12vrr_stack+3234, r12vrr_stack+6570, r12vrr_stack+981);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12106, r12vrr_stack+11656, r12vrr_stack+11206, r12vrr_stack+2308, r12vrr_stack+6705, r12vrr_stack+8020);
 tmp = r12vrr_stack + 12106;
 target_ptr = Libr12->gvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+981, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+984, r12vrr_stack+5152, r12vrr_stack+981, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+1780, r12vrr_stack+5155, r12vrr_stack+984, r12vrr_stack+3157, r12vrr_stack+5152, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+981, r12vrr_stack+5161, r12vrr_stack+1780, r12vrr_stack+0, r12vrr_stack+5155, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+996, r12vrr_stack+5171, r12vrr_stack+981, r12vrr_stack+3160, r12vrr_stack+5161, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+1017, r12vrr_stack+960, r12vrr_stack+996, r12vrr_stack+3170, r12vrr_stack+5171, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+981, r12vrr_stack+5186, r12vrr_stack+1017, r12vrr_stack+3185, r12vrr_stack+960, NULL);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1017, r12vrr_stack+5214, r12vrr_stack+981, r12vrr_stack+3206, r12vrr_stack+5186, NULL);

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+1062, r12vrr_stack+4171, r12vrr_stack+1017, NULL, NULL, r12vrr_stack+5214);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7804, r12vrr_stack+37, r12vrr_stack+1062, r12vrr_stack+6390, r12vrr_stack+4171, r12vrr_stack+1672);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+12781, r12vrr_stack+10936, r12vrr_stack+7804, r12vrr_stack+6435, r12vrr_stack+37, r12vrr_stack+5250);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13231, r12vrr_stack+11206, r12vrr_stack+12781, r12vrr_stack+6705, r12vrr_stack+10936, r12vrr_stack+9280);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+13906, r12vrr_stack+12106, r12vrr_stack+13231, r12vrr_stack+11656, r12vrr_stack+11206, r12vrr_stack+9640);

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9280, r12vrr_stack+6300, r12vrr_stack+6390, r12vrr_stack+4018, r12vrr_stack+4090, NULL);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9335, r12vrr_stack+6345, r12vrr_stack+6300, r12vrr_stack+4054, r12vrr_stack+4018, NULL);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9390, r12vrr_stack+6390, r12vrr_stack+4171, r12vrr_stack+4090, r12vrr_stack+2272, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9445, r12vrr_stack+9280, r12vrr_stack+9390, NULL, NULL, r12vrr_stack+6390);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9610, r12vrr_stack+9335, r12vrr_stack+9280, NULL, NULL, r12vrr_stack+6300);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9775, r12vrr_stack+9610, r12vrr_stack+9445, r12vrr_stack+9335, r12vrr_stack+9280, r12vrr_stack+6435);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+6390, r12vrr_stack+4126, r12vrr_stack+6345, r12vrr_stack+2236, r12vrr_stack+4054, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12781, r12vrr_stack+6390, r12vrr_stack+9335, NULL, NULL, r12vrr_stack+6345);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12946, r12vrr_stack+12781, r12vrr_stack+9610, r12vrr_stack+6390, r12vrr_stack+9335, r12vrr_stack+6570);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+9335, r12vrr_stack+4171, r12vrr_stack+1017, r12vrr_stack+2272, r12vrr_stack+5214, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+6300, r12vrr_stack+9390, r12vrr_stack+9335, NULL, NULL, r12vrr_stack+4171);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+4171, r12vrr_stack+9445, r12vrr_stack+6300, r12vrr_stack+9280, r12vrr_stack+9390, r12vrr_stack+37);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13276, r12vrr_stack+9775, r12vrr_stack+4171, r12vrr_stack+9610, r12vrr_stack+9445, r12vrr_stack+10936);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+7804, r12vrr_stack+12946, r12vrr_stack+9775, r12vrr_stack+12781, r12vrr_stack+9610, r12vrr_stack+6705);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+14851, r12vrr_stack+7804, r12vrr_stack+13276, r12vrr_stack+12946, r12vrr_stack+9775, r12vrr_stack+11206);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+12781, &(Data->ss_r12_ss), NULL, r12vrr_stack+6, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+0, r12vrr_stack+12781, &(Data->ss_r12_ss), r12vrr_stack+414, r12vrr_stack+6, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+12784, r12vrr_stack+0, r12vrr_stack+12781, r12vrr_stack+420, r12vrr_stack+414, r12vrr_stack+6, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+12794, r12vrr_stack+12784, r12vrr_stack+0, r12vrr_stack+294, r12vrr_stack+420, r12vrr_stack+414, NULL);

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+12809, r12vrr_stack+12794, NULL, r12vrr_stack+520, r12vrr_stack+294, NULL, r12vrr_stack+420);

 /*--- compute (d0||g0)^0 ---*/
 _R_BUILD_d0g0(Data,r12vrr_stack+12854, r12vrr_stack+12809, r12vrr_stack+12794, r12vrr_stack+1912, r12vrr_stack+520, r12vrr_stack+294, r12vrr_stack+430);

 /*--- compute (f0||g0)^0 ---*/
 _R_BUILD_f0g0(Data,r12vrr_stack+12944, r12vrr_stack+12854, r12vrr_stack+12809, r12vrr_stack+2002, r12vrr_stack+1912, r12vrr_stack+520, r12vrr_stack+460);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+12809, r12vrr_stack+12794, r12vrr_stack+12784, r12vrr_stack+673, r12vrr_stack+294, r12vrr_stack+420, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+13094, r12vrr_stack+12809, NULL, r12vrr_stack+190, r12vrr_stack+673, NULL, r12vrr_stack+294);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+13157, r12vrr_stack+13094, r12vrr_stack+12809, r12vrr_stack+1266, r12vrr_stack+190, r12vrr_stack+673, r12vrr_stack+520);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+13283, r12vrr_stack+13157, r12vrr_stack+13094, r12vrr_stack+3493, r12vrr_stack+1266, r12vrr_stack+190, r12vrr_stack+1912);

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+13094, r12vrr_stack+12809, r12vrr_stack+12794, r12vrr_stack+9, r12vrr_stack+673, r12vrr_stack+294, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+2152, r12vrr_stack+13094, NULL, r12vrr_stack+1790, r12vrr_stack+9, NULL, r12vrr_stack+673);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+13493, r12vrr_stack+2152, r12vrr_stack+13094, r12vrr_stack+4984, r12vrr_stack+1790, r12vrr_stack+9, r12vrr_stack+190);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+10936, r12vrr_stack+13493, r12vrr_stack+2152, r12vrr_stack+5600, r12vrr_stack+4984, r12vrr_stack+1790, r12vrr_stack+1266);

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+2272, r12vrr_stack+13094, r12vrr_stack+12809, r12vrr_stack+2236, r12vrr_stack+9, r12vrr_stack+673, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+4018, r12vrr_stack+2272, NULL, r12vrr_stack+565, r12vrr_stack+2236, NULL, r12vrr_stack+9);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+13661, r12vrr_stack+4018, r12vrr_stack+2272, r12vrr_stack+7588, r12vrr_stack+565, r12vrr_stack+2236, r12vrr_stack+1790);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+11216, r12vrr_stack+13661, r12vrr_stack+4018, r12vrr_stack+8380, r12vrr_stack+7588, r12vrr_stack+565, r12vrr_stack+4984);

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+4018, r12vrr_stack+2272, r12vrr_stack+13094, r12vrr_stack+4126, r12vrr_stack+2236, r12vrr_stack+9, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+0, r12vrr_stack+4018, NULL, r12vrr_stack+3234, r12vrr_stack+4126, NULL, r12vrr_stack+2236);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+135, r12vrr_stack+0, r12vrr_stack+4018, r12vrr_stack+2308, r12vrr_stack+3234, r12vrr_stack+4126, r12vrr_stack+565);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+4018, r12vrr_stack+135, r12vrr_stack+0, r12vrr_stack+11656, r12vrr_stack+2308, r12vrr_stack+3234, r12vrr_stack+7588);

 /*--- compute (g0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+405, r12vrr_stack+2617, r12vrr_stack+3703, r12vrr_stack+2842, r12vrr_stack+1462, r12vrr_stack+810);
 tmp = r12vrr_stack + 405;
 target_ptr = Libr12->t2vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+810, r12vrr_stack+3703, r12vrr_stack+5880, r12vrr_stack+4543, r12vrr_stack+2842, r12vrr_stack+2617);
 tmp = r12vrr_stack + 810;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9280, r12vrr_stack+5880, r12vrr_stack+8740, r12vrr_stack+7000, r12vrr_stack+4543, r12vrr_stack+3703);
 tmp = r12vrr_stack + 9280;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6300, r12vrr_stack+8740, r12vrr_stack+12106, r12vrr_stack+10180, r12vrr_stack+7000, r12vrr_stack+5880);
 tmp = r12vrr_stack + 6300;
 target_ptr = Libr12->t2vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+15676, r12vrr_stack+12106, r12vrr_stack+14851, r12vrr_stack+13906, r12vrr_stack+10180, r12vrr_stack+8740);
 tmp = r12vrr_stack + 15676;
 target_ptr = Libr12->t2vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_g0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9700, r12vrr_stack+2617, r12vrr_stack+2842, r12vrr_stack+3703, r12vrr_stack+3493, r12vrr_stack+2002);
 tmp = r12vrr_stack + 9700;
 target_ptr = Libr12->t1vrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+2842, r12vrr_stack+3703, r12vrr_stack+4543, r12vrr_stack+5880, r12vrr_stack+5600, r12vrr_stack+3493);
 tmp = r12vrr_stack + 2842;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+4468, r12vrr_stack+5880, r12vrr_stack+7000, r12vrr_stack+8740, r12vrr_stack+8380, r12vrr_stack+5600);
 tmp = r12vrr_stack + 4468;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+6840, r12vrr_stack+8740, r12vrr_stack+10180, r12vrr_stack+12106, r12vrr_stack+11656, r12vrr_stack+8380);
 tmp = r12vrr_stack + 6840;
 target_ptr = Libr12->t1vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+9925, r12vrr_stack+12106, r12vrr_stack+13906, r12vrr_stack+14851, r12vrr_stack+7804, r12vrr_stack+11656);
 tmp = r12vrr_stack + 9925;
 target_ptr = Libr12->t1vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||g0)^0 ---*/
 _R_BUILD_g0g0(Data,r12vrr_stack+7804, r12vrr_stack+12944, r12vrr_stack+12854, r12vrr_stack+2617, r12vrr_stack+2002, r12vrr_stack+1912, r12vrr_stack+710);
 tmp = r12vrr_stack + 7804;
 target_ptr = Libr12->rvrr_classes[4][4];
 for(i=0;i<225;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+8029, r12vrr_stack+13283, r12vrr_stack+13157, r12vrr_stack+3703, r12vrr_stack+3493, r12vrr_stack+1266, r12vrr_stack+2002);
 tmp = r12vrr_stack + 8029;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+1125, r12vrr_stack+10936, r12vrr_stack+13493, r12vrr_stack+5880, r12vrr_stack+5600, r12vrr_stack+4984, r12vrr_stack+3493);
 tmp = r12vrr_stack + 1125;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+3157, r12vrr_stack+11216, r12vrr_stack+13661, r12vrr_stack+8740, r12vrr_stack+8380, r12vrr_stack+7588, r12vrr_stack+5600);
 tmp = r12vrr_stack + 3157;
 target_ptr = Libr12->rvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+1545, r12vrr_stack+4018, r12vrr_stack+135, r12vrr_stack+12106, r12vrr_stack+11656, r12vrr_stack+2308, r12vrr_stack+8380);
 tmp = r12vrr_stack + 1545;
 target_ptr = Libr12->rvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];


}

