/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_dphh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (dp|hh) integrals */

void d12hrr_order_dphh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][10][11] = int_stack + 0;
 Libderiv->deriv_classes[3][10][10] = int_stack + 660;
 Libderiv->deriv_classes[3][10][9] = int_stack + 1320;
 Libderiv->deriv_classes[3][10][8] = int_stack + 1980;
 Libderiv->deriv_classes[3][10][7] = int_stack + 2640;
 Libderiv->dvrr_classes[3][9] = int_stack + 3300;
 Libderiv->deriv_classes[3][10][6] = int_stack + 3850;
 Libderiv->deriv_classes[3][10][2] = int_stack + 4510;
 Libderiv->deriv_classes[3][10][1] = int_stack + 5170;
 Libderiv->dvrr_classes[2][10] = int_stack + 5830;
 Libderiv->deriv_classes[3][10][0] = int_stack + 6226;
 Libderiv->deriv2_classes[2][5][143] = int_stack + 6886;
 Libderiv->deriv2_classes[2][6][143] = int_stack + 7012;
 Libderiv->deriv2_classes[2][7][143] = int_stack + 7180;
 Libderiv->deriv2_classes[2][8][143] = int_stack + 7396;
 Libderiv->deriv2_classes[2][9][143] = int_stack + 7666;
 Libderiv->deriv2_classes[2][10][143] = int_stack + 7996;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 8392;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 8602;
 Libderiv->deriv2_classes[3][7][143] = int_stack + 8882;
 Libderiv->deriv2_classes[3][8][143] = int_stack + 9242;
 Libderiv->deriv2_classes[3][9][143] = int_stack + 9692;
 Libderiv->deriv2_classes[3][10][143] = int_stack + 10242;
 Libderiv->deriv2_classes[2][5][131] = int_stack + 10902;
 Libderiv->deriv2_classes[2][6][131] = int_stack + 11028;
 Libderiv->deriv2_classes[2][7][131] = int_stack + 11196;
 Libderiv->deriv2_classes[2][8][131] = int_stack + 11412;
 Libderiv->deriv2_classes[2][9][131] = int_stack + 11682;
 Libderiv->deriv2_classes[2][10][131] = int_stack + 12012;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 12408;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 12618;
 Libderiv->deriv2_classes[3][7][131] = int_stack + 12898;
 Libderiv->deriv2_classes[3][8][131] = int_stack + 13258;
 Libderiv->deriv2_classes[3][9][131] = int_stack + 13708;
 Libderiv->deriv2_classes[3][10][131] = int_stack + 14258;
 Libderiv->deriv2_classes[2][5][130] = int_stack + 14918;
 Libderiv->deriv2_classes[2][6][130] = int_stack + 15044;
 Libderiv->deriv2_classes[2][7][130] = int_stack + 15212;
 Libderiv->deriv2_classes[2][8][130] = int_stack + 15428;
 Libderiv->deriv2_classes[2][9][130] = int_stack + 15698;
 Libderiv->deriv2_classes[2][10][130] = int_stack + 16028;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 16424;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 16634;
 Libderiv->deriv2_classes[3][7][130] = int_stack + 16914;
 Libderiv->deriv2_classes[3][8][130] = int_stack + 17274;
 Libderiv->deriv2_classes[3][9][130] = int_stack + 17724;
 Libderiv->deriv2_classes[3][10][130] = int_stack + 18274;
 Libderiv->deriv2_classes[2][5][119] = int_stack + 18934;
 Libderiv->deriv2_classes[2][6][119] = int_stack + 19060;
 Libderiv->deriv2_classes[2][7][119] = int_stack + 19228;
 Libderiv->deriv2_classes[2][8][119] = int_stack + 19444;
 Libderiv->deriv2_classes[2][9][119] = int_stack + 19714;
 Libderiv->deriv2_classes[2][10][119] = int_stack + 20044;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 20440;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 20650;
 Libderiv->deriv2_classes[3][7][119] = int_stack + 20930;
 Libderiv->deriv2_classes[3][8][119] = int_stack + 21290;
 Libderiv->deriv2_classes[3][9][119] = int_stack + 21740;
 Libderiv->deriv2_classes[3][10][119] = int_stack + 22290;
 Libderiv->deriv2_classes[2][5][118] = int_stack + 22950;
 Libderiv->deriv2_classes[2][6][118] = int_stack + 23076;
 Libderiv->deriv2_classes[2][7][118] = int_stack + 23244;
 Libderiv->deriv2_classes[2][8][118] = int_stack + 23460;
 Libderiv->deriv2_classes[2][9][118] = int_stack + 23730;
 Libderiv->deriv2_classes[2][10][118] = int_stack + 24060;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 24456;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 24666;
 Libderiv->deriv2_classes[3][7][118] = int_stack + 24946;
 Libderiv->deriv2_classes[3][8][118] = int_stack + 25306;
 Libderiv->deriv2_classes[3][9][118] = int_stack + 25756;
 Libderiv->deriv2_classes[3][10][118] = int_stack + 26306;
 Libderiv->deriv2_classes[2][5][117] = int_stack + 26966;
 Libderiv->deriv2_classes[2][6][117] = int_stack + 27092;
 Libderiv->deriv2_classes[2][7][117] = int_stack + 27260;
 Libderiv->deriv2_classes[2][8][117] = int_stack + 27476;
 Libderiv->deriv2_classes[2][9][117] = int_stack + 27746;
 Libderiv->deriv2_classes[2][10][117] = int_stack + 28076;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 28472;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 28682;
 Libderiv->deriv2_classes[3][7][117] = int_stack + 28962;
 Libderiv->deriv2_classes[3][8][117] = int_stack + 29322;
 Libderiv->deriv2_classes[3][9][117] = int_stack + 29772;
 Libderiv->deriv2_classes[3][10][117] = int_stack + 30322;
 Libderiv->deriv2_classes[2][5][107] = int_stack + 30982;
 Libderiv->deriv2_classes[2][6][107] = int_stack + 31108;
 Libderiv->deriv2_classes[2][7][107] = int_stack + 31276;
 Libderiv->deriv2_classes[2][8][107] = int_stack + 31492;
 Libderiv->deriv2_classes[2][9][107] = int_stack + 31762;
 Libderiv->deriv2_classes[2][10][107] = int_stack + 32092;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 32488;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 32698;
 Libderiv->deriv2_classes[3][7][107] = int_stack + 32978;
 Libderiv->deriv2_classes[3][8][107] = int_stack + 33338;
 Libderiv->deriv2_classes[3][9][107] = int_stack + 33788;
 Libderiv->deriv2_classes[3][10][107] = int_stack + 34338;
 Libderiv->deriv2_classes[2][5][106] = int_stack + 34998;
 Libderiv->deriv2_classes[2][6][106] = int_stack + 35124;
 Libderiv->deriv2_classes[2][7][106] = int_stack + 35292;
 Libderiv->deriv2_classes[2][8][106] = int_stack + 35508;
 Libderiv->deriv2_classes[2][9][106] = int_stack + 35778;
 Libderiv->deriv2_classes[2][10][106] = int_stack + 36108;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 36504;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 36714;
 Libderiv->deriv2_classes[3][7][106] = int_stack + 36994;
 Libderiv->deriv2_classes[3][8][106] = int_stack + 37354;
 Libderiv->deriv2_classes[3][9][106] = int_stack + 37804;
 Libderiv->deriv2_classes[3][10][106] = int_stack + 38354;
 Libderiv->deriv2_classes[2][5][105] = int_stack + 39014;
 Libderiv->deriv2_classes[2][6][105] = int_stack + 39140;
 Libderiv->deriv2_classes[2][7][105] = int_stack + 39308;
 Libderiv->deriv2_classes[2][8][105] = int_stack + 39524;
 Libderiv->deriv2_classes[2][9][105] = int_stack + 39794;
 Libderiv->deriv2_classes[2][10][105] = int_stack + 40124;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 40520;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 40730;
 Libderiv->deriv2_classes[3][7][105] = int_stack + 41010;
 Libderiv->deriv2_classes[3][8][105] = int_stack + 41370;
 Libderiv->deriv2_classes[3][9][105] = int_stack + 41820;
 Libderiv->deriv2_classes[3][10][105] = int_stack + 42370;
 Libderiv->deriv2_classes[2][5][104] = int_stack + 43030;
 Libderiv->deriv2_classes[2][6][104] = int_stack + 43156;
 Libderiv->deriv2_classes[2][7][104] = int_stack + 43324;
 Libderiv->deriv2_classes[2][8][104] = int_stack + 43540;
 Libderiv->deriv2_classes[2][9][104] = int_stack + 43810;
 Libderiv->deriv2_classes[2][10][104] = int_stack + 44140;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 44536;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 44746;
 Libderiv->deriv2_classes[3][7][104] = int_stack + 45026;
 Libderiv->deriv2_classes[3][8][104] = int_stack + 45386;
 Libderiv->deriv2_classes[3][9][104] = int_stack + 45836;
 Libderiv->deriv2_classes[3][10][104] = int_stack + 46386;
 Libderiv->deriv2_classes[2][5][95] = int_stack + 47046;
 Libderiv->deriv2_classes[2][6][95] = int_stack + 47172;
 Libderiv->deriv2_classes[2][7][95] = int_stack + 47340;
 Libderiv->deriv2_classes[2][8][95] = int_stack + 47556;
 Libderiv->deriv2_classes[2][9][95] = int_stack + 47826;
 Libderiv->deriv2_classes[2][10][95] = int_stack + 48156;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 48552;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 48762;
 Libderiv->deriv2_classes[3][7][95] = int_stack + 49042;
 Libderiv->deriv2_classes[3][8][95] = int_stack + 49402;
 Libderiv->deriv2_classes[3][9][95] = int_stack + 49852;
 Libderiv->deriv2_classes[3][10][95] = int_stack + 50402;
 Libderiv->deriv2_classes[2][5][94] = int_stack + 51062;
 Libderiv->deriv2_classes[2][6][94] = int_stack + 51188;
 Libderiv->deriv2_classes[2][7][94] = int_stack + 51356;
 Libderiv->deriv2_classes[2][8][94] = int_stack + 51572;
 Libderiv->deriv2_classes[2][9][94] = int_stack + 51842;
 Libderiv->deriv2_classes[2][10][94] = int_stack + 52172;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 52568;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 52778;
 Libderiv->deriv2_classes[3][7][94] = int_stack + 53058;
 Libderiv->deriv2_classes[3][8][94] = int_stack + 53418;
 Libderiv->deriv2_classes[3][9][94] = int_stack + 53868;
 Libderiv->deriv2_classes[3][10][94] = int_stack + 54418;
 Libderiv->deriv2_classes[2][5][93] = int_stack + 55078;
 Libderiv->deriv2_classes[2][6][93] = int_stack + 55204;
 Libderiv->deriv2_classes[2][7][93] = int_stack + 55372;
 Libderiv->deriv2_classes[2][8][93] = int_stack + 55588;
 Libderiv->deriv2_classes[2][9][93] = int_stack + 55858;
 Libderiv->deriv2_classes[2][10][93] = int_stack + 56188;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 56584;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 56794;
 Libderiv->deriv2_classes[3][7][93] = int_stack + 57074;
 Libderiv->deriv2_classes[3][8][93] = int_stack + 57434;
 Libderiv->deriv2_classes[3][9][93] = int_stack + 57884;
 Libderiv->deriv2_classes[3][10][93] = int_stack + 58434;
 Libderiv->deriv2_classes[2][5][92] = int_stack + 59094;
 Libderiv->deriv2_classes[2][6][92] = int_stack + 59220;
 Libderiv->deriv2_classes[2][7][92] = int_stack + 59388;
 Libderiv->deriv2_classes[2][8][92] = int_stack + 59604;
 Libderiv->deriv2_classes[2][9][92] = int_stack + 59874;
 Libderiv->deriv2_classes[2][10][92] = int_stack + 60204;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 60600;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 60810;
 Libderiv->deriv2_classes[3][7][92] = int_stack + 61090;
 Libderiv->deriv2_classes[3][8][92] = int_stack + 61450;
 Libderiv->deriv2_classes[3][9][92] = int_stack + 61900;
 Libderiv->deriv2_classes[3][10][92] = int_stack + 62450;
 Libderiv->deriv2_classes[2][5][91] = int_stack + 63110;
 Libderiv->deriv2_classes[2][6][91] = int_stack + 63236;
 Libderiv->deriv2_classes[2][7][91] = int_stack + 63404;
 Libderiv->deriv2_classes[2][8][91] = int_stack + 63620;
 Libderiv->deriv2_classes[2][9][91] = int_stack + 63890;
 Libderiv->deriv2_classes[2][10][91] = int_stack + 64220;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 64616;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 64826;
 Libderiv->deriv2_classes[3][7][91] = int_stack + 65106;
 Libderiv->deriv2_classes[3][8][91] = int_stack + 65466;
 Libderiv->deriv2_classes[3][9][91] = int_stack + 65916;
 Libderiv->deriv2_classes[3][10][91] = int_stack + 66466;
 Libderiv->deriv2_classes[2][5][83] = int_stack + 67126;
 Libderiv->deriv2_classes[2][6][83] = int_stack + 67252;
 Libderiv->deriv2_classes[2][7][83] = int_stack + 67420;
 Libderiv->deriv2_classes[2][8][83] = int_stack + 67636;
 Libderiv->deriv2_classes[2][9][83] = int_stack + 67906;
 Libderiv->deriv2_classes[2][10][83] = int_stack + 68236;
 Libderiv->deriv_classes[3][5][11] = int_stack + 68632;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 68842;
 Libderiv->deriv_classes[3][6][11] = int_stack + 69052;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 69332;
 Libderiv->deriv_classes[3][7][11] = int_stack + 69612;
 Libderiv->deriv2_classes[3][7][83] = int_stack + 69972;
 Libderiv->deriv_classes[3][8][11] = int_stack + 70332;
 Libderiv->deriv2_classes[3][8][83] = int_stack + 70782;
 Libderiv->deriv_classes[3][9][11] = int_stack + 71232;
 Libderiv->deriv2_classes[3][9][83] = int_stack + 71782;
 Libderiv->deriv2_classes[3][10][83] = int_stack + 72332;
 Libderiv->deriv2_classes[2][5][82] = int_stack + 72992;
 Libderiv->deriv2_classes[2][6][82] = int_stack + 73118;
 Libderiv->deriv2_classes[2][7][82] = int_stack + 73286;
 Libderiv->deriv2_classes[2][8][82] = int_stack + 73502;
 Libderiv->deriv2_classes[2][9][82] = int_stack + 73772;
 Libderiv->deriv2_classes[2][10][82] = int_stack + 74102;
 Libderiv->deriv_classes[3][5][10] = int_stack + 74498;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 74708;
 Libderiv->deriv_classes[3][6][10] = int_stack + 74918;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 75198;
 Libderiv->deriv_classes[3][7][10] = int_stack + 75478;
 Libderiv->deriv2_classes[3][7][82] = int_stack + 75838;
 Libderiv->deriv_classes[3][8][10] = int_stack + 76198;
 Libderiv->deriv2_classes[3][8][82] = int_stack + 76648;
 Libderiv->deriv_classes[3][9][10] = int_stack + 77098;
 Libderiv->deriv2_classes[3][9][82] = int_stack + 77648;
 Libderiv->deriv2_classes[3][10][82] = int_stack + 78198;
 Libderiv->deriv2_classes[2][5][81] = int_stack + 78858;
 Libderiv->deriv2_classes[2][6][81] = int_stack + 78984;
 Libderiv->deriv2_classes[2][7][81] = int_stack + 79152;
 Libderiv->deriv2_classes[2][8][81] = int_stack + 79368;
 Libderiv->deriv2_classes[2][9][81] = int_stack + 79638;
 Libderiv->deriv2_classes[2][10][81] = int_stack + 79968;
 Libderiv->deriv_classes[3][5][9] = int_stack + 80364;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 80574;
 Libderiv->deriv_classes[3][6][9] = int_stack + 80784;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 81064;
 Libderiv->deriv_classes[3][7][9] = int_stack + 81344;
 Libderiv->deriv2_classes[3][7][81] = int_stack + 81704;
 Libderiv->deriv_classes[3][8][9] = int_stack + 82064;
 Libderiv->deriv2_classes[3][8][81] = int_stack + 82514;
 Libderiv->deriv_classes[3][9][9] = int_stack + 82964;
 Libderiv->deriv2_classes[3][9][81] = int_stack + 83514;
 Libderiv->deriv2_classes[3][10][81] = int_stack + 84064;
 Libderiv->deriv2_classes[2][5][80] = int_stack + 84724;
 Libderiv->deriv2_classes[2][6][80] = int_stack + 84850;
 Libderiv->deriv2_classes[2][7][80] = int_stack + 85018;
 Libderiv->deriv2_classes[2][8][80] = int_stack + 85234;
 Libderiv->deriv2_classes[2][9][80] = int_stack + 85504;
 Libderiv->deriv2_classes[2][10][80] = int_stack + 85834;
 Libderiv->deriv_classes[3][5][8] = int_stack + 86230;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 86440;
 Libderiv->deriv_classes[3][6][8] = int_stack + 86650;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 86930;
 Libderiv->deriv_classes[3][7][8] = int_stack + 87210;
 Libderiv->deriv2_classes[3][7][80] = int_stack + 87570;
 Libderiv->deriv_classes[3][8][8] = int_stack + 87930;
 Libderiv->deriv2_classes[3][8][80] = int_stack + 88380;
 Libderiv->deriv_classes[3][9][8] = int_stack + 88830;
 Libderiv->deriv2_classes[3][9][80] = int_stack + 89380;
 Libderiv->deriv2_classes[3][10][80] = int_stack + 89930;
 Libderiv->deriv2_classes[2][5][79] = int_stack + 90590;
 Libderiv->deriv2_classes[2][6][79] = int_stack + 90716;
 Libderiv->deriv2_classes[2][7][79] = int_stack + 90884;
 Libderiv->deriv2_classes[2][8][79] = int_stack + 91100;
 Libderiv->deriv2_classes[2][9][79] = int_stack + 91370;
 Libderiv->deriv2_classes[2][10][79] = int_stack + 91700;
 Libderiv->deriv_classes[3][5][7] = int_stack + 92096;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 92306;
 Libderiv->deriv_classes[3][6][7] = int_stack + 92516;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 92796;
 Libderiv->deriv_classes[3][7][7] = int_stack + 93076;
 Libderiv->deriv2_classes[3][7][79] = int_stack + 93436;
 Libderiv->deriv_classes[3][8][7] = int_stack + 93796;
 Libderiv->deriv2_classes[3][8][79] = int_stack + 94246;
 Libderiv->deriv_classes[3][9][7] = int_stack + 94696;
 Libderiv->deriv2_classes[3][9][79] = int_stack + 95246;
 Libderiv->deriv2_classes[3][10][79] = int_stack + 95796;
 Libderiv->deriv2_classes[2][5][78] = int_stack + 96456;
 Libderiv->deriv2_classes[2][6][78] = int_stack + 96582;
 Libderiv->deriv2_classes[2][7][78] = int_stack + 96750;
 Libderiv->deriv2_classes[2][8][78] = int_stack + 96966;
 Libderiv->deriv2_classes[2][9][78] = int_stack + 97236;
 Libderiv->deriv2_classes[2][10][78] = int_stack + 97566;
 Libderiv->dvrr_classes[3][5] = int_stack + 97962;
 Libderiv->deriv_classes[3][5][6] = int_stack + 98172;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 98382;
 Libderiv->dvrr_classes[3][6] = int_stack + 98592;
 Libderiv->deriv_classes[3][6][6] = int_stack + 98872;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 99152;
 Libderiv->dvrr_classes[3][7] = int_stack + 99432;
 Libderiv->deriv_classes[3][7][6] = int_stack + 99792;
 Libderiv->deriv2_classes[3][7][78] = int_stack + 100152;
 Libderiv->dvrr_classes[3][8] = int_stack + 100512;
 Libderiv->deriv_classes[3][8][6] = int_stack + 100962;
 Libderiv->deriv2_classes[3][8][78] = int_stack + 101412;
 Libderiv->deriv_classes[3][9][6] = int_stack + 101862;
 Libderiv->deriv2_classes[3][9][78] = int_stack + 102412;
 Libderiv->deriv2_classes[3][10][78] = int_stack + 102962;
 Libderiv->deriv2_classes[2][5][35] = int_stack + 103622;
 Libderiv->deriv2_classes[2][6][35] = int_stack + 103748;
 Libderiv->deriv2_classes[2][7][35] = int_stack + 103916;
 Libderiv->deriv2_classes[2][8][35] = int_stack + 104132;
 Libderiv->deriv2_classes[2][9][35] = int_stack + 104402;
 Libderiv->deriv2_classes[2][10][35] = int_stack + 104732;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 105128;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 105338;
 Libderiv->deriv2_classes[3][7][35] = int_stack + 105618;
 Libderiv->deriv2_classes[3][8][35] = int_stack + 105978;
 Libderiv->deriv2_classes[3][9][35] = int_stack + 106428;
 Libderiv->deriv2_classes[3][10][35] = int_stack + 106978;
 Libderiv->deriv2_classes[2][5][34] = int_stack + 107638;
 Libderiv->deriv2_classes[2][6][34] = int_stack + 107764;
 Libderiv->deriv2_classes[2][7][34] = int_stack + 107932;
 Libderiv->deriv2_classes[2][8][34] = int_stack + 108148;
 Libderiv->deriv2_classes[2][9][34] = int_stack + 108418;
 Libderiv->deriv2_classes[2][10][34] = int_stack + 108748;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 109144;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 109354;
 Libderiv->deriv2_classes[3][7][34] = int_stack + 109634;
 Libderiv->deriv2_classes[3][8][34] = int_stack + 109994;
 Libderiv->deriv2_classes[3][9][34] = int_stack + 110444;
 Libderiv->deriv2_classes[3][10][34] = int_stack + 110994;
 Libderiv->deriv2_classes[2][5][33] = int_stack + 111654;
 Libderiv->deriv2_classes[2][6][33] = int_stack + 111780;
 Libderiv->deriv2_classes[2][7][33] = int_stack + 111948;
 Libderiv->deriv2_classes[2][8][33] = int_stack + 112164;
 Libderiv->deriv2_classes[2][9][33] = int_stack + 112434;
 Libderiv->deriv2_classes[2][10][33] = int_stack + 112764;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 113160;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 113370;
 Libderiv->deriv2_classes[3][7][33] = int_stack + 113650;
 Libderiv->deriv2_classes[3][8][33] = int_stack + 114010;
 Libderiv->deriv2_classes[3][9][33] = int_stack + 114460;
 Libderiv->deriv2_classes[3][10][33] = int_stack + 115010;
 Libderiv->deriv2_classes[2][5][32] = int_stack + 115670;
 Libderiv->deriv2_classes[2][6][32] = int_stack + 115796;
 Libderiv->deriv2_classes[2][7][32] = int_stack + 115964;
 Libderiv->deriv2_classes[2][8][32] = int_stack + 116180;
 Libderiv->deriv2_classes[2][9][32] = int_stack + 116450;
 Libderiv->deriv2_classes[2][10][32] = int_stack + 116780;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 117176;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 117386;
 Libderiv->deriv2_classes[3][7][32] = int_stack + 117666;
 Libderiv->deriv2_classes[3][8][32] = int_stack + 118026;
 Libderiv->deriv2_classes[3][9][32] = int_stack + 118476;
 Libderiv->deriv2_classes[3][10][32] = int_stack + 119026;
 Libderiv->deriv2_classes[2][5][31] = int_stack + 119686;
 Libderiv->deriv2_classes[2][6][31] = int_stack + 119812;
 Libderiv->deriv2_classes[2][7][31] = int_stack + 119980;
 Libderiv->deriv2_classes[2][8][31] = int_stack + 120196;
 Libderiv->deriv2_classes[2][9][31] = int_stack + 120466;
 Libderiv->deriv2_classes[2][10][31] = int_stack + 120796;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 121192;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 121402;
 Libderiv->deriv2_classes[3][7][31] = int_stack + 121682;
 Libderiv->deriv2_classes[3][8][31] = int_stack + 122042;
 Libderiv->deriv2_classes[3][9][31] = int_stack + 122492;
 Libderiv->deriv2_classes[3][10][31] = int_stack + 123042;
 Libderiv->deriv2_classes[2][5][30] = int_stack + 123702;
 Libderiv->deriv2_classes[2][6][30] = int_stack + 123828;
 Libderiv->deriv2_classes[2][7][30] = int_stack + 123996;
 Libderiv->deriv2_classes[2][8][30] = int_stack + 124212;
 Libderiv->deriv2_classes[2][9][30] = int_stack + 124482;
 Libderiv->deriv2_classes[2][10][30] = int_stack + 124812;
 Libderiv->deriv_classes[3][5][2] = int_stack + 125208;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 125418;
 Libderiv->deriv_classes[3][6][2] = int_stack + 125628;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 125908;
 Libderiv->deriv_classes[3][7][2] = int_stack + 126188;
 Libderiv->deriv2_classes[3][7][30] = int_stack + 126548;
 Libderiv->deriv_classes[3][8][2] = int_stack + 126908;
 Libderiv->deriv2_classes[3][8][30] = int_stack + 127358;
 Libderiv->deriv_classes[3][9][2] = int_stack + 127808;
 Libderiv->deriv2_classes[3][9][30] = int_stack + 128358;
 Libderiv->deriv2_classes[3][10][30] = int_stack + 128908;
 Libderiv->deriv2_classes[2][5][26] = int_stack + 129568;
 Libderiv->deriv2_classes[2][6][26] = int_stack + 129694;
 Libderiv->deriv2_classes[2][7][26] = int_stack + 129862;
 Libderiv->deriv2_classes[2][8][26] = int_stack + 130078;
 Libderiv->deriv2_classes[2][9][26] = int_stack + 130348;
 Libderiv->deriv2_classes[2][10][26] = int_stack + 130678;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 131074;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 131284;
 Libderiv->deriv2_classes[3][7][26] = int_stack + 131564;
 Libderiv->deriv2_classes[3][8][26] = int_stack + 131924;
 Libderiv->deriv2_classes[3][9][26] = int_stack + 132374;
 Libderiv->deriv2_classes[3][10][26] = int_stack + 132924;
 Libderiv->deriv2_classes[2][5][23] = int_stack + 133584;
 Libderiv->deriv2_classes[2][6][23] = int_stack + 133710;
 Libderiv->deriv2_classes[2][7][23] = int_stack + 133878;
 Libderiv->deriv2_classes[2][8][23] = int_stack + 134094;
 Libderiv->deriv2_classes[2][9][23] = int_stack + 134364;
 Libderiv->deriv2_classes[2][10][23] = int_stack + 134694;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 135090;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 135300;
 Libderiv->deriv2_classes[3][7][23] = int_stack + 135580;
 Libderiv->deriv2_classes[3][8][23] = int_stack + 135940;
 Libderiv->deriv2_classes[3][9][23] = int_stack + 136390;
 Libderiv->deriv2_classes[3][10][23] = int_stack + 136940;
 Libderiv->deriv2_classes[2][5][22] = int_stack + 137600;
 Libderiv->deriv2_classes[2][6][22] = int_stack + 137726;
 Libderiv->deriv2_classes[2][7][22] = int_stack + 137894;
 Libderiv->deriv2_classes[2][8][22] = int_stack + 138110;
 Libderiv->deriv2_classes[2][9][22] = int_stack + 138380;
 Libderiv->deriv2_classes[2][10][22] = int_stack + 138710;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 139106;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 139316;
 Libderiv->deriv2_classes[3][7][22] = int_stack + 139596;
 Libderiv->deriv2_classes[3][8][22] = int_stack + 139956;
 Libderiv->deriv2_classes[3][9][22] = int_stack + 140406;
 Libderiv->deriv2_classes[3][10][22] = int_stack + 140956;
 Libderiv->deriv2_classes[2][5][21] = int_stack + 141616;
 Libderiv->deriv2_classes[2][6][21] = int_stack + 141742;
 Libderiv->deriv2_classes[2][7][21] = int_stack + 141910;
 Libderiv->deriv2_classes[2][8][21] = int_stack + 142126;
 Libderiv->deriv2_classes[2][9][21] = int_stack + 142396;
 Libderiv->deriv2_classes[2][10][21] = int_stack + 142726;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 143122;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 143332;
 Libderiv->deriv2_classes[3][7][21] = int_stack + 143612;
 Libderiv->deriv2_classes[3][8][21] = int_stack + 143972;
 Libderiv->deriv2_classes[3][9][21] = int_stack + 144422;
 Libderiv->deriv2_classes[3][10][21] = int_stack + 144972;
 Libderiv->deriv2_classes[2][5][20] = int_stack + 145632;
 Libderiv->deriv2_classes[2][6][20] = int_stack + 145758;
 Libderiv->deriv2_classes[2][7][20] = int_stack + 145926;
 Libderiv->deriv2_classes[2][8][20] = int_stack + 146142;
 Libderiv->deriv2_classes[2][9][20] = int_stack + 146412;
 Libderiv->deriv2_classes[2][10][20] = int_stack + 146742;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 147138;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 147348;
 Libderiv->deriv2_classes[3][7][20] = int_stack + 147628;
 Libderiv->deriv2_classes[3][8][20] = int_stack + 147988;
 Libderiv->deriv2_classes[3][9][20] = int_stack + 148438;
 Libderiv->deriv2_classes[3][10][20] = int_stack + 148988;
 Libderiv->deriv2_classes[2][5][19] = int_stack + 149648;
 Libderiv->deriv2_classes[2][6][19] = int_stack + 149774;
 Libderiv->deriv2_classes[2][7][19] = int_stack + 149942;
 Libderiv->deriv2_classes[2][8][19] = int_stack + 150158;
 Libderiv->deriv2_classes[2][9][19] = int_stack + 150428;
 Libderiv->deriv2_classes[2][10][19] = int_stack + 150758;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 151154;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 151364;
 Libderiv->deriv2_classes[3][7][19] = int_stack + 151644;
 Libderiv->deriv2_classes[3][8][19] = int_stack + 152004;
 Libderiv->deriv2_classes[3][9][19] = int_stack + 152454;
 Libderiv->deriv2_classes[3][10][19] = int_stack + 153004;
 Libderiv->deriv2_classes[2][5][18] = int_stack + 153664;
 Libderiv->deriv2_classes[2][6][18] = int_stack + 153790;
 Libderiv->deriv2_classes[2][7][18] = int_stack + 153958;
 Libderiv->deriv2_classes[2][8][18] = int_stack + 154174;
 Libderiv->deriv2_classes[2][9][18] = int_stack + 154444;
 Libderiv->deriv2_classes[2][10][18] = int_stack + 154774;
 Libderiv->deriv_classes[3][5][1] = int_stack + 155170;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 155380;
 Libderiv->deriv_classes[3][6][1] = int_stack + 155590;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 155870;
 Libderiv->deriv_classes[3][7][1] = int_stack + 156150;
 Libderiv->deriv2_classes[3][7][18] = int_stack + 156510;
 Libderiv->deriv_classes[3][8][1] = int_stack + 156870;
 Libderiv->deriv2_classes[3][8][18] = int_stack + 157320;
 Libderiv->deriv_classes[3][9][1] = int_stack + 157770;
 Libderiv->deriv2_classes[3][9][18] = int_stack + 158320;
 Libderiv->deriv2_classes[3][10][18] = int_stack + 158870;
 Libderiv->deriv2_classes[2][5][14] = int_stack + 159530;
 Libderiv->deriv2_classes[2][6][14] = int_stack + 159656;
 Libderiv->deriv2_classes[2][7][14] = int_stack + 159824;
 Libderiv->deriv2_classes[2][8][14] = int_stack + 160040;
 Libderiv->deriv2_classes[2][9][14] = int_stack + 160310;
 Libderiv->deriv2_classes[2][10][14] = int_stack + 160640;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 161036;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 161246;
 Libderiv->deriv2_classes[3][7][14] = int_stack + 161526;
 Libderiv->deriv2_classes[3][8][14] = int_stack + 161886;
 Libderiv->deriv2_classes[3][9][14] = int_stack + 162336;
 Libderiv->deriv2_classes[3][10][14] = int_stack + 162886;
 Libderiv->deriv2_classes[2][5][13] = int_stack + 163546;
 Libderiv->deriv2_classes[2][6][13] = int_stack + 163672;
 Libderiv->deriv2_classes[2][7][13] = int_stack + 163840;
 Libderiv->deriv2_classes[2][8][13] = int_stack + 164056;
 Libderiv->deriv2_classes[2][9][13] = int_stack + 164326;
 Libderiv->deriv2_classes[2][10][13] = int_stack + 164656;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 165052;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 165262;
 Libderiv->deriv2_classes[3][7][13] = int_stack + 165542;
 Libderiv->deriv2_classes[3][8][13] = int_stack + 165902;
 Libderiv->deriv2_classes[3][9][13] = int_stack + 166352;
 Libderiv->deriv2_classes[3][10][13] = int_stack + 166902;
 Libderiv->deriv_classes[2][5][11] = int_stack + 167562;
 Libderiv->deriv_classes[2][6][11] = int_stack + 167688;
 Libderiv->deriv_classes[2][7][11] = int_stack + 167856;
 Libderiv->deriv_classes[2][8][11] = int_stack + 168072;
 Libderiv->deriv_classes[2][9][11] = int_stack + 168342;
 Libderiv->deriv_classes[2][10][11] = int_stack + 168672;
 Libderiv->deriv2_classes[2][5][11] = int_stack + 169068;
 Libderiv->deriv2_classes[2][6][11] = int_stack + 169194;
 Libderiv->deriv2_classes[2][7][11] = int_stack + 169362;
 Libderiv->deriv2_classes[2][8][11] = int_stack + 169578;
 Libderiv->deriv2_classes[2][9][11] = int_stack + 169848;
 Libderiv->deriv2_classes[2][10][11] = int_stack + 170178;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 170574;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 170784;
 Libderiv->deriv2_classes[3][7][11] = int_stack + 171064;
 Libderiv->deriv2_classes[3][8][11] = int_stack + 171424;
 Libderiv->deriv2_classes[3][9][11] = int_stack + 171874;
 Libderiv->deriv2_classes[3][10][11] = int_stack + 172424;
 Libderiv->deriv_classes[2][5][10] = int_stack + 173084;
 Libderiv->deriv_classes[2][6][10] = int_stack + 173210;
 Libderiv->deriv_classes[2][7][10] = int_stack + 173378;
 Libderiv->deriv_classes[2][8][10] = int_stack + 173594;
 Libderiv->deriv_classes[2][9][10] = int_stack + 173864;
 Libderiv->deriv_classes[2][10][10] = int_stack + 174194;
 Libderiv->deriv2_classes[2][5][10] = int_stack + 174590;
 Libderiv->deriv2_classes[2][6][10] = int_stack + 174716;
 Libderiv->deriv2_classes[2][7][10] = int_stack + 174884;
 Libderiv->deriv2_classes[2][8][10] = int_stack + 175100;
 Libderiv->deriv2_classes[2][9][10] = int_stack + 175370;
 Libderiv->deriv2_classes[2][10][10] = int_stack + 175700;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 176096;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 176306;
 Libderiv->deriv2_classes[3][7][10] = int_stack + 176586;
 Libderiv->deriv2_classes[3][8][10] = int_stack + 176946;
 Libderiv->deriv2_classes[3][9][10] = int_stack + 177396;
 Libderiv->deriv2_classes[3][10][10] = int_stack + 177946;
 Libderiv->deriv_classes[2][5][9] = int_stack + 178606;
 Libderiv->deriv_classes[2][6][9] = int_stack + 178732;
 Libderiv->deriv_classes[2][7][9] = int_stack + 178900;
 Libderiv->deriv_classes[2][8][9] = int_stack + 179116;
 Libderiv->deriv_classes[2][9][9] = int_stack + 179386;
 Libderiv->deriv_classes[2][10][9] = int_stack + 179716;
 Libderiv->deriv2_classes[2][5][9] = int_stack + 180112;
 Libderiv->deriv2_classes[2][6][9] = int_stack + 180238;
 Libderiv->deriv2_classes[2][7][9] = int_stack + 180406;
 Libderiv->deriv2_classes[2][8][9] = int_stack + 180622;
 Libderiv->deriv2_classes[2][9][9] = int_stack + 180892;
 Libderiv->deriv2_classes[2][10][9] = int_stack + 181222;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 181618;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 181828;
 Libderiv->deriv2_classes[3][7][9] = int_stack + 182108;
 Libderiv->deriv2_classes[3][8][9] = int_stack + 182468;
 Libderiv->deriv2_classes[3][9][9] = int_stack + 182918;
 Libderiv->deriv2_classes[3][10][9] = int_stack + 183468;
 Libderiv->deriv_classes[2][5][8] = int_stack + 184128;
 Libderiv->deriv_classes[2][6][8] = int_stack + 184254;
 Libderiv->deriv_classes[2][7][8] = int_stack + 184422;
 Libderiv->deriv_classes[2][8][8] = int_stack + 184638;
 Libderiv->deriv_classes[2][9][8] = int_stack + 184908;
 Libderiv->deriv_classes[2][10][8] = int_stack + 185238;
 Libderiv->deriv2_classes[2][5][8] = int_stack + 185634;
 Libderiv->deriv2_classes[2][6][8] = int_stack + 185760;
 Libderiv->deriv2_classes[2][7][8] = int_stack + 185928;
 Libderiv->deriv2_classes[2][8][8] = int_stack + 186144;
 Libderiv->deriv2_classes[2][9][8] = int_stack + 186414;
 Libderiv->deriv2_classes[2][10][8] = int_stack + 186744;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 187140;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 187350;
 Libderiv->deriv2_classes[3][7][8] = int_stack + 187630;
 Libderiv->deriv2_classes[3][8][8] = int_stack + 187990;
 Libderiv->deriv2_classes[3][9][8] = int_stack + 188440;
 Libderiv->deriv2_classes[3][10][8] = int_stack + 188990;
 Libderiv->deriv_classes[2][5][7] = int_stack + 189650;
 Libderiv->deriv_classes[2][6][7] = int_stack + 189776;
 Libderiv->deriv_classes[2][7][7] = int_stack + 189944;
 Libderiv->deriv_classes[2][8][7] = int_stack + 190160;
 Libderiv->deriv_classes[2][9][7] = int_stack + 190430;
 Libderiv->deriv_classes[2][10][7] = int_stack + 190760;
 Libderiv->deriv2_classes[2][5][7] = int_stack + 191156;
 Libderiv->deriv2_classes[2][6][7] = int_stack + 191282;
 Libderiv->deriv2_classes[2][7][7] = int_stack + 191450;
 Libderiv->deriv2_classes[2][8][7] = int_stack + 191666;
 Libderiv->deriv2_classes[2][9][7] = int_stack + 191936;
 Libderiv->deriv2_classes[2][10][7] = int_stack + 192266;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 192662;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 192872;
 Libderiv->deriv2_classes[3][7][7] = int_stack + 193152;
 Libderiv->deriv2_classes[3][8][7] = int_stack + 193512;
 Libderiv->deriv2_classes[3][9][7] = int_stack + 193962;
 Libderiv->deriv2_classes[3][10][7] = int_stack + 194512;
 Libderiv->dvrr_classes[2][5] = int_stack + 195172;
 Libderiv->deriv_classes[2][5][6] = int_stack + 195298;
 Libderiv->dvrr_classes[2][6] = int_stack + 195424;
 Libderiv->deriv_classes[2][6][6] = int_stack + 195592;
 Libderiv->dvrr_classes[2][7] = int_stack + 195760;
 Libderiv->deriv_classes[2][7][6] = int_stack + 195976;
 Libderiv->dvrr_classes[2][8] = int_stack + 196192;
 Libderiv->deriv_classes[2][8][6] = int_stack + 196462;
 Libderiv->dvrr_classes[2][9] = int_stack + 196732;
 Libderiv->deriv_classes[2][9][6] = int_stack + 197062;
 Libderiv->deriv_classes[2][10][6] = int_stack + 197392;
 Libderiv->deriv2_classes[2][5][6] = int_stack + 197788;
 Libderiv->deriv2_classes[2][6][6] = int_stack + 197914;
 Libderiv->deriv2_classes[2][7][6] = int_stack + 198082;
 Libderiv->deriv2_classes[2][8][6] = int_stack + 198298;
 Libderiv->deriv2_classes[2][9][6] = int_stack + 198568;
 Libderiv->deriv2_classes[2][10][6] = int_stack + 198898;
 Libderiv->deriv_classes[3][5][0] = int_stack + 199294;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 199504;
 Libderiv->deriv_classes[3][6][0] = int_stack + 199714;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 199994;
 Libderiv->deriv_classes[3][7][0] = int_stack + 200274;
 Libderiv->deriv2_classes[3][7][6] = int_stack + 200634;
 Libderiv->deriv_classes[3][8][0] = int_stack + 200994;
 Libderiv->deriv2_classes[3][8][6] = int_stack + 201444;
 Libderiv->deriv_classes[3][9][0] = int_stack + 201894;
 Libderiv->deriv2_classes[3][9][6] = int_stack + 202444;
 Libderiv->deriv2_classes[3][10][6] = int_stack + 202994;
 Libderiv->deriv_classes[2][5][2] = int_stack + 203654;
 Libderiv->deriv_classes[2][6][2] = int_stack + 203780;
 Libderiv->deriv_classes[2][7][2] = int_stack + 203948;
 Libderiv->deriv_classes[2][8][2] = int_stack + 204164;
 Libderiv->deriv_classes[2][9][2] = int_stack + 204434;
 Libderiv->deriv_classes[2][10][2] = int_stack + 204764;
 Libderiv->deriv2_classes[2][5][2] = int_stack + 205160;
 Libderiv->deriv2_classes[2][6][2] = int_stack + 205286;
 Libderiv->deriv2_classes[2][7][2] = int_stack + 205454;
 Libderiv->deriv2_classes[2][8][2] = int_stack + 205670;
 Libderiv->deriv2_classes[2][9][2] = int_stack + 205940;
 Libderiv->deriv2_classes[2][10][2] = int_stack + 206270;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 206666;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 206876;
 Libderiv->deriv2_classes[3][7][2] = int_stack + 207156;
 Libderiv->deriv2_classes[3][8][2] = int_stack + 207516;
 Libderiv->deriv2_classes[3][9][2] = int_stack + 207966;
 Libderiv->deriv2_classes[3][10][2] = int_stack + 208516;
 Libderiv->deriv_classes[2][5][1] = int_stack + 209176;
 Libderiv->deriv_classes[2][6][1] = int_stack + 209302;
 Libderiv->deriv_classes[2][7][1] = int_stack + 209470;
 Libderiv->deriv_classes[2][8][1] = int_stack + 209686;
 Libderiv->deriv_classes[2][9][1] = int_stack + 209956;
 Libderiv->deriv_classes[2][10][1] = int_stack + 210286;
 Libderiv->deriv2_classes[2][5][1] = int_stack + 210682;
 Libderiv->deriv2_classes[2][6][1] = int_stack + 210808;
 Libderiv->deriv2_classes[2][7][1] = int_stack + 210976;
 Libderiv->deriv2_classes[2][8][1] = int_stack + 211192;
 Libderiv->deriv2_classes[2][9][1] = int_stack + 211462;
 Libderiv->deriv2_classes[2][10][1] = int_stack + 211792;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 212188;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 212398;
 Libderiv->deriv2_classes[3][7][1] = int_stack + 212678;
 Libderiv->deriv2_classes[3][8][1] = int_stack + 213038;
 Libderiv->deriv2_classes[3][9][1] = int_stack + 213488;
 Libderiv->deriv2_classes[3][10][1] = int_stack + 214038;
 Libderiv->deriv_classes[2][5][0] = int_stack + 214698;
 Libderiv->deriv_classes[2][6][0] = int_stack + 214824;
 Libderiv->deriv_classes[2][7][0] = int_stack + 214992;
 Libderiv->deriv_classes[2][8][0] = int_stack + 215208;
 Libderiv->deriv_classes[2][9][0] = int_stack + 215478;
 Libderiv->deriv_classes[2][10][0] = int_stack + 215808;
 Libderiv->deriv2_classes[2][5][0] = int_stack + 216204;
 Libderiv->deriv2_classes[2][6][0] = int_stack + 216330;
 Libderiv->deriv2_classes[2][7][0] = int_stack + 216498;
 Libderiv->deriv2_classes[2][8][0] = int_stack + 216714;
 Libderiv->deriv2_classes[2][9][0] = int_stack + 216984;
 Libderiv->deriv2_classes[2][10][0] = int_stack + 217314;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 217710;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 217920;
 Libderiv->deriv2_classes[3][7][0] = int_stack + 218200;
 Libderiv->deriv2_classes[3][8][0] = int_stack + 218560;
 Libderiv->deriv2_classes[3][9][0] = int_stack + 219010;
 Libderiv->deriv2_classes[3][10][0] = int_stack + 219560;
 memset(int_stack,0,1761760);

 Libderiv->dvrr_stack = int_stack + 595428;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_dphh(Libderiv, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+220220,int_stack+195424,int_stack+195172,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+220598,int_stack+195760,int_stack+195424,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+221102,int_stack+220598,int_stack+220220,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+221858,int_stack+196192,int_stack+195760,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+222506,int_stack+221858,int_stack+220598,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+223514,int_stack+222506,int_stack+221102,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+224774,int_stack+196732,int_stack+196192,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+225584,int_stack+224774,int_stack+221858,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+226880,int_stack+225584,int_stack+222506,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+228560,int_stack+226880,int_stack+223514,6);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+230450,int_stack+167688,int_stack+167562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195172,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+230828,int_stack+167856,int_stack+167688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195424,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+231332,int_stack+230828,int_stack+230450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220220,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+232088,int_stack+168072,int_stack+167856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195760,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+232736,int_stack+232088,int_stack+230828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220598,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+233744,int_stack+232736,int_stack+231332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221102,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+235004,int_stack+168342,int_stack+168072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196192,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+235814,int_stack+235004,int_stack+232088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221858,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+237110,int_stack+235814,int_stack+232736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222506,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+238790,int_stack+237110,int_stack+233744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+223514,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+240680,int_stack+168672,int_stack+168342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196732,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+241670,int_stack+240680,int_stack+235004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224774,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+243290,int_stack+241670,int_stack+235814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225584,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+240680,int_stack+243290,int_stack+237110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226880,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+243200,int_stack+240680,int_stack+238790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228560,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+240680,int_stack+98592,int_stack+97962,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+241310,int_stack+99432,int_stack+98592,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+245846,int_stack+241310,int_stack+240680,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+247106,int_stack+100512,int_stack+99432,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+248186,int_stack+247106,int_stack+241310,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+249866,int_stack+248186,int_stack+245846,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+251966,int_stack+3300,int_stack+100512,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+253316,int_stack+251966,int_stack+247106,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+255476,int_stack+253316,int_stack+248186,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+258276,int_stack+255476,int_stack+249866,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+242150,int_stack+69052,int_stack+68632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97962,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+261426,int_stack+69612,int_stack+69052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98592,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+262266,int_stack+261426,int_stack+242150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240680,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+263526,int_stack+70332,int_stack+69612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99432,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+264606,int_stack+263526,int_stack+261426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241310,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+266286,int_stack+264606,int_stack+262266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245846,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+268386,int_stack+71232,int_stack+70332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100512,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+269736,int_stack+268386,int_stack+263526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247106,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+271896,int_stack+269736,int_stack+264606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248186,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+274696,int_stack+271896,int_stack+266286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249866,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+277846,int_stack+0,int_stack+71232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3300,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+279496,int_stack+277846,int_stack+268386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251966,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+282196,int_stack+279496,int_stack+269736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253316,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+277846,int_stack+282196,int_stack+271896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255476,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+282046,int_stack+277846,int_stack+274696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258276,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+277846,int_stack+173210,int_stack+173084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195172, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+278224,int_stack+173378,int_stack+173210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195424, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+278728,int_stack+278224,int_stack+277846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220220, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+279484,int_stack+173594,int_stack+173378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195760, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+280132,int_stack+279484,int_stack+278224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220598, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+286456,int_stack+280132,int_stack+278728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221102, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+281140,int_stack+173864,int_stack+173594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196192, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+287716,int_stack+281140,int_stack+279484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221858, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+289012,int_stack+287716,int_stack+280132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222506, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+290692,int_stack+289012,int_stack+286456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+223514, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+292582,int_stack+174194,int_stack+173864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196732, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+293572,int_stack+292582,int_stack+281140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224774, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+295192,int_stack+293572,int_stack+287716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225584, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+292582,int_stack+295192,int_stack+289012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226880, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+295102,int_stack+292582,int_stack+290692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228560, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+292582,int_stack+74918,int_stack+74498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97962, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+293212,int_stack+75478,int_stack+74918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98592, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+297748,int_stack+293212,int_stack+292582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240680, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+299008,int_stack+76198,int_stack+75478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99432, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+300088,int_stack+299008,int_stack+293212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241310, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+301768,int_stack+300088,int_stack+297748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245846, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+303868,int_stack+77098,int_stack+76198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100512, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+305218,int_stack+303868,int_stack+299008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247106, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+307378,int_stack+305218,int_stack+300088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248186, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+310178,int_stack+307378,int_stack+301768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249866, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+313328,int_stack+660,int_stack+77098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3300, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+314978,int_stack+313328,int_stack+303868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251966, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+317678,int_stack+314978,int_stack+305218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253316, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+313328,int_stack+317678,int_stack+307378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255476, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+317528,int_stack+313328,int_stack+310178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258276, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+313328,int_stack+178732,int_stack+178606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195172, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+313706,int_stack+178900,int_stack+178732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195424, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+314210,int_stack+313706,int_stack+313328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220220, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+314966,int_stack+179116,int_stack+178900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195760, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+315614,int_stack+314966,int_stack+313706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220598, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+315614,int_stack+314210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221102, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+316622,int_stack+179386,int_stack+179116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196192, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+321938,int_stack+316622,int_stack+314966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221858, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+323234,int_stack+321938,int_stack+315614, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222506, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+324914,int_stack+323234,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+223514, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+294052,int_stack+179716,int_stack+179386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196732, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+326804,int_stack+294052,int_stack+316622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224774, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+328424,int_stack+326804,int_stack+321938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225584, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+330584,int_stack+328424,int_stack+323234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226880, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+326804,int_stack+330584,int_stack+324914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228560, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+329450,int_stack+80784,int_stack+80364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97962, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+330080,int_stack+81344,int_stack+80784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98592, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+330920,int_stack+330080,int_stack+329450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240680, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+332180,int_stack+82064,int_stack+81344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99432, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+333260,int_stack+332180,int_stack+330080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241310, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+334940,int_stack+333260,int_stack+330920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245846, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+337040,int_stack+82964,int_stack+82064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100512, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+338390,int_stack+337040,int_stack+332180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247106, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+340550,int_stack+338390,int_stack+333260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248186, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+343350,int_stack+340550,int_stack+334940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249866, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+346500,int_stack+1320,int_stack+82964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3300, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+348150,int_stack+346500,int_stack+337040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251966, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+350850,int_stack+348150,int_stack+338390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253316, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+346500,int_stack+350850,int_stack+340550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255476, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+350700,int_stack+346500,int_stack+343350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258276, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+346500,int_stack+184254,int_stack+184128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+346878,int_stack+184422,int_stack+184254, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+347382,int_stack+346878,int_stack+346500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+348138,int_stack+184638,int_stack+184422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+348786,int_stack+348138,int_stack+346878, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+355110,int_stack+348786,int_stack+347382, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+349794,int_stack+184908,int_stack+184638, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+356370,int_stack+349794,int_stack+348138, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+357666,int_stack+356370,int_stack+348786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+359346,int_stack+357666,int_stack+355110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+223514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+294052,int_stack+185238,int_stack+184908, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+361236,int_stack+294052,int_stack+349794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+362856,int_stack+361236,int_stack+356370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+365016,int_stack+362856,int_stack+357666, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+361236,int_stack+365016,int_stack+359346, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+228560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+363882,int_stack+86650,int_stack+86230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+97962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+364512,int_stack+87210,int_stack+86650, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+365352,int_stack+364512,int_stack+363882, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+366612,int_stack+87930,int_stack+87210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+367692,int_stack+366612,int_stack+364512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+241310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+369372,int_stack+367692,int_stack+365352, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+371472,int_stack+88830,int_stack+87930, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+372822,int_stack+371472,int_stack+366612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+374982,int_stack+372822,int_stack+367692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+377782,int_stack+374982,int_stack+369372, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+380932,int_stack+1980,int_stack+88830, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+382582,int_stack+380932,int_stack+371472, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+251966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+385282,int_stack+382582,int_stack+372822, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+380932,int_stack+385282,int_stack+374982, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+385132,int_stack+380932,int_stack+377782, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+380932,int_stack+189776,int_stack+189650, 0.0, zero_stack, 1.0, int_stack+195172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+381310,int_stack+189944,int_stack+189776, 0.0, zero_stack, 1.0, int_stack+195424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+381814,int_stack+381310,int_stack+380932, 0.0, zero_stack, 1.0, int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+382570,int_stack+190160,int_stack+189944, 0.0, zero_stack, 1.0, int_stack+195760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+383218,int_stack+382570,int_stack+381310, 0.0, zero_stack, 1.0, int_stack+220598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1260,int_stack+383218,int_stack+381814, 0.0, zero_stack, 1.0, int_stack+221102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+384226,int_stack+190430,int_stack+190160, 0.0, zero_stack, 1.0, int_stack+196192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+389542,int_stack+384226,int_stack+382570, 0.0, zero_stack, 1.0, int_stack+221858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+390838,int_stack+389542,int_stack+383218, 0.0, zero_stack, 1.0, int_stack+222506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+392518,int_stack+390838,int_stack+1260, 0.0, zero_stack, 1.0, int_stack+223514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+294052,int_stack+190760,int_stack+190430, 0.0, zero_stack, 1.0, int_stack+196732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+394408,int_stack+294052,int_stack+384226, 0.0, zero_stack, 1.0, int_stack+224774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+396028,int_stack+394408,int_stack+389542, 0.0, zero_stack, 1.0, int_stack+225584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+398188,int_stack+396028,int_stack+390838, 0.0, zero_stack, 1.0, int_stack+226880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+394408,int_stack+398188,int_stack+392518, 0.0, zero_stack, 1.0, int_stack+228560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397054,int_stack+92516,int_stack+92096, 0.0, zero_stack, 1.0, int_stack+97962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+397684,int_stack+93076,int_stack+92516, 0.0, zero_stack, 1.0, int_stack+98592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+398524,int_stack+397684,int_stack+397054, 0.0, zero_stack, 1.0, int_stack+240680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+399784,int_stack+93796,int_stack+93076, 0.0, zero_stack, 1.0, int_stack+99432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+400864,int_stack+399784,int_stack+397684, 0.0, zero_stack, 1.0, int_stack+241310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+402544,int_stack+400864,int_stack+398524, 0.0, zero_stack, 1.0, int_stack+245846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+404644,int_stack+94696,int_stack+93796, 0.0, zero_stack, 1.0, int_stack+100512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+405994,int_stack+404644,int_stack+399784, 0.0, zero_stack, 1.0, int_stack+247106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+408154,int_stack+405994,int_stack+400864, 0.0, zero_stack, 1.0, int_stack+248186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+410954,int_stack+408154,int_stack+402544, 0.0, zero_stack, 1.0, int_stack+249866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+414104,int_stack+2640,int_stack+94696, 0.0, zero_stack, 1.0, int_stack+3300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+415754,int_stack+414104,int_stack+404644, 0.0, zero_stack, 1.0, int_stack+251966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+418454,int_stack+415754,int_stack+405994, 0.0, zero_stack, 1.0, int_stack+253316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+414104,int_stack+418454,int_stack+408154, 0.0, zero_stack, 1.0, int_stack+255476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+418304,int_stack+414104,int_stack+410954, 0.0, zero_stack, 1.0, int_stack+258276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+414104,int_stack+195592,int_stack+195298, 1.0, int_stack+195172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+414482,int_stack+195976,int_stack+195592, 1.0, int_stack+195424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+414986,int_stack+414482,int_stack+414104, 1.0, int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+415742,int_stack+196462,int_stack+195976, 1.0, int_stack+195760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+416390,int_stack+415742,int_stack+414482, 1.0, int_stack+220598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+422714,int_stack+416390,int_stack+414986, 1.0, int_stack+221102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+220220,int_stack+197062,int_stack+196462, 1.0, int_stack+196192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+423974,int_stack+220220,int_stack+415742, 1.0, int_stack+221858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+425270,int_stack+423974,int_stack+416390, 1.0, int_stack+222506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+221030,int_stack+425270,int_stack+422714, 1.0, int_stack+223514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+222920,int_stack+197392,int_stack+197062, 1.0, int_stack+196732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+426950,int_stack+222920,int_stack+220220, 1.0, int_stack+224774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+428570,int_stack+426950,int_stack+423974, 1.0, int_stack+225584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+430730,int_stack+428570,int_stack+425270, 1.0, int_stack+226880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+426950,int_stack+430730,int_stack+221030, 1.0, int_stack+228560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+429596,int_stack+98872,int_stack+98172, 1.0, int_stack+97962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+430226,int_stack+99792,int_stack+98872, 1.0, int_stack+98592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+431066,int_stack+430226,int_stack+429596, 1.0, int_stack+240680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+432326,int_stack+100962,int_stack+99792, 1.0, int_stack+99432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+222920,int_stack+432326,int_stack+430226, 1.0, int_stack+241310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+433406,int_stack+222920,int_stack+431066, 1.0, int_stack+245846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+240680,int_stack+101862,int_stack+100962, 1.0, int_stack+100512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+435506,int_stack+240680,int_stack+432326, 1.0, int_stack+247106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+437666,int_stack+435506,int_stack+222920, 1.0, int_stack+248186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+245846,int_stack+437666,int_stack+433406, 1.0, int_stack+249866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+248996,int_stack+3850,int_stack+101862, 1.0, int_stack+3300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+440466,int_stack+248996,int_stack+240680, 1.0, int_stack+251966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+248996,int_stack+440466,int_stack+435506, 1.0, int_stack+253316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+440466,int_stack+248996,int_stack+437666, 1.0, int_stack+255476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+248996,int_stack+440466,int_stack+245846, 1.0, int_stack+258276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+440466,int_stack+5830,int_stack+196732,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+441456,int_stack+440466,int_stack+224774,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+253406,int_stack+441456,int_stack+225584,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+440466,int_stack+253406,int_stack+226880,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+253406,int_stack+440466,int_stack+228560,6);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+440466,int_stack+203780,int_stack+203654,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+440844,int_stack+203948,int_stack+203780,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+441348,int_stack+440844,int_stack+440466,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+442104,int_stack+204164,int_stack+203948,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+442752,int_stack+442104,int_stack+440844,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+256052,int_stack+442752,int_stack+441348,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+443760,int_stack+204434,int_stack+204164,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+257312,int_stack+443760,int_stack+442104,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+258608,int_stack+257312,int_stack+442752,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+224600,int_stack+258608,int_stack+256052,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+260288,int_stack+204764,int_stack+204434,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+226490,int_stack+260288,int_stack+443760,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+228110,int_stack+226490,int_stack+257312,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+444570,int_stack+228110,int_stack+258608,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+226490,int_stack+444570,int_stack+224600,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+444570,int_stack+125628,int_stack+125208,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+445200,int_stack+126188,int_stack+125628,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+446040,int_stack+445200,int_stack+444570,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+229136,int_stack+126908,int_stack+126188,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+2520,int_stack+229136,int_stack+445200,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+447300,int_stack+2520,int_stack+446040,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+449400,int_stack+127808,int_stack+126908,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+450750,int_stack+449400,int_stack+229136,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+452910,int_stack+450750,int_stack+2520,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+455710,int_stack+452910,int_stack+447300,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+458860,int_stack+4510,int_stack+127808,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+460510,int_stack+458860,int_stack+449400,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+463210,int_stack+460510,int_stack+450750,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+458860,int_stack+463210,int_stack+452910,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+463060,int_stack+458860,int_stack+455710,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+458860,int_stack+209302,int_stack+209176,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+459238,int_stack+209470,int_stack+209302,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+459742,int_stack+459238,int_stack+458860,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+460498,int_stack+209686,int_stack+209470,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+461146,int_stack+460498,int_stack+459238,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+467470,int_stack+461146,int_stack+459742,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+462154,int_stack+209956,int_stack+209686,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+468730,int_stack+462154,int_stack+460498,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+470026,int_stack+468730,int_stack+461146,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+471706,int_stack+470026,int_stack+467470,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+260288,int_stack+210286,int_stack+209956,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+473596,int_stack+260288,int_stack+462154,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+475216,int_stack+473596,int_stack+468730,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+477376,int_stack+475216,int_stack+470026,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+473596,int_stack+477376,int_stack+471706,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+476242,int_stack+155590,int_stack+155170,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+476872,int_stack+156150,int_stack+155590,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+477712,int_stack+476872,int_stack+476242,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+260288,int_stack+156870,int_stack+156150,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+478972,int_stack+260288,int_stack+476872,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+480652,int_stack+478972,int_stack+477712,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+482752,int_stack+157770,int_stack+156870,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+484102,int_stack+482752,int_stack+260288,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+486262,int_stack+484102,int_stack+478972,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+489062,int_stack+486262,int_stack+480652,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+492212,int_stack+5170,int_stack+157770,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+493862,int_stack+492212,int_stack+482752,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+496562,int_stack+493862,int_stack+484102,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+492212,int_stack+496562,int_stack+486262,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+496412,int_stack+492212,int_stack+489062,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+492212,int_stack+214824,int_stack+214698,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+492590,int_stack+214992,int_stack+214824,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+493094,int_stack+492590,int_stack+492212,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+493850,int_stack+215208,int_stack+214992,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+494498,int_stack+493850,int_stack+492590,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+4200,int_stack+494498,int_stack+493094,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+495506,int_stack+215478,int_stack+215208,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+500822,int_stack+495506,int_stack+493850,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+502118,int_stack+500822,int_stack+494498,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+503798,int_stack+502118,int_stack+4200,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+294052,int_stack+215808,int_stack+215478,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+505688,int_stack+294052,int_stack+495506,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+507308,int_stack+505688,int_stack+500822,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+509468,int_stack+507308,int_stack+502118,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+505688,int_stack+509468,int_stack+503798,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+508334,int_stack+199714,int_stack+199294,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+508964,int_stack+200274,int_stack+199714,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+509804,int_stack+508964,int_stack+508334,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+511064,int_stack+200994,int_stack+200274,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+512144,int_stack+511064,int_stack+508964,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+513824,int_stack+512144,int_stack+509804,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+515924,int_stack+201894,int_stack+200994,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+517274,int_stack+515924,int_stack+511064,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+519434,int_stack+517274,int_stack+512144,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+522234,int_stack+519434,int_stack+513824,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+525384,int_stack+6226,int_stack+201894,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+527034,int_stack+525384,int_stack+515924,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+529734,int_stack+527034,int_stack+517274,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+525384,int_stack+529734,int_stack+519434,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+529584,int_stack+525384,int_stack+522234,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+525384,int_stack+7012,int_stack+6886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+167562,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+525762,int_stack+7180,int_stack+7012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+167688,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+526266,int_stack+525762,int_stack+525384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+230450,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+527022,int_stack+7396,int_stack+7180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+167856,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+527670,int_stack+527022,int_stack+525762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+230828,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5460,int_stack+527670,int_stack+526266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+231332,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+525384,int_stack+7666,int_stack+7396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+168072,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+533994,int_stack+525384,int_stack+527022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+232088,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+535290,int_stack+533994,int_stack+527670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+232736,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+526194,int_stack+535290,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+233744,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5460,int_stack+7996,int_stack+7666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+168342,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+6450,int_stack+5460,int_stack+525384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+235004,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+536970,int_stack+6450,int_stack+533994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+235814,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5460,int_stack+536970,int_stack+535290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+237110,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+533994,int_stack+5460,int_stack+526194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+238790,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5460,int_stack+8602,int_stack+8392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+68632,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6090,int_stack+8882,int_stack+8602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+69052,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6930,int_stack+6090,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+242150,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+536640,int_stack+9242,int_stack+8882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+69612,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+537720,int_stack+536640,int_stack+6090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+261426,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+525384,int_stack+537720,int_stack+6930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+262266,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5460,int_stack+9692,int_stack+9242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+70332,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+6810,int_stack+5460,int_stack+536640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+263526,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+539400,int_stack+6810,int_stack+537720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+264606,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+542200,int_stack+539400,int_stack+525384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+266286,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+525384,int_stack+10242,int_stack+9692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+71232,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+536640,int_stack+525384,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+268386,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+525384,int_stack+536640,int_stack+6810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+269736,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5460,int_stack+525384,int_stack+539400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+271896,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+536640,int_stack+5460,int_stack+542200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+274696,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5460,int_stack+11028,int_stack+10902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167562, 1.0, int_stack+173084,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5838,int_stack+11196,int_stack+11028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167688, 1.0, int_stack+173210,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6342,int_stack+5838,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230450, 1.0, int_stack+277846,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7098,int_stack+11412,int_stack+11196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167856, 1.0, int_stack+173378,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7746,int_stack+7098,int_stack+5838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230828, 1.0, int_stack+278224,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8754,int_stack+7746,int_stack+6342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231332, 1.0, int_stack+278728,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5460,int_stack+11682,int_stack+11412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168072, 1.0, int_stack+173594,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10014,int_stack+5460,int_stack+7098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232088, 1.0, int_stack+279484,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+525384,int_stack+10014,int_stack+7746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232736, 1.0, int_stack+280132,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6270,int_stack+525384,int_stack+8754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233744, 1.0, int_stack+286456,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8160,int_stack+12012,int_stack+11682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168342, 1.0, int_stack+173864,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+527064,int_stack+8160,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235004, 1.0, int_stack+281140,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+541050,int_stack+527064,int_stack+10014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235814, 1.0, int_stack+287716,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+527064,int_stack+541050,int_stack+525384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237110, 1.0, int_stack+289012,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+541050,int_stack+527064,int_stack+6270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238790, 1.0, int_stack+290692,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+525384,int_stack+12618,int_stack+12408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68632, 1.0, int_stack+74498,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+526014,int_stack+12898,int_stack+12618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69052, 1.0, int_stack+74918,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+526854,int_stack+526014,int_stack+525384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242150, 1.0, int_stack+292582,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+528114,int_stack+13258,int_stack+12898, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69612, 1.0, int_stack+75478,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+543696,int_stack+528114,int_stack+526014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261426, 1.0, int_stack+293212,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+5460,int_stack+543696,int_stack+526854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262266, 1.0, int_stack+297748,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+525384,int_stack+13708,int_stack+13258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70332, 1.0, int_stack+76198,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+7560,int_stack+525384,int_stack+528114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263526, 1.0, int_stack+299008,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+526734,int_stack+7560,int_stack+543696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264606, 1.0, int_stack+300088,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+9720,int_stack+526734,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+266286, 1.0, int_stack+301768,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+5460,int_stack+14258,int_stack+13708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71232, 1.0, int_stack+77098,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+543696,int_stack+5460,int_stack+525384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268386, 1.0, int_stack+303868,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+546396,int_stack+543696,int_stack+7560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269736, 1.0, int_stack+305218,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+5460,int_stack+546396,int_stack+526734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271896, 1.0, int_stack+307378,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+543696,int_stack+5460,int_stack+9720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274696, 1.0, int_stack+310178,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5460,int_stack+15044,int_stack+14918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+173084, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5838,int_stack+15212,int_stack+15044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+173210, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6342,int_stack+5838,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+277846, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7098,int_stack+15428,int_stack+15212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+173378, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7746,int_stack+7098,int_stack+5838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+278224, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8754,int_stack+7746,int_stack+6342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+278728, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5460,int_stack+15698,int_stack+15428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+173594, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10014,int_stack+5460,int_stack+7098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+279484, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11310,int_stack+10014,int_stack+7746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+280132, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6270,int_stack+11310,int_stack+8754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+286456, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8160,int_stack+16028,int_stack+15698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+173864, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12990,int_stack+8160,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+281140, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+525384,int_stack+12990,int_stack+10014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+287716, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+12990,int_stack+525384,int_stack+11310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+289012, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+525384,int_stack+12990,int_stack+6270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+290692, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+528030,int_stack+16634,int_stack+16424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+74498, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+528660,int_stack+16914,int_stack+16634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+74918, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5460,int_stack+528660,int_stack+528030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+292582, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+6720,int_stack+17274,int_stack+16914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+75478, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7800,int_stack+6720,int_stack+528660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+293212, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+9480,int_stack+7800,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+297748, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+528030,int_stack+17724,int_stack+17274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+76198, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+11580,int_stack+528030,int_stack+6720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+299008, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+13740,int_stack+11580,int_stack+7800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+300088, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+5460,int_stack+13740,int_stack+9480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+301768, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8610,int_stack+18274,int_stack+17724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+77098, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+548106,int_stack+8610,int_stack+528030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+303868, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+550806,int_stack+548106,int_stack+11580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+305218, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8610,int_stack+550806,int_stack+13740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+307378, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+548106,int_stack+8610,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+310178, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5460,int_stack+19060,int_stack+18934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167562, 0.0, zero_stack, 1.0, int_stack+178606,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5838,int_stack+19228,int_stack+19060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167688, 0.0, zero_stack, 1.0, int_stack+178732,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6342,int_stack+5838,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230450, 0.0, zero_stack, 1.0, int_stack+313328,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+7098,int_stack+19444,int_stack+19228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167856, 0.0, zero_stack, 1.0, int_stack+178900,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+7746,int_stack+7098,int_stack+5838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230828, 0.0, zero_stack, 1.0, int_stack+313706,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+8754,int_stack+7746,int_stack+6342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231332, 0.0, zero_stack, 1.0, int_stack+314210,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5460,int_stack+19714,int_stack+19444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168072, 0.0, zero_stack, 1.0, int_stack+179116,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+10014,int_stack+5460,int_stack+7098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232088, 0.0, zero_stack, 1.0, int_stack+314966,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+11310,int_stack+10014,int_stack+7746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232736, 0.0, zero_stack, 1.0, int_stack+315614,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+6270,int_stack+11310,int_stack+8754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233744, 0.0, zero_stack, 1.0, int_stack+0,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+8160,int_stack+20044,int_stack+19714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168342, 0.0, zero_stack, 1.0, int_stack+179386,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+12990,int_stack+8160,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235004, 0.0, zero_stack, 1.0, int_stack+316622,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+14610,int_stack+12990,int_stack+10014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235814, 0.0, zero_stack, 1.0, int_stack+321938,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+8160,int_stack+14610,int_stack+11310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237110, 0.0, zero_stack, 1.0, int_stack+323234,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+10680,int_stack+8160,int_stack+6270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238790, 0.0, zero_stack, 1.0, int_stack+324914,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5460,int_stack+20650,int_stack+20440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68632, 0.0, zero_stack, 1.0, int_stack+80364,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+6090,int_stack+20930,int_stack+20650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69052, 0.0, zero_stack, 1.0, int_stack+80784,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6930,int_stack+6090,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242150, 0.0, zero_stack, 1.0, int_stack+329450,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+8190,int_stack+21290,int_stack+20930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69612, 0.0, zero_stack, 1.0, int_stack+81344,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+13326,int_stack+8190,int_stack+6090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261426, 0.0, zero_stack, 1.0, int_stack+330080,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15006,int_stack+13326,int_stack+6930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262266, 0.0, zero_stack, 1.0, int_stack+330920,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+5460,int_stack+21740,int_stack+21290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70332, 0.0, zero_stack, 1.0, int_stack+82064,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+17106,int_stack+5460,int_stack+8190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263526, 0.0, zero_stack, 1.0, int_stack+332180,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+6810,int_stack+17106,int_stack+13326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264606, 0.0, zero_stack, 1.0, int_stack+333260,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+552516,int_stack+6810,int_stack+15006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+266286, 0.0, zero_stack, 1.0, int_stack+334940,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13326,int_stack+22290,int_stack+21740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71232, 0.0, zero_stack, 1.0, int_stack+82964,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+19266,int_stack+13326,int_stack+5460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268386, 0.0, zero_stack, 1.0, int_stack+337040,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13326,int_stack+19266,int_stack+17106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269736, 0.0, zero_stack, 1.0, int_stack+338390,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+16926,int_stack+13326,int_stack+6810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271896, 0.0, zero_stack, 1.0, int_stack+340550,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+5460,int_stack+16926,int_stack+552516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274696, 0.0, zero_stack, 1.0, int_stack+343350,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+552516,int_stack+23076,int_stack+22950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173084, 1.0, int_stack+178606, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+552894,int_stack+23244,int_stack+23076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173210, 1.0, int_stack+178732, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+553398,int_stack+552894,int_stack+552516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277846, 1.0, int_stack+313328, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+554154,int_stack+23460,int_stack+23244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173378, 1.0, int_stack+178900, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+554802,int_stack+554154,int_stack+552894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278224, 1.0, int_stack+313706, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+13326,int_stack+554802,int_stack+553398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278728, 1.0, int_stack+314210, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+23730,int_stack+23460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173594, 1.0, int_stack+179116, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+552516,int_stack+9870,int_stack+554154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279484, 1.0, int_stack+314966, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+14586,int_stack+552516,int_stack+554802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280132, 1.0, int_stack+315614, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+553812,int_stack+14586,int_stack+13326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286456, 1.0, int_stack+0, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+13326,int_stack+24060,int_stack+23730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173864, 1.0, int_stack+179386, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+16266,int_stack+13326,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281140, 1.0, int_stack+316622, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+17886,int_stack+16266,int_stack+552516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+287716, 1.0, int_stack+321938, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+20046,int_stack+17886,int_stack+14586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289012, 1.0, int_stack+323234, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13326,int_stack+20046,int_stack+553812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290692, 1.0, int_stack+324914, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+552516,int_stack+24666,int_stack+24456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74498, 1.0, int_stack+80364, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+553146,int_stack+24946,int_stack+24666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74918, 1.0, int_stack+80784, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+553986,int_stack+553146,int_stack+552516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292582, 1.0, int_stack+329450, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15972,int_stack+25306,int_stack+24946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75478, 1.0, int_stack+81344, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+17052,int_stack+15972,int_stack+553146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293212, 1.0, int_stack+330080, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+18732,int_stack+17052,int_stack+553986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297748, 1.0, int_stack+330920, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+552516,int_stack+25756,int_stack+25306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76198, 1.0, int_stack+82064, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+20832,int_stack+552516,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299008, 1.0, int_stack+332180, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+553866,int_stack+20832,int_stack+17052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300088, 1.0, int_stack+333260, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+556666,int_stack+553866,int_stack+18732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301768, 1.0, int_stack+334940, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15972,int_stack+26306,int_stack+25756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77098, 1.0, int_stack+82964, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+17622,int_stack+15972,int_stack+552516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303868, 1.0, int_stack+337040, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+22992,int_stack+17622,int_stack+20832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305218, 1.0, int_stack+338390, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+15972,int_stack+22992,int_stack+553866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+307378, 1.0, int_stack+340550, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+20172,int_stack+15972,int_stack+556666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310178, 1.0, int_stack+343350, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15972,int_stack+27092,int_stack+26966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+178606, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16350,int_stack+27260,int_stack+27092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+178732, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16854,int_stack+16350,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+313328, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17610,int_stack+27476,int_stack+27260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+178900, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+18258,int_stack+17610,int_stack+16350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+313706, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+552516,int_stack+18258,int_stack+16854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+314210, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+27746,int_stack+27476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+179116, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15972,int_stack+9870,int_stack+17610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+314966, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+553776,int_stack+15972,int_stack+18258, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+315614, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+17268,int_stack+553776,int_stack+552516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+552516,int_stack+28076,int_stack+27746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+179386, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+555456,int_stack+552516,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+316622, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+557076,int_stack+555456,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+321938, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+24582,int_stack+557076,int_stack+553776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+323234, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+552516,int_stack+24582,int_stack+17268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+324914, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+24582,int_stack+28682,int_stack+28472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+80364, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+25212,int_stack+28962,int_stack+28682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+80784, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+26052,int_stack+25212,int_stack+24582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+329450, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+27312,int_stack+29322,int_stack+28962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+81344, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15972,int_stack+27312,int_stack+25212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+330080, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+17652,int_stack+15972,int_stack+26052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+330920, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24582,int_stack+29772,int_stack+29322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+82064, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+555162,int_stack+24582,int_stack+27312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+332180, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+25932,int_stack+555162,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+333260, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+557322,int_stack+25932,int_stack+17652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+334940, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15972,int_stack+30322,int_stack+29772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+82964, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+560472,int_stack+15972,int_stack+24582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+337040, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+15972,int_stack+560472,int_stack+555162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+338390, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+560472,int_stack+15972,int_stack+25932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+340550, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+24582,int_stack+560472,int_stack+557322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+343350, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15972,int_stack+31108,int_stack+30982, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184128,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16350,int_stack+31276,int_stack+31108, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184254,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16854,int_stack+16350,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346500,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17610,int_stack+31492,int_stack+31276, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+167856, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184422,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+18258,int_stack+17610,int_stack+16350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+230828, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346878,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+555162,int_stack+18258,int_stack+16854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231332, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+347382,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+31762,int_stack+31492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184638,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15972,int_stack+9870,int_stack+17610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232088, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348138,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+556422,int_stack+15972,int_stack+18258, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+232736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348786,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+17268,int_stack+556422,int_stack+555162, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355110,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+555162,int_stack+32092,int_stack+31762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+168342, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+184908,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+558102,int_stack+555162,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349794,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+559722,int_stack+558102,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235814, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356370,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+561882,int_stack+559722,int_stack+556422, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237110, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+357666,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+555162,int_stack+561882,int_stack+17268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238790, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359346,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15972,int_stack+32698,int_stack+32488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+68632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86230,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16602,int_stack+32978,int_stack+32698, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+86650,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17442,int_stack+16602,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242150, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363882,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18702,int_stack+33338,int_stack+32978, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+69612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87210,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+557808,int_stack+18702,int_stack+16602, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261426, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364512,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+559488,int_stack+557808,int_stack+17442, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365352,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+15972,int_stack+33788,int_stack+33338, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+70332, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+87930,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+561588,int_stack+15972,int_stack+18702, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263526, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366612,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17322,int_stack+561588,int_stack+557808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264606, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+367692,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+28992,int_stack+17322,int_stack+559488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+266286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369372,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+557808,int_stack+34338,int_stack+33788, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+71232, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+88830,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+32142,int_stack+557808,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371472,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+557808,int_stack+32142,int_stack+561588, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+372822,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+561408,int_stack+557808,int_stack+17322, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+374982,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+565608,int_stack+561408,int_stack+28992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377782,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28992,int_stack+35124,int_stack+34998, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173084, 0.0, zero_stack, 1.0, int_stack+184128, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29370,int_stack+35292,int_stack+35124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173210, 0.0, zero_stack, 1.0, int_stack+184254, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29874,int_stack+29370,int_stack+28992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277846, 0.0, zero_stack, 1.0, int_stack+346500, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+30630,int_stack+35508,int_stack+35292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173378, 0.0, zero_stack, 1.0, int_stack+184422, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31278,int_stack+30630,int_stack+29370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278224, 0.0, zero_stack, 1.0, int_stack+346878, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+32286,int_stack+31278,int_stack+29874, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278728, 0.0, zero_stack, 1.0, int_stack+347382, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+35778,int_stack+35508, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173594, 0.0, zero_stack, 1.0, int_stack+184638, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+28992,int_stack+9870,int_stack+30630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279484, 0.0, zero_stack, 1.0, int_stack+348138, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+33546,int_stack+28992,int_stack+31278, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280132, 0.0, zero_stack, 1.0, int_stack+348786, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+30288,int_stack+33546,int_stack+32286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+286456, 0.0, zero_stack, 1.0, int_stack+355110, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+32178,int_stack+36108,int_stack+35778, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173864, 0.0, zero_stack, 1.0, int_stack+184908, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+557808,int_stack+32178,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281140, 0.0, zero_stack, 1.0, int_stack+349794, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+559428,int_stack+557808,int_stack+28992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+287716, 0.0, zero_stack, 1.0, int_stack+356370, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+561588,int_stack+559428,int_stack+33546, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289012, 0.0, zero_stack, 1.0, int_stack+357666, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+557808,int_stack+561588,int_stack+30288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290692, 0.0, zero_stack, 1.0, int_stack+359346, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+28992,int_stack+36714,int_stack+36504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74498, 0.0, zero_stack, 1.0, int_stack+86230, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+29622,int_stack+36994,int_stack+36714, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+74918, 0.0, zero_stack, 1.0, int_stack+86650, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30462,int_stack+29622,int_stack+28992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292582, 0.0, zero_stack, 1.0, int_stack+363882, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+31722,int_stack+37354,int_stack+36994, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+75478, 0.0, zero_stack, 1.0, int_stack+87210, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+32802,int_stack+31722,int_stack+29622, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293212, 0.0, zero_stack, 1.0, int_stack+364512, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+34482,int_stack+32802,int_stack+30462, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297748, 0.0, zero_stack, 1.0, int_stack+365352, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+28992,int_stack+37804,int_stack+37354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+76198, 0.0, zero_stack, 1.0, int_stack+87930, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+560454,int_stack+28992,int_stack+31722, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299008, 0.0, zero_stack, 1.0, int_stack+366612, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+562614,int_stack+560454,int_stack+32802, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300088, 0.0, zero_stack, 1.0, int_stack+367692, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+30342,int_stack+562614,int_stack+34482, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301768, 0.0, zero_stack, 1.0, int_stack+369372, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+33492,int_stack+38354,int_stack+37804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+77098, 0.0, zero_stack, 1.0, int_stack+88830, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+35142,int_stack+33492,int_stack+28992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303868, 0.0, zero_stack, 1.0, int_stack+371472, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+15972,int_stack+35142,int_stack+560454, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305218, 0.0, zero_stack, 1.0, int_stack+372822, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+33492,int_stack+15972,int_stack+562614, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+307378, 0.0, zero_stack, 1.0, int_stack+374982, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+560454,int_stack+33492,int_stack+30342, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310178, 0.0, zero_stack, 1.0, int_stack+377782, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15972,int_stack+39140,int_stack+39014, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178606, 1.0, int_stack+184128, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16350,int_stack+39308,int_stack+39140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178732, 1.0, int_stack+184254, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16854,int_stack+16350,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+313328, 1.0, int_stack+346500, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17610,int_stack+39524,int_stack+39308, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178900, 1.0, int_stack+184422, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+18258,int_stack+17610,int_stack+16350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+313706, 1.0, int_stack+346878, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+28992,int_stack+18258,int_stack+16854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+314210, 1.0, int_stack+347382, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+39794,int_stack+39524, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179116, 1.0, int_stack+184638, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15972,int_stack+9870,int_stack+17610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+314966, 1.0, int_stack+348138, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+30252,int_stack+15972,int_stack+18258, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315614, 1.0, int_stack+348786, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+17268,int_stack+30252,int_stack+28992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+355110, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+28992,int_stack+40124,int_stack+39794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+179386, 1.0, int_stack+184908, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+31932,int_stack+28992,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+316622, 1.0, int_stack+349794, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+33552,int_stack+31932,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+321938, 1.0, int_stack+356370, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+35712,int_stack+33552,int_stack+30252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323234, 1.0, int_stack+357666, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+28992,int_stack+35712,int_stack+17268, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+324914, 1.0, int_stack+359346, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15972,int_stack+40730,int_stack+40520, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80364, 1.0, int_stack+86230, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16602,int_stack+41010,int_stack+40730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+80784, 1.0, int_stack+86650, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17442,int_stack+16602,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+329450, 1.0, int_stack+363882, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18702,int_stack+41370,int_stack+41010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+81344, 1.0, int_stack+87210, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31638,int_stack+18702,int_stack+16602, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330080, 1.0, int_stack+364512, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+33318,int_stack+31638,int_stack+17442, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330920, 1.0, int_stack+365352, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+15972,int_stack+41820,int_stack+41370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82064, 1.0, int_stack+87930, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+35418,int_stack+15972,int_stack+18702, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332180, 1.0, int_stack+366612, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17322,int_stack+35418,int_stack+31638, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333260, 1.0, int_stack+367692, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+37578,int_stack+17322,int_stack+33318, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334940, 1.0, int_stack+369372, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+31638,int_stack+42370,int_stack+41820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+82964, 1.0, int_stack+88830, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+570018,int_stack+31638,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337040, 1.0, int_stack+371472, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+31638,int_stack+570018,int_stack+35418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338390, 1.0, int_stack+372822, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+570018,int_stack+31638,int_stack+17322, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340550, 1.0, int_stack+374982, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+31638,int_stack+570018,int_stack+37578, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+343350, 1.0, int_stack+377782, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570018,int_stack+43156,int_stack+43030, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+184128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+570396,int_stack+43324,int_stack+43156, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+184254, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+570900,int_stack+570396,int_stack+570018, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+346500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+571656,int_stack+43540,int_stack+43324, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+184422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+572304,int_stack+571656,int_stack+570396, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+346878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+573312,int_stack+572304,int_stack+570900, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+347382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+43810,int_stack+43540, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+184638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+570018,int_stack+9870,int_stack+571656, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+348138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+36048,int_stack+570018,int_stack+572304, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+348786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+571314,int_stack+36048,int_stack+573312, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+355110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+573204,int_stack+44140,int_stack+43810, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+184908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+37728,int_stack+573204,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+349794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+39348,int_stack+37728,int_stack+570018, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+356370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+41508,int_stack+39348,int_stack+36048, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+357666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+36048,int_stack+41508,int_stack+571314, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+359346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38694,int_stack+44746,int_stack+44536, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+86230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+39324,int_stack+45026,int_stack+44746, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+86650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+40164,int_stack+39324,int_stack+38694, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+363882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+41424,int_stack+45386,int_stack+45026, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+87210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+42504,int_stack+41424,int_stack+39324, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+364512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+570018,int_stack+42504,int_stack+40164, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+365352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+38694,int_stack+45836,int_stack+45386, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+87930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+572118,int_stack+38694,int_stack+41424, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+366612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+15972,int_stack+572118,int_stack+42504, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+367692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+40044,int_stack+15972,int_stack+570018, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+369372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+570018,int_stack+46386,int_stack+45836, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+88830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+43194,int_stack+570018,int_stack+38694, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+371472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+574278,int_stack+43194,int_stack+572118, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+372822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+570018,int_stack+574278,int_stack+15972, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+374982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+574218,int_stack+570018,int_stack+40044, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+377782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570018,int_stack+47172,int_stack+47046, 0.0, zero_stack, 1.0, int_stack+167562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189650,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+570396,int_stack+47340,int_stack+47172, 0.0, zero_stack, 1.0, int_stack+167688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189776,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+570900,int_stack+570396,int_stack+570018, 0.0, zero_stack, 1.0, int_stack+230450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380932,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+571656,int_stack+47556,int_stack+47340, 0.0, zero_stack, 1.0, int_stack+167856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189944,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+572304,int_stack+571656,int_stack+570396, 0.0, zero_stack, 1.0, int_stack+230828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381310,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15972,int_stack+572304,int_stack+570900, 0.0, zero_stack, 1.0, int_stack+231332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381814,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+47826,int_stack+47556, 0.0, zero_stack, 1.0, int_stack+168072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190160,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+570018,int_stack+9870,int_stack+571656, 0.0, zero_stack, 1.0, int_stack+232088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382570,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17232,int_stack+570018,int_stack+572304, 0.0, zero_stack, 1.0, int_stack+232736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383218,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+571314,int_stack+17232,int_stack+15972, 0.0, zero_stack, 1.0, int_stack+233744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15972,int_stack+48156,int_stack+47826, 0.0, zero_stack, 1.0, int_stack+168342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190430,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+38694,int_stack+15972,int_stack+9870, 0.0, zero_stack, 1.0, int_stack+235004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384226,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+40314,int_stack+38694,int_stack+570018, 0.0, zero_stack, 1.0, int_stack+235814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389542,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+42474,int_stack+40314,int_stack+17232, 0.0, zero_stack, 1.0, int_stack+237110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390838,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+38694,int_stack+42474,int_stack+571314, 0.0, zero_stack, 1.0, int_stack+238790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392518,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570018,int_stack+48762,int_stack+48552, 0.0, zero_stack, 1.0, int_stack+68632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92096,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+570648,int_stack+49042,int_stack+48762, 0.0, zero_stack, 1.0, int_stack+69052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92516,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+571488,int_stack+570648,int_stack+570018, 0.0, zero_stack, 1.0, int_stack+242150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397054,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+572748,int_stack+49402,int_stack+49042, 0.0, zero_stack, 1.0, int_stack+69612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93076,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+41340,int_stack+572748,int_stack+570648, 0.0, zero_stack, 1.0, int_stack+261426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397684,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+43020,int_stack+41340,int_stack+571488, 0.0, zero_stack, 1.0, int_stack+262266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398524,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+570018,int_stack+49852,int_stack+49402, 0.0, zero_stack, 1.0, int_stack+70332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93796,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+45120,int_stack+570018,int_stack+572748, 0.0, zero_stack, 1.0, int_stack+263526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399784,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+571368,int_stack+45120,int_stack+41340, 0.0, zero_stack, 1.0, int_stack+264606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400864,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+15972,int_stack+571368,int_stack+43020, 0.0, zero_stack, 1.0, int_stack+266286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+402544,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+41340,int_stack+50402,int_stack+49852, 0.0, zero_stack, 1.0, int_stack+71232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94696,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+47280,int_stack+41340,int_stack+570018, 0.0, zero_stack, 1.0, int_stack+268386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404644,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+41340,int_stack+47280,int_stack+45120, 0.0, zero_stack, 1.0, int_stack+269736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405994,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+44940,int_stack+41340,int_stack+571368, 0.0, zero_stack, 1.0, int_stack+271896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408154,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+578628,int_stack+44940,int_stack+15972, 0.0, zero_stack, 1.0, int_stack+274696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410954,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15972,int_stack+51188,int_stack+51062, 0.0, zero_stack, 1.0, int_stack+173084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189650, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16350,int_stack+51356,int_stack+51188, 0.0, zero_stack, 1.0, int_stack+173210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189776, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+16854,int_stack+16350,int_stack+15972, 0.0, zero_stack, 1.0, int_stack+277846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+380932, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17610,int_stack+51572,int_stack+51356, 0.0, zero_stack, 1.0, int_stack+173378, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189944, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+18258,int_stack+17610,int_stack+16350, 0.0, zero_stack, 1.0, int_stack+278224, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381310, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+41340,int_stack+18258,int_stack+16854, 0.0, zero_stack, 1.0, int_stack+278728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381814, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+51842,int_stack+51572, 0.0, zero_stack, 1.0, int_stack+173594, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190160, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15972,int_stack+9870,int_stack+17610, 0.0, zero_stack, 1.0, int_stack+279484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382570, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+42600,int_stack+15972,int_stack+18258, 0.0, zero_stack, 1.0, int_stack+280132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383218, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+17268,int_stack+42600,int_stack+41340, 0.0, zero_stack, 1.0, int_stack+286456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+41340,int_stack+52172,int_stack+51842, 0.0, zero_stack, 1.0, int_stack+173864, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190430, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+44280,int_stack+41340,int_stack+9870, 0.0, zero_stack, 1.0, int_stack+281140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384226, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+45900,int_stack+44280,int_stack+15972, 0.0, zero_stack, 1.0, int_stack+287716, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+389542, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+48060,int_stack+45900,int_stack+42600, 0.0, zero_stack, 1.0, int_stack+289012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390838, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+41340,int_stack+48060,int_stack+17268, 0.0, zero_stack, 1.0, int_stack+290692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+392518, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15972,int_stack+52778,int_stack+52568, 0.0, zero_stack, 1.0, int_stack+74498, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92096, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16602,int_stack+53058,int_stack+52778, 0.0, zero_stack, 1.0, int_stack+74918, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+92516, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17442,int_stack+16602,int_stack+15972, 0.0, zero_stack, 1.0, int_stack+292582, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397054, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18702,int_stack+53418,int_stack+53058, 0.0, zero_stack, 1.0, int_stack+75478, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93076, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+43986,int_stack+18702,int_stack+16602, 0.0, zero_stack, 1.0, int_stack+293212, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397684, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+45666,int_stack+43986,int_stack+17442, 0.0, zero_stack, 1.0, int_stack+297748, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398524, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+15972,int_stack+53868,int_stack+53418, 0.0, zero_stack, 1.0, int_stack+76198, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+93796, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+47766,int_stack+15972,int_stack+18702, 0.0, zero_stack, 1.0, int_stack+299008, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+399784, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17322,int_stack+47766,int_stack+43986, 0.0, zero_stack, 1.0, int_stack+300088, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400864, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+49926,int_stack+17322,int_stack+45666, 0.0, zero_stack, 1.0, int_stack+301768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+402544, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+43986,int_stack+54418,int_stack+53868, 0.0, zero_stack, 1.0, int_stack+77098, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+94696, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+570018,int_stack+43986,int_stack+15972, 0.0, zero_stack, 1.0, int_stack+303868, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404644, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+43986,int_stack+570018,int_stack+47766, 0.0, zero_stack, 1.0, int_stack+305218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405994, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+570018,int_stack+43986,int_stack+17322, 0.0, zero_stack, 1.0, int_stack+307378, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+408154, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+43986,int_stack+570018,int_stack+49926, 0.0, zero_stack, 1.0, int_stack+310178, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410954, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570018,int_stack+55204,int_stack+55078, 0.0, zero_stack, 1.0, int_stack+178606, 0.0, zero_stack, 1.0, int_stack+189650, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+570396,int_stack+55372,int_stack+55204, 0.0, zero_stack, 1.0, int_stack+178732, 0.0, zero_stack, 1.0, int_stack+189776, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+570900,int_stack+570396,int_stack+570018, 0.0, zero_stack, 1.0, int_stack+313328, 0.0, zero_stack, 1.0, int_stack+380932, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+571656,int_stack+55588,int_stack+55372, 0.0, zero_stack, 1.0, int_stack+178900, 0.0, zero_stack, 1.0, int_stack+189944, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+572304,int_stack+571656,int_stack+570396, 0.0, zero_stack, 1.0, int_stack+313706, 0.0, zero_stack, 1.0, int_stack+381310, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+48396,int_stack+572304,int_stack+570900, 0.0, zero_stack, 1.0, int_stack+314210, 0.0, zero_stack, 1.0, int_stack+381814, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+55858,int_stack+55588, 0.0, zero_stack, 1.0, int_stack+179116, 0.0, zero_stack, 1.0, int_stack+190160, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+570018,int_stack+9870,int_stack+571656, 0.0, zero_stack, 1.0, int_stack+314966, 0.0, zero_stack, 1.0, int_stack+382570, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+49656,int_stack+570018,int_stack+572304, 0.0, zero_stack, 1.0, int_stack+315614, 0.0, zero_stack, 1.0, int_stack+383218, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+571314,int_stack+49656,int_stack+48396, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+48396,int_stack+56188,int_stack+55858, 0.0, zero_stack, 1.0, int_stack+179386, 0.0, zero_stack, 1.0, int_stack+190430, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+51336,int_stack+48396,int_stack+9870, 0.0, zero_stack, 1.0, int_stack+316622, 0.0, zero_stack, 1.0, int_stack+384226, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+52956,int_stack+51336,int_stack+570018, 0.0, zero_stack, 1.0, int_stack+321938, 0.0, zero_stack, 1.0, int_stack+389542, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+15972,int_stack+52956,int_stack+49656, 0.0, zero_stack, 1.0, int_stack+323234, 0.0, zero_stack, 1.0, int_stack+390838, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+48396,int_stack+15972,int_stack+571314, 0.0, zero_stack, 1.0, int_stack+324914, 0.0, zero_stack, 1.0, int_stack+392518, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15972,int_stack+56794,int_stack+56584, 0.0, zero_stack, 1.0, int_stack+80364, 0.0, zero_stack, 1.0, int_stack+92096, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16602,int_stack+57074,int_stack+56794, 0.0, zero_stack, 1.0, int_stack+80784, 0.0, zero_stack, 1.0, int_stack+92516, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17442,int_stack+16602,int_stack+15972, 0.0, zero_stack, 1.0, int_stack+329450, 0.0, zero_stack, 1.0, int_stack+397054, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18702,int_stack+57434,int_stack+57074, 0.0, zero_stack, 1.0, int_stack+81344, 0.0, zero_stack, 1.0, int_stack+93076, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+570018,int_stack+18702,int_stack+16602, 0.0, zero_stack, 1.0, int_stack+330080, 0.0, zero_stack, 1.0, int_stack+397684, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+571698,int_stack+570018,int_stack+17442, 0.0, zero_stack, 1.0, int_stack+330920, 0.0, zero_stack, 1.0, int_stack+398524, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+15972,int_stack+57884,int_stack+57434, 0.0, zero_stack, 1.0, int_stack+82064, 0.0, zero_stack, 1.0, int_stack+93796, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+51042,int_stack+15972,int_stack+18702, 0.0, zero_stack, 1.0, int_stack+332180, 0.0, zero_stack, 1.0, int_stack+399784, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17322,int_stack+51042,int_stack+570018, 0.0, zero_stack, 1.0, int_stack+333260, 0.0, zero_stack, 1.0, int_stack+400864, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+53202,int_stack+17322,int_stack+571698, 0.0, zero_stack, 1.0, int_stack+334940, 0.0, zero_stack, 1.0, int_stack+402544, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+570018,int_stack+58434,int_stack+57884, 0.0, zero_stack, 1.0, int_stack+82964, 0.0, zero_stack, 1.0, int_stack+94696, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+56352,int_stack+570018,int_stack+15972, 0.0, zero_stack, 1.0, int_stack+337040, 0.0, zero_stack, 1.0, int_stack+404644, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+570018,int_stack+56352,int_stack+51042, 0.0, zero_stack, 1.0, int_stack+338390, 0.0, zero_stack, 1.0, int_stack+405994, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+583038,int_stack+570018,int_stack+17322, 0.0, zero_stack, 1.0, int_stack+340550, 0.0, zero_stack, 1.0, int_stack+408154, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+587238,int_stack+583038,int_stack+53202, 0.0, zero_stack, 1.0, int_stack+343350, 0.0, zero_stack, 1.0, int_stack+410954, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+583038,int_stack+59220,int_stack+59094, 0.0, zero_stack, 1.0, int_stack+184128, 1.0, int_stack+189650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+583416,int_stack+59388,int_stack+59220, 0.0, zero_stack, 1.0, int_stack+184254, 1.0, int_stack+189776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+583920,int_stack+583416,int_stack+583038, 0.0, zero_stack, 1.0, int_stack+346500, 1.0, int_stack+380932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+584676,int_stack+59604,int_stack+59388, 0.0, zero_stack, 1.0, int_stack+184422, 1.0, int_stack+189944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+585324,int_stack+584676,int_stack+583416, 0.0, zero_stack, 1.0, int_stack+346878, 1.0, int_stack+381310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+570018,int_stack+585324,int_stack+583920, 0.0, zero_stack, 1.0, int_stack+347382, 1.0, int_stack+381814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+59874,int_stack+59604, 0.0, zero_stack, 1.0, int_stack+184638, 1.0, int_stack+190160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+583038,int_stack+9870,int_stack+584676, 0.0, zero_stack, 1.0, int_stack+348138, 1.0, int_stack+382570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+571278,int_stack+583038,int_stack+585324, 0.0, zero_stack, 1.0, int_stack+348786, 1.0, int_stack+383218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+584334,int_stack+571278,int_stack+570018, 0.0, zero_stack, 1.0, int_stack+355110, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+570018,int_stack+60204,int_stack+59874, 0.0, zero_stack, 1.0, int_stack+184908, 1.0, int_stack+190430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+51042,int_stack+570018,int_stack+9870, 0.0, zero_stack, 1.0, int_stack+349794, 1.0, int_stack+384226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+52662,int_stack+51042,int_stack+583038, 0.0, zero_stack, 1.0, int_stack+356370, 1.0, int_stack+389542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+54822,int_stack+52662,int_stack+571278, 0.0, zero_stack, 1.0, int_stack+357666, 1.0, int_stack+390838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+51042,int_stack+54822,int_stack+584334, 0.0, zero_stack, 1.0, int_stack+359346, 1.0, int_stack+392518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+583038,int_stack+60810,int_stack+60600, 0.0, zero_stack, 1.0, int_stack+86230, 1.0, int_stack+92096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+583668,int_stack+61090,int_stack+60810, 0.0, zero_stack, 1.0, int_stack+86650, 1.0, int_stack+92516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+584508,int_stack+583668,int_stack+583038, 0.0, zero_stack, 1.0, int_stack+363882, 1.0, int_stack+397054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+585768,int_stack+61450,int_stack+61090, 0.0, zero_stack, 1.0, int_stack+87210, 1.0, int_stack+93076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+53688,int_stack+585768,int_stack+583668, 0.0, zero_stack, 1.0, int_stack+364512, 1.0, int_stack+397684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+55368,int_stack+53688,int_stack+584508, 0.0, zero_stack, 1.0, int_stack+365352, 1.0, int_stack+398524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+583038,int_stack+61900,int_stack+61450, 0.0, zero_stack, 1.0, int_stack+87930, 1.0, int_stack+93796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+57468,int_stack+583038,int_stack+585768, 0.0, zero_stack, 1.0, int_stack+366612, 1.0, int_stack+399784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+584388,int_stack+57468,int_stack+53688, 0.0, zero_stack, 1.0, int_stack+367692, 1.0, int_stack+400864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+570018,int_stack+584388,int_stack+55368, 0.0, zero_stack, 1.0, int_stack+369372, 1.0, int_stack+402544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+53688,int_stack+62450,int_stack+61900, 0.0, zero_stack, 1.0, int_stack+88830, 1.0, int_stack+94696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+59628,int_stack+53688,int_stack+583038, 0.0, zero_stack, 1.0, int_stack+371472, 1.0, int_stack+404644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+53688,int_stack+59628,int_stack+57468, 0.0, zero_stack, 1.0, int_stack+372822, 1.0, int_stack+405994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+15972,int_stack+53688,int_stack+584388, 0.0, zero_stack, 1.0, int_stack+374982, 1.0, int_stack+408154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+53688,int_stack+15972,int_stack+570018, 0.0, zero_stack, 1.0, int_stack+377782, 1.0, int_stack+410954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570018,int_stack+63236,int_stack+63110, 0.0, zero_stack, 2.0, int_stack+189650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+570396,int_stack+63404,int_stack+63236, 0.0, zero_stack, 2.0, int_stack+189776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+570900,int_stack+570396,int_stack+570018, 0.0, zero_stack, 2.0, int_stack+380932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+571656,int_stack+63620,int_stack+63404, 0.0, zero_stack, 2.0, int_stack+189944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+572304,int_stack+571656,int_stack+570396, 0.0, zero_stack, 2.0, int_stack+381310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15972,int_stack+572304,int_stack+570900, 0.0, zero_stack, 2.0, int_stack+381814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+63890,int_stack+63620, 0.0, zero_stack, 2.0, int_stack+190160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+570018,int_stack+9870,int_stack+571656, 0.0, zero_stack, 2.0, int_stack+382570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17232,int_stack+570018,int_stack+572304, 0.0, zero_stack, 2.0, int_stack+383218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+571314,int_stack+17232,int_stack+15972, 0.0, zero_stack, 2.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15972,int_stack+64220,int_stack+63890, 0.0, zero_stack, 2.0, int_stack+190430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+58098,int_stack+15972,int_stack+9870, 0.0, zero_stack, 2.0, int_stack+384226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+59718,int_stack+58098,int_stack+570018, 0.0, zero_stack, 2.0, int_stack+389542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+61878,int_stack+59718,int_stack+17232, 0.0, zero_stack, 2.0, int_stack+390838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+58098,int_stack+61878,int_stack+571314, 0.0, zero_stack, 2.0, int_stack+392518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570018,int_stack+64826,int_stack+64616, 0.0, zero_stack, 2.0, int_stack+92096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+570648,int_stack+65106,int_stack+64826, 0.0, zero_stack, 2.0, int_stack+92516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+571488,int_stack+570648,int_stack+570018, 0.0, zero_stack, 2.0, int_stack+397054, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+572748,int_stack+65466,int_stack+65106, 0.0, zero_stack, 2.0, int_stack+93076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+60744,int_stack+572748,int_stack+570648, 0.0, zero_stack, 2.0, int_stack+397684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+62424,int_stack+60744,int_stack+571488, 0.0, zero_stack, 2.0, int_stack+398524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+570018,int_stack+65916,int_stack+65466, 0.0, zero_stack, 2.0, int_stack+93796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15972,int_stack+570018,int_stack+572748, 0.0, zero_stack, 2.0, int_stack+399784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+571368,int_stack+15972,int_stack+60744, 0.0, zero_stack, 2.0, int_stack+400864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+583038,int_stack+571368,int_stack+62424, 0.0, zero_stack, 2.0, int_stack+402544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+60744,int_stack+66466,int_stack+65916, 0.0, zero_stack, 2.0, int_stack+94696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+62394,int_stack+60744,int_stack+570018, 0.0, zero_stack, 2.0, int_stack+404644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+591648,int_stack+62394,int_stack+15972, 0.0, zero_stack, 2.0, int_stack+405994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+15972,int_stack+591648,int_stack+571368, 0.0, zero_stack, 2.0, int_stack+408154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+60744,int_stack+15972,int_stack+583038, 0.0, zero_stack, 2.0, int_stack+410954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+583038,int_stack+67252,int_stack+67126, 1.0, int_stack+167562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195298,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+583416,int_stack+67420,int_stack+67252, 1.0, int_stack+167688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195592,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+583920,int_stack+583416,int_stack+583038, 1.0, int_stack+230450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414104,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+584676,int_stack+67636,int_stack+67420, 1.0, int_stack+167856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195976,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+585324,int_stack+584676,int_stack+583416, 1.0, int_stack+230828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414482,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15972,int_stack+585324,int_stack+583920, 1.0, int_stack+231332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414986,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+67906,int_stack+67636, 1.0, int_stack+168072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196462,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+583038,int_stack+9870,int_stack+584676, 1.0, int_stack+232088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+415742,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+17232,int_stack+583038,int_stack+585324, 1.0, int_stack+232736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416390,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+584334,int_stack+17232,int_stack+15972, 1.0, int_stack+233744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422714,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+15972,int_stack+68236,int_stack+67906, 1.0, int_stack+168342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197062,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+591648,int_stack+15972,int_stack+9870, 1.0, int_stack+235004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220220,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+593268,int_stack+591648,int_stack+583038, 1.0, int_stack+235814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423974,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+570018,int_stack+593268,int_stack+17232, 1.0, int_stack+237110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425270,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+591648,int_stack+570018,int_stack+584334, 1.0, int_stack+238790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221030,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570018,int_stack+69332,int_stack+68842, 1.0, int_stack+68632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98172,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+570648,int_stack+69972,int_stack+69332, 1.0, int_stack+69052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98872,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+571488,int_stack+570648,int_stack+570018, 1.0, int_stack+242150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429596,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+572748,int_stack+70782,int_stack+69972, 1.0, int_stack+69612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99792,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+583038,int_stack+572748,int_stack+570648, 1.0, int_stack+261426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430226,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+584718,int_stack+583038,int_stack+571488, 1.0, int_stack+262266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431066,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+570018,int_stack+71782,int_stack+70782, 1.0, int_stack+70332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100962,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+15972,int_stack+570018,int_stack+572748, 1.0, int_stack+263526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+432326,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+571368,int_stack+15972,int_stack+583038, 1.0, int_stack+264606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222920,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+65154,int_stack+571368,int_stack+584718, 1.0, int_stack+266286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433406,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+583038,int_stack+72332,int_stack+71782, 1.0, int_stack+71232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101862,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+68304,int_stack+583038,int_stack+570018, 1.0, int_stack+268386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240680,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+583038,int_stack+68304,int_stack+15972, 1.0, int_stack+269736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+435506,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+15972,int_stack+583038,int_stack+571368, 1.0, int_stack+271896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437666,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+68304,int_stack+15972,int_stack+65154, 1.0, int_stack+274696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245846,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65154,int_stack+73118,int_stack+72992, 1.0, int_stack+173084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195298, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65532,int_stack+73286,int_stack+73118, 1.0, int_stack+173210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195592, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+66036,int_stack+65532,int_stack+65154, 1.0, int_stack+277846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414104, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+66792,int_stack+73502,int_stack+73286, 1.0, int_stack+173378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195976, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15972,int_stack+66792,int_stack+65532, 1.0, int_stack+278224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414482, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+16980,int_stack+15972,int_stack+66036, 1.0, int_stack+278728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414986, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+73772,int_stack+73502, 1.0, int_stack+173594, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196462, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+65154,int_stack+9870,int_stack+66792, 1.0, int_stack+279484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+415742, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+66450,int_stack+65154,int_stack+15972, 1.0, int_stack+280132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416390, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+18240,int_stack+66450,int_stack+16980, 1.0, int_stack+286456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422714, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+286456,int_stack+74102,int_stack+73772, 1.0, int_stack+173864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197062, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+15972,int_stack+286456,int_stack+9870, 1.0, int_stack+281140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220220, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+583038,int_stack+15972,int_stack+65154, 1.0, int_stack+287716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423974, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+286456,int_stack+583038,int_stack+66450, 1.0, int_stack+289012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425270, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+583038,int_stack+286456,int_stack+18240, 1.0, int_stack+290692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221030, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+286456,int_stack+75198,int_stack+74708, 1.0, int_stack+74498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98172, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+287086,int_stack+75838,int_stack+75198, 1.0, int_stack+74918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98872, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+287926,int_stack+287086,int_stack+286456, 1.0, int_stack+292582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429596, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+289186,int_stack+76648,int_stack+75838, 1.0, int_stack+75478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99792, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+290266,int_stack+289186,int_stack+287086, 1.0, int_stack+293212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430226, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+291946,int_stack+290266,int_stack+287926, 1.0, int_stack+297748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431066, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+286456,int_stack+77648,int_stack+76648, 1.0, int_stack+76198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100962, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+65154,int_stack+286456,int_stack+289186, 1.0, int_stack+299008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+432326, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+15972,int_stack+65154,int_stack+290266, 1.0, int_stack+300088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222920, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+297748,int_stack+15972,int_stack+291946, 1.0, int_stack+301768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433406, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+300898,int_stack+78198,int_stack+77648, 1.0, int_stack+77098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101862, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+287806,int_stack+300898,int_stack+286456, 1.0, int_stack+303868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240680, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+300898,int_stack+287806,int_stack+65154, 1.0, int_stack+305218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+435506, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+570018,int_stack+300898,int_stack+15972, 1.0, int_stack+307378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437666, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+300898,int_stack+570018,int_stack+297748, 1.0, int_stack+310178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245846, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+297748,int_stack+78984,int_stack+78858, 1.0, int_stack+178606, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195298, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+298126,int_stack+79152,int_stack+78984, 1.0, int_stack+178732, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195592, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+298630,int_stack+298126,int_stack+297748, 1.0, int_stack+313328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414104, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+299386,int_stack+79368,int_stack+79152, 1.0, int_stack+178900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+195976, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+570018,int_stack+299386,int_stack+298126, 1.0, int_stack+313706, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414482, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+571026,int_stack+570018,int_stack+298630, 1.0, int_stack+314210, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414986, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+79638,int_stack+79368, 1.0, int_stack+179116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+196462, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+297748,int_stack+9870,int_stack+299386, 1.0, int_stack+314966, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+415742, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+299044,int_stack+297748,int_stack+570018, 1.0, int_stack+315614, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+416390, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+572286,int_stack+299044,int_stack+571026, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422714, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+79968,int_stack+79638, 1.0, int_stack+179386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197062, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+570018,int_stack+0,int_stack+9870, 1.0, int_stack+316622, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220220, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+15972,int_stack+570018,int_stack+297748, 1.0, int_stack+321938, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423974, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+305308,int_stack+15972,int_stack+299044, 1.0, int_stack+323234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425270, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+15972,int_stack+305308,int_stack+572286, 1.0, int_stack+324914, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221030, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+305308,int_stack+81064,int_stack+80574, 1.0, int_stack+80364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98172, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+305938,int_stack+81704,int_stack+81064, 1.0, int_stack+80784, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+98872, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+305938,int_stack+305308, 1.0, int_stack+329450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+429596, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+306778,int_stack+82514,int_stack+81704, 1.0, int_stack+81344, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+99792, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+307858,int_stack+306778,int_stack+305938, 1.0, int_stack+330080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+430226, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+309538,int_stack+307858,int_stack+0, 1.0, int_stack+330920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431066, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+329450,int_stack+83514,int_stack+82514, 1.0, int_stack+82064, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+100962, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+311638,int_stack+329450,int_stack+306778, 1.0, int_stack+332180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+432326, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+313798,int_stack+311638,int_stack+307858, 1.0, int_stack+333260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+222920, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+297748,int_stack+313798,int_stack+309538, 1.0, int_stack+334940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433406, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+330800,int_stack+84064,int_stack+83514, 1.0, int_stack+82964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+101862, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+332450,int_stack+330800,int_stack+329450, 1.0, int_stack+337040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240680, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+305308,int_stack+332450,int_stack+311638, 1.0, int_stack+338390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+435506, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+570018,int_stack+305308,int_stack+313798, 1.0, int_stack+340550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437666, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+305308,int_stack+570018,int_stack+297748, 1.0, int_stack+343350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245846, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+297748,int_stack+84850,int_stack+84724, 1.0, int_stack+184128, 0.0, zero_stack, 1.0, int_stack+195298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+298126,int_stack+85018,int_stack+84850, 1.0, int_stack+184254, 0.0, zero_stack, 1.0, int_stack+195592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+298630,int_stack+298126,int_stack+297748, 1.0, int_stack+346500, 0.0, zero_stack, 1.0, int_stack+414104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+299386,int_stack+85234,int_stack+85018, 1.0, int_stack+184422, 0.0, zero_stack, 1.0, int_stack+195976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+570018,int_stack+299386,int_stack+298126, 1.0, int_stack+346878, 0.0, zero_stack, 1.0, int_stack+414482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+570018,int_stack+298630, 1.0, int_stack+347382, 0.0, zero_stack, 1.0, int_stack+414986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+85504,int_stack+85234, 1.0, int_stack+184638, 0.0, zero_stack, 1.0, int_stack+196462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+297748,int_stack+9870,int_stack+299386, 1.0, int_stack+348138, 0.0, zero_stack, 1.0, int_stack+415742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+299044,int_stack+297748,int_stack+570018, 1.0, int_stack+348786, 0.0, zero_stack, 1.0, int_stack+416390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+570018,int_stack+299044,int_stack+0, 1.0, int_stack+355110, 0.0, zero_stack, 1.0, int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+355110,int_stack+85834,int_stack+85504, 1.0, int_stack+184908, 0.0, zero_stack, 1.0, int_stack+197062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+571908,int_stack+355110,int_stack+9870, 1.0, int_stack+349794, 0.0, zero_stack, 1.0, int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+309718,int_stack+571908,int_stack+297748, 1.0, int_stack+356370, 0.0, zero_stack, 1.0, int_stack+423974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+355110,int_stack+309718,int_stack+299044, 1.0, int_stack+357666, 0.0, zero_stack, 1.0, int_stack+425270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+309718,int_stack+355110,int_stack+570018, 1.0, int_stack+359346, 0.0, zero_stack, 1.0, int_stack+221030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570018,int_stack+86930,int_stack+86440, 1.0, int_stack+86230, 0.0, zero_stack, 1.0, int_stack+98172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+570648,int_stack+87570,int_stack+86930, 1.0, int_stack+86650, 0.0, zero_stack, 1.0, int_stack+98872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+570648,int_stack+570018, 1.0, int_stack+363882, 0.0, zero_stack, 1.0, int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+571488,int_stack+88380,int_stack+87570, 1.0, int_stack+87210, 0.0, zero_stack, 1.0, int_stack+99792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+355110,int_stack+571488,int_stack+570648, 1.0, int_stack+364512, 0.0, zero_stack, 1.0, int_stack+430226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+356790,int_stack+355110,int_stack+0, 1.0, int_stack+365352, 0.0, zero_stack, 1.0, int_stack+431066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+363882,int_stack+89380,int_stack+88380, 1.0, int_stack+87930, 0.0, zero_stack, 1.0, int_stack+100962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+358890,int_stack+363882,int_stack+571488, 1.0, int_stack+366612, 0.0, zero_stack, 1.0, int_stack+432326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+570018,int_stack+358890,int_stack+355110, 1.0, int_stack+367692, 0.0, zero_stack, 1.0, int_stack+222920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+297748,int_stack+570018,int_stack+356790, 1.0, int_stack+369372, 0.0, zero_stack, 1.0, int_stack+433406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+355110,int_stack+89930,int_stack+89380, 1.0, int_stack+88830, 0.0, zero_stack, 1.0, int_stack+101862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+365232,int_stack+355110,int_stack+363882, 1.0, int_stack+371472, 0.0, zero_stack, 1.0, int_stack+240680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+355110,int_stack+365232,int_stack+358890, 1.0, int_stack+372822, 0.0, zero_stack, 1.0, int_stack+435506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+363882,int_stack+355110,int_stack+570018, 1.0, int_stack+374982, 0.0, zero_stack, 1.0, int_stack+437666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+355110,int_stack+363882,int_stack+297748, 1.0, int_stack+377782, 0.0, zero_stack, 1.0, int_stack+245846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+297748,int_stack+90716,int_stack+90590, 1.0, int_stack+189650, 1.0, int_stack+195298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+298126,int_stack+90884,int_stack+90716, 1.0, int_stack+189776, 1.0, int_stack+195592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+298630,int_stack+298126,int_stack+297748, 1.0, int_stack+380932, 1.0, int_stack+414104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+299386,int_stack+91100,int_stack+90884, 1.0, int_stack+189944, 1.0, int_stack+195976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+363882,int_stack+299386,int_stack+298126, 1.0, int_stack+381310, 1.0, int_stack+414482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+363882,int_stack+298630, 1.0, int_stack+381814, 1.0, int_stack+414986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+91370,int_stack+91100, 1.0, int_stack+190160, 1.0, int_stack+196462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+297748,int_stack+9870,int_stack+299386, 1.0, int_stack+382570, 1.0, int_stack+415742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+299044,int_stack+297748,int_stack+363882, 1.0, int_stack+383218, 1.0, int_stack+416390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+363882,int_stack+299044,int_stack+0, 1.0, int_stack+1260, 1.0, int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+91700,int_stack+91370, 1.0, int_stack+190430, 1.0, int_stack+197062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+365772,int_stack+0,int_stack+9870, 1.0, int_stack+384226, 1.0, int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+365772,int_stack+297748, 1.0, int_stack+389542, 1.0, int_stack+423974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+365772,int_stack+0,int_stack+299044, 1.0, int_stack+390838, 1.0, int_stack+425270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+389542,int_stack+365772,int_stack+363882, 1.0, int_stack+392518, 1.0, int_stack+221030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+363882,int_stack+92796,int_stack+92306, 1.0, int_stack+92096, 1.0, int_stack+98172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+364512,int_stack+93436,int_stack+92796, 1.0, int_stack+92516, 1.0, int_stack+98872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+365352,int_stack+364512,int_stack+363882, 1.0, int_stack+397054, 1.0, int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+366612,int_stack+94246,int_stack+93436, 1.0, int_stack+93076, 1.0, int_stack+99792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+367692,int_stack+366612,int_stack+364512, 1.0, int_stack+397684, 1.0, int_stack+430226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+369372,int_stack+367692,int_stack+365352, 1.0, int_stack+398524, 1.0, int_stack+431066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+397054,int_stack+95246,int_stack+94246, 1.0, int_stack+93796, 1.0, int_stack+100962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+363882,int_stack+397054,int_stack+366612, 1.0, int_stack+399784, 1.0, int_stack+432326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+371472,int_stack+363882,int_stack+367692, 1.0, int_stack+400864, 1.0, int_stack+222920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+297748,int_stack+371472,int_stack+369372, 1.0, int_stack+402544, 1.0, int_stack+433406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+398404,int_stack+95796,int_stack+95246, 1.0, int_stack+94696, 1.0, int_stack+101862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+400054,int_stack+398404,int_stack+397054, 1.0, int_stack+404644, 1.0, int_stack+240680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+366042,int_stack+400054,int_stack+363882, 1.0, int_stack+405994, 1.0, int_stack+435506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+570018,int_stack+366042,int_stack+371472, 1.0, int_stack+408154, 1.0, int_stack+437666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+363882,int_stack+570018,int_stack+297748, 1.0, int_stack+410954, 1.0, int_stack+245846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+297748,int_stack+96582,int_stack+96456, 2.0, int_stack+195298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+298126,int_stack+96750,int_stack+96582, 2.0, int_stack+195592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+298630,int_stack+298126,int_stack+297748, 2.0, int_stack+414104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+299386,int_stack+96966,int_stack+96750, 2.0, int_stack+195976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+570018,int_stack+299386,int_stack+298126, 2.0, int_stack+414482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+571026,int_stack+570018,int_stack+298630, 2.0, int_stack+414986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+97236,int_stack+96966, 2.0, int_stack+196462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+297748,int_stack+9870,int_stack+299386, 2.0, int_stack+415742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+299044,int_stack+297748,int_stack+570018, 2.0, int_stack+416390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+195172,int_stack+299044,int_stack+571026, 2.0, int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+422714,int_stack+97566,int_stack+97236, 2.0, int_stack+197062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+570018,int_stack+422714,int_stack+9870, 2.0, int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+571638,int_stack+570018,int_stack+297748, 2.0, int_stack+423974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+571638,int_stack+299044, 2.0, int_stack+425270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+297748,int_stack+0,int_stack+195172, 2.0, int_stack+221030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+195172,int_stack+99152,int_stack+98382, 2.0, int_stack+98172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+195802,int_stack+100152,int_stack+99152, 2.0, int_stack+98872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+195802,int_stack+195172, 2.0, int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+196642,int_stack+101412,int_stack+100152, 2.0, int_stack+99792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+570018,int_stack+196642,int_stack+195802, 2.0, int_stack+430226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+571698,int_stack+570018,int_stack+0, 2.0, int_stack+431066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+102412,int_stack+101412, 2.0, int_stack+100962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+429596,int_stack+0,int_stack+196642, 2.0, int_stack+432326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+422714,int_stack+429596,int_stack+570018, 2.0, int_stack+222920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+65154,int_stack+422714,int_stack+571698, 2.0, int_stack+433406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+570018,int_stack+102962,int_stack+102412, 2.0, int_stack+101862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+431756,int_stack+570018,int_stack+0, 2.0, int_stack+240680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+570018,int_stack+431756,int_stack+429596, 2.0, int_stack+435506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+429596,int_stack+570018,int_stack+422714, 2.0, int_stack+437666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+433796,int_stack+429596,int_stack+65154, 2.0, int_stack+245846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+245846,int_stack+103748,int_stack+103622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203654,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300394,int_stack+103916,int_stack+103748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203780,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+246224,int_stack+300394,int_stack+245846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440466,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+246980,int_stack+104132,int_stack+103916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203948,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+247628,int_stack+246980,int_stack+300394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440844,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+65154,int_stack+247628,int_stack+246224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441348,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+104402,int_stack+104132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204164,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+66414,int_stack+9870,int_stack+246980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442104,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+245846,int_stack+66414,int_stack+247628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442752,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+429596,int_stack+245846,int_stack+65154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256052,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+65154,int_stack+104732,int_stack+104402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204434,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+431486,int_stack+65154,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443760,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+431486,int_stack+66414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257312,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+422714,int_stack+245846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258608,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+245846,int_stack+0,int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224600,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+429596,int_stack+105338,int_stack+105128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125208,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+430226,int_stack+105618,int_stack+105338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125628,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+431066,int_stack+430226,int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444570,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+432326,int_stack+105978,int_stack+105618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126188,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+432326,int_stack+430226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445200,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+422714,int_stack+0,int_stack+431066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+446040,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+429596,int_stack+106428,int_stack+105978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126908,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+65154,int_stack+429596,int_stack+432326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229136,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+430946,int_stack+65154,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+570018,int_stack+430946,int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447300,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+422714,int_stack+106978,int_stack+106428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127808,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+220220,int_stack+422714,int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+449400,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+220220,int_stack+65154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450750,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+220220,int_stack+422714,int_stack+430946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452910,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+368292,int_stack+220220,int_stack+570018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455710,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+570018,int_stack+107764,int_stack+107638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203654, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+248492,int_stack+107932,int_stack+107764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203780, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+570396,int_stack+248492,int_stack+570018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440466, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+571152,int_stack+108148,int_stack+107932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203948, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+571800,int_stack+571152,int_stack+248492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440844, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+572808,int_stack+571800,int_stack+570396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441348, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+108418,int_stack+108148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204164, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+220220,int_stack+9870,int_stack+571152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442104, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+570018,int_stack+220220,int_stack+571800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442752, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+221516,int_stack+570018,int_stack+572808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256052, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+571698,int_stack+108748,int_stack+108418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204434, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+422714,int_stack+571698,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443760, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+571698,int_stack+422714,int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257312, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+571698,int_stack+570018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258608, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+570018,int_stack+0,int_stack+221516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224600, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+109354,int_stack+109144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125208, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+630,int_stack+109634,int_stack+109354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125628, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+572664,int_stack+630,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444570, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+220220,int_stack+109994,int_stack+109634, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126188, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+221300,int_stack+220220,int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445200, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+221300,int_stack+572664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+446040, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+572664,int_stack+110444,int_stack+109994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126908, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+422714,int_stack+572664,int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229136, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+65154,int_stack+422714,int_stack+221300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+220220,int_stack+65154,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447300, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+110994,int_stack+110444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127808, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+429596,int_stack+0,int_stack+572664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+449400, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+372702,int_stack+429596,int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450750, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+429596,int_stack+372702,int_stack+65154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452910, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+372702,int_stack+429596,int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455710, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+220220,int_stack+111780,int_stack+111654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203654, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+248492,int_stack+111948,int_stack+111780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203780, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+220598,int_stack+248492,int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440466, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+221354,int_stack+112164,int_stack+111948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203948, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+222002,int_stack+221354,int_stack+248492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440844, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+223010,int_stack+222002,int_stack+220598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441348, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+112434,int_stack+112164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204164, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+429596,int_stack+9870,int_stack+221354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442104, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+220220,int_stack+429596,int_stack+222002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442752, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+430892,int_stack+220220,int_stack+223010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256052, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+221900,int_stack+112764,int_stack+112434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204434, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+222890,int_stack+221900,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443760, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+65154,int_stack+222890,int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257312, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+65154,int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258608, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+220220,int_stack+0,int_stack+430892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224600, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+113370,int_stack+113160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125208, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+630,int_stack+113650,int_stack+113370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125628, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+222866,int_stack+630,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444570, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+65154,int_stack+114010,int_stack+113650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126188, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+66234,int_stack+65154,int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445200, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+66234,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+446040, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+222866,int_stack+114460,int_stack+114010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126908, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+429596,int_stack+222866,int_stack+65154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229136, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+377112,int_stack+429596,int_stack+66234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+65154,int_stack+377112,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447300, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+115010,int_stack+114460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127808, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+379912,int_stack+0,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+449400, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+379912,int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450750, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+429596,int_stack+422714,int_stack+377112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452910, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+377112,int_stack+429596,int_stack+65154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455710, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+65154,int_stack+115796,int_stack+115670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+248492,int_stack+115964,int_stack+115796, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+65532,int_stack+248492,int_stack+65154, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+66288,int_stack+116180,int_stack+115964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+66936,int_stack+66288,int_stack+248492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+429596,int_stack+66936,int_stack+65532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+116450,int_stack+116180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+430856,int_stack+9870,int_stack+66288, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+65154,int_stack+430856,int_stack+66936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+381522,int_stack+65154,int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+429596,int_stack+116780,int_stack+116450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+432152,int_stack+429596,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+443760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+432152,int_stack+430856, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+422714,int_stack+65154, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+258608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+65154,int_stack+0,int_stack+381522, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+224600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+381522,int_stack+117386,int_stack+117176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+382152,int_stack+117666,int_stack+117386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+125628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+382992,int_stack+382152,int_stack+381522, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+444570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+118026,int_stack+117666, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+422714,int_stack+0,int_stack+382152, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+424394,int_stack+422714,int_stack+382992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+446040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+381522,int_stack+118476,int_stack+118026, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+382872,int_stack+381522,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+429596,int_stack+382872,int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+397054,int_stack+429596,int_stack+424394, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+422714,int_stack+119026,int_stack+118476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+400204,int_stack+422714,int_stack+381522, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+449400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+400204,int_stack+382872, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+400204,int_stack+422714,int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+404404,int_stack+400204,int_stack+397054, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+455710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397054,int_stack+119812,int_stack+119686, 0.0, zero_stack, 1.0, int_stack+203654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+119980,int_stack+119812, 0.0, zero_stack, 1.0, int_stack+203780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+397432,int_stack+67800,int_stack+397054, 0.0, zero_stack, 1.0, int_stack+440466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+398188,int_stack+120196,int_stack+119980, 0.0, zero_stack, 1.0, int_stack+203948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+398836,int_stack+398188,int_stack+67800, 0.0, zero_stack, 1.0, int_stack+440844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+399844,int_stack+398836,int_stack+397432, 0.0, zero_stack, 1.0, int_stack+441348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+120466,int_stack+120196, 0.0, zero_stack, 1.0, int_stack+204164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+401104,int_stack+9870,int_stack+398188, 0.0, zero_stack, 1.0, int_stack+442104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+397054,int_stack+401104,int_stack+398836, 0.0, zero_stack, 1.0, int_stack+442752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+402400,int_stack+397054,int_stack+399844, 0.0, zero_stack, 1.0, int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+398734,int_stack+120796,int_stack+120466, 0.0, zero_stack, 1.0, int_stack+204434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+429596,int_stack+398734,int_stack+9870, 0.0, zero_stack, 1.0, int_stack+443760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+398734,int_stack+429596,int_stack+401104, 0.0, zero_stack, 1.0, int_stack+257312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+398734,int_stack+397054, 0.0, zero_stack, 1.0, int_stack+258608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+397054,int_stack+0,int_stack+402400, 0.0, zero_stack, 1.0, int_stack+224600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+121402,int_stack+121192, 0.0, zero_stack, 1.0, int_stack+125208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+630,int_stack+121682,int_stack+121402, 0.0, zero_stack, 1.0, int_stack+125628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+399700,int_stack+630,int_stack+0, 0.0, zero_stack, 1.0, int_stack+444570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+400960,int_stack+122042,int_stack+121682, 0.0, zero_stack, 1.0, int_stack+126188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+402040,int_stack+400960,int_stack+630, 0.0, zero_stack, 1.0, int_stack+445200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+402040,int_stack+399700, 0.0, zero_stack, 1.0, int_stack+446040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+429596,int_stack+122492,int_stack+122042, 0.0, zero_stack, 1.0, int_stack+126908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+430946,int_stack+429596,int_stack+400960, 0.0, zero_stack, 1.0, int_stack+229136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+422714,int_stack+430946,int_stack+402040, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+399700,int_stack+422714,int_stack+0, 0.0, zero_stack, 1.0, int_stack+447300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+123042,int_stack+122492, 0.0, zero_stack, 1.0, int_stack+127808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+408814,int_stack+0,int_stack+429596, 0.0, zero_stack, 1.0, int_stack+449400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+411514,int_stack+408814,int_stack+430946, 0.0, zero_stack, 1.0, int_stack+450750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+429596,int_stack+411514,int_stack+422714, 0.0, zero_stack, 1.0, int_stack+452910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+408814,int_stack+429596,int_stack+399700, 0.0, zero_stack, 1.0, int_stack+455710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+399700,int_stack+123828,int_stack+123702, 1.0, int_stack+203654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+123996,int_stack+123828, 1.0, int_stack+203780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+400078,int_stack+67800,int_stack+399700, 1.0, int_stack+440466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+400834,int_stack+124212,int_stack+123996, 1.0, int_stack+203948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+401482,int_stack+400834,int_stack+67800, 1.0, int_stack+440844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+402490,int_stack+401482,int_stack+400078, 1.0, int_stack+441348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+124482,int_stack+124212, 1.0, int_stack+204164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+429596,int_stack+9870,int_stack+400834, 1.0, int_stack+442104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+399700,int_stack+429596,int_stack+401482, 1.0, int_stack+442752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+430892,int_stack+399700,int_stack+402490, 1.0, int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+256052,int_stack+124812,int_stack+124482, 1.0, int_stack+204434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+401380,int_stack+256052,int_stack+9870, 1.0, int_stack+443760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+401380,int_stack+429596, 1.0, int_stack+257312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+0,int_stack+422714,int_stack+399700, 1.0, int_stack+258608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+399700,int_stack+0,int_stack+430892, 1.0, int_stack+224600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+125908,int_stack+125418, 1.0, int_stack+125208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+630,int_stack+126548,int_stack+125908, 1.0, int_stack+125628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+402346,int_stack+630,int_stack+0, 1.0, int_stack+444570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+422714,int_stack+127358,int_stack+126548, 1.0, int_stack+126188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+423794,int_stack+422714,int_stack+630, 1.0, int_stack+445200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+423794,int_stack+402346, 1.0, int_stack+446040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+402346,int_stack+128358,int_stack+127358, 1.0, int_stack+126908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+429596,int_stack+402346,int_stack+422714, 1.0, int_stack+229136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+229136,int_stack+429596,int_stack+423794, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+231936,int_stack+229136,int_stack+0, 1.0, int_stack+447300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+128908,int_stack+128358, 1.0, int_stack+127808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+235086,int_stack+0,int_stack+402346, 1.0, int_stack+449400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+235086,int_stack+429596, 1.0, int_stack+450750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+429596,int_stack+0,int_stack+229136, 1.0, int_stack+452910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+235086,int_stack+429596,int_stack+231936, 1.0, int_stack+455710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+429596,int_stack+129694,int_stack+129568,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+129862,int_stack+129694,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+429974,int_stack+67800,int_stack+429596,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+430730,int_stack+130078,int_stack+129862,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+431378,int_stack+430730,int_stack+67800,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+432386,int_stack+431378,int_stack+429974,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+130348,int_stack+130078,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+229136,int_stack+9870,int_stack+430730,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+429596,int_stack+229136,int_stack+431378,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+230432,int_stack+429596,int_stack+432386,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+431276,int_stack+130678,int_stack+130348,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+232322,int_stack+431276,int_stack+9870,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+431276,int_stack+232322,int_stack+229136,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+232322,int_stack+431276,int_stack+429596,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+429596,int_stack+232322,int_stack+230432,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+432242,int_stack+131284,int_stack+131074,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+432872,int_stack+131564,int_stack+131284,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+229136,int_stack+432872,int_stack+432242,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+230396,int_stack+131924,int_stack+131564,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+231476,int_stack+230396,int_stack+432872,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+231476,int_stack+229136,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+432242,int_stack+132374,int_stack+131924,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+239496,int_stack+432242,int_stack+230396,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+422714,int_stack+239496,int_stack+231476,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+229136,int_stack+422714,int_stack+0,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+132924,int_stack+132374,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+232286,int_stack+0,int_stack+432242,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+232286,int_stack+239496,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+256052,int_stack+0,int_stack+422714,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+413224,int_stack+256052,int_stack+229136,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+229136,int_stack+133710,int_stack+133584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209176,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+133878,int_stack+133710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209302,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+229514,int_stack+67800,int_stack+229136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458860,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+230270,int_stack+134094,int_stack+133878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209470,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+230918,int_stack+230270,int_stack+67800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459238,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+231926,int_stack+230918,int_stack+229514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459742,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+134364,int_stack+134094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209686,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+233186,int_stack+9870,int_stack+230270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460498,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+229136,int_stack+233186,int_stack+230918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461146,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+256052,int_stack+229136,int_stack+231926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467470,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+230816,int_stack+134694,int_stack+134364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209956,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+257942,int_stack+230816,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462154,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+230816,int_stack+257942,int_stack+233186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468730,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+422714,int_stack+230816,int_stack+229136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470026,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+229136,int_stack+422714,int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471706,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+256052,int_stack+135300,int_stack+135090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155170,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+256682,int_stack+135580,int_stack+135300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155590,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+257522,int_stack+256682,int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476242,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+258782,int_stack+135940,int_stack+135580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156150,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+422714,int_stack+258782,int_stack+256682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476872,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+424394,int_stack+422714,int_stack+257522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477712,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+256052,int_stack+136390,int_stack+135940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156870,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+231782,int_stack+256052,int_stack+258782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260288,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+257402,int_stack+231782,int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478972,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+0,int_stack+257402,int_stack+424394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480652,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+422714,int_stack+136940,int_stack+136390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157770,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+239496,int_stack+422714,int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482752,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+239496,int_stack+231782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484102,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+438206,int_stack+422714,int_stack+257402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486262,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+442406,int_stack+438206,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489062,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+137726,int_stack+137600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209176, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+137894,int_stack+137726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209302, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+378,int_stack+67800,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458860, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1134,int_stack+138110,int_stack+137894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209470, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1782,int_stack+1134,int_stack+67800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459238, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2790,int_stack+1782,int_stack+378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459742, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+138380,int_stack+138110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209686, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+438206,int_stack+9870,int_stack+1134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460498, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+0,int_stack+438206,int_stack+1782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461146, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+439502,int_stack+0,int_stack+2790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467470, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1680,int_stack+138710,int_stack+138380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209956, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+422714,int_stack+1680,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462154, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1680,int_stack+422714,int_stack+438206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468730, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+422714,int_stack+1680,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470026, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+0,int_stack+422714,int_stack+439502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471706, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+422714,int_stack+139316,int_stack+139106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155170, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423344,int_stack+139596,int_stack+139316, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155590, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+424184,int_stack+423344,int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476242, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+425444,int_stack+139956,int_stack+139596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156150, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+438206,int_stack+425444,int_stack+423344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476872, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+439886,int_stack+438206,int_stack+424184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477712, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+422714,int_stack+140406,int_stack+139956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156870, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+231782,int_stack+422714,int_stack+425444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260288, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+424064,int_stack+231782,int_stack+438206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478972, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+239496,int_stack+424064,int_stack+439886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480652, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+438206,int_stack+140956,int_stack+140406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157770, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+256052,int_stack+438206,int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482752, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+438206,int_stack+256052,int_stack+231782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484102, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+256052,int_stack+438206,int_stack+424064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486262, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+446816,int_stack+256052,int_stack+239496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489062, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+239496,int_stack+141742,int_stack+141616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209176, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+141910,int_stack+141742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209302, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+239874,int_stack+67800,int_stack+239496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458860, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+240630,int_stack+142126,int_stack+141910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209470, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+241278,int_stack+240630,int_stack+67800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459238, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+256052,int_stack+241278,int_stack+239874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459742, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+142396,int_stack+142126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209686, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+257312,int_stack+9870,int_stack+240630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460498, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+258608,int_stack+257312,int_stack+241278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461146, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+239496,int_stack+258608,int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467470, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+256052,int_stack+142726,int_stack+142396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209956, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+241386,int_stack+256052,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462154, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+438206,int_stack+241386,int_stack+257312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468730, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+256052,int_stack+438206,int_stack+258608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470026, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+438206,int_stack+256052,int_stack+239496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471706, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+239496,int_stack+143332,int_stack+143122, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155170, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+240126,int_stack+143612,int_stack+143332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155590, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+240966,int_stack+240126,int_stack+239496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476242, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+256052,int_stack+143972,int_stack+143612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156150, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+257132,int_stack+256052,int_stack+240126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476872, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+231782,int_stack+257132,int_stack+240966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477712, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+239496,int_stack+144422,int_stack+143972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156870, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+240846,int_stack+239496,int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260288, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+422714,int_stack+240846,int_stack+257132, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478972, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+256052,int_stack+422714,int_stack+231782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480652, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+231782,int_stack+144972,int_stack+144422, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157770, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+381522,int_stack+231782,int_stack+239496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482752, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+222866,int_stack+381522,int_stack+240846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484102, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+451226,int_stack+222866,int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486262, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+312364,int_stack+451226,int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489062, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+256052,int_stack+145758,int_stack+145632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+145926,int_stack+145758, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+256430,int_stack+67800,int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+257186,int_stack+146142,int_stack+145926, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+257834,int_stack+257186,int_stack+67800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+258842,int_stack+257834,int_stack+256430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+146412,int_stack+146142, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+451226,int_stack+9870,int_stack+257186, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+460498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+256052,int_stack+451226,int_stack+257834, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+452522,int_stack+256052,int_stack+258842, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+257732,int_stack+146742,int_stack+146412, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+454412,int_stack+257732,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+257732,int_stack+454412,int_stack+451226, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+468730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+454412,int_stack+257732,int_stack+256052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+256052,int_stack+454412,int_stack+452522, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+258698,int_stack+147348,int_stack+147138, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+259328,int_stack+147628,int_stack+147348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+155590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+451226,int_stack+259328,int_stack+258698, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+452486,int_stack+147988,int_stack+147628, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+453566,int_stack+452486,int_stack+259328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+455246,int_stack+453566,int_stack+451226, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+258698,int_stack+148438,int_stack+147988, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+156870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+422714,int_stack+258698,int_stack+452486, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+222866,int_stack+422714,int_stack+453566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+478972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+451226,int_stack+222866,int_stack+455246, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+454376,int_stack+148988,int_stack+148438, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+157770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+456026,int_stack+454376,int_stack+258698, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+381522,int_stack+456026,int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+484102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+422714,int_stack+381522,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+454376,int_stack+422714,int_stack+451226, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+489062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+451226,int_stack+149774,int_stack+149648, 0.0, zero_stack, 1.0, int_stack+209176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+149942,int_stack+149774, 0.0, zero_stack, 1.0, int_stack+209302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+451604,int_stack+67800,int_stack+451226, 0.0, zero_stack, 1.0, int_stack+458860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+452360,int_stack+150158,int_stack+149942, 0.0, zero_stack, 1.0, int_stack+209470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+453008,int_stack+452360,int_stack+67800, 0.0, zero_stack, 1.0, int_stack+459238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+422714,int_stack+453008,int_stack+451604, 0.0, zero_stack, 1.0, int_stack+459742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+150428,int_stack+150158, 0.0, zero_stack, 1.0, int_stack+209686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+423974,int_stack+9870,int_stack+452360, 0.0, zero_stack, 1.0, int_stack+460498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+425270,int_stack+423974,int_stack+453008, 0.0, zero_stack, 1.0, int_stack+461146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+451226,int_stack+425270,int_stack+422714, 0.0, zero_stack, 1.0, int_stack+467470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+422714,int_stack+150758,int_stack+150428, 0.0, zero_stack, 1.0, int_stack+209956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+222866,int_stack+422714,int_stack+9870, 0.0, zero_stack, 1.0, int_stack+462154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+381522,int_stack+222866,int_stack+423974, 0.0, zero_stack, 1.0, int_stack+468730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+222866,int_stack+381522,int_stack+425270, 0.0, zero_stack, 1.0, int_stack+470026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+381522,int_stack+222866,int_stack+451226, 0.0, zero_stack, 1.0, int_stack+471706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+451226,int_stack+151364,int_stack+151154, 0.0, zero_stack, 1.0, int_stack+155170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+451856,int_stack+151644,int_stack+151364, 0.0, zero_stack, 1.0, int_stack+155590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+452696,int_stack+451856,int_stack+451226, 0.0, zero_stack, 1.0, int_stack+476242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+222866,int_stack+152004,int_stack+151644, 0.0, zero_stack, 1.0, int_stack+156150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+223946,int_stack+222866,int_stack+451856, 0.0, zero_stack, 1.0, int_stack+476872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+422714,int_stack+223946,int_stack+452696, 0.0, zero_stack, 1.0, int_stack+477712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+451226,int_stack+152454,int_stack+152004, 0.0, zero_stack, 1.0, int_stack+156870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+239496,int_stack+451226,int_stack+222866, 0.0, zero_stack, 1.0, int_stack+260288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+231782,int_stack+239496,int_stack+223946, 0.0, zero_stack, 1.0, int_stack+478972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+222866,int_stack+231782,int_stack+422714, 0.0, zero_stack, 1.0, int_stack+480652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+422714,int_stack+153004,int_stack+152454, 0.0, zero_stack, 1.0, int_stack+157770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+329450,int_stack+422714,int_stack+451226, 0.0, zero_stack, 1.0, int_stack+482752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+329450,int_stack+239496, 0.0, zero_stack, 1.0, int_stack+484102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+329450,int_stack+422714,int_stack+231782, 0.0, zero_stack, 1.0, int_stack+486262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+333650,int_stack+329450,int_stack+222866, 0.0, zero_stack, 1.0, int_stack+489062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+222866,int_stack+153790,int_stack+153664, 1.0, int_stack+209176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+153958,int_stack+153790, 1.0, int_stack+209302, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+223244,int_stack+67800,int_stack+222866, 1.0, int_stack+458860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+224000,int_stack+154174,int_stack+153958, 1.0, int_stack+209470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+224648,int_stack+224000,int_stack+67800, 1.0, int_stack+459238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+329450,int_stack+224648,int_stack+223244, 1.0, int_stack+459742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+154444,int_stack+154174, 1.0, int_stack+209686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330710,int_stack+9870,int_stack+224000, 1.0, int_stack+460498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+222866,int_stack+330710,int_stack+224648, 1.0, int_stack+461146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+224546,int_stack+222866,int_stack+329450, 1.0, int_stack+467470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+467470,int_stack+154774,int_stack+154444, 1.0, int_stack+209956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+332006,int_stack+467470,int_stack+9870, 1.0, int_stack+462154, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+231782,int_stack+332006,int_stack+330710, 1.0, int_stack+468730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+467470,int_stack+231782,int_stack+222866, 1.0, int_stack+470026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+231782,int_stack+467470,int_stack+224546, 1.0, int_stack+471706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+467470,int_stack+155870,int_stack+155380, 1.0, int_stack+155170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+468100,int_stack+156510,int_stack+155870, 1.0, int_stack+155590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+468940,int_stack+468100,int_stack+467470, 1.0, int_stack+476242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+470200,int_stack+157320,int_stack+156510, 1.0, int_stack+156150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+471280,int_stack+470200,int_stack+468100, 1.0, int_stack+476872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+222866,int_stack+471280,int_stack+468940, 1.0, int_stack+477712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+476242,int_stack+158320,int_stack+157320, 1.0, int_stack+156870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+467470,int_stack+476242,int_stack+470200, 1.0, int_stack+260288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+329450,int_stack+467470,int_stack+471280, 1.0, int_stack+478972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+451226,int_stack+329450,int_stack+222866, 1.0, int_stack+480652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+222866,int_stack+158870,int_stack+158320, 1.0, int_stack+157770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+477592,int_stack+222866,int_stack+476242, 1.0, int_stack+482752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+222866,int_stack+477592,int_stack+467470, 1.0, int_stack+484102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+467470,int_stack+222866,int_stack+329450, 1.0, int_stack+486262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+476242,int_stack+467470,int_stack+451226, 1.0, int_stack+489062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+451226,int_stack+159656,int_stack+159530,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+67800,int_stack+159824,int_stack+159656,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+451604,int_stack+67800,int_stack+451226,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+452360,int_stack+160040,int_stack+159824,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+453008,int_stack+452360,int_stack+67800,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+467470,int_stack+453008,int_stack+451604,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+160310,int_stack+160040,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+468730,int_stack+9870,int_stack+452360,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+451226,int_stack+468730,int_stack+453008,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+470026,int_stack+451226,int_stack+467470,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+467470,int_stack+160640,int_stack+160310,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+471916,int_stack+467470,int_stack+9870,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+329450,int_stack+471916,int_stack+468730,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+467470,int_stack+329450,int_stack+451226,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+451226,int_stack+467470,int_stack+470026,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+467470,int_stack+161246,int_stack+161036,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+468100,int_stack+161526,int_stack+161246,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+468940,int_stack+468100,int_stack+467470,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+470200,int_stack+161886,int_stack+161526,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+471280,int_stack+470200,int_stack+468100,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+329450,int_stack+471280,int_stack+468940,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+467470,int_stack+162336,int_stack+161886,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+222866,int_stack+467470,int_stack+470200,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+480652,int_stack+222866,int_stack+471280,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+468820,int_stack+480652,int_stack+329450,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+329450,int_stack+162886,int_stack+162336,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+483452,int_stack+329450,int_stack+467470,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+329450,int_stack+483452,int_stack+222866,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+483452,int_stack+329450,int_stack+480652,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+487652,int_stack+483452,int_stack+468820,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+480652,int_stack+163672,int_stack+163546,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+453872,int_stack+163840,int_stack+163672,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+481030,int_stack+453872,int_stack+480652,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+481786,int_stack+164056,int_stack+163840,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+482434,int_stack+481786,int_stack+453872,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+483442,int_stack+482434,int_stack+481030,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+164326,int_stack+164056,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+484702,int_stack+9870,int_stack+481786,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+480652,int_stack+484702,int_stack+482434,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+329450,int_stack+480652,int_stack+483442,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+482332,int_stack+164656,int_stack+164326,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+485998,int_stack+482332,int_stack+9870,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+482332,int_stack+485998,int_stack+484702,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+484492,int_stack+482332,int_stack+480652,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+480652,int_stack+484492,int_stack+329450,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+329450,int_stack+165262,int_stack+165052,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+330080,int_stack+165542,int_stack+165262,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+330920,int_stack+330080,int_stack+329450,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+332180,int_stack+165902,int_stack+165542,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+483298,int_stack+332180,int_stack+330080,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+484978,int_stack+483298,int_stack+330920,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+329450,int_stack+166352,int_stack+165902,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+222866,int_stack+329450,int_stack+332180,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+330800,int_stack+222866,int_stack+483298,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+467470,int_stack+330800,int_stack+484978,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+483298,int_stack+166902,int_stack+166352,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+484948,int_stack+483298,int_stack+329450,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+484948,int_stack+222866,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+483298,int_stack+422714,int_stack+330800,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+338060,int_stack+483298,int_stack+467470,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+467470,int_stack+169194,int_stack+169068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214698,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+453872,int_stack+169362,int_stack+169194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214824,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+467848,int_stack+453872,int_stack+467470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492212,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+468604,int_stack+169578,int_stack+169362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214992,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+469252,int_stack+468604,int_stack+453872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492590,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+470260,int_stack+469252,int_stack+467848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493094,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+169848,int_stack+169578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215208,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+471520,int_stack+9870,int_stack+468604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493850,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+467470,int_stack+471520,int_stack+469252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494498,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+483298,int_stack+467470,int_stack+470260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4200,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+469150,int_stack+170178,int_stack+169848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215478,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+485188,int_stack+469150,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495506,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+469150,int_stack+485188,int_stack+471520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500822,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+422714,int_stack+469150,int_stack+467470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502118,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+467470,int_stack+422714,int_stack+483298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503798,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+483298,int_stack+170784,int_stack+170574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199294,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+483928,int_stack+171064,int_stack+170784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199714,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484768,int_stack+483928,int_stack+483298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508334,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+486028,int_stack+171424,int_stack+171064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200274,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+422714,int_stack+486028,int_stack+483928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508964,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+424394,int_stack+422714,int_stack+484768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509804,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+483298,int_stack+171874,int_stack+171424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200994,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+470116,int_stack+483298,int_stack+486028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511064,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+484648,int_stack+470116,int_stack+422714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512144,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+222866,int_stack+484648,int_stack+424394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+513824,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+422714,int_stack+172424,int_stack+171874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201894,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+329450,int_stack+422714,int_stack+483298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515924,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+329450,int_stack+470116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517274,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+329450,int_stack+422714,int_stack+484648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519434,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+342470,int_stack+329450,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522234,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+222866,int_stack+174716,int_stack+174590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214698, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+453872,int_stack+174884,int_stack+174716, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214824, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+223244,int_stack+453872,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492212, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+224000,int_stack+175100,int_stack+174884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214992, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+224648,int_stack+224000,int_stack+453872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492590, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+329450,int_stack+224648,int_stack+223244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493094, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+175370,int_stack+175100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215208, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330710,int_stack+9870,int_stack+224000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493850, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+222866,int_stack+330710,int_stack+224648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494498, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+224546,int_stack+222866,int_stack+329450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4200, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+329450,int_stack+175700,int_stack+175370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215478, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+332006,int_stack+329450,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495506, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+422714,int_stack+332006,int_stack+330710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500822, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+329450,int_stack+422714,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502118, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+422714,int_stack+329450,int_stack+224546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503798, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+329450,int_stack+176306,int_stack+176096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199294, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+330080,int_stack+176586,int_stack+176306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199714, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+330920,int_stack+330080,int_stack+329450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508334, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+332180,int_stack+176946,int_stack+176586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200274, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+222866,int_stack+332180,int_stack+330080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508964, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+470116,int_stack+222866,int_stack+330920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509804, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+329450,int_stack+177396,int_stack+176946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200994, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+483298,int_stack+329450,int_stack+332180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511064, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+330800,int_stack+483298,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512144, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+222866,int_stack+330800,int_stack+470116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+513824, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+470116,int_stack+177946,int_stack+177396, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201894, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+239496,int_stack+470116,int_stack+329450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515924, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+346880,int_stack+239496,int_stack+483298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517274, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+483298,int_stack+346880,int_stack+330800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519434, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+258698,int_stack+483298,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522234, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+222866,int_stack+180238,int_stack+180112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214698, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+453872,int_stack+180406,int_stack+180238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214824, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+223244,int_stack+453872,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492212, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+224000,int_stack+180622,int_stack+180406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214992, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+224648,int_stack+224000,int_stack+453872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492590, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+483298,int_stack+224648,int_stack+223244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493094, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+180892,int_stack+180622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215208, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+484558,int_stack+9870,int_stack+224000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493850, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+222866,int_stack+484558,int_stack+224648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494498, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+224546,int_stack+222866,int_stack+483298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4200, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+483298,int_stack+181222,int_stack+180892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215478, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+485854,int_stack+483298,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495506, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+346880,int_stack+485854,int_stack+484558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500822, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+483298,int_stack+346880,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502118, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+346880,int_stack+483298,int_stack+224546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503798, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+483298,int_stack+181828,int_stack+181618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199294, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+483928,int_stack+182108,int_stack+181828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199714, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484768,int_stack+483928,int_stack+483298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508334, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+486028,int_stack+182468,int_stack+182108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200274, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+222866,int_stack+486028,int_stack+483928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508964, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+239496,int_stack+222866,int_stack+484768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509804, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+483298,int_stack+182918,int_stack+182468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200994, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+329450,int_stack+483298,int_stack+486028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511064, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+484648,int_stack+329450,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512144, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+222866,int_stack+484648,int_stack+239496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+513824, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+239496,int_stack+183468,int_stack+182918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201894, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+470116,int_stack+239496,int_stack+483298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515924, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+239496,int_stack+470116,int_stack+329450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517274, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+329450,int_stack+239496,int_stack+484648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519434, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+263108,int_stack+329450,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522234, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+222866,int_stack+185760,int_stack+185634, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+453872,int_stack+185928,int_stack+185760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+223244,int_stack+453872,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+224000,int_stack+186144,int_stack+185928, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+224648,int_stack+224000,int_stack+453872, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+329450,int_stack+224648,int_stack+223244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+186414,int_stack+186144, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+330710,int_stack+9870,int_stack+224000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+222866,int_stack+330710,int_stack+224648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+224546,int_stack+222866,int_stack+329450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+329450,int_stack+186744,int_stack+186414, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+332006,int_stack+329450,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+495506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+239496,int_stack+332006,int_stack+330710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+329450,int_stack+239496,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+502118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+239496,int_stack+329450,int_stack+224546, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+329450,int_stack+187350,int_stack+187140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+330080,int_stack+187630,int_stack+187350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+199714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+330920,int_stack+330080,int_stack+329450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+332180,int_stack+187990,int_stack+187630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+222866,int_stack+332180,int_stack+330080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+508964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+470116,int_stack+222866,int_stack+330920, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+509804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+329450,int_stack+188440,int_stack+187990, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+200994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+483298,int_stack+329450,int_stack+332180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+330800,int_stack+483298,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+222866,int_stack+330800,int_stack+470116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+513824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+470116,int_stack+188990,int_stack+188440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+201894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+267518,int_stack+470116,int_stack+329450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+270218,int_stack+267518,int_stack+483298, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+483298,int_stack+270218,int_stack+330800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+267518,int_stack+483298,int_stack+222866, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+222866,int_stack+191282,int_stack+191156, 0.0, zero_stack, 1.0, int_stack+214698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+453872,int_stack+191450,int_stack+191282, 0.0, zero_stack, 1.0, int_stack+214824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+223244,int_stack+453872,int_stack+222866, 0.0, zero_stack, 1.0, int_stack+492212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+224000,int_stack+191666,int_stack+191450, 0.0, zero_stack, 1.0, int_stack+214992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+224648,int_stack+224000,int_stack+453872, 0.0, zero_stack, 1.0, int_stack+492590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+483298,int_stack+224648,int_stack+223244, 0.0, zero_stack, 1.0, int_stack+493094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+191936,int_stack+191666, 0.0, zero_stack, 1.0, int_stack+215208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+484558,int_stack+9870,int_stack+224000, 0.0, zero_stack, 1.0, int_stack+493850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+222866,int_stack+484558,int_stack+224648, 0.0, zero_stack, 1.0, int_stack+494498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+224546,int_stack+222866,int_stack+483298, 0.0, zero_stack, 1.0, int_stack+4200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+483298,int_stack+192266,int_stack+191936, 0.0, zero_stack, 1.0, int_stack+215478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+485854,int_stack+483298,int_stack+9870, 0.0, zero_stack, 1.0, int_stack+495506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+271928,int_stack+485854,int_stack+484558, 0.0, zero_stack, 1.0, int_stack+500822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+483298,int_stack+271928,int_stack+222866, 0.0, zero_stack, 1.0, int_stack+502118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+271928,int_stack+483298,int_stack+224546, 0.0, zero_stack, 1.0, int_stack+503798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+483298,int_stack+192872,int_stack+192662, 0.0, zero_stack, 1.0, int_stack+199294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+483928,int_stack+193152,int_stack+192872, 0.0, zero_stack, 1.0, int_stack+199714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+484768,int_stack+483928,int_stack+483298, 0.0, zero_stack, 1.0, int_stack+508334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+486028,int_stack+193512,int_stack+193152, 0.0, zero_stack, 1.0, int_stack+200274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+222866,int_stack+486028,int_stack+483928, 0.0, zero_stack, 1.0, int_stack+508964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+274574,int_stack+222866,int_stack+484768, 0.0, zero_stack, 1.0, int_stack+509804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+483298,int_stack+193962,int_stack+193512, 0.0, zero_stack, 1.0, int_stack+200994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+276674,int_stack+483298,int_stack+486028, 0.0, zero_stack, 1.0, int_stack+511064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+484648,int_stack+276674,int_stack+222866, 0.0, zero_stack, 1.0, int_stack+512144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+222866,int_stack+484648,int_stack+274574, 0.0, zero_stack, 1.0, int_stack+513824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+274574,int_stack+194512,int_stack+193962, 0.0, zero_stack, 1.0, int_stack+201894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+278834,int_stack+274574,int_stack+483298, 0.0, zero_stack, 1.0, int_stack+515924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+329450,int_stack+278834,int_stack+276674, 0.0, zero_stack, 1.0, int_stack+517274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+274574,int_stack+329450,int_stack+484648, 0.0, zero_stack, 1.0, int_stack+519434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+321938,int_stack+274574,int_stack+222866, 0.0, zero_stack, 1.0, int_stack+522234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+222866,int_stack+197914,int_stack+197788, 1.0, int_stack+214698, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+453872,int_stack+198082,int_stack+197914, 1.0, int_stack+214824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+223244,int_stack+453872,int_stack+222866, 1.0, int_stack+492212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+224000,int_stack+198298,int_stack+198082, 1.0, int_stack+214992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+224648,int_stack+224000,int_stack+453872, 1.0, int_stack+492590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+274574,int_stack+224648,int_stack+223244, 1.0, int_stack+493094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+198568,int_stack+198298, 1.0, int_stack+215208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+275834,int_stack+9870,int_stack+224000, 1.0, int_stack+493850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+222866,int_stack+275834,int_stack+224648, 1.0, int_stack+494498, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+224546,int_stack+222866,int_stack+274574, 1.0, int_stack+4200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+274574,int_stack+198898,int_stack+198568, 1.0, int_stack+215478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+277130,int_stack+274574,int_stack+9870, 1.0, int_stack+495506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+278750,int_stack+277130,int_stack+275834, 1.0, int_stack+500822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+274574,int_stack+278750,int_stack+222866, 1.0, int_stack+502118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (d0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+500822,int_stack+274574,int_stack+224546, 1.0, int_stack+503798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,6);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+274574,int_stack+199994,int_stack+199504, 1.0, int_stack+199294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+275204,int_stack+200634,int_stack+199994, 1.0, int_stack+199714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+276044,int_stack+275204,int_stack+274574, 1.0, int_stack+508334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+277304,int_stack+201444,int_stack+200634, 1.0, int_stack+200274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+278384,int_stack+277304,int_stack+275204, 1.0, int_stack+508964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+222866,int_stack+278384,int_stack+276044, 1.0, int_stack+509804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+508334,int_stack+202444,int_stack+201444, 1.0, int_stack+200994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+274574,int_stack+508334,int_stack+277304, 1.0, int_stack+511064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+329450,int_stack+274574,int_stack+278384, 1.0, int_stack+512144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+509684,int_stack+329450,int_stack+222866, 1.0, int_stack+513824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+222866,int_stack+202994,int_stack+202444, 1.0, int_stack+201894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+512834,int_stack+222866,int_stack+508334, 1.0, int_stack+515924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+222866,int_stack+512834,int_stack+274574, 1.0, int_stack+517274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+274574,int_stack+222866,int_stack+329450, 1.0, int_stack+519434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+512834,int_stack+274574,int_stack+509684, 1.0, int_stack+522234, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+274574,int_stack+205286,int_stack+205160,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+453872,int_stack+205454,int_stack+205286,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+274952,int_stack+453872,int_stack+274574,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+275708,int_stack+205670,int_stack+205454,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+276356,int_stack+275708,int_stack+453872,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+277364,int_stack+276356,int_stack+274952,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+205940,int_stack+205670,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+278624,int_stack+9870,int_stack+275708,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+274574,int_stack+278624,int_stack+276356,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+279920,int_stack+274574,int_stack+277364,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+276254,int_stack+206270,int_stack+205940,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+329450,int_stack+276254,int_stack+9870,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+276254,int_stack+329450,int_stack+278624,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+329450,int_stack+276254,int_stack+274574,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+274574,int_stack+329450,int_stack+279920,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+329450,int_stack+206876,int_stack+206666,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+330080,int_stack+207156,int_stack+206876,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+330920,int_stack+330080,int_stack+329450,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+332180,int_stack+207516,int_stack+207156,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+277220,int_stack+332180,int_stack+330080,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+278900,int_stack+277220,int_stack+330920,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+329450,int_stack+207966,int_stack+207516,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+222866,int_stack+329450,int_stack+332180,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+330800,int_stack+222866,int_stack+277220,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+517244,int_stack+330800,int_stack+278900,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+277220,int_stack+208516,int_stack+207966,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+278870,int_stack+277220,int_stack+329450,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+520394,int_stack+278870,int_stack+222866,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+277220,int_stack+520394,int_stack+330800,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+520394,int_stack+277220,int_stack+517244,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+517244,int_stack+210808,int_stack+210682,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+453872,int_stack+210976,int_stack+210808,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+517622,int_stack+453872,int_stack+517244,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+518378,int_stack+211192,int_stack+210976,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+519026,int_stack+518378,int_stack+453872,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+277220,int_stack+519026,int_stack+517622,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+211462,int_stack+211192,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+278480,int_stack+9870,int_stack+518378,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+517244,int_stack+278480,int_stack+519026,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+279776,int_stack+517244,int_stack+277220,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+277220,int_stack+211792,int_stack+211462,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+222866,int_stack+277220,int_stack+9870,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+329450,int_stack+222866,int_stack+278480,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+222866,int_stack+329450,int_stack+517244,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+517244,int_stack+222866,int_stack+279776,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+222866,int_stack+212398,int_stack+212188,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+223496,int_stack+212678,int_stack+212398,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+224336,int_stack+223496,int_stack+222866,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+329450,int_stack+213038,int_stack+212678,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+330530,int_stack+329450,int_stack+223496,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+277220,int_stack+330530,int_stack+224336,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+222866,int_stack+213488,int_stack+213038,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+224216,int_stack+222866,int_stack+329450,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+508334,int_stack+224216,int_stack+330530,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+329450,int_stack+508334,int_stack+277220,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+277220,int_stack+214038,int_stack+213488,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+278870,int_stack+277220,int_stack+222866,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+483298,int_stack+278870,int_stack+224216,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+277220,int_stack+483298,int_stack+508334,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+508334,int_stack+277220,int_stack+329450,10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+329450,int_stack+216330,int_stack+216204,6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+519890,int_stack+216498,int_stack+216330,6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+329828,int_stack+519890,int_stack+329450,6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+330584,int_stack+216714,int_stack+216498,6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+331232,int_stack+330584,int_stack+519890,6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+332240,int_stack+331232,int_stack+329828,6);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+9870,int_stack+216984,int_stack+216714,6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+277220,int_stack+9870,int_stack+330584,6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+329450,int_stack+277220,int_stack+331232,6);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+278516,int_stack+329450,int_stack+332240,6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+331130,int_stack+217314,int_stack+216984,6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+280406,int_stack+331130,int_stack+9870,6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+331130,int_stack+280406,int_stack+277220,6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+483298,int_stack+331130,int_stack+329450,6);
 /*--- compute (d0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+329450,int_stack+483298,int_stack+278516,6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+483298,int_stack+217920,int_stack+217710,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+483928,int_stack+218200,int_stack+217920,10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+484768,int_stack+483928,int_stack+483298,10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+486028,int_stack+218560,int_stack+218200,10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+277220,int_stack+486028,int_stack+483928,10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+278900,int_stack+277220,int_stack+484768,10);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+483298,int_stack+219010,int_stack+218560,10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+222866,int_stack+483298,int_stack+486028,10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+484648,int_stack+222866,int_stack+277220,10);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+470116,int_stack+484648,int_stack+278900,10);
 /*--- compute (f0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+277220,int_stack+219560,int_stack+219010,10);
 /*--- compute (f0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+278870,int_stack+277220,int_stack+483298,10);
 /*--- compute (f0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+492062,int_stack+278870,int_stack+222866,10);
 /*--- compute (f0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+277220,int_stack+492062,int_stack+484648,10);
 /*--- compute (f0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+286456,int_stack+277220,int_stack+470116,10);
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+72714,int_stack+282046,int_stack+243200,441);
     Libderiv->ABCD[11] = int_stack + 72714;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+277220,int_stack+317528,int_stack+295102,441);
     Libderiv->ABCD[10] = int_stack + 277220;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+80652,int_stack+350700,int_stack+326804,441);
     Libderiv->ABCD[9] = int_stack + 80652;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+88590,int_stack+385132,int_stack+361236,441);
     Libderiv->ABCD[8] = int_stack + 88590;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+96528,int_stack+418304,int_stack+394408,441);
     Libderiv->ABCD[7] = int_stack + 96528;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+104466,int_stack+248996,int_stack+426950,441);
     Libderiv->ABCD[6] = int_stack + 104466;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+112404,int_stack+463060,int_stack+226490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+253406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[2] = int_stack + 112404;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+458786,int_stack+496412,int_stack+473596, 0.0, zero_stack, 1.0, int_stack+253406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[1] = int_stack + 458786;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+492062,int_stack+529584,int_stack+505688, 1.0, int_stack+253406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[0] = int_stack + 492062;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+120342,int_stack+536640,int_stack+533994,441);
     Libderiv->ABCD[155] = int_stack + 120342;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+128280,int_stack+543696,int_stack+541050,441);
     Libderiv->ABCD[143] = int_stack + 128280;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+136218,int_stack+548106,int_stack+525384,441);
     Libderiv->ABCD[142] = int_stack + 136218;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+524804,int_stack+5460,int_stack+10680,441);
     Libderiv->ABCD[131] = int_stack + 524804;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+532742,int_stack+20172,int_stack+13326,441);
     Libderiv->ABCD[130] = int_stack + 532742;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+540680,int_stack+24582,int_stack+552516,441);
     Libderiv->ABCD[129] = int_stack + 540680;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+2646,int_stack+565608,int_stack+555162,441);
     Libderiv->ABCD[119] = int_stack + 2646;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+548618,int_stack+560454,int_stack+557808,441);
     Libderiv->ABCD[118] = int_stack + 548618;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+556556,int_stack+31638,int_stack+28992,441);
     Libderiv->ABCD[117] = int_stack + 556556;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+18618,int_stack+574218,int_stack+36048,441);
     Libderiv->ABCD[116] = int_stack + 18618;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+26556,int_stack+578628,int_stack+38694,441);
     Libderiv->ABCD[107] = int_stack + 26556;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+572664,int_stack+43986,int_stack+41340,441);
     Libderiv->ABCD[106] = int_stack + 572664;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+34494,int_stack+587238,int_stack+48396,441);
     Libderiv->ABCD[105] = int_stack + 34494;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+42432,int_stack+53688,int_stack+51042,441);
     Libderiv->ABCD[104] = int_stack + 42432;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+144156,int_stack+60744,int_stack+58098,441);
     Libderiv->ABCD[103] = int_stack + 144156;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+50370,int_stack+68304,int_stack+591648,441);
     Libderiv->ABCD[95] = int_stack + 50370;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+585684,int_stack+300898,int_stack+583038,441);
     Libderiv->ABCD[94] = int_stack + 585684;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+152094,int_stack+305308,int_stack+15972,441);
     Libderiv->ABCD[93] = int_stack + 152094;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+10584,int_stack+355110,int_stack+309718,441);
     Libderiv->ABCD[92] = int_stack + 10584;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+349526,int_stack+363882,int_stack+389542,441);
     Libderiv->ABCD[91] = int_stack + 349526;
 /*--- compute (dp|hh) ---*/
   hrr1_build_dp(Libderiv->AB,int_stack+384168,int_stack+433796,int_stack+297748,441);
     Libderiv->ABCD[90] = int_stack + 384168;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+297748,int_stack+368292,int_stack+245846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[47] = int_stack + 297748;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+245846,int_stack+372702,int_stack+570018, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[46] = int_stack + 245846;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+363882,int_stack+377112,int_stack+220220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+326804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[45] = int_stack + 363882;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+371820,int_stack+404404,int_stack+65154, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+361236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[44] = int_stack + 371820;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+564494,int_stack+408814,int_stack+397054, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+394408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[43] = int_stack + 564494;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+402346,int_stack+235086,int_stack+399700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+426950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[42] = int_stack + 402346;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+58308,int_stack+413224,int_stack+429596, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+226490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[38] = int_stack + 58308;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+429596,int_stack+442406,int_stack+229136, 0.0, zero_stack, 1.0, int_stack+243200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[35] = int_stack + 429596;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+410284,int_stack+446816,int_stack+0, 0.0, zero_stack, 1.0, int_stack+295102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[34] = int_stack + 410284;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+440852,int_stack+312364,int_stack+438206, 0.0, zero_stack, 1.0, int_stack+326804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[33] = int_stack + 440852;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+305686,int_stack+454376,int_stack+256052, 0.0, zero_stack, 1.0, int_stack+361236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[32] = int_stack + 305686;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+313624,int_stack+333650,int_stack+381522, 0.0, zero_stack, 1.0, int_stack+394408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[31] = int_stack + 313624;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+160032,int_stack+476242,int_stack+231782, 0.0, zero_stack, 1.0, int_stack+426950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[30] = int_stack + 160032;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+229136,int_stack+487652,int_stack+451226, 0.0, zero_stack, 1.0, int_stack+226490, 1.0, int_stack+473596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[26] = int_stack + 229136;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+483298,int_stack+338060,int_stack+480652, 0.0, zero_stack, 2.0, int_stack+473596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[25] = int_stack + 483298;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+332096,int_stack+342470,int_stack+467470, 1.0, int_stack+243200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[23] = int_stack + 332096;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+448790,int_stack+258698,int_stack+422714, 1.0, int_stack+295102, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[22] = int_stack + 448790;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+253784,int_stack+263108,int_stack+346880, 1.0, int_stack+326804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[21] = int_stack + 253784;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+340034,int_stack+267518,int_stack+239496, 1.0, int_stack+361236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[20] = int_stack + 340034;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+237074,int_stack+321938,int_stack+271928, 1.0, int_stack+394408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[19] = int_stack + 237074;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+261722,int_stack+512834,int_stack+500822, 1.0, int_stack+426950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[18] = int_stack + 261722;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+392106,int_stack+520394,int_stack+274574, 1.0, int_stack+226490, 0.0, zero_stack, 1.0, int_stack+505688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[14] = int_stack + 392106;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+418222,int_stack+508334,int_stack+517244, 1.0, int_stack+473596, 1.0, int_stack+505688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[13] = int_stack + 418222;
 /*--- compute (dp|hh) ---*/
   d1hrr1_build_dp(Libderiv->AB,int_stack+508334,int_stack+286456,int_stack+329450, 2.0, int_stack+505688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[12] = int_stack + 508334;

}
