/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hdgg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hd|gg) integrals */

void d12hrr_order_hdgg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[7][8][11] = int_stack + 0;
 Libderiv->deriv_classes[7][8][10] = int_stack + 1620;
 Libderiv->deriv_classes[7][8][9] = int_stack + 3240;
 Libderiv->deriv_classes[7][8][8] = int_stack + 4860;
 Libderiv->deriv_classes[7][8][7] = int_stack + 6480;
 Libderiv->dvrr_classes[7][7] = int_stack + 8100;
 Libderiv->deriv_classes[7][8][6] = int_stack + 9396;
 Libderiv->deriv_classes[7][8][2] = int_stack + 11016;
 Libderiv->deriv_classes[7][8][1] = int_stack + 12636;
 Libderiv->dvrr_classes[6][8] = int_stack + 14256;
 Libderiv->deriv_classes[7][8][0] = int_stack + 15516;
 Libderiv->deriv2_classes[5][4][143] = int_stack + 17136;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 17451;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 17892;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 18480;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 19236;
 Libderiv->deriv2_classes[6][4][143] = int_stack + 20181;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 20601;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 21189;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 21973;
 Libderiv->deriv2_classes[6][8][143] = int_stack + 22981;
 Libderiv->deriv2_classes[7][4][143] = int_stack + 24241;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 24781;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 25537;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 26545;
 Libderiv->deriv2_classes[7][8][143] = int_stack + 27841;
 Libderiv->deriv2_classes[5][4][131] = int_stack + 29461;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 29776;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 30217;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 30805;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 31561;
 Libderiv->deriv2_classes[6][4][131] = int_stack + 32506;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 32926;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 33514;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 34298;
 Libderiv->deriv2_classes[6][8][131] = int_stack + 35306;
 Libderiv->deriv2_classes[7][4][131] = int_stack + 36566;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 37106;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 37862;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 38870;
 Libderiv->deriv2_classes[7][8][131] = int_stack + 40166;
 Libderiv->deriv2_classes[5][4][130] = int_stack + 41786;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 42101;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 42542;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 43130;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 43886;
 Libderiv->deriv2_classes[6][4][130] = int_stack + 44831;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 45251;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 45839;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 46623;
 Libderiv->deriv2_classes[6][8][130] = int_stack + 47631;
 Libderiv->deriv2_classes[7][4][130] = int_stack + 48891;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 49431;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 50187;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 51195;
 Libderiv->deriv2_classes[7][8][130] = int_stack + 52491;
 Libderiv->deriv2_classes[5][4][119] = int_stack + 54111;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 54426;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 54867;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 55455;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 56211;
 Libderiv->deriv2_classes[6][4][119] = int_stack + 57156;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 57576;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 58164;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 58948;
 Libderiv->deriv2_classes[6][8][119] = int_stack + 59956;
 Libderiv->deriv2_classes[7][4][119] = int_stack + 61216;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 61756;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 62512;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 63520;
 Libderiv->deriv2_classes[7][8][119] = int_stack + 64816;
 Libderiv->deriv2_classes[5][4][118] = int_stack + 66436;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 66751;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 67192;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 67780;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 68536;
 Libderiv->deriv2_classes[6][4][118] = int_stack + 69481;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 69901;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 70489;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 71273;
 Libderiv->deriv2_classes[6][8][118] = int_stack + 72281;
 Libderiv->deriv2_classes[7][4][118] = int_stack + 73541;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 74081;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 74837;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 75845;
 Libderiv->deriv2_classes[7][8][118] = int_stack + 77141;
 Libderiv->deriv2_classes[5][4][117] = int_stack + 78761;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 79076;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 79517;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 80105;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 80861;
 Libderiv->deriv2_classes[6][4][117] = int_stack + 81806;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 82226;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 82814;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 83598;
 Libderiv->deriv2_classes[6][8][117] = int_stack + 84606;
 Libderiv->deriv2_classes[7][4][117] = int_stack + 85866;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 86406;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 87162;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 88170;
 Libderiv->deriv2_classes[7][8][117] = int_stack + 89466;
 Libderiv->deriv2_classes[5][4][107] = int_stack + 91086;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 91401;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 91842;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 92430;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 93186;
 Libderiv->deriv2_classes[6][4][107] = int_stack + 94131;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 94551;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 95139;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 95923;
 Libderiv->deriv2_classes[6][8][107] = int_stack + 96931;
 Libderiv->deriv2_classes[7][4][107] = int_stack + 98191;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 98731;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 99487;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 100495;
 Libderiv->deriv2_classes[7][8][107] = int_stack + 101791;
 Libderiv->deriv2_classes[5][4][106] = int_stack + 103411;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 103726;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 104167;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 104755;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 105511;
 Libderiv->deriv2_classes[6][4][106] = int_stack + 106456;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 106876;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 107464;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 108248;
 Libderiv->deriv2_classes[6][8][106] = int_stack + 109256;
 Libderiv->deriv2_classes[7][4][106] = int_stack + 110516;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 111056;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 111812;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 112820;
 Libderiv->deriv2_classes[7][8][106] = int_stack + 114116;
 Libderiv->deriv2_classes[5][4][105] = int_stack + 115736;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 116051;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 116492;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 117080;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 117836;
 Libderiv->deriv2_classes[6][4][105] = int_stack + 118781;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 119201;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 119789;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 120573;
 Libderiv->deriv2_classes[6][8][105] = int_stack + 121581;
 Libderiv->deriv2_classes[7][4][105] = int_stack + 122841;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 123381;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 124137;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 125145;
 Libderiv->deriv2_classes[7][8][105] = int_stack + 126441;
 Libderiv->deriv2_classes[5][4][104] = int_stack + 128061;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 128376;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 128817;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 129405;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 130161;
 Libderiv->deriv2_classes[6][4][104] = int_stack + 131106;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 131526;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 132114;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 132898;
 Libderiv->deriv2_classes[6][8][104] = int_stack + 133906;
 Libderiv->deriv2_classes[7][4][104] = int_stack + 135166;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 135706;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 136462;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 137470;
 Libderiv->deriv2_classes[7][8][104] = int_stack + 138766;
 Libderiv->deriv2_classes[5][4][95] = int_stack + 140386;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 140701;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 141142;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 141730;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 142486;
 Libderiv->deriv2_classes[6][4][95] = int_stack + 143431;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 143851;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 144439;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 145223;
 Libderiv->deriv2_classes[6][8][95] = int_stack + 146231;
 Libderiv->deriv2_classes[7][4][95] = int_stack + 147491;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 148031;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 148787;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 149795;
 Libderiv->deriv2_classes[7][8][95] = int_stack + 151091;
 Libderiv->deriv2_classes[5][4][94] = int_stack + 152711;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 153026;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 153467;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 154055;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 154811;
 Libderiv->deriv2_classes[6][4][94] = int_stack + 155756;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 156176;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 156764;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 157548;
 Libderiv->deriv2_classes[6][8][94] = int_stack + 158556;
 Libderiv->deriv2_classes[7][4][94] = int_stack + 159816;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 160356;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 161112;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 162120;
 Libderiv->deriv2_classes[7][8][94] = int_stack + 163416;
 Libderiv->deriv2_classes[5][4][93] = int_stack + 165036;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 165351;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 165792;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 166380;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 167136;
 Libderiv->deriv2_classes[6][4][93] = int_stack + 168081;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 168501;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 169089;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 169873;
 Libderiv->deriv2_classes[6][8][93] = int_stack + 170881;
 Libderiv->deriv2_classes[7][4][93] = int_stack + 172141;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 172681;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 173437;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 174445;
 Libderiv->deriv2_classes[7][8][93] = int_stack + 175741;
 Libderiv->deriv2_classes[5][4][92] = int_stack + 177361;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 177676;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 178117;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 178705;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 179461;
 Libderiv->deriv2_classes[6][4][92] = int_stack + 180406;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 180826;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 181414;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 182198;
 Libderiv->deriv2_classes[6][8][92] = int_stack + 183206;
 Libderiv->deriv2_classes[7][4][92] = int_stack + 184466;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 185006;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 185762;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 186770;
 Libderiv->deriv2_classes[7][8][92] = int_stack + 188066;
 Libderiv->deriv2_classes[5][4][91] = int_stack + 189686;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 190001;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 190442;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 191030;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 191786;
 Libderiv->deriv2_classes[6][4][91] = int_stack + 192731;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 193151;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 193739;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 194523;
 Libderiv->deriv2_classes[6][8][91] = int_stack + 195531;
 Libderiv->deriv2_classes[7][4][91] = int_stack + 196791;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 197331;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 198087;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 199095;
 Libderiv->deriv2_classes[7][8][91] = int_stack + 200391;
 Libderiv->deriv2_classes[5][4][83] = int_stack + 202011;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 202326;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 202767;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 203355;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 204111;
 Libderiv->deriv2_classes[6][4][83] = int_stack + 205056;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 205476;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 206064;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 206848;
 Libderiv->deriv2_classes[6][8][83] = int_stack + 207856;
 Libderiv->deriv_classes[7][4][11] = int_stack + 209116;
 Libderiv->deriv2_classes[7][4][83] = int_stack + 209656;
 Libderiv->deriv_classes[7][5][11] = int_stack + 210196;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 210952;
 Libderiv->deriv_classes[7][6][11] = int_stack + 211708;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 212716;
 Libderiv->deriv_classes[7][7][11] = int_stack + 213724;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 215020;
 Libderiv->deriv2_classes[7][8][83] = int_stack + 216316;
 Libderiv->deriv2_classes[5][4][82] = int_stack + 217936;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 218251;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 218692;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 219280;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 220036;
 Libderiv->deriv2_classes[6][4][82] = int_stack + 220981;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 221401;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 221989;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 222773;
 Libderiv->deriv2_classes[6][8][82] = int_stack + 223781;
 Libderiv->deriv_classes[7][4][10] = int_stack + 225041;
 Libderiv->deriv2_classes[7][4][82] = int_stack + 225581;
 Libderiv->deriv_classes[7][5][10] = int_stack + 226121;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 226877;
 Libderiv->deriv_classes[7][6][10] = int_stack + 227633;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 228641;
 Libderiv->deriv_classes[7][7][10] = int_stack + 229649;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 230945;
 Libderiv->deriv2_classes[7][8][82] = int_stack + 232241;
 Libderiv->deriv2_classes[5][4][81] = int_stack + 233861;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 234176;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 234617;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 235205;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 235961;
 Libderiv->deriv2_classes[6][4][81] = int_stack + 236906;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 237326;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 237914;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 238698;
 Libderiv->deriv2_classes[6][8][81] = int_stack + 239706;
 Libderiv->deriv_classes[7][4][9] = int_stack + 240966;
 Libderiv->deriv2_classes[7][4][81] = int_stack + 241506;
 Libderiv->deriv_classes[7][5][9] = int_stack + 242046;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 242802;
 Libderiv->deriv_classes[7][6][9] = int_stack + 243558;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 244566;
 Libderiv->deriv_classes[7][7][9] = int_stack + 245574;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 246870;
 Libderiv->deriv2_classes[7][8][81] = int_stack + 248166;
 Libderiv->deriv2_classes[5][4][80] = int_stack + 249786;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 250101;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 250542;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 251130;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 251886;
 Libderiv->deriv2_classes[6][4][80] = int_stack + 252831;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 253251;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 253839;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 254623;
 Libderiv->deriv2_classes[6][8][80] = int_stack + 255631;
 Libderiv->deriv_classes[7][4][8] = int_stack + 256891;
 Libderiv->deriv2_classes[7][4][80] = int_stack + 257431;
 Libderiv->deriv_classes[7][5][8] = int_stack + 257971;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 258727;
 Libderiv->deriv_classes[7][6][8] = int_stack + 259483;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 260491;
 Libderiv->deriv_classes[7][7][8] = int_stack + 261499;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 262795;
 Libderiv->deriv2_classes[7][8][80] = int_stack + 264091;
 Libderiv->deriv2_classes[5][4][79] = int_stack + 265711;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 266026;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 266467;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 267055;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 267811;
 Libderiv->deriv2_classes[6][4][79] = int_stack + 268756;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 269176;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 269764;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 270548;
 Libderiv->deriv2_classes[6][8][79] = int_stack + 271556;
 Libderiv->deriv_classes[7][4][7] = int_stack + 272816;
 Libderiv->deriv2_classes[7][4][79] = int_stack + 273356;
 Libderiv->deriv_classes[7][5][7] = int_stack + 273896;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 274652;
 Libderiv->deriv_classes[7][6][7] = int_stack + 275408;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 276416;
 Libderiv->deriv_classes[7][7][7] = int_stack + 277424;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 278720;
 Libderiv->deriv2_classes[7][8][79] = int_stack + 280016;
 Libderiv->deriv2_classes[5][4][78] = int_stack + 281636;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 281951;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 282392;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 282980;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 283736;
 Libderiv->deriv2_classes[6][4][78] = int_stack + 284681;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 285101;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 285689;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 286473;
 Libderiv->deriv2_classes[6][8][78] = int_stack + 287481;
 Libderiv->dvrr_classes[7][4] = int_stack + 288741;
 Libderiv->deriv_classes[7][4][6] = int_stack + 289281;
 Libderiv->deriv2_classes[7][4][78] = int_stack + 289821;
 Libderiv->dvrr_classes[7][5] = int_stack + 290361;
 Libderiv->deriv_classes[7][5][6] = int_stack + 291117;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 291873;
 Libderiv->dvrr_classes[7][6] = int_stack + 292629;
 Libderiv->deriv_classes[7][6][6] = int_stack + 293637;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 294645;
 Libderiv->deriv_classes[7][7][6] = int_stack + 295653;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 296949;
 Libderiv->deriv2_classes[7][8][78] = int_stack + 298245;
 Libderiv->deriv2_classes[5][4][35] = int_stack + 299865;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 300180;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 300621;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 301209;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 301965;
 Libderiv->deriv2_classes[6][4][35] = int_stack + 302910;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 303330;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 303918;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 304702;
 Libderiv->deriv2_classes[6][8][35] = int_stack + 305710;
 Libderiv->deriv2_classes[7][4][35] = int_stack + 306970;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 307510;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 308266;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 309274;
 Libderiv->deriv2_classes[7][8][35] = int_stack + 310570;
 Libderiv->deriv2_classes[5][4][34] = int_stack + 312190;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 312505;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 312946;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 313534;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 314290;
 Libderiv->deriv2_classes[6][4][34] = int_stack + 315235;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 315655;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 316243;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 317027;
 Libderiv->deriv2_classes[6][8][34] = int_stack + 318035;
 Libderiv->deriv2_classes[7][4][34] = int_stack + 319295;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 319835;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 320591;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 321599;
 Libderiv->deriv2_classes[7][8][34] = int_stack + 322895;
 Libderiv->deriv2_classes[5][4][33] = int_stack + 324515;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 324830;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 325271;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 325859;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 326615;
 Libderiv->deriv2_classes[6][4][33] = int_stack + 327560;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 327980;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 328568;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 329352;
 Libderiv->deriv2_classes[6][8][33] = int_stack + 330360;
 Libderiv->deriv2_classes[7][4][33] = int_stack + 331620;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 332160;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 332916;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 333924;
 Libderiv->deriv2_classes[7][8][33] = int_stack + 335220;
 Libderiv->deriv2_classes[5][4][32] = int_stack + 336840;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 337155;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 337596;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 338184;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 338940;
 Libderiv->deriv2_classes[6][4][32] = int_stack + 339885;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 340305;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 340893;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 341677;
 Libderiv->deriv2_classes[6][8][32] = int_stack + 342685;
 Libderiv->deriv2_classes[7][4][32] = int_stack + 343945;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 344485;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 345241;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 346249;
 Libderiv->deriv2_classes[7][8][32] = int_stack + 347545;
 Libderiv->deriv2_classes[5][4][31] = int_stack + 349165;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 349480;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 349921;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 350509;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 351265;
 Libderiv->deriv2_classes[6][4][31] = int_stack + 352210;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 352630;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 353218;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 354002;
 Libderiv->deriv2_classes[6][8][31] = int_stack + 355010;
 Libderiv->deriv2_classes[7][4][31] = int_stack + 356270;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 356810;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 357566;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 358574;
 Libderiv->deriv2_classes[7][8][31] = int_stack + 359870;
 Libderiv->deriv2_classes[5][4][30] = int_stack + 361490;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 361805;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 362246;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 362834;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 363590;
 Libderiv->deriv2_classes[6][4][30] = int_stack + 364535;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 364955;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 365543;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 366327;
 Libderiv->deriv2_classes[6][8][30] = int_stack + 367335;
 Libderiv->deriv_classes[7][4][2] = int_stack + 368595;
 Libderiv->deriv2_classes[7][4][30] = int_stack + 369135;
 Libderiv->deriv_classes[7][5][2] = int_stack + 369675;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 370431;
 Libderiv->deriv_classes[7][6][2] = int_stack + 371187;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 372195;
 Libderiv->deriv_classes[7][7][2] = int_stack + 373203;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 374499;
 Libderiv->deriv2_classes[7][8][30] = int_stack + 375795;
 Libderiv->deriv2_classes[5][4][26] = int_stack + 377415;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 377730;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 378171;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 378759;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 379515;
 Libderiv->deriv2_classes[6][4][26] = int_stack + 380460;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 380880;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 381468;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 382252;
 Libderiv->deriv2_classes[6][8][26] = int_stack + 383260;
 Libderiv->deriv2_classes[7][4][26] = int_stack + 384520;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 385060;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 385816;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 386824;
 Libderiv->deriv2_classes[7][8][26] = int_stack + 388120;
 Libderiv->deriv2_classes[5][4][23] = int_stack + 389740;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 390055;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 390496;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 391084;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 391840;
 Libderiv->deriv2_classes[6][4][23] = int_stack + 392785;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 393205;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 393793;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 394577;
 Libderiv->deriv2_classes[6][8][23] = int_stack + 395585;
 Libderiv->deriv2_classes[7][4][23] = int_stack + 396845;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 397385;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 398141;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 399149;
 Libderiv->deriv2_classes[7][8][23] = int_stack + 400445;
 Libderiv->deriv2_classes[5][4][22] = int_stack + 402065;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 402380;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 402821;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 403409;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 404165;
 Libderiv->deriv2_classes[6][4][22] = int_stack + 405110;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 405530;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 406118;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 406902;
 Libderiv->deriv2_classes[6][8][22] = int_stack + 407910;
 Libderiv->deriv2_classes[7][4][22] = int_stack + 409170;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 409710;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 410466;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 411474;
 Libderiv->deriv2_classes[7][8][22] = int_stack + 412770;
 Libderiv->deriv2_classes[5][4][21] = int_stack + 414390;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 414705;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 415146;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 415734;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 416490;
 Libderiv->deriv2_classes[6][4][21] = int_stack + 417435;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 417855;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 418443;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 419227;
 Libderiv->deriv2_classes[6][8][21] = int_stack + 420235;
 Libderiv->deriv2_classes[7][4][21] = int_stack + 421495;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 422035;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 422791;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 423799;
 Libderiv->deriv2_classes[7][8][21] = int_stack + 425095;
 Libderiv->deriv2_classes[5][4][20] = int_stack + 426715;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 427030;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 427471;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 428059;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 428815;
 Libderiv->deriv2_classes[6][4][20] = int_stack + 429760;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 430180;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 430768;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 431552;
 Libderiv->deriv2_classes[6][8][20] = int_stack + 432560;
 Libderiv->deriv2_classes[7][4][20] = int_stack + 433820;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 434360;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 435116;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 436124;
 Libderiv->deriv2_classes[7][8][20] = int_stack + 437420;
 Libderiv->deriv2_classes[5][4][19] = int_stack + 439040;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 439355;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 439796;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 440384;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 441140;
 Libderiv->deriv2_classes[6][4][19] = int_stack + 442085;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 442505;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 443093;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 443877;
 Libderiv->deriv2_classes[6][8][19] = int_stack + 444885;
 Libderiv->deriv2_classes[7][4][19] = int_stack + 446145;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 446685;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 447441;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 448449;
 Libderiv->deriv2_classes[7][8][19] = int_stack + 449745;
 Libderiv->deriv2_classes[5][4][18] = int_stack + 451365;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 451680;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 452121;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 452709;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 453465;
 Libderiv->deriv2_classes[6][4][18] = int_stack + 454410;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 454830;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 455418;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 456202;
 Libderiv->deriv2_classes[6][8][18] = int_stack + 457210;
 Libderiv->deriv_classes[7][4][1] = int_stack + 458470;
 Libderiv->deriv2_classes[7][4][18] = int_stack + 459010;
 Libderiv->deriv_classes[7][5][1] = int_stack + 459550;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 460306;
 Libderiv->deriv_classes[7][6][1] = int_stack + 461062;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 462070;
 Libderiv->deriv_classes[7][7][1] = int_stack + 463078;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 464374;
 Libderiv->deriv2_classes[7][8][18] = int_stack + 465670;
 Libderiv->deriv2_classes[5][4][14] = int_stack + 467290;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 467605;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 468046;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 468634;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 469390;
 Libderiv->deriv2_classes[6][4][14] = int_stack + 470335;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 470755;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 471343;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 472127;
 Libderiv->deriv2_classes[6][8][14] = int_stack + 473135;
 Libderiv->deriv2_classes[7][4][14] = int_stack + 474395;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 474935;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 475691;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 476699;
 Libderiv->deriv2_classes[7][8][14] = int_stack + 477995;
 Libderiv->deriv2_classes[5][4][13] = int_stack + 479615;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 479930;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 480371;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 480959;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 481715;
 Libderiv->deriv2_classes[6][4][13] = int_stack + 482660;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 483080;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 483668;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 484452;
 Libderiv->deriv2_classes[6][8][13] = int_stack + 485460;
 Libderiv->deriv2_classes[7][4][13] = int_stack + 486720;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 487260;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 488016;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 489024;
 Libderiv->deriv2_classes[7][8][13] = int_stack + 490320;
 Libderiv->deriv_classes[5][4][11] = int_stack + 491940;
 Libderiv->deriv_classes[5][5][11] = int_stack + 492255;
 Libderiv->deriv_classes[5][6][11] = int_stack + 492696;
 Libderiv->deriv_classes[5][7][11] = int_stack + 493284;
 Libderiv->deriv_classes[5][8][11] = int_stack + 494040;
 Libderiv->deriv2_classes[5][4][11] = int_stack + 494985;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 495300;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 495741;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 496329;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 497085;
 Libderiv->deriv_classes[6][4][11] = int_stack + 498030;
 Libderiv->deriv_classes[6][5][11] = int_stack + 498450;
 Libderiv->deriv_classes[6][6][11] = int_stack + 499038;
 Libderiv->deriv_classes[6][7][11] = int_stack + 499822;
 Libderiv->deriv_classes[6][8][11] = int_stack + 500830;
 Libderiv->deriv2_classes[6][4][11] = int_stack + 502090;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 502510;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 503098;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 503882;
 Libderiv->deriv2_classes[6][8][11] = int_stack + 504890;
 Libderiv->deriv2_classes[7][4][11] = int_stack + 506150;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 506690;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 507446;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 508454;
 Libderiv->deriv2_classes[7][8][11] = int_stack + 509750;
 Libderiv->deriv_classes[5][4][10] = int_stack + 511370;
 Libderiv->deriv_classes[5][5][10] = int_stack + 511685;
 Libderiv->deriv_classes[5][6][10] = int_stack + 512126;
 Libderiv->deriv_classes[5][7][10] = int_stack + 512714;
 Libderiv->deriv_classes[5][8][10] = int_stack + 513470;
 Libderiv->deriv2_classes[5][4][10] = int_stack + 514415;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 514730;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 515171;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 515759;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 516515;
 Libderiv->deriv_classes[6][4][10] = int_stack + 517460;
 Libderiv->deriv_classes[6][5][10] = int_stack + 517880;
 Libderiv->deriv_classes[6][6][10] = int_stack + 518468;
 Libderiv->deriv_classes[6][7][10] = int_stack + 519252;
 Libderiv->deriv_classes[6][8][10] = int_stack + 520260;
 Libderiv->deriv2_classes[6][4][10] = int_stack + 521520;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 521940;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 522528;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 523312;
 Libderiv->deriv2_classes[6][8][10] = int_stack + 524320;
 Libderiv->deriv2_classes[7][4][10] = int_stack + 525580;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 526120;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 526876;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 527884;
 Libderiv->deriv2_classes[7][8][10] = int_stack + 529180;
 Libderiv->deriv_classes[5][4][9] = int_stack + 530800;
 Libderiv->deriv_classes[5][5][9] = int_stack + 531115;
 Libderiv->deriv_classes[5][6][9] = int_stack + 531556;
 Libderiv->deriv_classes[5][7][9] = int_stack + 532144;
 Libderiv->deriv_classes[5][8][9] = int_stack + 532900;
 Libderiv->deriv2_classes[5][4][9] = int_stack + 533845;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 534160;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 534601;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 535189;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 535945;
 Libderiv->deriv_classes[6][4][9] = int_stack + 536890;
 Libderiv->deriv_classes[6][5][9] = int_stack + 537310;
 Libderiv->deriv_classes[6][6][9] = int_stack + 537898;
 Libderiv->deriv_classes[6][7][9] = int_stack + 538682;
 Libderiv->deriv_classes[6][8][9] = int_stack + 539690;
 Libderiv->deriv2_classes[6][4][9] = int_stack + 540950;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 541370;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 541958;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 542742;
 Libderiv->deriv2_classes[6][8][9] = int_stack + 543750;
 Libderiv->deriv2_classes[7][4][9] = int_stack + 545010;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 545550;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 546306;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 547314;
 Libderiv->deriv2_classes[7][8][9] = int_stack + 548610;
 Libderiv->deriv_classes[5][4][8] = int_stack + 550230;
 Libderiv->deriv_classes[5][5][8] = int_stack + 550545;
 Libderiv->deriv_classes[5][6][8] = int_stack + 550986;
 Libderiv->deriv_classes[5][7][8] = int_stack + 551574;
 Libderiv->deriv_classes[5][8][8] = int_stack + 552330;
 Libderiv->deriv2_classes[5][4][8] = int_stack + 553275;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 553590;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 554031;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 554619;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 555375;
 Libderiv->deriv_classes[6][4][8] = int_stack + 556320;
 Libderiv->deriv_classes[6][5][8] = int_stack + 556740;
 Libderiv->deriv_classes[6][6][8] = int_stack + 557328;
 Libderiv->deriv_classes[6][7][8] = int_stack + 558112;
 Libderiv->deriv_classes[6][8][8] = int_stack + 559120;
 Libderiv->deriv2_classes[6][4][8] = int_stack + 560380;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 560800;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 561388;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 562172;
 Libderiv->deriv2_classes[6][8][8] = int_stack + 563180;
 Libderiv->deriv2_classes[7][4][8] = int_stack + 564440;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 564980;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 565736;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 566744;
 Libderiv->deriv2_classes[7][8][8] = int_stack + 568040;
 Libderiv->deriv_classes[5][4][7] = int_stack + 569660;
 Libderiv->deriv_classes[5][5][7] = int_stack + 569975;
 Libderiv->deriv_classes[5][6][7] = int_stack + 570416;
 Libderiv->deriv_classes[5][7][7] = int_stack + 571004;
 Libderiv->deriv_classes[5][8][7] = int_stack + 571760;
 Libderiv->deriv2_classes[5][4][7] = int_stack + 572705;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 573020;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 573461;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 574049;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 574805;
 Libderiv->deriv_classes[6][4][7] = int_stack + 575750;
 Libderiv->deriv_classes[6][5][7] = int_stack + 576170;
 Libderiv->deriv_classes[6][6][7] = int_stack + 576758;
 Libderiv->deriv_classes[6][7][7] = int_stack + 577542;
 Libderiv->deriv_classes[6][8][7] = int_stack + 578550;
 Libderiv->deriv2_classes[6][4][7] = int_stack + 579810;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 580230;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 580818;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 581602;
 Libderiv->deriv2_classes[6][8][7] = int_stack + 582610;
 Libderiv->deriv2_classes[7][4][7] = int_stack + 583870;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 584410;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 585166;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 586174;
 Libderiv->deriv2_classes[7][8][7] = int_stack + 587470;
 Libderiv->deriv_classes[5][4][6] = int_stack + 589090;
 Libderiv->deriv_classes[5][5][6] = int_stack + 589405;
 Libderiv->deriv_classes[5][6][6] = int_stack + 589846;
 Libderiv->deriv_classes[5][7][6] = int_stack + 590434;
 Libderiv->deriv_classes[5][8][6] = int_stack + 591190;
 Libderiv->deriv2_classes[5][4][6] = int_stack + 592135;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 592450;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 592891;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 593479;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 594235;
 Libderiv->dvrr_classes[6][4] = int_stack + 595180;
 Libderiv->deriv_classes[6][4][6] = int_stack + 595600;
 Libderiv->dvrr_classes[6][5] = int_stack + 596020;
 Libderiv->deriv_classes[6][5][6] = int_stack + 596608;
 Libderiv->dvrr_classes[6][6] = int_stack + 597196;
 Libderiv->deriv_classes[6][6][6] = int_stack + 597980;
 Libderiv->dvrr_classes[6][7] = int_stack + 598764;
 Libderiv->deriv_classes[6][7][6] = int_stack + 599772;
 Libderiv->deriv_classes[6][8][6] = int_stack + 600780;
 Libderiv->deriv2_classes[6][4][6] = int_stack + 602040;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 602460;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 603048;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 603832;
 Libderiv->deriv2_classes[6][8][6] = int_stack + 604840;
 Libderiv->deriv_classes[7][4][0] = int_stack + 606100;
 Libderiv->deriv2_classes[7][4][6] = int_stack + 606640;
 Libderiv->deriv_classes[7][5][0] = int_stack + 607180;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 607936;
 Libderiv->deriv_classes[7][6][0] = int_stack + 608692;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 609700;
 Libderiv->deriv_classes[7][7][0] = int_stack + 610708;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 612004;
 Libderiv->deriv2_classes[7][8][6] = int_stack + 613300;
 Libderiv->deriv_classes[5][4][2] = int_stack + 614920;
 Libderiv->deriv_classes[5][5][2] = int_stack + 615235;
 Libderiv->deriv_classes[5][6][2] = int_stack + 615676;
 Libderiv->deriv_classes[5][7][2] = int_stack + 616264;
 Libderiv->deriv_classes[5][8][2] = int_stack + 617020;
 Libderiv->deriv2_classes[5][4][2] = int_stack + 617965;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 618280;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 618721;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 619309;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 620065;
 Libderiv->deriv_classes[6][4][2] = int_stack + 621010;
 Libderiv->deriv_classes[6][5][2] = int_stack + 621430;
 Libderiv->deriv_classes[6][6][2] = int_stack + 622018;
 Libderiv->deriv_classes[6][7][2] = int_stack + 622802;
 Libderiv->deriv_classes[6][8][2] = int_stack + 623810;
 Libderiv->deriv2_classes[6][4][2] = int_stack + 625070;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 625490;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 626078;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 626862;
 Libderiv->deriv2_classes[6][8][2] = int_stack + 627870;
 Libderiv->deriv2_classes[7][4][2] = int_stack + 629130;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 629670;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 630426;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 631434;
 Libderiv->deriv2_classes[7][8][2] = int_stack + 632730;
 Libderiv->deriv_classes[5][4][1] = int_stack + 634350;
 Libderiv->deriv_classes[5][5][1] = int_stack + 634665;
 Libderiv->deriv_classes[5][6][1] = int_stack + 635106;
 Libderiv->deriv_classes[5][7][1] = int_stack + 635694;
 Libderiv->deriv_classes[5][8][1] = int_stack + 636450;
 Libderiv->deriv2_classes[5][4][1] = int_stack + 637395;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 637710;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 638151;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 638739;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 639495;
 Libderiv->deriv_classes[6][4][1] = int_stack + 640440;
 Libderiv->deriv_classes[6][5][1] = int_stack + 640860;
 Libderiv->deriv_classes[6][6][1] = int_stack + 641448;
 Libderiv->deriv_classes[6][7][1] = int_stack + 642232;
 Libderiv->deriv_classes[6][8][1] = int_stack + 643240;
 Libderiv->deriv2_classes[6][4][1] = int_stack + 644500;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 644920;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 645508;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 646292;
 Libderiv->deriv2_classes[6][8][1] = int_stack + 647300;
 Libderiv->deriv2_classes[7][4][1] = int_stack + 648560;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 649100;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 649856;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 650864;
 Libderiv->deriv2_classes[7][8][1] = int_stack + 652160;
 Libderiv->dvrr_classes[5][4] = int_stack + 653780;
 Libderiv->dvrr_classes[5][5] = int_stack + 654095;
 Libderiv->dvrr_classes[5][6] = int_stack + 654536;
 Libderiv->dvrr_classes[5][7] = int_stack + 655124;
 Libderiv->dvrr_classes[5][8] = int_stack + 655880;
 Libderiv->deriv_classes[5][4][0] = int_stack + 656825;
 Libderiv->deriv_classes[5][5][0] = int_stack + 657140;
 Libderiv->deriv_classes[5][6][0] = int_stack + 657581;
 Libderiv->deriv_classes[5][7][0] = int_stack + 658169;
 Libderiv->deriv_classes[5][8][0] = int_stack + 658925;
 Libderiv->deriv2_classes[5][4][0] = int_stack + 659870;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 660185;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 660626;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 661214;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 661970;
 Libderiv->deriv_classes[6][4][0] = int_stack + 662915;
 Libderiv->deriv_classes[6][5][0] = int_stack + 663335;
 Libderiv->deriv_classes[6][6][0] = int_stack + 663923;
 Libderiv->deriv_classes[6][7][0] = int_stack + 664707;
 Libderiv->deriv_classes[6][8][0] = int_stack + 665715;
 Libderiv->deriv2_classes[6][4][0] = int_stack + 666975;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 667395;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 667983;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 668767;
 Libderiv->deriv2_classes[6][8][0] = int_stack + 669775;
 Libderiv->deriv2_classes[7][4][0] = int_stack + 671035;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 671575;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 672331;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 673339;
 Libderiv->deriv2_classes[7][8][0] = int_stack + 674635;
 memset(int_stack,0,5410040);

 Libderiv->dvrr_stack = int_stack + 2183536;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hdgg(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+676255,int_stack+654095,int_stack+653780,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+677200,int_stack+654536,int_stack+654095,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+678523,int_stack+677200,int_stack+676255,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+680413,int_stack+655124,int_stack+654536,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+682177,int_stack+680413,int_stack+677200,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+684823,int_stack+682177,int_stack+678523,21);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+687973,int_stack+492255,int_stack+491940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653780,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+688918,int_stack+492696,int_stack+492255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654095,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+690241,int_stack+688918,int_stack+687973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676255,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+692131,int_stack+493284,int_stack+492696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654536,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+693895,int_stack+692131,int_stack+688918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677200,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+696541,int_stack+693895,int_stack+690241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+678523,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+699691,int_stack+494040,int_stack+493284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655124,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+701959,int_stack+699691,int_stack+692131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680413,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+705487,int_stack+701959,int_stack+693895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+682177,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+699691,int_stack+705487,int_stack+696541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684823,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+704416,int_stack+596020,int_stack+595180,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+705676,int_stack+597196,int_stack+596020,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+707440,int_stack+705676,int_stack+704416,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+709960,int_stack+598764,int_stack+597196,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+712312,int_stack+709960,int_stack+705676,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+715840,int_stack+712312,int_stack+707440,28);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+720040,int_stack+498450,int_stack+498030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595180,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+721300,int_stack+499038,int_stack+498450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596020,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+723064,int_stack+721300,int_stack+720040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704416,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+725584,int_stack+499822,int_stack+499038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597196,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+727936,int_stack+725584,int_stack+721300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705676,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+731464,int_stack+727936,int_stack+723064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+707440,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+735664,int_stack+500830,int_stack+499822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+598764,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+738688,int_stack+735664,int_stack+725584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+709960,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+743392,int_stack+738688,int_stack+727936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+712312,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+735664,int_stack+743392,int_stack+731464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715840,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+741964,int_stack+735664,int_stack+699691,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+756139,int_stack+290361,int_stack+288741,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+757759,int_stack+292629,int_stack+290361,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+760027,int_stack+757759,int_stack+756139,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+763267,int_stack+8100,int_stack+292629,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+766291,int_stack+763267,int_stack+757759,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+770827,int_stack+766291,int_stack+760027,36);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+776227,int_stack+210196,int_stack+209116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288741,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+777847,int_stack+211708,int_stack+210196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290361,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+780115,int_stack+777847,int_stack+776227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756139,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+783355,int_stack+213724,int_stack+211708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292629,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+786379,int_stack+783355,int_stack+777847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757759,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+790915,int_stack+786379,int_stack+780115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760027,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+796315,int_stack+0,int_stack+213724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+800203,int_stack+796315,int_stack+783355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+763267,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+806251,int_stack+800203,int_stack+786379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+766291,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+796315,int_stack+806251,int_stack+790915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770827,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+804415,int_stack+796315,int_stack+735664,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+494040,int_stack+511685,int_stack+511370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653780, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+796315,int_stack+512126,int_stack+511685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654095, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+797638,int_stack+796315,int_stack+494040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676255, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+799528,int_stack+512714,int_stack+512126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654536, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+801292,int_stack+799528,int_stack+796315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677200, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+801292,int_stack+797638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+678523, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+826465,int_stack+513470,int_stack+512714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655124, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+828733,int_stack+826465,int_stack+799528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680413, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+832261,int_stack+828733,int_stack+801292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+682177, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+826465,int_stack+832261,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684823, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+500830,int_stack+517880,int_stack+517460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595180, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+831190,int_stack+518468,int_stack+517880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596020, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+832954,int_stack+831190,int_stack+500830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704416, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+835474,int_stack+519252,int_stack+518468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597196, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+837826,int_stack+835474,int_stack+831190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705676, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+841354,int_stack+837826,int_stack+832954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+707440, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+845554,int_stack+520260,int_stack+519252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+598764, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+848578,int_stack+845554,int_stack+835474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+709960, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+853282,int_stack+848578,int_stack+837826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+712312, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+845554,int_stack+853282,int_stack+841354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715840, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+851854,int_stack+845554,int_stack+826465,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+226121,int_stack+225041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288741, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+866029,int_stack+227633,int_stack+226121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290361, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+868297,int_stack+866029,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756139, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+871537,int_stack+229649,int_stack+227633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292629, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+874561,int_stack+871537,int_stack+866029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757759, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+879097,int_stack+874561,int_stack+868297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760027, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+884497,int_stack+1620,int_stack+229649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+888385,int_stack+884497,int_stack+871537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+763267, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+894433,int_stack+888385,int_stack+874561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+766291, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+884497,int_stack+894433,int_stack+879097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770827, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+892597,int_stack+884497,int_stack+845554,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+513470,int_stack+531115,int_stack+530800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653780, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+884497,int_stack+531556,int_stack+531115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654095, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+885820,int_stack+884497,int_stack+513470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676255, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+887710,int_stack+532144,int_stack+531556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654536, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+889474,int_stack+887710,int_stack+884497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677200, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+911497,int_stack+889474,int_stack+885820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+678523, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+914647,int_stack+532900,int_stack+532144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655124, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+916915,int_stack+914647,int_stack+887710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680413, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+920443,int_stack+916915,int_stack+889474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+682177, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+914647,int_stack+920443,int_stack+911497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684823, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+520260,int_stack+537310,int_stack+536890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595180, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+919372,int_stack+537898,int_stack+537310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596020, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+921136,int_stack+919372,int_stack+520260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704416, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+923656,int_stack+538682,int_stack+537898, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597196, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+926008,int_stack+923656,int_stack+919372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705676, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+929536,int_stack+926008,int_stack+921136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+707440, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+933736,int_stack+539690,int_stack+538682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+598764, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+936760,int_stack+933736,int_stack+923656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+709960, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+941464,int_stack+936760,int_stack+926008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+712312, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+933736,int_stack+941464,int_stack+929536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715840, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+940036,int_stack+933736,int_stack+914647,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1620,int_stack+242046,int_stack+240966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288741, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+954211,int_stack+243558,int_stack+242046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290361, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+956479,int_stack+954211,int_stack+1620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756139, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+959719,int_stack+245574,int_stack+243558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292629, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+962743,int_stack+959719,int_stack+954211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757759, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+967279,int_stack+962743,int_stack+956479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760027, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+972679,int_stack+3240,int_stack+245574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+976567,int_stack+972679,int_stack+959719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+763267, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+982615,int_stack+976567,int_stack+962743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+766291, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+972679,int_stack+982615,int_stack+967279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770827, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+980779,int_stack+972679,int_stack+933736,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+532900,int_stack+550545,int_stack+550230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+972679,int_stack+550986,int_stack+550545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+974002,int_stack+972679,int_stack+532900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+975892,int_stack+551574,int_stack+550986, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+654536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+977656,int_stack+975892,int_stack+972679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+999679,int_stack+977656,int_stack+974002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+678523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1002829,int_stack+552330,int_stack+551574, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+655124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1005097,int_stack+1002829,int_stack+975892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1008625,int_stack+1005097,int_stack+977656, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+682177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1002829,int_stack+1008625,int_stack+999679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+684823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+539690,int_stack+556740,int_stack+556320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1007554,int_stack+557328,int_stack+556740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1009318,int_stack+1007554,int_stack+539690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1011838,int_stack+558112,int_stack+557328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1014190,int_stack+1011838,int_stack+1007554, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+705676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1017718,int_stack+1014190,int_stack+1009318, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+707440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1021918,int_stack+559120,int_stack+558112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+598764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1024942,int_stack+1021918,int_stack+1011838, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+709960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1029646,int_stack+1024942,int_stack+1014190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+712312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1021918,int_stack+1029646,int_stack+1017718, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+715840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1028218,int_stack+1021918,int_stack+1002829,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+3240,int_stack+257971,int_stack+256891, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1042393,int_stack+259483,int_stack+257971, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1044661,int_stack+1042393,int_stack+3240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1047901,int_stack+261499,int_stack+259483, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1050925,int_stack+1047901,int_stack+1042393, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+757759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1055461,int_stack+1050925,int_stack+1044661, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+760027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1060861,int_stack+4860,int_stack+261499, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1064749,int_stack+1060861,int_stack+1047901, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+763267, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1070797,int_stack+1064749,int_stack+1050925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+766291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1060861,int_stack+1070797,int_stack+1055461, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+770827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1068961,int_stack+1060861,int_stack+1021918,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+552330,int_stack+569975,int_stack+569660, 0.0, zero_stack, 1.0, int_stack+653780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1060861,int_stack+570416,int_stack+569975, 0.0, zero_stack, 1.0, int_stack+654095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1062184,int_stack+1060861,int_stack+552330, 0.0, zero_stack, 1.0, int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1064074,int_stack+571004,int_stack+570416, 0.0, zero_stack, 1.0, int_stack+654536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1065838,int_stack+1064074,int_stack+1060861, 0.0, zero_stack, 1.0, int_stack+677200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1087861,int_stack+1065838,int_stack+1062184, 0.0, zero_stack, 1.0, int_stack+678523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1091011,int_stack+571760,int_stack+571004, 0.0, zero_stack, 1.0, int_stack+655124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1093279,int_stack+1091011,int_stack+1064074, 0.0, zero_stack, 1.0, int_stack+680413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1096807,int_stack+1093279,int_stack+1065838, 0.0, zero_stack, 1.0, int_stack+682177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1091011,int_stack+1096807,int_stack+1087861, 0.0, zero_stack, 1.0, int_stack+684823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+559120,int_stack+576170,int_stack+575750, 0.0, zero_stack, 1.0, int_stack+595180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1095736,int_stack+576758,int_stack+576170, 0.0, zero_stack, 1.0, int_stack+596020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1097500,int_stack+1095736,int_stack+559120, 0.0, zero_stack, 1.0, int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1100020,int_stack+577542,int_stack+576758, 0.0, zero_stack, 1.0, int_stack+597196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1102372,int_stack+1100020,int_stack+1095736, 0.0, zero_stack, 1.0, int_stack+705676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1105900,int_stack+1102372,int_stack+1097500, 0.0, zero_stack, 1.0, int_stack+707440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1110100,int_stack+578550,int_stack+577542, 0.0, zero_stack, 1.0, int_stack+598764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1113124,int_stack+1110100,int_stack+1100020, 0.0, zero_stack, 1.0, int_stack+709960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1117828,int_stack+1113124,int_stack+1102372, 0.0, zero_stack, 1.0, int_stack+712312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1110100,int_stack+1117828,int_stack+1105900, 0.0, zero_stack, 1.0, int_stack+715840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1116400,int_stack+1110100,int_stack+1091011,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+4860,int_stack+273896,int_stack+272816, 0.0, zero_stack, 1.0, int_stack+288741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1130575,int_stack+275408,int_stack+273896, 0.0, zero_stack, 1.0, int_stack+290361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1132843,int_stack+1130575,int_stack+4860, 0.0, zero_stack, 1.0, int_stack+756139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1136083,int_stack+277424,int_stack+275408, 0.0, zero_stack, 1.0, int_stack+292629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1139107,int_stack+1136083,int_stack+1130575, 0.0, zero_stack, 1.0, int_stack+757759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1143643,int_stack+1139107,int_stack+1132843, 0.0, zero_stack, 1.0, int_stack+760027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1149043,int_stack+6480,int_stack+277424, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1152931,int_stack+1149043,int_stack+1136083, 0.0, zero_stack, 1.0, int_stack+763267, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1158979,int_stack+1152931,int_stack+1139107, 0.0, zero_stack, 1.0, int_stack+766291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1149043,int_stack+1158979,int_stack+1143643, 0.0, zero_stack, 1.0, int_stack+770827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1157143,int_stack+1149043,int_stack+1110100,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+571760,int_stack+589405,int_stack+589090, 1.0, int_stack+653780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1149043,int_stack+589846,int_stack+589405, 1.0, int_stack+654095, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1150366,int_stack+1149043,int_stack+571760, 1.0, int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1152256,int_stack+590434,int_stack+589846, 1.0, int_stack+654536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1154020,int_stack+1152256,int_stack+1149043, 1.0, int_stack+677200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1176043,int_stack+1154020,int_stack+1150366, 1.0, int_stack+678523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+676255,int_stack+591190,int_stack+590434, 1.0, int_stack+655124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1179193,int_stack+676255,int_stack+1152256, 1.0, int_stack+680413, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1182721,int_stack+1179193,int_stack+1154020, 1.0, int_stack+682177, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1187131,int_stack+1182721,int_stack+1176043, 1.0, int_stack+684823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+578550,int_stack+596608,int_stack+595600, 1.0, int_stack+595180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1179193,int_stack+597980,int_stack+596608, 1.0, int_stack+596020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1180957,int_stack+1179193,int_stack+578550, 1.0, int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1183477,int_stack+599772,int_stack+597980, 1.0, int_stack+597196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+676255,int_stack+1183477,int_stack+1179193, 1.0, int_stack+705676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1191856,int_stack+676255,int_stack+1180957, 1.0, int_stack+707440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+704416,int_stack+600780,int_stack+599772, 1.0, int_stack+598764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1196056,int_stack+704416,int_stack+1183477, 1.0, int_stack+709960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1200760,int_stack+1196056,int_stack+676255, 1.0, int_stack+712312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1206640,int_stack+1200760,int_stack+1191856, 1.0, int_stack+715840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1212940,int_stack+1206640,int_stack+1187131,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+6480,int_stack+291117,int_stack+289281, 1.0, int_stack+288741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1196056,int_stack+293637,int_stack+291117, 1.0, int_stack+290361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1198324,int_stack+1196056,int_stack+6480, 1.0, int_stack+756139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1201564,int_stack+295653,int_stack+293637, 1.0, int_stack+292629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704416,int_stack+1201564,int_stack+1196056, 1.0, int_stack+757759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+704416,int_stack+1198324, 1.0, int_stack+760027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+756139,int_stack+9396,int_stack+295653, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232515,int_stack+756139,int_stack+1201564, 1.0, int_stack+763267, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+756139,int_stack+1232515,int_stack+704416, 1.0, int_stack+766291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1232515,int_stack+756139,int_stack+1227115, 1.0, int_stack+770827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+756139,int_stack+1232515,int_stack+1206640,225);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1232515,int_stack+655880,int_stack+655124,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1234783,int_stack+1232515,int_stack+680413,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1238311,int_stack+1234783,int_stack+682177,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1232515,int_stack+1238311,int_stack+684823,21);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1237240,int_stack+14256,int_stack+598764,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+679783,int_stack+1237240,int_stack+709960,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1237240,int_stack+679783,int_stack+712312,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+1237240,int_stack+715840,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1237240,int_stack+679783,int_stack+1232515,225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+591190,int_stack+615235,int_stack+614920,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+686083,int_stack+615676,int_stack+615235,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+8100,int_stack+686083,int_stack+591190,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1204588,int_stack+616264,int_stack+615676,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+708952,int_stack+1204588,int_stack+686083,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+711598,int_stack+708952,int_stack+8100,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+714748,int_stack+617020,int_stack+616264,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1251415,int_stack+714748,int_stack+1204588,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+714748,int_stack+1251415,int_stack+708952,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1251415,int_stack+714748,int_stack+711598,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+621430,int_stack+621010,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+714748,int_stack+622018,int_stack+621430,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+716512,int_stack+714748,int_stack+14256,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+653780,int_stack+622802,int_stack+622018,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1256140,int_stack+653780,int_stack+714748,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1259668,int_stack+1256140,int_stack+716512,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1263868,int_stack+623810,int_stack+622802,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1266892,int_stack+1263868,int_stack+653780,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1271596,int_stack+1266892,int_stack+1256140,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1263868,int_stack+1271596,int_stack+1259668,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1270168,int_stack+1263868,int_stack+1251415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1284343,int_stack+369675,int_stack+368595,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1285963,int_stack+371187,int_stack+369675,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1288231,int_stack+1285963,int_stack+1284343,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1291471,int_stack+373203,int_stack+371187,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1294495,int_stack+1291471,int_stack+1285963,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1299031,int_stack+1294495,int_stack+1288231,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1304431,int_stack+11016,int_stack+373203,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1308319,int_stack+1304431,int_stack+1291471,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1314367,int_stack+1308319,int_stack+1294495,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1304431,int_stack+1314367,int_stack+1299031,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1312531,int_stack+1304431,int_stack+1263868, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+617020,int_stack+634665,int_stack+634350,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1304431,int_stack+635106,int_stack+634665,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1305754,int_stack+1304431,int_stack+617020,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1307644,int_stack+635694,int_stack+635106,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9990,int_stack+1307644,int_stack+1304431,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1331431,int_stack+9990,int_stack+1305754,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1309408,int_stack+636450,int_stack+635694,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1334581,int_stack+1309408,int_stack+1307644,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1338109,int_stack+1334581,int_stack+9990,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1342519,int_stack+1338109,int_stack+1331431,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+623810,int_stack+640860,int_stack+640440,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1334581,int_stack+641448,int_stack+640860,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1336345,int_stack+1334581,int_stack+623810,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1338865,int_stack+642232,int_stack+641448,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1347244,int_stack+1338865,int_stack+1334581,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1350772,int_stack+1347244,int_stack+1336345,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1309408,int_stack+643240,int_stack+642232,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1354972,int_stack+1309408,int_stack+1338865,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1359676,int_stack+1354972,int_stack+1347244,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1365556,int_stack+1359676,int_stack+1350772,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1371856,int_stack+1365556,int_stack+1342519, 0.0, zero_stack, 1.0, int_stack+1232515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1354972,int_stack+459550,int_stack+458470,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1356592,int_stack+461062,int_stack+459550,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1358860,int_stack+1356592,int_stack+1354972,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1362100,int_stack+463078,int_stack+461062,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1386031,int_stack+1362100,int_stack+1356592,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1390567,int_stack+1386031,int_stack+1358860,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1395967,int_stack+12636,int_stack+463078,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1399855,int_stack+1395967,int_stack+1362100,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1405903,int_stack+1399855,int_stack+1386031,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1395967,int_stack+1405903,int_stack+1390567,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1404067,int_stack+1395967,int_stack+1365556, 0.0, zero_stack, 1.0, int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+636450,int_stack+657140,int_stack+656825,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1395967,int_stack+657581,int_stack+657140,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1397290,int_stack+1395967,int_stack+636450,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1399180,int_stack+658169,int_stack+657581,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1400944,int_stack+1399180,int_stack+1395967,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1422967,int_stack+1400944,int_stack+1397290,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1309408,int_stack+658925,int_stack+658169,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1426117,int_stack+1309408,int_stack+1399180,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1429645,int_stack+1426117,int_stack+1400944,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1434055,int_stack+1429645,int_stack+1422967,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+643240,int_stack+663335,int_stack+662915,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1426117,int_stack+663923,int_stack+663335,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1427881,int_stack+1426117,int_stack+643240,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1430401,int_stack+664707,int_stack+663923,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1438780,int_stack+1430401,int_stack+1426117,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1442308,int_stack+1438780,int_stack+1427881,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1309408,int_stack+665715,int_stack+664707,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1446508,int_stack+1309408,int_stack+1430401,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1451212,int_stack+1446508,int_stack+1438780,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1457092,int_stack+1451212,int_stack+1442308,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1463392,int_stack+1457092,int_stack+1434055, 1.0, int_stack+1232515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+12636,int_stack+607180,int_stack+606100,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1232515,int_stack+608692,int_stack+607180,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1446508,int_stack+1232515,int_stack+12636,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1449748,int_stack+610708,int_stack+608692,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1477567,int_stack+1449748,int_stack+1232515,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1482103,int_stack+1477567,int_stack+1446508,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1452772,int_stack+15516,int_stack+610708,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1487503,int_stack+1452772,int_stack+1449748,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1493551,int_stack+1487503,int_stack+1477567,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1501111,int_stack+1493551,int_stack+1482103,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1509211,int_stack+1501111,int_stack+1457092, 1.0, int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+17451,int_stack+17136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+491940,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+679783,int_stack+17892,int_stack+17451, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+492255,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+681106,int_stack+679783,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+687973,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+682996,int_stack+18480,int_stack+17892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+492696,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1487503,int_stack+682996,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+688918,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1490149,int_stack+1487503,int_stack+681106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+690241,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+679783,int_stack+19236,int_stack+18480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+493284,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1493299,int_stack+679783,int_stack+682996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+692131,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+679783,int_stack+1493299,int_stack+1487503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+693895,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1493299,int_stack+679783,int_stack+1490149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+696541,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+20601,int_stack+20181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+498030,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+679783,int_stack+21189,int_stack+20601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+498450,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+681547,int_stack+679783,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+720040,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1487503,int_stack+21973,int_stack+21189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+499038,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1498024,int_stack+1487503,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+721300,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1501552,int_stack+1498024,int_stack+681547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+723064,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+679783,int_stack+22981,int_stack+21973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+499822,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+15516,int_stack+679783,int_stack+1487503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+725584,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+679783,int_stack+15516,int_stack+1498024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+727936,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+15516,int_stack+679783,int_stack+1501552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+731464,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1528111,int_stack+15516,int_stack+1493299,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+679783,int_stack+24781,int_stack+24241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+209116,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+681403,int_stack+25537,int_stack+24781, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+210196,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+21816,int_stack+681403,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+776227,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1487503,int_stack+26545,int_stack+25537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+211708,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1490527,int_stack+1487503,int_stack+681403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+777847,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+679783,int_stack+1490527,int_stack+21816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+780115,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+21816,int_stack+27841,int_stack+26545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+213724,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1495063,int_stack+21816,int_stack+1487503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+783355,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+21816,int_stack+1495063,int_stack+1490527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+786379,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1487503,int_stack+21816,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+790915,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1542286,int_stack+1487503,int_stack+15516,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+29776,int_stack+29461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491940, 1.0, int_stack+511370,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15516,int_stack+30217,int_stack+29776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492255, 1.0, int_stack+511685,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+16839,int_stack+15516,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687973, 1.0, int_stack+494040,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18729,int_stack+30805,int_stack+30217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492696, 1.0, int_stack+512126,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20493,int_stack+18729,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688918, 1.0, int_stack+796315,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+23139,int_stack+20493,int_stack+16839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+690241, 1.0, int_stack+797638,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15516,int_stack+31561,int_stack+30805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493284, 1.0, int_stack+512714,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26289,int_stack+15516,int_stack+18729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692131, 1.0, int_stack+799528,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15516,int_stack+26289,int_stack+20493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693895, 1.0, int_stack+801292,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+26289,int_stack+15516,int_stack+23139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696541, 1.0, int_stack+823315,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+32926,int_stack+32506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498030, 1.0, int_stack+517460,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15516,int_stack+33514,int_stack+32926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498450, 1.0, int_stack+517880,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+17280,int_stack+15516,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+720040, 1.0, int_stack+500830,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19800,int_stack+34298,int_stack+33514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499038, 1.0, int_stack+518468,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22152,int_stack+19800,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+721300, 1.0, int_stack+831190,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1487503,int_stack+22152,int_stack+17280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+723064, 1.0, int_stack+832954,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15516,int_stack+35306,int_stack+34298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499822, 1.0, int_stack+519252,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31014,int_stack+15516,int_stack+19800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+725584, 1.0, int_stack+835474,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15516,int_stack+31014,int_stack+22152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+727936, 1.0, int_stack+837826,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+15516,int_stack+1487503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+731464, 1.0, int_stack+841354,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1487503,int_stack+679783,int_stack+26289,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1501678,int_stack+37106,int_stack+36566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209116, 1.0, int_stack+225041,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1503298,int_stack+37862,int_stack+37106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210196, 1.0, int_stack+226121,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1505566,int_stack+1503298,int_stack+1501678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776227, 1.0, int_stack+0,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15516,int_stack+38870,int_stack+37862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211708, 1.0, int_stack+227633,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18540,int_stack+15516,int_stack+1503298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777847, 1.0, int_stack+866029,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+23076,int_stack+18540,int_stack+1505566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780115, 1.0, int_stack+868297,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1501678,int_stack+40166,int_stack+38870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213724, 1.0, int_stack+229649,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28476,int_stack+1501678,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+783355, 1.0, int_stack+871537,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1561186,int_stack+28476,int_stack+18540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+786379, 1.0, int_stack+874561,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+28476,int_stack+1561186,int_stack+23076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790915, 1.0, int_stack+879097,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1561186,int_stack+28476,int_stack+679783,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+42101,int_stack+41786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+511370, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+679783,int_stack+42542,int_stack+42101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+511685, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+681106,int_stack+679783,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+494040, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+682996,int_stack+43130,int_stack+42542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+512126, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15516,int_stack+682996,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+796315, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+18162,int_stack+15516,int_stack+681106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+797638, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+679783,int_stack+43886,int_stack+43130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+512714, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+21312,int_stack+679783,int_stack+682996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+799528, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+679783,int_stack+21312,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+801292, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+21312,int_stack+679783,int_stack+18162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+823315, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+45251,int_stack+44831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+517460, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+679783,int_stack+45839,int_stack+45251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+517880, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+681547,int_stack+679783,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+500830, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15516,int_stack+46623,int_stack+45839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+518468, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+26037,int_stack+15516,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+831190, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+29565,int_stack+26037,int_stack+681547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+832954, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+679783,int_stack+47631,int_stack+46623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+519252, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+33765,int_stack+679783,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+835474, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+679783,int_stack+33765,int_stack+26037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+837826, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+33765,int_stack+679783,int_stack+29565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+841354, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1580086,int_stack+33765,int_stack+21312,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+679783,int_stack+49431,int_stack+48891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+225041, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+681403,int_stack+50187,int_stack+49431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+226121, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+40065,int_stack+681403,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+43305,int_stack+51195,int_stack+50187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+227633, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+46329,int_stack+43305,int_stack+681403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+866029, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+679783,int_stack+46329,int_stack+40065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+868297, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15516,int_stack+52491,int_stack+51195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+229649, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+19404,int_stack+15516,int_stack+43305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+871537, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+25452,int_stack+19404,int_stack+46329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+874561, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+15516,int_stack+25452,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+879097, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1594261,int_stack+15516,int_stack+33765,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+54426,int_stack+54111, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491940, 0.0, zero_stack, 1.0, int_stack+530800,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15516,int_stack+54867,int_stack+54426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492255, 0.0, zero_stack, 1.0, int_stack+531115,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+16839,int_stack+15516,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687973, 0.0, zero_stack, 1.0, int_stack+513470,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18729,int_stack+55455,int_stack+54867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492696, 0.0, zero_stack, 1.0, int_stack+531556,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20493,int_stack+18729,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688918, 0.0, zero_stack, 1.0, int_stack+884497,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+23139,int_stack+20493,int_stack+16839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+690241, 0.0, zero_stack, 1.0, int_stack+885820,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15516,int_stack+56211,int_stack+55455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493284, 0.0, zero_stack, 1.0, int_stack+532144,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26289,int_stack+15516,int_stack+18729, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692131, 0.0, zero_stack, 1.0, int_stack+887710,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15516,int_stack+26289,int_stack+20493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693895, 0.0, zero_stack, 1.0, int_stack+889474,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+26289,int_stack+15516,int_stack+23139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696541, 0.0, zero_stack, 1.0, int_stack+911497,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+57576,int_stack+57156, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498030, 0.0, zero_stack, 1.0, int_stack+536890,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15516,int_stack+58164,int_stack+57576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498450, 0.0, zero_stack, 1.0, int_stack+537310,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+17280,int_stack+15516,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+720040, 0.0, zero_stack, 1.0, int_stack+520260,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19800,int_stack+58948,int_stack+58164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499038, 0.0, zero_stack, 1.0, int_stack+537898,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22152,int_stack+19800,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+721300, 0.0, zero_stack, 1.0, int_stack+919372,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+31014,int_stack+22152,int_stack+17280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+723064, 0.0, zero_stack, 1.0, int_stack+921136,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15516,int_stack+59956,int_stack+58948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499822, 0.0, zero_stack, 1.0, int_stack+538682,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+35214,int_stack+15516,int_stack+19800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+725584, 0.0, zero_stack, 1.0, int_stack+923656,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15516,int_stack+35214,int_stack+22152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+727936, 0.0, zero_stack, 1.0, int_stack+926008,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+15516,int_stack+31014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+731464, 0.0, zero_stack, 1.0, int_stack+929536,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+31014,int_stack+679783,int_stack+26289,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+45189,int_stack+61756,int_stack+61216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209116, 0.0, zero_stack, 1.0, int_stack+240966,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46809,int_stack+62512,int_stack+61756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210196, 0.0, zero_stack, 1.0, int_stack+242046,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+49077,int_stack+46809,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776227, 0.0, zero_stack, 1.0, int_stack+1620,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52317,int_stack+63520,int_stack+62512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211708, 0.0, zero_stack, 1.0, int_stack+243558,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+55341,int_stack+52317,int_stack+46809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777847, 0.0, zero_stack, 1.0, int_stack+954211,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+15516,int_stack+55341,int_stack+49077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780115, 0.0, zero_stack, 1.0, int_stack+956479,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45189,int_stack+64816,int_stack+63520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213724, 0.0, zero_stack, 1.0, int_stack+245574,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+59877,int_stack+45189,int_stack+52317, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+783355, 0.0, zero_stack, 1.0, int_stack+959719,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+45189,int_stack+59877,int_stack+55341, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+786379, 0.0, zero_stack, 1.0, int_stack+962743,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+52749,int_stack+45189,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790915, 0.0, zero_stack, 1.0, int_stack+967279,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1613161,int_stack+52749,int_stack+679783,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+66751,int_stack+66436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511370, 1.0, int_stack+530800, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+679783,int_stack+67192,int_stack+66751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511685, 1.0, int_stack+531115, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+681106,int_stack+679783,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494040, 1.0, int_stack+513470, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+682996,int_stack+67780,int_stack+67192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512126, 1.0, int_stack+531556, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15516,int_stack+682996,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796315, 1.0, int_stack+884497, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+18162,int_stack+15516,int_stack+681106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+797638, 1.0, int_stack+885820, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+679783,int_stack+68536,int_stack+67780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512714, 1.0, int_stack+532144, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+21312,int_stack+679783,int_stack+682996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+799528, 1.0, int_stack+887710, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+679783,int_stack+21312,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+801292, 1.0, int_stack+889474, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+21312,int_stack+679783,int_stack+18162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+823315, 1.0, int_stack+911497, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+69901,int_stack+69481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517460, 1.0, int_stack+536890, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+679783,int_stack+70489,int_stack+69901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517880, 1.0, int_stack+537310, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+681547,int_stack+679783,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500830, 1.0, int_stack+520260, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15516,int_stack+71273,int_stack+70489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518468, 1.0, int_stack+537898, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+26037,int_stack+15516,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+831190, 1.0, int_stack+919372, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+45189,int_stack+26037,int_stack+681547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832954, 1.0, int_stack+921136, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+679783,int_stack+72281,int_stack+71273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519252, 1.0, int_stack+538682, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+49389,int_stack+679783,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+835474, 1.0, int_stack+923656, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+679783,int_stack+49389,int_stack+26037, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837826, 1.0, int_stack+926008, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+49389,int_stack+679783,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841354, 1.0, int_stack+929536, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+55689,int_stack+49389,int_stack+21312,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+45189,int_stack+74081,int_stack+73541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225041, 1.0, int_stack+240966, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46809,int_stack+74837,int_stack+74081, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226121, 1.0, int_stack+242046, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+679783,int_stack+46809,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+1620, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+683023,int_stack+75845,int_stack+74837, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227633, 1.0, int_stack+243558, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+69864,int_stack+683023,int_stack+46809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866029, 1.0, int_stack+954211, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+15516,int_stack+69864,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868297, 1.0, int_stack+956479, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45189,int_stack+77141,int_stack+75845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229649, 1.0, int_stack+245574, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+20916,int_stack+45189,int_stack+683023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871537, 1.0, int_stack+959719, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1632061,int_stack+20916,int_stack+69864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+874561, 1.0, int_stack+962743, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+69864,int_stack+1632061,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+879097, 1.0, int_stack+967279, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1632061,int_stack+69864,int_stack+49389,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+79076,int_stack+78761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+530800, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+69864,int_stack+79517,int_stack+79076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+531115, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+71187,int_stack+69864,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+513470, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+73077,int_stack+80105,int_stack+79517, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+531556, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+74841,int_stack+73077,int_stack+69864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+884497, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+15516,int_stack+74841,int_stack+71187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+885820, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+69864,int_stack+80861,int_stack+80105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+532144, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+77487,int_stack+69864,int_stack+73077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+887710, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+69864,int_stack+77487,int_stack+74841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+889474, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+74274,int_stack+69864,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+911497, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+82226,int_stack+81806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+536890, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15516,int_stack+82814,int_stack+82226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+537310, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+17280,int_stack+15516,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+520260, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19800,int_stack+83598,int_stack+82814, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+537898, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22152,int_stack+19800,int_stack+15516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+919372, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+25680,int_stack+22152,int_stack+17280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+921136, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+15516,int_stack+84606,int_stack+83598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+538682, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+78999,int_stack+15516,int_stack+19800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+923656, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+15516,int_stack+78999,int_stack+22152, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+926008, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+15516,int_stack+25680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+929536, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+15516,int_stack+679783,int_stack+74274,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+69864,int_stack+86406,int_stack+85866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+240966, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+71484,int_stack+87162,int_stack+86406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+242046, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+73752,int_stack+71484,int_stack+69864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1620, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+76992,int_stack+88170,int_stack+87162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+243558, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+80016,int_stack+76992,int_stack+71484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+954211, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+45189,int_stack+80016,int_stack+73752, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+956479, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+69864,int_stack+89466,int_stack+88170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+245574, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+84552,int_stack+69864,int_stack+76992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+959719, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+69864,int_stack+84552,int_stack+80016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+962743, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+77424,int_stack+69864,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+967279, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1650961,int_stack+77424,int_stack+679783,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+91401,int_stack+91086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+491940, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+550230,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+91842,int_stack+91401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+550545,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+679783,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+687973, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+532900,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+681673,int_stack+92430,int_stack+91842, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+550986,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+683437,int_stack+681673,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+688918, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+972679,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+45189,int_stack+683437,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+690241, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+974002,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+48339,int_stack+93186,int_stack+92430, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551574,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50607,int_stack+48339,int_stack+681673, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+692131, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+975892,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+69864,int_stack+50607,int_stack+683437, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+693895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+977656,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+48339,int_stack+69864,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+696541, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+999679,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+94551,int_stack+94131, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556320,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45189,int_stack+95139,int_stack+94551, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556740,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+69864,int_stack+45189,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+720040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+539690,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+72384,int_stack+95923,int_stack+95139, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499038, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557328,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+74736,int_stack+72384,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+721300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1007554,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+78264,int_stack+74736,int_stack+69864, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+723064, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1009318,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45189,int_stack+96931,int_stack+95923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499822, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558112,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+82464,int_stack+45189,int_stack+72384, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+725584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1011838,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+87168,int_stack+82464,int_stack+74736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+727936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1014190,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+87168,int_stack+78264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+731464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1017718,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+69864,int_stack+679783,int_stack+48339,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+45189,int_stack+98731,int_stack+98191, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256891,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46809,int_stack+99487,int_stack+98731, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+210196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257971,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+49077,int_stack+46809,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+776227, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3240,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52317,int_stack+100495,int_stack+99487, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+211708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259483,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+84039,int_stack+52317,int_stack+46809, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+777847, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042393,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+88575,int_stack+84039,int_stack+49077, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+780115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1044661,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45189,int_stack+101791,int_stack+100495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+213724, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+261499,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+93975,int_stack+45189,int_stack+52317, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+783355, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1047901,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+45189,int_stack+93975,int_stack+84039, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+786379, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1050925,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+93975,int_stack+45189,int_stack+88575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+790915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1055461,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1669861,int_stack+93975,int_stack+679783,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+103726,int_stack+103411, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511370, 0.0, zero_stack, 1.0, int_stack+550230, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+104167,int_stack+103726, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511685, 0.0, zero_stack, 1.0, int_stack+550545, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+679783,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494040, 0.0, zero_stack, 1.0, int_stack+532900, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+681673,int_stack+104755,int_stack+104167, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512126, 0.0, zero_stack, 1.0, int_stack+550986, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+683437,int_stack+681673,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+796315, 0.0, zero_stack, 1.0, int_stack+972679, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+45189,int_stack+683437,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+797638, 0.0, zero_stack, 1.0, int_stack+974002, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+48339,int_stack+105511,int_stack+104755, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+512714, 0.0, zero_stack, 1.0, int_stack+551574, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50607,int_stack+48339,int_stack+681673, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+799528, 0.0, zero_stack, 1.0, int_stack+975892, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+84039,int_stack+50607,int_stack+683437, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+801292, 0.0, zero_stack, 1.0, int_stack+977656, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+48339,int_stack+84039,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+823315, 0.0, zero_stack, 1.0, int_stack+999679, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+106876,int_stack+106456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517460, 0.0, zero_stack, 1.0, int_stack+556320, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45189,int_stack+107464,int_stack+106876, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517880, 0.0, zero_stack, 1.0, int_stack+556740, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+84039,int_stack+45189,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500830, 0.0, zero_stack, 1.0, int_stack+539690, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+86559,int_stack+108248,int_stack+107464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+518468, 0.0, zero_stack, 1.0, int_stack+557328, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+88911,int_stack+86559,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+831190, 0.0, zero_stack, 1.0, int_stack+1007554, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+92439,int_stack+88911,int_stack+84039, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+832954, 0.0, zero_stack, 1.0, int_stack+1009318, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45189,int_stack+109256,int_stack+108248, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+519252, 0.0, zero_stack, 1.0, int_stack+558112, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+96639,int_stack+45189,int_stack+86559, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+835474, 0.0, zero_stack, 1.0, int_stack+1011838, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+101343,int_stack+96639,int_stack+88911, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+837826, 0.0, zero_stack, 1.0, int_stack+1014190, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+101343,int_stack+92439, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+841354, 0.0, zero_stack, 1.0, int_stack+1017718, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+84039,int_stack+679783,int_stack+48339,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+45189,int_stack+111056,int_stack+110516, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225041, 0.0, zero_stack, 1.0, int_stack+256891, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46809,int_stack+111812,int_stack+111056, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226121, 0.0, zero_stack, 1.0, int_stack+257971, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+49077,int_stack+46809,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+3240, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52317,int_stack+112820,int_stack+111812, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227633, 0.0, zero_stack, 1.0, int_stack+259483, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+98214,int_stack+52317,int_stack+46809, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+866029, 0.0, zero_stack, 1.0, int_stack+1042393, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+102750,int_stack+98214,int_stack+49077, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+868297, 0.0, zero_stack, 1.0, int_stack+1044661, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45189,int_stack+114116,int_stack+112820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229649, 0.0, zero_stack, 1.0, int_stack+261499, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+108150,int_stack+45189,int_stack+52317, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+871537, 0.0, zero_stack, 1.0, int_stack+1047901, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+45189,int_stack+108150,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+874561, 0.0, zero_stack, 1.0, int_stack+1050925, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+45189,int_stack+102750, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+879097, 0.0, zero_stack, 1.0, int_stack+1055461, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1696861,int_stack+1688761,int_stack+679783,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+116051,int_stack+115736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530800, 1.0, int_stack+550230, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+116492,int_stack+116051, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+531115, 1.0, int_stack+550545, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+679783,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+513470, 1.0, int_stack+532900, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+681673,int_stack+117080,int_stack+116492, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+531556, 1.0, int_stack+550986, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+683437,int_stack+681673,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+884497, 1.0, int_stack+972679, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+683437,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+885820, 1.0, int_stack+974002, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1691911,int_stack+117836,int_stack+117080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+532144, 1.0, int_stack+551574, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+45189,int_stack+1691911,int_stack+681673, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+887710, 1.0, int_stack+975892, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1691911,int_stack+45189,int_stack+683437, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+889474, 1.0, int_stack+977656, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+45189,int_stack+1691911,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+911497, 1.0, int_stack+999679, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+119201,int_stack+118781, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536890, 1.0, int_stack+556320, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1688761,int_stack+119789,int_stack+119201, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+537310, 1.0, int_stack+556740, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1690525,int_stack+1688761,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+520260, 1.0, int_stack+539690, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1693045,int_stack+120573,int_stack+119789, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+537898, 1.0, int_stack+557328, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49914,int_stack+1693045,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+919372, 1.0, int_stack+1007554, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+679783,int_stack+49914,int_stack+1690525, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+921136, 1.0, int_stack+1009318, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+121581,int_stack+120573, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+538682, 1.0, int_stack+558112, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+1688761,int_stack+1693045, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+923656, 1.0, int_stack+1011838, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+98214,int_stack+49914, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+926008, 1.0, int_stack+1014190, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1688761,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+929536, 1.0, int_stack+1017718, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+104514,int_stack+98214,int_stack+45189,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+45189,int_stack+123381,int_stack+122841, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+240966, 1.0, int_stack+256891, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+46809,int_stack+124137,int_stack+123381, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+242046, 1.0, int_stack+257971, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+49077,int_stack+46809,int_stack+45189, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1620, 1.0, int_stack+3240, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52317,int_stack+125145,int_stack+124137, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243558, 1.0, int_stack+259483, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+679783,int_stack+52317,int_stack+46809, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+954211, 1.0, int_stack+1042393, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+679783,int_stack+49077, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+956479, 1.0, int_stack+1044661, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45189,int_stack+126441,int_stack+125145, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245574, 1.0, int_stack+261499, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+118689,int_stack+45189,int_stack+52317, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+959719, 1.0, int_stack+1047901, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+45189,int_stack+118689,int_stack+679783, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962743, 1.0, int_stack+1050925, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+118689,int_stack+45189,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+967279, 1.0, int_stack+1055461, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1715761,int_stack+118689,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+128376,int_stack+128061, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+550230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+128817,int_stack+128376, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+550545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+532900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+129405,int_stack+128817, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+550986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+972679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+118689,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+974002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121839,int_stack+130161,int_stack+129405, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+551574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+124107,int_stack+121839,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+975892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+124107,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+977656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+121839,int_stack+1688761,int_stack+118689, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+999679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+131526,int_stack+131106, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+556320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+118689,int_stack+132114,int_stack+131526, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+556740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1688761,int_stack+118689,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+539690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1691281,int_stack+132898,int_stack+132114, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+557328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+126564,int_stack+1691281,int_stack+118689, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1007554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+98214,int_stack+126564,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1009318, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+118689,int_stack+133906,int_stack+132898, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+558112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+130092,int_stack+118689,int_stack+1691281, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1011838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+130092,int_stack+126564, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1014190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1017718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1734661,int_stack+679783,int_stack+121839,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+98214,int_stack+135706,int_stack+135166, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+256891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+99834,int_stack+136462,int_stack+135706, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+257971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1688761,int_stack+99834,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1692001,int_stack+137470,int_stack+136462, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+259483, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+118689,int_stack+1692001,int_stack+99834, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1042393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+98214,int_stack+118689,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1044661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+123225,int_stack+138766,int_stack+137470, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+261499, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+127113,int_stack+123225,int_stack+1692001, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1047901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+127113,int_stack+118689, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1050925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+118689,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1055461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1748836,int_stack+118689,int_stack+679783,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+140701,int_stack+140386, 0.0, zero_stack, 1.0, int_stack+491940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569660,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+141142,int_stack+140701, 0.0, zero_stack, 1.0, int_stack+492255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569975,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+679783,int_stack+29691,int_stack+658925, 0.0, zero_stack, 1.0, int_stack+687973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552330,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+681673,int_stack+141730,int_stack+141142, 0.0, zero_stack, 1.0, int_stack+492696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+570416,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+683437,int_stack+681673,int_stack+29691, 0.0, zero_stack, 1.0, int_stack+688918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060861,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+118689,int_stack+683437,int_stack+679783, 0.0, zero_stack, 1.0, int_stack+690241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1062184,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+121839,int_stack+142486,int_stack+141730, 0.0, zero_stack, 1.0, int_stack+493284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571004,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+124107,int_stack+121839,int_stack+681673, 0.0, zero_stack, 1.0, int_stack+692131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1064074,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+127635,int_stack+124107,int_stack+683437, 0.0, zero_stack, 1.0, int_stack+693895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1065838,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+121839,int_stack+127635,int_stack+118689, 0.0, zero_stack, 1.0, int_stack+696541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1087861,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+143851,int_stack+143431, 0.0, zero_stack, 1.0, int_stack+498030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575750,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+118689,int_stack+144439,int_stack+143851, 0.0, zero_stack, 1.0, int_stack+498450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576170,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+126564,int_stack+118689,int_stack+665715, 0.0, zero_stack, 1.0, int_stack+720040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559120,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+129084,int_stack+145223,int_stack+144439, 0.0, zero_stack, 1.0, int_stack+499038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576758,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+131436,int_stack+129084,int_stack+118689, 0.0, zero_stack, 1.0, int_stack+721300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1095736,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+134964,int_stack+131436,int_stack+126564, 0.0, zero_stack, 1.0, int_stack+723064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1097500,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+118689,int_stack+146231,int_stack+145223, 0.0, zero_stack, 1.0, int_stack+499822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577542,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+139164,int_stack+118689,int_stack+129084, 0.0, zero_stack, 1.0, int_stack+725584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1100020,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+679783,int_stack+139164,int_stack+131436, 0.0, zero_stack, 1.0, int_stack+727936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102372,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+679783,int_stack+134964, 0.0, zero_stack, 1.0, int_stack+731464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1105900,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+126564,int_stack+98214,int_stack+121839,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+679783,int_stack+148031,int_stack+147491, 0.0, zero_stack, 1.0, int_stack+209116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272816,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+681403,int_stack+148787,int_stack+148031, 0.0, zero_stack, 1.0, int_stack+210196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273896,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+118689,int_stack+681403,int_stack+679783, 0.0, zero_stack, 1.0, int_stack+776227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+121929,int_stack+149795,int_stack+148787, 0.0, zero_stack, 1.0, int_stack+211708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275408,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+140739,int_stack+121929,int_stack+681403, 0.0, zero_stack, 1.0, int_stack+777847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1130575,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+679783,int_stack+140739,int_stack+118689, 0.0, zero_stack, 1.0, int_stack+780115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1132843,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+145275,int_stack+151091,int_stack+149795, 0.0, zero_stack, 1.0, int_stack+213724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277424,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1688761,int_stack+145275,int_stack+121929, 0.0, zero_stack, 1.0, int_stack+783355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1136083,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+118689,int_stack+1688761,int_stack+140739, 0.0, zero_stack, 1.0, int_stack+786379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1139107,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+118689,int_stack+679783, 0.0, zero_stack, 1.0, int_stack+790915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1143643,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1767736,int_stack+1688761,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+153026,int_stack+152711, 0.0, zero_stack, 1.0, int_stack+511370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569660, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+153467,int_stack+153026, 0.0, zero_stack, 1.0, int_stack+511685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569975, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 1.0, int_stack+494040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552330, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+154055,int_stack+153467, 0.0, zero_stack, 1.0, int_stack+512126, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+570416, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 1.0, int_stack+796315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1060861, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+101868,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+797638, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1062184, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1691911,int_stack+154811,int_stack+154055, 0.0, zero_stack, 1.0, int_stack+512714, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571004, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+679783,int_stack+1691911,int_stack+100104, 0.0, zero_stack, 1.0, int_stack+799528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1064074, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1691911,int_stack+679783,int_stack+101868, 0.0, zero_stack, 1.0, int_stack+801292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1065838, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+1691911,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1087861, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+156176,int_stack+155756, 0.0, zero_stack, 1.0, int_stack+517460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575750, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1688761,int_stack+156764,int_stack+156176, 0.0, zero_stack, 1.0, int_stack+517880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576170, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1690525,int_stack+1688761,int_stack+665715, 0.0, zero_stack, 1.0, int_stack+500830, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+559120, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1693045,int_stack+157548,int_stack+156764, 0.0, zero_stack, 1.0, int_stack+518468, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576758, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+98214,int_stack+1693045,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+831190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1095736, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+118689,int_stack+98214,int_stack+1690525, 0.0, zero_stack, 1.0, int_stack+832954, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1097500, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+158556,int_stack+157548, 0.0, zero_stack, 1.0, int_stack+519252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+577542, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+140739,int_stack+1688761,int_stack+1693045, 0.0, zero_stack, 1.0, int_stack+835474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1100020, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+140739,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+837826, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102372, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1688761,int_stack+118689, 0.0, zero_stack, 1.0, int_stack+841354, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1105900, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+140739,int_stack+98214,int_stack+679783,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+679783,int_stack+160356,int_stack+159816, 0.0, zero_stack, 1.0, int_stack+225041, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+272816, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+681403,int_stack+161112,int_stack+160356, 0.0, zero_stack, 1.0, int_stack+226121, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273896, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+118689,int_stack+681403,int_stack+679783, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+121929,int_stack+162120,int_stack+161112, 0.0, zero_stack, 1.0, int_stack+227633, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275408, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+121929,int_stack+681403, 0.0, zero_stack, 1.0, int_stack+866029, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1130575, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+679783,int_stack+1688761,int_stack+118689, 0.0, zero_stack, 1.0, int_stack+868297, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1132843, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+154914,int_stack+163416,int_stack+162120, 0.0, zero_stack, 1.0, int_stack+229649, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277424, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+158802,int_stack+154914,int_stack+121929, 0.0, zero_stack, 1.0, int_stack+871537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1136083, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+118689,int_stack+158802,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+874561, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1139107, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+118689,int_stack+679783, 0.0, zero_stack, 1.0, int_stack+879097, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1143643, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1786636,int_stack+1688761,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+165351,int_stack+165036, 0.0, zero_stack, 1.0, int_stack+530800, 0.0, zero_stack, 1.0, int_stack+569660, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+165792,int_stack+165351, 0.0, zero_stack, 1.0, int_stack+531115, 0.0, zero_stack, 1.0, int_stack+569975, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 1.0, int_stack+513470, 0.0, zero_stack, 1.0, int_stack+552330, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+166380,int_stack+165792, 0.0, zero_stack, 1.0, int_stack+531556, 0.0, zero_stack, 1.0, int_stack+570416, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 1.0, int_stack+884497, 0.0, zero_stack, 1.0, int_stack+1060861, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+101868,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+885820, 0.0, zero_stack, 1.0, int_stack+1062184, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1691911,int_stack+167136,int_stack+166380, 0.0, zero_stack, 1.0, int_stack+532144, 0.0, zero_stack, 1.0, int_stack+571004, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+679783,int_stack+1691911,int_stack+100104, 0.0, zero_stack, 1.0, int_stack+887710, 0.0, zero_stack, 1.0, int_stack+1064074, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1691911,int_stack+679783,int_stack+101868, 0.0, zero_stack, 1.0, int_stack+889474, 0.0, zero_stack, 1.0, int_stack+1065838, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+1691911,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+911497, 0.0, zero_stack, 1.0, int_stack+1087861, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+168501,int_stack+168081, 0.0, zero_stack, 1.0, int_stack+536890, 0.0, zero_stack, 1.0, int_stack+575750, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1688761,int_stack+169089,int_stack+168501, 0.0, zero_stack, 1.0, int_stack+537310, 0.0, zero_stack, 1.0, int_stack+576170, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1690525,int_stack+1688761,int_stack+665715, 0.0, zero_stack, 1.0, int_stack+520260, 0.0, zero_stack, 1.0, int_stack+559120, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1693045,int_stack+169873,int_stack+169089, 0.0, zero_stack, 1.0, int_stack+537898, 0.0, zero_stack, 1.0, int_stack+576758, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+98214,int_stack+1693045,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+919372, 0.0, zero_stack, 1.0, int_stack+1095736, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+118689,int_stack+98214,int_stack+1690525, 0.0, zero_stack, 1.0, int_stack+921136, 0.0, zero_stack, 1.0, int_stack+1097500, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+170881,int_stack+169873, 0.0, zero_stack, 1.0, int_stack+538682, 0.0, zero_stack, 1.0, int_stack+577542, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+154914,int_stack+1688761,int_stack+1693045, 0.0, zero_stack, 1.0, int_stack+923656, 0.0, zero_stack, 1.0, int_stack+1100020, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+154914,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+926008, 0.0, zero_stack, 1.0, int_stack+1102372, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1688761,int_stack+118689, 0.0, zero_stack, 1.0, int_stack+929536, 0.0, zero_stack, 1.0, int_stack+1105900, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+154914,int_stack+98214,int_stack+679783,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+679783,int_stack+172681,int_stack+172141, 0.0, zero_stack, 1.0, int_stack+240966, 0.0, zero_stack, 1.0, int_stack+272816, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+681403,int_stack+173437,int_stack+172681, 0.0, zero_stack, 1.0, int_stack+242046, 0.0, zero_stack, 1.0, int_stack+273896, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+118689,int_stack+681403,int_stack+679783, 0.0, zero_stack, 1.0, int_stack+1620, 0.0, zero_stack, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+121929,int_stack+174445,int_stack+173437, 0.0, zero_stack, 1.0, int_stack+243558, 0.0, zero_stack, 1.0, int_stack+275408, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+121929,int_stack+681403, 0.0, zero_stack, 1.0, int_stack+954211, 0.0, zero_stack, 1.0, int_stack+1130575, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+679783,int_stack+1688761,int_stack+118689, 0.0, zero_stack, 1.0, int_stack+956479, 0.0, zero_stack, 1.0, int_stack+1132843, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+169089,int_stack+175741,int_stack+174445, 0.0, zero_stack, 1.0, int_stack+245574, 0.0, zero_stack, 1.0, int_stack+277424, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+45189,int_stack+169089,int_stack+121929, 0.0, zero_stack, 1.0, int_stack+959719, 0.0, zero_stack, 1.0, int_stack+1136083, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+169089,int_stack+45189,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+962743, 0.0, zero_stack, 1.0, int_stack+1139107, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+169089,int_stack+679783, 0.0, zero_stack, 1.0, int_stack+967279, 0.0, zero_stack, 1.0, int_stack+1143643, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1805536,int_stack+1688761,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+177676,int_stack+177361, 0.0, zero_stack, 1.0, int_stack+550230, 1.0, int_stack+569660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+178117,int_stack+177676, 0.0, zero_stack, 1.0, int_stack+550545, 1.0, int_stack+569975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 1.0, int_stack+532900, 1.0, int_stack+552330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+178705,int_stack+178117, 0.0, zero_stack, 1.0, int_stack+550986, 1.0, int_stack+570416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 1.0, int_stack+972679, 1.0, int_stack+1060861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+101868,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+974002, 1.0, int_stack+1062184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1691911,int_stack+179461,int_stack+178705, 0.0, zero_stack, 1.0, int_stack+551574, 1.0, int_stack+571004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+679783,int_stack+1691911,int_stack+100104, 0.0, zero_stack, 1.0, int_stack+975892, 1.0, int_stack+1064074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1691911,int_stack+679783,int_stack+101868, 0.0, zero_stack, 1.0, int_stack+977656, 1.0, int_stack+1065838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+679783,int_stack+1691911,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+999679, 1.0, int_stack+1087861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+180826,int_stack+180406, 0.0, zero_stack, 1.0, int_stack+556320, 1.0, int_stack+575750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1688761,int_stack+181414,int_stack+180826, 0.0, zero_stack, 1.0, int_stack+556740, 1.0, int_stack+576170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1690525,int_stack+1688761,int_stack+665715, 0.0, zero_stack, 1.0, int_stack+539690, 1.0, int_stack+559120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1693045,int_stack+182198,int_stack+181414, 0.0, zero_stack, 1.0, int_stack+557328, 1.0, int_stack+576758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+98214,int_stack+1693045,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+1007554, 1.0, int_stack+1095736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+169089,int_stack+98214,int_stack+1690525, 0.0, zero_stack, 1.0, int_stack+1009318, 1.0, int_stack+1097500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+183206,int_stack+182198, 0.0, zero_stack, 1.0, int_stack+558112, 1.0, int_stack+577542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+173289,int_stack+1688761,int_stack+1693045, 0.0, zero_stack, 1.0, int_stack+1011838, 1.0, int_stack+1100020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+173289,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+1014190, 1.0, int_stack+1102372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1688761,int_stack+169089, 0.0, zero_stack, 1.0, int_stack+1017718, 1.0, int_stack+1105900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+169089,int_stack+98214,int_stack+679783,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+679783,int_stack+185006,int_stack+184466, 0.0, zero_stack, 1.0, int_stack+256891, 1.0, int_stack+272816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+681403,int_stack+185762,int_stack+185006, 0.0, zero_stack, 1.0, int_stack+257971, 1.0, int_stack+273896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1688761,int_stack+681403,int_stack+679783, 0.0, zero_stack, 1.0, int_stack+3240, 1.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1692001,int_stack+186770,int_stack+185762, 0.0, zero_stack, 1.0, int_stack+259483, 1.0, int_stack+275408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+45189,int_stack+1692001,int_stack+681403, 0.0, zero_stack, 1.0, int_stack+1042393, 1.0, int_stack+1130575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+679783,int_stack+45189,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+1044661, 1.0, int_stack+1132843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+49725,int_stack+188066,int_stack+186770, 0.0, zero_stack, 1.0, int_stack+261499, 1.0, int_stack+277424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+183264,int_stack+49725,int_stack+1692001, 0.0, zero_stack, 1.0, int_stack+1047901, 1.0, int_stack+1136083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+183264,int_stack+45189, 0.0, zero_stack, 1.0, int_stack+1050925, 1.0, int_stack+1139107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+45189,int_stack+1688761,int_stack+679783, 0.0, zero_stack, 1.0, int_stack+1055461, 1.0, int_stack+1143643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1824436,int_stack+45189,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+190001,int_stack+189686, 0.0, zero_stack, 2.0, int_stack+569660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+190442,int_stack+190001, 0.0, zero_stack, 2.0, int_stack+569975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 2.0, int_stack+552330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+191030,int_stack+190442, 0.0, zero_stack, 2.0, int_stack+570416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 2.0, int_stack+1060861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+45189,int_stack+101868,int_stack+98214, 0.0, zero_stack, 2.0, int_stack+1062184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+48339,int_stack+191786,int_stack+191030, 0.0, zero_stack, 2.0, int_stack+571004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50607,int_stack+48339,int_stack+100104, 0.0, zero_stack, 2.0, int_stack+1064074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+679783,int_stack+50607,int_stack+101868, 0.0, zero_stack, 2.0, int_stack+1065838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+48339,int_stack+679783,int_stack+45189, 0.0, zero_stack, 2.0, int_stack+1087861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+193151,int_stack+192731, 0.0, zero_stack, 2.0, int_stack+575750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+45189,int_stack+193739,int_stack+193151, 0.0, zero_stack, 2.0, int_stack+576170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+679783,int_stack+45189,int_stack+665715, 0.0, zero_stack, 2.0, int_stack+559120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+682303,int_stack+194523,int_stack+193739, 0.0, zero_stack, 2.0, int_stack+576758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+98214,int_stack+682303,int_stack+45189, 0.0, zero_stack, 2.0, int_stack+1095736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+98214,int_stack+679783, 0.0, zero_stack, 2.0, int_stack+1097500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+45189,int_stack+195531,int_stack+194523, 0.0, zero_stack, 2.0, int_stack+577542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+183264,int_stack+45189,int_stack+682303, 0.0, zero_stack, 2.0, int_stack+1100020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+679783,int_stack+183264,int_stack+98214, 0.0, zero_stack, 2.0, int_stack+1102372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+679783,int_stack+1688761, 0.0, zero_stack, 2.0, int_stack+1105900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1843336,int_stack+98214,int_stack+48339,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+1688761,int_stack+197331,int_stack+196791, 0.0, zero_stack, 2.0, int_stack+272816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1690381,int_stack+198087,int_stack+197331, 0.0, zero_stack, 2.0, int_stack+273896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1692649,int_stack+1690381,int_stack+1688761, 0.0, zero_stack, 2.0, int_stack+4860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+679783,int_stack+199095,int_stack+198087, 0.0, zero_stack, 2.0, int_stack+275408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+183264,int_stack+679783,int_stack+1690381, 0.0, zero_stack, 2.0, int_stack+1130575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+187800,int_stack+183264,int_stack+1692649, 0.0, zero_stack, 2.0, int_stack+1132843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+200391,int_stack+199095, 0.0, zero_stack, 2.0, int_stack+277424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+193200,int_stack+1688761,int_stack+679783, 0.0, zero_stack, 2.0, int_stack+1136083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+193200,int_stack+183264, 0.0, zero_stack, 2.0, int_stack+1139107, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+193200,int_stack+1688761,int_stack+187800, 0.0, zero_stack, 2.0, int_stack+1143643, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1857511,int_stack+193200,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+202326,int_stack+202011, 1.0, int_stack+491940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589090,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+202767,int_stack+202326, 1.0, int_stack+492255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589405,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 1.0, int_stack+687973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571760,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+203355,int_stack+202767, 1.0, int_stack+492696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589846,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 1.0, int_stack+688918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149043,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+101868,int_stack+98214, 1.0, int_stack+690241, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150366,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1691911,int_stack+204111,int_stack+203355, 1.0, int_stack+493284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+590434,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+183264,int_stack+1691911,int_stack+100104, 1.0, int_stack+692131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1152256,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1691911,int_stack+183264,int_stack+101868, 1.0, int_stack+693895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1154020,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1691911,int_stack+1688761, 1.0, int_stack+696541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1176043,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+205476,int_stack+205056, 1.0, int_stack+498030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595600,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1688761,int_stack+206064,int_stack+205476, 1.0, int_stack+498450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596608,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1690525,int_stack+1688761,int_stack+665715, 1.0, int_stack+720040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578550,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1693045,int_stack+206848,int_stack+206064, 1.0, int_stack+499038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597980,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+187989,int_stack+1693045,int_stack+1688761, 1.0, int_stack+721300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1179193,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+191517,int_stack+187989,int_stack+1690525, 1.0, int_stack+723064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1180957,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+207856,int_stack+206848, 1.0, int_stack+499822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599772,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+195717,int_stack+1688761,int_stack+1693045, 1.0, int_stack+725584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1183477,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+195717,int_stack+187989, 1.0, int_stack+727936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676255,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1688761,int_stack+191517, 1.0, int_stack+731464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191856,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+187989,int_stack+98214,int_stack+183264,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+210952,int_stack+209656, 1.0, int_stack+209116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289281,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+212716,int_stack+210952, 1.0, int_stack+210196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291117,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1688761,int_stack+184884,int_stack+183264, 1.0, int_stack+776227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1692001,int_stack+215020,int_stack+212716, 1.0, int_stack+211708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293637,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+202164,int_stack+1692001,int_stack+184884, 1.0, int_stack+777847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1196056,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+206700,int_stack+202164,int_stack+1688761, 1.0, int_stack+780115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1198324,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+216316,int_stack+215020, 1.0, int_stack+213724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295653,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+679783,int_stack+183264,int_stack+1692001, 1.0, int_stack+783355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1201564,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+679783,int_stack+202164, 1.0, int_stack+786379, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704416,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+45189,int_stack+1688761,int_stack+206700, 1.0, int_stack+790915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1227115,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+775039,int_stack+45189,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+218251,int_stack+217936, 1.0, int_stack+511370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589090, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+218692,int_stack+218251, 1.0, int_stack+511685, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589405, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 1.0, int_stack+494040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571760, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+219280,int_stack+218692, 1.0, int_stack+512126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589846, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 1.0, int_stack+796315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149043, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+45189,int_stack+101868,int_stack+98214, 1.0, int_stack+797638, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150366, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+48339,int_stack+220036,int_stack+219280, 1.0, int_stack+512714, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+590434, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+50607,int_stack+48339,int_stack+100104, 1.0, int_stack+799528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1152256, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+50607,int_stack+101868, 1.0, int_stack+801292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1154020, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1688761,int_stack+45189, 1.0, int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1176043, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+221401,int_stack+220981, 1.0, int_stack+517460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595600, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+221989,int_stack+221401, 1.0, int_stack+517880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596608, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+45189,int_stack+823315,int_stack+665715, 1.0, int_stack+500830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578550, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+47709,int_stack+222773,int_stack+221989, 1.0, int_stack+518468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597980, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+50061,int_stack+47709,int_stack+823315, 1.0, int_stack+831190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1179193, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+50061,int_stack+45189, 1.0, int_stack+832954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1180957, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+831190,int_stack+223781,int_stack+222773, 1.0, int_stack+519252, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599772, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+831190,int_stack+47709, 1.0, int_stack+835474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1183477, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+831190,int_stack+98214,int_stack+50061, 1.0, int_stack+837826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676255, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+831190,int_stack+1688761, 1.0, int_stack+841354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191856, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+831190,int_stack+98214,int_stack+183264,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+226877,int_stack+225581, 1.0, int_stack+225041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289281, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+228641,int_stack+226877, 1.0, int_stack+226121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291117, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1688761,int_stack+184884,int_stack+183264, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1692001,int_stack+230945,int_stack+228641, 1.0, int_stack+227633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293637, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+45189,int_stack+1692001,int_stack+184884, 1.0, int_stack+866029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1196056, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+49725,int_stack+45189,int_stack+1688761, 1.0, int_stack+868297, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1198324, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+866029,int_stack+232241,int_stack+230945, 1.0, int_stack+229649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295653, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+202164,int_stack+866029,int_stack+1692001, 1.0, int_stack+871537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1201564, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+866029,int_stack+202164,int_stack+45189, 1.0, int_stack+874561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704416, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+866029,int_stack+49725, 1.0, int_stack+879097, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1227115, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+202164,int_stack+1688761,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+234176,int_stack+233861, 1.0, int_stack+530800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589090, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+234617,int_stack+234176, 1.0, int_stack+531115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589405, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 1.0, int_stack+513470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+571760, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+235205,int_stack+234617, 1.0, int_stack+531556, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589846, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 1.0, int_stack+884497, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149043, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 1.0, int_stack+885820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150366, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+235961,int_stack+235205, 1.0, int_stack+532144, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+590434, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 1.0, int_stack+887710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1152256, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+866029,int_stack+1691029,int_stack+101868, 1.0, int_stack+889474, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1154020, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+866029,int_stack+823315, 1.0, int_stack+911497, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1176043, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+237326,int_stack+236906, 1.0, int_stack+536890, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595600, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+911497,int_stack+237914,int_stack+237326, 1.0, int_stack+537310, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+596608, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+823315,int_stack+911497,int_stack+665715, 1.0, int_stack+520260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578550, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+866029,int_stack+238698,int_stack+237914, 1.0, int_stack+537898, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+597980, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+868381,int_stack+866029,int_stack+911497, 1.0, int_stack+919372, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1179193, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+871909,int_stack+868381,int_stack+823315, 1.0, int_stack+921136, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1180957, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+239706,int_stack+238698, 1.0, int_stack+538682, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+599772, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+876109,int_stack+823315,int_stack+866029, 1.0, int_stack+923656, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1183477, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+919372,int_stack+876109,int_stack+868381, 1.0, int_stack+926008, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+676255, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+919372,int_stack+871909, 1.0, int_stack+929536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191856, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+919372,int_stack+98214,int_stack+183264,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+0,int_stack+242802,int_stack+241506, 1.0, int_stack+240966, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289281, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+183264,int_stack+244566,int_stack+242802, 1.0, int_stack+242046, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+291117, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+866029,int_stack+183264,int_stack+0, 1.0, int_stack+1620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+246870,int_stack+244566, 1.0, int_stack+243558, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293637, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+869269,int_stack+0,int_stack+183264, 1.0, int_stack+954211, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1196056, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+873805,int_stack+869269,int_stack+866029, 1.0, int_stack+956479, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1198324, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+954211,int_stack+248166,int_stack+246870, 1.0, int_stack+245574, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+295653, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+879205,int_stack+954211,int_stack+0, 1.0, int_stack+959719, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1201564, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+954211,int_stack+879205,int_stack+869269, 1.0, int_stack+962743, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+704416, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+954211,int_stack+873805, 1.0, int_stack+967279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+866029,int_stack+1688761,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+250101,int_stack+249786, 1.0, int_stack+550230, 0.0, zero_stack, 1.0, int_stack+589090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+250542,int_stack+250101, 1.0, int_stack+550545, 0.0, zero_stack, 1.0, int_stack+589405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 1.0, int_stack+532900, 0.0, zero_stack, 1.0, int_stack+571760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+251130,int_stack+250542, 1.0, int_stack+550986, 0.0, zero_stack, 1.0, int_stack+589846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 1.0, int_stack+972679, 0.0, zero_stack, 1.0, int_stack+1149043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 1.0, int_stack+974002, 0.0, zero_stack, 1.0, int_stack+1150366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+251886,int_stack+251130, 1.0, int_stack+551574, 0.0, zero_stack, 1.0, int_stack+590434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 1.0, int_stack+975892, 0.0, zero_stack, 1.0, int_stack+1152256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+954211,int_stack+1691029,int_stack+101868, 1.0, int_stack+977656, 0.0, zero_stack, 1.0, int_stack+1154020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+954211,int_stack+823315, 1.0, int_stack+999679, 0.0, zero_stack, 1.0, int_stack+1176043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+253251,int_stack+252831, 1.0, int_stack+556320, 0.0, zero_stack, 1.0, int_stack+595600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+999679,int_stack+253839,int_stack+253251, 1.0, int_stack+556740, 0.0, zero_stack, 1.0, int_stack+596608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+823315,int_stack+999679,int_stack+665715, 1.0, int_stack+539690, 0.0, zero_stack, 1.0, int_stack+578550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+954211,int_stack+254623,int_stack+253839, 1.0, int_stack+557328, 0.0, zero_stack, 1.0, int_stack+597980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+956563,int_stack+954211,int_stack+999679, 1.0, int_stack+1007554, 0.0, zero_stack, 1.0, int_stack+1179193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+960091,int_stack+956563,int_stack+823315, 1.0, int_stack+1009318, 0.0, zero_stack, 1.0, int_stack+1180957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+255631,int_stack+254623, 1.0, int_stack+558112, 0.0, zero_stack, 1.0, int_stack+599772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+964291,int_stack+823315,int_stack+954211, 1.0, int_stack+1011838, 0.0, zero_stack, 1.0, int_stack+1183477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1007554,int_stack+964291,int_stack+956563, 1.0, int_stack+1014190, 0.0, zero_stack, 1.0, int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1007554,int_stack+960091, 1.0, int_stack+1017718, 0.0, zero_stack, 1.0, int_stack+1191856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1007554,int_stack+98214,int_stack+183264,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+258727,int_stack+257431, 1.0, int_stack+256891, 0.0, zero_stack, 1.0, int_stack+289281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+260491,int_stack+258727, 1.0, int_stack+257971, 0.0, zero_stack, 1.0, int_stack+291117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+0,int_stack+184884,int_stack+183264, 1.0, int_stack+3240, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+954211,int_stack+262795,int_stack+260491, 1.0, int_stack+259483, 0.0, zero_stack, 1.0, int_stack+293637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+957235,int_stack+954211,int_stack+184884, 1.0, int_stack+1042393, 0.0, zero_stack, 1.0, int_stack+1196056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+961771,int_stack+957235,int_stack+0, 1.0, int_stack+1044661, 0.0, zero_stack, 1.0, int_stack+1198324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+264091,int_stack+262795, 1.0, int_stack+261499, 0.0, zero_stack, 1.0, int_stack+295653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+967171,int_stack+0,int_stack+954211, 1.0, int_stack+1047901, 0.0, zero_stack, 1.0, int_stack+1201564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+973219,int_stack+967171,int_stack+957235, 1.0, int_stack+1050925, 0.0, zero_stack, 1.0, int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+973219,int_stack+961771, 1.0, int_stack+1055461, 0.0, zero_stack, 1.0, int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+954211,int_stack+1688761,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+266026,int_stack+265711, 1.0, int_stack+569660, 1.0, int_stack+589090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+266467,int_stack+266026, 1.0, int_stack+569975, 1.0, int_stack+589405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 1.0, int_stack+552330, 1.0, int_stack+571760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+267055,int_stack+266467, 1.0, int_stack+570416, 1.0, int_stack+589846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 1.0, int_stack+1060861, 1.0, int_stack+1149043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 1.0, int_stack+1062184, 1.0, int_stack+1150366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+267811,int_stack+267055, 1.0, int_stack+571004, 1.0, int_stack+590434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 1.0, int_stack+1064074, 1.0, int_stack+1152256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+973111,int_stack+1691029,int_stack+101868, 1.0, int_stack+1065838, 1.0, int_stack+1154020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+973111,int_stack+823315, 1.0, int_stack+1087861, 1.0, int_stack+1176043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+269176,int_stack+268756, 1.0, int_stack+575750, 1.0, int_stack+595600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1087861,int_stack+269764,int_stack+269176, 1.0, int_stack+576170, 1.0, int_stack+596608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+823315,int_stack+1087861,int_stack+665715, 1.0, int_stack+559120, 1.0, int_stack+578550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+973111,int_stack+270548,int_stack+269764, 1.0, int_stack+576758, 1.0, int_stack+597980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+975463,int_stack+973111,int_stack+1087861, 1.0, int_stack+1095736, 1.0, int_stack+1179193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+975463,int_stack+823315, 1.0, int_stack+1097500, 1.0, int_stack+1180957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+271556,int_stack+270548, 1.0, int_stack+577542, 1.0, int_stack+599772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+973111, 1.0, int_stack+1100020, 1.0, int_stack+1183477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1095736,int_stack+98214,int_stack+975463, 1.0, int_stack+1102372, 1.0, int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1095736,int_stack+1688761, 1.0, int_stack+1105900, 1.0, int_stack+1191856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1095736,int_stack+98214,int_stack+183264,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+274652,int_stack+273356, 1.0, int_stack+272816, 1.0, int_stack+289281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+276416,int_stack+274652, 1.0, int_stack+273896, 1.0, int_stack+291117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1688761,int_stack+184884,int_stack+183264, 1.0, int_stack+4860, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1692001,int_stack+278720,int_stack+276416, 1.0, int_stack+275408, 1.0, int_stack+293637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+973111,int_stack+1692001,int_stack+184884, 1.0, int_stack+1130575, 1.0, int_stack+1196056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+0,int_stack+973111,int_stack+1688761, 1.0, int_stack+1132843, 1.0, int_stack+1198324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1130575,int_stack+280016,int_stack+278720, 1.0, int_stack+277424, 1.0, int_stack+295653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1042393,int_stack+1130575,int_stack+1692001, 1.0, int_stack+1136083, 1.0, int_stack+1201564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1130575,int_stack+1042393,int_stack+973111, 1.0, int_stack+1139107, 1.0, int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1130575,int_stack+0, 1.0, int_stack+1143643, 1.0, int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1042393,int_stack+1688761,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+281951,int_stack+281636, 2.0, int_stack+589090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+282392,int_stack+281951, 2.0, int_stack+589405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 2.0, int_stack+571760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+282980,int_stack+282392, 2.0, int_stack+589846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 2.0, int_stack+1149043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 2.0, int_stack+1150366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+283736,int_stack+282980, 2.0, int_stack+590434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 2.0, int_stack+1152256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+1691029,int_stack+101868, 2.0, int_stack+1154020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+0,int_stack+823315, 2.0, int_stack+1176043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+285101,int_stack+284681, 2.0, int_stack+595600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1176043,int_stack+285689,int_stack+285101, 2.0, int_stack+596608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+823315,int_stack+1176043,int_stack+665715, 2.0, int_stack+578550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+286473,int_stack+285689, 2.0, int_stack+597980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2352,int_stack+0,int_stack+1176043, 2.0, int_stack+1179193, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1176043,int_stack+2352,int_stack+823315, 2.0, int_stack+1180957, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+287481,int_stack+286473, 2.0, int_stack+599772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1688761,int_stack+823315,int_stack+0, 2.0, int_stack+1183477, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1180243,int_stack+1688761,int_stack+2352, 2.0, int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1180243,int_stack+1176043, 2.0, int_stack+1191856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1130575,int_stack+98214,int_stack+183264,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+291873,int_stack+289821, 2.0, int_stack+289281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+294645,int_stack+291873, 2.0, int_stack+291117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1191856,int_stack+184884,int_stack+183264, 2.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1176043,int_stack+296949,int_stack+294645, 2.0, int_stack+293637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1179067,int_stack+1176043,int_stack+184884, 2.0, int_stack+1196056, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+676255,int_stack+1179067,int_stack+1191856, 2.0, int_stack+1198324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1191856,int_stack+298245,int_stack+296949, 2.0, int_stack+295653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1688761,int_stack+1191856,int_stack+1176043, 2.0, int_stack+1201564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1191856,int_stack+1688761,int_stack+1179067, 2.0, int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1191856,int_stack+676255, 2.0, int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+221064,int_stack+1688761,int_stack+98214,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+300180,int_stack+299865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614920,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+300621,int_stack+300180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615235,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591190,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+301209,int_stack+300621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615676,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686083,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+301965,int_stack+301209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616264,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1204588,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708952,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+711598,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+303330,int_stack+302910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621010,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+303918,int_stack+303330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621430,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14256,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+304702,int_stack+303918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622018,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+714748,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716512,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+305710,int_stack+304702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622802,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653780,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1256140,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+676255,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1259668,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+239964,int_stack+98214,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+699691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+307510,int_stack+306970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368595,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+308266,int_stack+307510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369675,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+676255,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284343,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+679495,int_stack+309274,int_stack+308266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371187,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704416,int_stack+679495,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1285963,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+704416,int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288231,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+310570,int_stack+309274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373203,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1688761,int_stack+183264,int_stack+679495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1291471,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+1688761,int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1294495,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+676255,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299031,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+254139,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+735664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+312505,int_stack+312190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614920, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+312946,int_stack+312505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615235, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591190, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+313534,int_stack+312946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615676, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686083, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+314290,int_stack+313534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616264, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1204588, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708952, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+711598, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+315655,int_stack+315235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621010, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+316243,int_stack+315655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621430, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14256, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+317027,int_stack+316243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622018, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+714748, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716512, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+318035,int_stack+317027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622802, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653780, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1256140, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+676255,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1259668, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+273039,int_stack+98214,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+319835,int_stack+319295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368595, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+320591,int_stack+319835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369675, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+676255,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284343, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+679495,int_stack+321599,int_stack+320591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371187, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704416,int_stack+679495,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1285963, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+704416,int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288231, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+322895,int_stack+321599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373203, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1688761,int_stack+183264,int_stack+679495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1291471, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+1688761,int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1294495, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+676255,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299031, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+287214,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+845554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+324830,int_stack+324515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614920, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+325271,int_stack+324830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615235, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591190, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+325859,int_stack+325271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615676, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686083, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+326615,int_stack+325859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616264, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1204588, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708952, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+711598, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+327980,int_stack+327560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621010, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+328568,int_stack+327980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621430, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14256, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+329352,int_stack+328568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622018, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+714748, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716512, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+330360,int_stack+329352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622802, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1256140, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+676255,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1259668, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+306114,int_stack+98214,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+914647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+332160,int_stack+331620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368595, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+332916,int_stack+332160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369675, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+676255,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284343, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+679495,int_stack+333924,int_stack+332916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371187, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704416,int_stack+679495,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1285963, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+704416,int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288231, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+335220,int_stack+333924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373203, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1688761,int_stack+183264,int_stack+679495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1291471, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+1688761,int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1294495, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+676255,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299031, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1876411,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+933736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+337155,int_stack+336840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+337596,int_stack+337155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+591190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+338184,int_stack+337596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+615676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+686083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+338940,int_stack+338184, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+616264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1204588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+711598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+340305,int_stack+339885, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+340893,int_stack+340305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+665715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+341677,int_stack+340893, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+714748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+342685,int_stack+341677, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+622802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+653780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1256140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+676255,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1259668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+320289,int_stack+98214,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1002829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+344485,int_stack+343945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+368595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+345241,int_stack+344485, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+676255,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+679495,int_stack+346249,int_stack+345241, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704416,int_stack+679495,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1285963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+704416,int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+347545,int_stack+346249, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1688761,int_stack+183264,int_stack+679495, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1291471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+1688761,int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1294495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+676255,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1895311,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1021918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+349480,int_stack+349165, 0.0, zero_stack, 1.0, int_stack+614920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+349921,int_stack+349480, 0.0, zero_stack, 1.0, int_stack+615235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 1.0, int_stack+591190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+350509,int_stack+349921, 0.0, zero_stack, 1.0, int_stack+615676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 1.0, int_stack+686083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+351265,int_stack+350509, 0.0, zero_stack, 1.0, int_stack+616264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 1.0, int_stack+1204588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 1.0, int_stack+708952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 1.0, int_stack+711598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+352630,int_stack+352210, 0.0, zero_stack, 1.0, int_stack+621010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+353218,int_stack+352630, 0.0, zero_stack, 1.0, int_stack+621430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+665715, 0.0, zero_stack, 1.0, int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+354002,int_stack+353218, 0.0, zero_stack, 1.0, int_stack+622018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 1.0, int_stack+714748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 1.0, int_stack+716512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+355010,int_stack+354002, 0.0, zero_stack, 1.0, int_stack+622802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 1.0, int_stack+653780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+1256140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+676255,int_stack+1692289, 0.0, zero_stack, 1.0, int_stack+1259668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+334464,int_stack+98214,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1091011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+356810,int_stack+356270, 0.0, zero_stack, 1.0, int_stack+368595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+357566,int_stack+356810, 0.0, zero_stack, 1.0, int_stack+369675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+676255,int_stack+184884,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+1284343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+679495,int_stack+358574,int_stack+357566, 0.0, zero_stack, 1.0, int_stack+371187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704416,int_stack+679495,int_stack+184884, 0.0, zero_stack, 1.0, int_stack+1285963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+704416,int_stack+676255, 0.0, zero_stack, 1.0, int_stack+1288231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+359870,int_stack+358574, 0.0, zero_stack, 1.0, int_stack+373203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1688761,int_stack+183264,int_stack+679495, 0.0, zero_stack, 1.0, int_stack+1291471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+1688761,int_stack+704416, 0.0, zero_stack, 1.0, int_stack+1294495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+676255,int_stack+1227115, 0.0, zero_stack, 1.0, int_stack+1299031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1914211,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1110100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+361805,int_stack+361490, 1.0, int_stack+614920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+362246,int_stack+361805, 1.0, int_stack+615235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 1.0, int_stack+591190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+362834,int_stack+362246, 1.0, int_stack+615676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 1.0, int_stack+686083, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+363590,int_stack+362834, 1.0, int_stack+616264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 1.0, int_stack+1204588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 1.0, int_stack+708952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 1.0, int_stack+711598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+665715,int_stack+364955,int_stack+364535, 1.0, int_stack+621010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+365543,int_stack+364955, 1.0, int_stack+621430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+665715, 1.0, int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+366327,int_stack+365543, 1.0, int_stack+622018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 1.0, int_stack+714748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 1.0, int_stack+716512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+367335,int_stack+366327, 1.0, int_stack+622802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 1.0, int_stack+653780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+676255,int_stack+98214,int_stack+1688761, 1.0, int_stack+1256140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+676255,int_stack+1692289, 1.0, int_stack+1259668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+676255,int_stack+98214,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1187131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+370431,int_stack+369135, 1.0, int_stack+368595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+372195,int_stack+370431, 1.0, int_stack+369675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+690430,int_stack+184884,int_stack+183264, 1.0, int_stack+1284343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+693670,int_stack+374499,int_stack+372195, 1.0, int_stack+371187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1256140,int_stack+693670,int_stack+184884, 1.0, int_stack+1285963, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1256140,int_stack+690430, 1.0, int_stack+1288231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1284343,int_stack+375795,int_stack+374499, 1.0, int_stack+373203, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1688761,int_stack+1284343,int_stack+693670, 1.0, int_stack+1291471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1284343,int_stack+1688761,int_stack+1256140, 1.0, int_stack+1294495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1284343,int_stack+1227115, 1.0, int_stack+1299031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1284343,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1206640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+377730,int_stack+377415,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+378171,int_stack+377730,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+378759,int_stack+378171,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+379515,int_stack+378759,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+380880,int_stack+380460,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+381468,int_stack+380880,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+382252,int_stack+381468,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+383260,int_stack+382252,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+98214,int_stack+1688761,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1256140,int_stack+1692289,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+704416,int_stack+98214,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1251415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+385060,int_stack+384520,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+385816,int_stack+385060,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1256140,int_stack+184884,int_stack+183264,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1259380,int_stack+386824,int_stack+385816,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1259380,int_stack+184884,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1256140,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+388120,int_stack+386824,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+690430,int_stack+183264,int_stack+1259380,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+690430,int_stack+1688761,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1256140,int_stack+1227115,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+348639,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1263868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+390055,int_stack+389740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634350,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+390496,int_stack+390055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634665,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617020,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+391084,int_stack+390496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635106,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1304431,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1305754,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+391840,int_stack+391084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635694,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1307644,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9990,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331431,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+393205,int_stack+392785, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640440,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+393793,int_stack+393205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640860,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623810,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+394577,int_stack+393793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641448,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1334581,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336345,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+395585,int_stack+394577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642232,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1338865,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347244,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1256140,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350772,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+718591,int_stack+98214,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+699691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+397385,int_stack+396845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458470,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+398141,int_stack+397385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459550,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1256140,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1354972,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1259380,int_stack+399149,int_stack+398141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461062,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1259380,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1356592,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1256140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358860,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+400445,int_stack+399149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463078,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+690430,int_stack+183264,int_stack+1259380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1362100,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+690430,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386031,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1256140,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1390567,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+367539,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+735664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+402380,int_stack+402065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634350, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+402821,int_stack+402380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634665, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617020, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+403409,int_stack+402821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635106, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1304431, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1305754, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+404165,int_stack+403409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635694, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1307644, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9990, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331431, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+405530,int_stack+405110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640440, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+406118,int_stack+405530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640860, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623810, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+406902,int_stack+406118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641448, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1334581, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336345, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+407910,int_stack+406902, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642232, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1338865, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347244, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1256140,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350772, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1191856,int_stack+98214,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+826465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+409710,int_stack+409170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458470, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+410466,int_stack+409710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459550, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1256140,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1354972, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1259380,int_stack+411474,int_stack+410466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461062, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1259380,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1356592, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1256140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358860, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+412770,int_stack+411474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463078, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+690430,int_stack+183264,int_stack+1259380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1362100, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+690430,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386031, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1256140,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1390567, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+386439,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+845554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+414705,int_stack+414390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634350, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+415146,int_stack+414705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634665, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617020, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+415734,int_stack+415146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635106, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1304431, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1305754, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+416490,int_stack+415734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635694, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1307644, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9990, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331431, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+417855,int_stack+417435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640440, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+418443,int_stack+417855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640860, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623810, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+419227,int_stack+418443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1334581, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336345, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+420235,int_stack+419227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642232, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1338865, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347244, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1256140,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350772, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+405339,int_stack+98214,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+914647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+422035,int_stack+421495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458470, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+422791,int_stack+422035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459550, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1256140,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1354972, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1259380,int_stack+423799,int_stack+422791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461062, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1259380,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1356592, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1256140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358860, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+425095,int_stack+423799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463078, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+690430,int_stack+183264,int_stack+1259380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1362100, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+690430,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386031, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1256140,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1390567, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1933111,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+933736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+427030,int_stack+426715, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+427471,int_stack+427030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+634665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+428059,int_stack+427471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1304431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1305754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+428815,int_stack+428059, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1307644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+430180,int_stack+429760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+430768,int_stack+430180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+640860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+431552,int_stack+430768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1334581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+432560,int_stack+431552, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+642232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1338865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1256140,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1350772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+419514,int_stack+98214,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+1002829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+434360,int_stack+433820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+435116,int_stack+434360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1256140,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1354972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1259380,int_stack+436124,int_stack+435116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1259380,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1356592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1256140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+437420,int_stack+436124, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+463078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+690430,int_stack+183264,int_stack+1259380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1362100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+690430,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1386031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1256140,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1390567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1952011,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+1021918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+439355,int_stack+439040, 0.0, zero_stack, 1.0, int_stack+634350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+439796,int_stack+439355, 0.0, zero_stack, 1.0, int_stack+634665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 1.0, int_stack+617020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+440384,int_stack+439796, 0.0, zero_stack, 1.0, int_stack+635106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 1.0, int_stack+1304431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+1305754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+441140,int_stack+440384, 0.0, zero_stack, 1.0, int_stack+635694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 1.0, int_stack+1307644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 1.0, int_stack+9990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 1.0, int_stack+1331431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+442505,int_stack+442085, 0.0, zero_stack, 1.0, int_stack+640440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+443093,int_stack+442505, 0.0, zero_stack, 1.0, int_stack+640860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256, 0.0, zero_stack, 1.0, int_stack+623810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+443877,int_stack+443093, 0.0, zero_stack, 1.0, int_stack+641448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 1.0, int_stack+1334581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 1.0, int_stack+1336345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+444885,int_stack+443877, 0.0, zero_stack, 1.0, int_stack+642232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 1.0, int_stack+1338865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+1347244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1256140,int_stack+1692289, 0.0, zero_stack, 1.0, int_stack+1350772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1970911,int_stack+98214,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+1091011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+446685,int_stack+446145, 0.0, zero_stack, 1.0, int_stack+458470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+447441,int_stack+446685, 0.0, zero_stack, 1.0, int_stack+459550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1256140,int_stack+184884,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+1354972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1259380,int_stack+448449,int_stack+447441, 0.0, zero_stack, 1.0, int_stack+461062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1259380,int_stack+184884, 0.0, zero_stack, 1.0, int_stack+1356592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1256140, 0.0, zero_stack, 1.0, int_stack+1358860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+449745,int_stack+448449, 0.0, zero_stack, 1.0, int_stack+463078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+690430,int_stack+183264,int_stack+1259380, 0.0, zero_stack, 1.0, int_stack+1362100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1256140,int_stack+690430,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+1386031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1256140,int_stack+1227115, 0.0, zero_stack, 1.0, int_stack+1390567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1985086,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+1110100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+451680,int_stack+451365, 1.0, int_stack+634350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+452121,int_stack+451680, 1.0, int_stack+634665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 1.0, int_stack+617020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+452709,int_stack+452121, 1.0, int_stack+635106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 1.0, int_stack+1304431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 1.0, int_stack+1305754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+453465,int_stack+452709, 1.0, int_stack+635694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 1.0, int_stack+1307644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 1.0, int_stack+9990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 1.0, int_stack+1331431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+454830,int_stack+454410, 1.0, int_stack+640440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1331431,int_stack+455418,int_stack+454830, 1.0, int_stack+640860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+823315,int_stack+1331431,int_stack+14256, 1.0, int_stack+623810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1227115,int_stack+456202,int_stack+455418, 1.0, int_stack+641448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1227115,int_stack+1331431, 1.0, int_stack+1334581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1331431,int_stack+1688761,int_stack+823315, 1.0, int_stack+1336345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+457210,int_stack+456202, 1.0, int_stack+642232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1227115, 1.0, int_stack+1338865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1335631,int_stack+98214,int_stack+1688761, 1.0, int_stack+1347244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1335631,int_stack+1331431, 1.0, int_stack+1350772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+433689,int_stack+98214,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+1187131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+460306,int_stack+459010, 1.0, int_stack+458470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+462070,int_stack+460306, 1.0, int_stack+459550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1331431,int_stack+184884,int_stack+183264, 1.0, int_stack+1354972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1334671,int_stack+464374,int_stack+462070, 1.0, int_stack+461062, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1337695,int_stack+1334671,int_stack+184884, 1.0, int_stack+1356592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1337695,int_stack+1331431, 1.0, int_stack+1358860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+465670,int_stack+464374, 1.0, int_stack+463078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1347244,int_stack+183264,int_stack+1334671, 1.0, int_stack+1362100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1353292,int_stack+1347244,int_stack+1337695, 1.0, int_stack+1386031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1353292,int_stack+1227115, 1.0, int_stack+1390567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+447864,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+1206640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+467605,int_stack+467290,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+468046,int_stack+467605,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+468634,int_stack+468046,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+469390,int_stack+468634,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+470755,int_stack+470335,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+471343,int_stack+470755,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+472127,int_stack+471343,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+473135,int_stack+472127,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+98214,int_stack+1688761,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1386031,int_stack+1692289,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1347244,int_stack+98214,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+1251415, 1.0, int_stack+1342519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+474935,int_stack+474395,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+475691,int_stack+474935,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1386031,int_stack+184884,int_stack+183264,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1389271,int_stack+476699,int_stack+475691,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1389271,int_stack+184884,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1386031,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+477995,int_stack+476699,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1331431,int_stack+183264,int_stack+1389271,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+1331431,int_stack+1688761,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1386031,int_stack+1227115,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2003986,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+1263868, 1.0, int_stack+1365556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+479930,int_stack+479615,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+480371,int_stack+479930,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+480959,int_stack+480371,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+481715,int_stack+480959,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+483080,int_stack+482660,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+483668,int_stack+483080,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+484452,int_stack+483668,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+485460,int_stack+484452,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+98214,int_stack+1688761,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1386031,int_stack+1692289,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+466764,int_stack+98214,int_stack+183264, 0.0, zero_stack, 2.0, int_stack+1342519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+487260,int_stack+486720,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+488016,int_stack+487260,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1386031,int_stack+184884,int_stack+183264,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1389271,int_stack+489024,int_stack+488016,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1389271,int_stack+184884,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1386031,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+490320,int_stack+489024,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1331431,int_stack+183264,int_stack+1389271,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+1331431,int_stack+1688761,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1386031,int_stack+1227115,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+2022886,int_stack+1688761,int_stack+98214, 0.0, zero_stack, 2.0, int_stack+1365556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+495300,int_stack+494985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+656825,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+495741,int_stack+495300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657140,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+636450,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+496329,int_stack+495741, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657581,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1395967,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1397290,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+497085,int_stack+496329, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+658169,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1399180,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400944,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422967,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+502510,int_stack+502090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+662915,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+503098,int_stack+502510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663335,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643240,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+503882,int_stack+503098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663923,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1426117,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1427881,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+504890,int_stack+503882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+664707,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1430401,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1438780,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1386031,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1442308,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+480939,int_stack+98214,int_stack+183264, 1.0, int_stack+699691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+506690,int_stack+506150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606100,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+507446,int_stack+506690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607180,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1386031,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1389271,int_stack+508454,int_stack+507446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608692,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1389271,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232515,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1386031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1446508,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+509750,int_stack+508454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610708,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1331431,int_stack+183264,int_stack+1389271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449748,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+1331431,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477567,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1386031,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1482103,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+495114,int_stack+1688761,int_stack+98214, 1.0, int_stack+735664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+514730,int_stack+514415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+656825, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+515171,int_stack+514730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657140, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+636450, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+515759,int_stack+515171, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657581, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1395967, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+823315,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1397290, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+516515,int_stack+515759, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+658169, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1399180, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400944, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422967, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+521940,int_stack+521520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+662915, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+823315,int_stack+522528,int_stack+521940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663335, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+823315,int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643240, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+523312,int_stack+522528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663923, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+823315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1426117, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1427881, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+823315,int_stack+524320,int_stack+523312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+664707, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+823315,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1430401, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1438780, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1386031,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1442308, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2041786,int_stack+98214,int_stack+183264, 1.0, int_stack+826465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+526120,int_stack+525580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606100, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+526876,int_stack+526120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607180, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1386031,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1389271,int_stack+527884,int_stack+526876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608692, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1389271,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232515, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1386031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1446508, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+529180,int_stack+527884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610708, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+823315,int_stack+183264,int_stack+1389271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449748, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+823315,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477567, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1386031,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1482103, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+514014,int_stack+1688761,int_stack+98214, 1.0, int_stack+845554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+534160,int_stack+533845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+656825, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+534601,int_stack+534160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657140, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+636450, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+535189,int_stack+534601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657581, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1395967, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1087861,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1397290, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+535945,int_stack+535189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+658169, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1399180, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400944, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+1087861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422967, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+541370,int_stack+540950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+662915, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1087861,int_stack+541958,int_stack+541370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663335, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+1087861,int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643240, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+542742,int_stack+541958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663923, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+1087861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1426117, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1427881, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1087861,int_stack+543750,int_stack+542742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+664707, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+1087861,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1430401, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1438780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1386031,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1442308, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2055961,int_stack+98214,int_stack+183264, 1.0, int_stack+914647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+545550,int_stack+545010, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606100, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+546306,int_stack+545550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607180, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1386031,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1389271,int_stack+547314,int_stack+546306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608692, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1389271,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232515, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1386031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1446508, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+548610,int_stack+547314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610708, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+823315,int_stack+183264,int_stack+1389271, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449748, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+823315,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477567, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1386031,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1482103, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+532914,int_stack+1688761,int_stack+98214, 1.0, int_stack+933736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+553590,int_stack+553275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+656825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+554031,int_stack+553590, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+636450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+554619,int_stack+554031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+657581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1395967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1087861,int_stack+101868,int_stack+98214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1397290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+555375,int_stack+554619, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+658169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1399180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1400944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+1087861, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1422967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+560800,int_stack+560380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+662915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1087861,int_stack+561388,int_stack+560800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+1087861,int_stack+14256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+562172,int_stack+561388, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+663923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+1087861, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1426117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1427881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1087861,int_stack+563180,int_stack+562172, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+664707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+1087861,int_stack+1229635, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1430401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1438780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1386031,int_stack+1692289, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1442308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2070136,int_stack+98214,int_stack+183264, 1.0, int_stack+1002829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+564980,int_stack+564440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+565736,int_stack+564980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1386031,int_stack+184884,int_stack+183264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1389271,int_stack+566744,int_stack+565736, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+608692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1389271,int_stack+184884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1386031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1446508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+568040,int_stack+566744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+610708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+823315,int_stack+183264,int_stack+1389271, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+823315,int_stack+1688761, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1386031,int_stack+1227115, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1482103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+551814,int_stack+1688761,int_stack+98214, 1.0, int_stack+1021918, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+573020,int_stack+572705, 0.0, zero_stack, 1.0, int_stack+656825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+573461,int_stack+573020, 0.0, zero_stack, 1.0, int_stack+657140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 0.0, zero_stack, 1.0, int_stack+636450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+574049,int_stack+573461, 0.0, zero_stack, 1.0, int_stack+657581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 0.0, zero_stack, 1.0, int_stack+1395967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1087861,int_stack+101868,int_stack+98214, 0.0, zero_stack, 1.0, int_stack+1397290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+574805,int_stack+574049, 0.0, zero_stack, 1.0, int_stack+658169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1691029,int_stack+1688761,int_stack+100104, 0.0, zero_stack, 1.0, int_stack+1399180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1691029,int_stack+101868, 0.0, zero_stack, 1.0, int_stack+1400944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1227115,int_stack+1087861, 0.0, zero_stack, 1.0, int_stack+1422967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+580230,int_stack+579810, 0.0, zero_stack, 1.0, int_stack+662915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1087861,int_stack+580818,int_stack+580230, 0.0, zero_stack, 1.0, int_stack+663335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+1087861,int_stack+14256, 0.0, zero_stack, 1.0, int_stack+643240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1229635,int_stack+581602,int_stack+580818, 0.0, zero_stack, 1.0, int_stack+663923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1229635,int_stack+1087861, 0.0, zero_stack, 1.0, int_stack+1426117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1227115, 0.0, zero_stack, 1.0, int_stack+1427881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1087861,int_stack+582610,int_stack+581602, 0.0, zero_stack, 1.0, int_stack+664707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+1087861,int_stack+1229635, 0.0, zero_stack, 1.0, int_stack+1430401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+98214,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+1438780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1386031,int_stack+1692289, 0.0, zero_stack, 1.0, int_stack+1442308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+2084311,int_stack+98214,int_stack+183264, 1.0, int_stack+1091011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+584410,int_stack+583870, 0.0, zero_stack, 1.0, int_stack+606100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+585166,int_stack+584410, 0.0, zero_stack, 1.0, int_stack+607180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1386031,int_stack+184884,int_stack+183264, 0.0, zero_stack, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1389271,int_stack+586174,int_stack+585166, 0.0, zero_stack, 1.0, int_stack+608692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1389271,int_stack+184884, 0.0, zero_stack, 1.0, int_stack+1232515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1688761,int_stack+1386031, 0.0, zero_stack, 1.0, int_stack+1446508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+587470,int_stack+586174, 0.0, zero_stack, 1.0, int_stack+610708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1087861,int_stack+183264,int_stack+1389271, 0.0, zero_stack, 1.0, int_stack+1449748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1386031,int_stack+1087861,int_stack+1688761, 0.0, zero_stack, 1.0, int_stack+1477567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1386031,int_stack+1227115, 0.0, zero_stack, 1.0, int_stack+1482103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+570714,int_stack+1688761,int_stack+98214, 1.0, int_stack+1110100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+658925,int_stack+592450,int_stack+592135, 1.0, int_stack+656825, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+592891,int_stack+592450, 1.0, int_stack+657140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+98214,int_stack+29691,int_stack+658925, 1.0, int_stack+636450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+100104,int_stack+593479,int_stack+592891, 1.0, int_stack+657581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+101868,int_stack+100104,int_stack+29691, 1.0, int_stack+1395967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+101868,int_stack+98214, 1.0, int_stack+1397290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1691911,int_stack+594235,int_stack+593479, 1.0, int_stack+658169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1227115,int_stack+1691911,int_stack+100104, 1.0, int_stack+1399180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1691911,int_stack+1227115,int_stack+101868, 1.0, int_stack+1400944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1691911,int_stack+1688761, 1.0, int_stack+1422967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+14256,int_stack+602460,int_stack+602040, 1.0, int_stack+662915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1422967,int_stack+603048,int_stack+602460, 1.0, int_stack+663335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1688761,int_stack+1422967,int_stack+14256, 1.0, int_stack+643240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1691281,int_stack+603832,int_stack+603048, 1.0, int_stack+663923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1227115,int_stack+1691281,int_stack+1422967, 1.0, int_stack+1426117, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1422967,int_stack+1227115,int_stack+1688761, 1.0, int_stack+1427881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1427167,int_stack+604840,int_stack+603832, 1.0, int_stack+664707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+98214,int_stack+1427167,int_stack+1691281, 1.0, int_stack+1430401, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1427167,int_stack+98214,int_stack+1227115, 1.0, int_stack+1438780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1427167,int_stack+1422967, 1.0, int_stack+1442308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1386031,int_stack+98214,int_stack+183264, 1.0, int_stack+1187131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   d1hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+607936,int_stack+606640, 1.0, int_stack+606100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+609700,int_stack+607936, 1.0, int_stack+607180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gd) ---*/
   d1hrr3_build_gd(Libderiv->CD,int_stack+1422967,int_stack+184884,int_stack+183264, 1.0, int_stack+12636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1426207,int_stack+612004,int_stack+609700, 1.0, int_stack+608692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1429231,int_stack+1426207,int_stack+184884, 1.0, int_stack+1232515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gf) ---*/
   d1hrr3_build_gf(Libderiv->CD,int_stack+1438780,int_stack+1429231,int_stack+1422967, 1.0, int_stack+1446508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+613300,int_stack+612004, 1.0, int_stack+610708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1227115,int_stack+183264,int_stack+1426207, 1.0, int_stack+1449748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1444180,int_stack+1227115,int_stack+1429231, 1.0, int_stack+1477567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|gg) ---*/
   d1hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1444180,int_stack+1438780, 1.0, int_stack+1482103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+589614,int_stack+1688761,int_stack+98214, 1.0, int_stack+1206640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+98214,int_stack+618280,int_stack+617965,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+618721,int_stack+618280,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+99159,int_stack+29691,int_stack+98214,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+101049,int_stack+619309,int_stack+618721,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+101049,int_stack+29691,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1691407,int_stack+1688761,int_stack+99159,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+98214,int_stack+620065,int_stack+619309,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1438780,int_stack+98214,int_stack+101049,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+98214,int_stack+1438780,int_stack+1688761,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+98214,int_stack+1691407,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+98214,int_stack+625490,int_stack+625070,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+99474,int_stack+626078,int_stack+625490,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+101238,int_stack+99474,int_stack+98214,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1688761,int_stack+626862,int_stack+626078,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1691113,int_stack+1688761,int_stack+99474,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1438780,int_stack+1691113,int_stack+101238,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+98214,int_stack+627870,int_stack+626862,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1442980,int_stack+98214,int_stack+1688761,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+98214,int_stack+1442980,int_stack+1691113,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1442980,int_stack+98214,int_stack+1438780,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1176043,int_stack+1442980,int_stack+183264, 1.0, int_stack+1251415, 0.0, zero_stack, 1.0, int_stack+1434055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1251415,int_stack+629670,int_stack+629130,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1253035,int_stack+630426,int_stack+629670,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1255303,int_stack+1253035,int_stack+1251415,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1258543,int_stack+631434,int_stack+630426,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+183264,int_stack+1258543,int_stack+1253035,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+98214,int_stack+183264,int_stack+1255303,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1251415,int_stack+632730,int_stack+631434,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1449280,int_stack+1251415,int_stack+1258543,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1251415,int_stack+1449280,int_stack+183264,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1251415,int_stack+98214,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+608514,int_stack+1688761,int_stack+1442980, 1.0, int_stack+1263868, 0.0, zero_stack, 1.0, int_stack+1457092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1688761,int_stack+637710,int_stack+637395,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+638151,int_stack+637710,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1689706,int_stack+29691,int_stack+1688761,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1691596,int_stack+638739,int_stack+638151,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1693360,int_stack+1691596,int_stack+29691,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+98214,int_stack+1693360,int_stack+1689706,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+639495,int_stack+638739,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1251415,int_stack+1688761,int_stack+1691596,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+1251415,int_stack+1693360,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1688761,int_stack+98214,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+98214,int_stack+644920,int_stack+644500,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+99474,int_stack+645508,int_stack+644920,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+101238,int_stack+99474,int_stack+98214,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1688761,int_stack+646292,int_stack+645508,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1691113,int_stack+1688761,int_stack+99474,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1251415,int_stack+1691113,int_stack+101238,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+98214,int_stack+647300,int_stack+646292,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1255615,int_stack+98214,int_stack+1688761,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+98214,int_stack+1255615,int_stack+1691113,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1255615,int_stack+98214,int_stack+1251415,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1438780,int_stack+1255615,int_stack+183264, 1.0, int_stack+1342519, 1.0, int_stack+1434055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+649100,int_stack+648560,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+649856,int_stack+649100,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1251415,int_stack+184884,int_stack+183264,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+98214,int_stack+650864,int_stack+649856,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1261915,int_stack+98214,int_stack+184884,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1688761,int_stack+1261915,int_stack+1251415,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1251415,int_stack+652160,int_stack+650864,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1477567,int_stack+1251415,int_stack+98214,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1477567,int_stack+1261915,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1261915,int_stack+1227115,int_stack+1688761,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+627414,int_stack+1261915,int_stack+1255615, 1.0, int_stack+1365556, 1.0, int_stack+1457092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1688761,int_stack+660185,int_stack+659870,21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+29691,int_stack+660626,int_stack+660185,21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1689706,int_stack+29691,int_stack+1688761,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1691596,int_stack+661214,int_stack+660626,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1693360,int_stack+1691596,int_stack+29691,21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1227115,int_stack+1693360,int_stack+1689706,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1688761,int_stack+661970,int_stack+661214,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1230265,int_stack+1688761,int_stack+1691596,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1688761,int_stack+1230265,int_stack+1693360,21);
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+183264,int_stack+1688761,int_stack+1227115,21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+1227115,int_stack+667395,int_stack+666975,28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1228375,int_stack+667983,int_stack+667395,28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1230139,int_stack+1228375,int_stack+1227115,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1232659,int_stack+668767,int_stack+667983,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1232659,int_stack+1228375,28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1692289,int_stack+1688761,int_stack+1230139,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1227115,int_stack+669775,int_stack+668767,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1477567,int_stack+1227115,int_stack+1232659,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1477567,int_stack+1688761,28);
 /*--- compute (i0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+98214,int_stack+1227115,int_stack+1692289,28);
 /*--- compute (hp|gg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1251415,int_stack+98214,int_stack+183264, 2.0, int_stack+1434055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (k0|gp) ---*/
   hrr3_build_gp(Libderiv->CD,int_stack+183264,int_stack+671575,int_stack+671035,36);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+184884,int_stack+672331,int_stack+671575,36);
 /*--- compute (k0|gd) ---*/
   hrr3_build_gd(Libderiv->CD,int_stack+1227115,int_stack+184884,int_stack+183264,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1230355,int_stack+673339,int_stack+672331,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1688761,int_stack+1230355,int_stack+184884,36);
 /*--- compute (k0|gf) ---*/
   hrr3_build_gf(Libderiv->CD,int_stack+1477567,int_stack+1688761,int_stack+1227115,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+183264,int_stack+674635,int_stack+673339,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1422967,int_stack+183264,int_stack+1230355,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1227115,int_stack+1422967,int_stack+1688761,36);
 /*--- compute (k0|gg) ---*/
   hrr3_build_gg(Libderiv->CD,int_stack+1688761,int_stack+1227115,int_stack+1477567,36);
 /*--- compute (ip|gg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+646314,int_stack+1688761,int_stack+98214, 2.0, int_stack+1457092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2098486,int_stack+804415,int_stack+741964,225);
     Libderiv->ABCD[11] = int_stack + 2098486;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+793939,int_stack+892597,int_stack+851854,225);
     Libderiv->ABCD[10] = int_stack + 793939;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+884929,int_stack+980779,int_stack+940036,225);
     Libderiv->ABCD[9] = int_stack + 884929;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+973111,int_stack+1068961,int_stack+1028218,225);
     Libderiv->ABCD[8] = int_stack + 973111;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1061293,int_stack+1157143,int_stack+1116400,225);
     Libderiv->ABCD[7] = int_stack + 1061293;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1144750,int_stack+756139,int_stack+1212940,225);
     Libderiv->ABCD[6] = int_stack + 1144750;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2126836,int_stack+1312531,int_stack+1270168, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1237240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[2] = int_stack + 2126836;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1303243,int_stack+1404067,int_stack+1371856, 0.0, zero_stack, 1.0, int_stack+1237240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[1] = int_stack + 1303243;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1400206,int_stack+1509211,int_stack+1463392, 1.0, int_stack+1237240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[0] = int_stack + 1400206;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2155186,int_stack+1542286,int_stack+1528111,225);
     Libderiv->ABCD[155] = int_stack + 2155186;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1501678,int_stack+1561186,int_stack+1487503,225);
     Libderiv->ABCD[143] = int_stack + 1501678;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1530028,int_stack+1594261,int_stack+1580086,225);
     Libderiv->ABCD[142] = int_stack + 1530028;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1558378,int_stack+1613161,int_stack+31014,225);
     Libderiv->ABCD[131] = int_stack + 1558378;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1586728,int_stack+1632061,int_stack+55689,225);
     Libderiv->ABCD[130] = int_stack + 1586728;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+29691,int_stack+1650961,int_stack+15516,225);
     Libderiv->ABCD[129] = int_stack + 29691;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+0,int_stack+1669861,int_stack+69864,225);
     Libderiv->ABCD[119] = int_stack + 0;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1615078,int_stack+1696861,int_stack+84039,225);
     Libderiv->ABCD[118] = int_stack + 1615078;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+58041,int_stack+1715761,int_stack+104514,225);
     Libderiv->ABCD[117] = int_stack + 58041;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+86391,int_stack+1748836,int_stack+1734661,225);
     Libderiv->ABCD[116] = int_stack + 86391;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1643428,int_stack+1767736,int_stack+126564,225);
     Libderiv->ABCD[107] = int_stack + 1643428;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1671778,int_stack+1786636,int_stack+140739,225);
     Libderiv->ABCD[106] = int_stack + 1671778;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+114741,int_stack+1805536,int_stack+154914,225);
     Libderiv->ABCD[105] = int_stack + 114741;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1700128,int_stack+1824436,int_stack+169089,225);
     Libderiv->ABCD[104] = int_stack + 1700128;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+143091,int_stack+1857511,int_stack+1843336,225);
     Libderiv->ABCD[103] = int_stack + 143091;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1728478,int_stack+775039,int_stack+187989,225);
     Libderiv->ABCD[95] = int_stack + 1728478;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+756139,int_stack+202164,int_stack+831190,225);
     Libderiv->ABCD[94] = int_stack + 756139;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+171441,int_stack+866029,int_stack+919372,225);
     Libderiv->ABCD[93] = int_stack + 171441;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1756828,int_stack+954211,int_stack+1007554,225);
     Libderiv->ABCD[92] = int_stack + 1756828;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1785178,int_stack+1042393,int_stack+1095736,225);
     Libderiv->ABCD[91] = int_stack + 1785178;
 /*--- compute (hd|gg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1813528,int_stack+221064,int_stack+1130575,225);
     Libderiv->ABCD[90] = int_stack + 1813528;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+199791,int_stack+254139,int_stack+239964, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+741964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[47] = int_stack + 199791;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+228141,int_stack+287214,int_stack+273039, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+851854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[46] = int_stack + 228141;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+256491,int_stack+1876411,int_stack+306114, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+940036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[45] = int_stack + 256491;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+284841,int_stack+1895311,int_stack+320289, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1028218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[44] = int_stack + 284841;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1841878,int_stack+1914211,int_stack+334464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1116400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[43] = int_stack + 1841878;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+313191,int_stack+1284343,int_stack+676255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1212940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[42] = int_stack + 313191;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+665214,int_stack+348639,int_stack+704416, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1270168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[38] = int_stack + 665214;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1870228,int_stack+367539,int_stack+718591, 0.0, zero_stack, 1.0, int_stack+741964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[35] = int_stack + 1870228;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+341541,int_stack+386439,int_stack+1191856, 0.0, zero_stack, 1.0, int_stack+851854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[34] = int_stack + 341541;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+369891,int_stack+1933111,int_stack+405339, 0.0, zero_stack, 1.0, int_stack+940036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[33] = int_stack + 369891;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+693564,int_stack+1952011,int_stack+419514, 0.0, zero_stack, 1.0, int_stack+1028218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[32] = int_stack + 693564;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+398241,int_stack+1985086,int_stack+1970911, 0.0, zero_stack, 1.0, int_stack+1116400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[31] = int_stack + 398241;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1898578,int_stack+447864,int_stack+433689, 0.0, zero_stack, 1.0, int_stack+1212940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[30] = int_stack + 1898578;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+426591,int_stack+2003986,int_stack+1347244, 0.0, zero_stack, 1.0, int_stack+1270168, 1.0, int_stack+1371856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[26] = int_stack + 426591;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1331593,int_stack+2022886,int_stack+466764, 0.0, zero_stack, 2.0, int_stack+1371856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[25] = int_stack + 1331593;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1926928,int_stack+495114,int_stack+480939, 1.0, int_stack+741964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[23] = int_stack + 1926928;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+454941,int_stack+514014,int_stack+2041786, 1.0, int_stack+851854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[22] = int_stack + 454941;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+483291,int_stack+532914,int_stack+2055961, 1.0, int_stack+940036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[21] = int_stack + 483291;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+511641,int_stack+551814,int_stack+2070136, 1.0, int_stack+1028218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[20] = int_stack + 511641;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+539991,int_stack+570714,int_stack+2084311, 1.0, int_stack+1116400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[19] = int_stack + 539991;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1001461,int_stack+589614,int_stack+1386031, 1.0, int_stack+1212940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[18] = int_stack + 1001461;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+568341,int_stack+608514,int_stack+1176043, 1.0, int_stack+1270168, 0.0, zero_stack, 1.0, int_stack+1463392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[14] = int_stack + 568341;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+596691,int_stack+627414,int_stack+1438780, 1.0, int_stack+1371856, 1.0, int_stack+1463392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[13] = int_stack + 596691;
 /*--- compute (hd|gg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1265590,int_stack+646314,int_stack+1251415, 2.0, int_stack+1463392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,225);
     Libderiv->ABCD[12] = int_stack + 1265590;

}
