/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hdhd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hd|hd) integrals */

void d12hrr_order_hdhd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[7][7][11] = int_stack + 0;
 Libderiv->deriv_classes[7][7][10] = int_stack + 1296;
 Libderiv->deriv_classes[7][7][9] = int_stack + 2592;
 Libderiv->deriv_classes[7][7][8] = int_stack + 3888;
 Libderiv->deriv_classes[7][7][7] = int_stack + 5184;
 Libderiv->dvrr_classes[7][6] = int_stack + 6480;
 Libderiv->deriv_classes[7][7][6] = int_stack + 7488;
 Libderiv->deriv_classes[7][7][2] = int_stack + 8784;
 Libderiv->deriv_classes[7][7][1] = int_stack + 10080;
 Libderiv->dvrr_classes[6][7] = int_stack + 11376;
 Libderiv->deriv_classes[7][7][0] = int_stack + 12384;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 13680;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 14121;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 14709;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 15465;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 16053;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 16837;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 17845;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 18601;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 19609;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 20905;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 21346;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 21934;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 22690;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 23278;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 24062;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 25070;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 25826;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 26834;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 28130;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 28571;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 29159;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 29915;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 30503;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 31287;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 32295;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 33051;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 34059;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 35355;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 35796;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 36384;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 37140;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 37728;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 38512;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 39520;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 40276;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 41284;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 42580;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 43021;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 43609;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 44365;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 44953;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 45737;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 46745;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 47501;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 48509;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 49805;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 50246;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 50834;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 51590;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 52178;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 52962;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 53970;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 54726;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 55734;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 57030;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 57471;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 58059;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 58815;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 59403;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 60187;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 61195;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 61951;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 62959;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 64255;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 64696;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 65284;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 66040;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 66628;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 67412;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 68420;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 69176;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 70184;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 71480;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 71921;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 72509;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 73265;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 73853;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 74637;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 75645;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 76401;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 77409;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 78705;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 79146;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 79734;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 80490;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 81078;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 81862;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 82870;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 83626;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 84634;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 85930;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 86371;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 86959;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 87715;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 88303;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 89087;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 90095;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 90851;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 91859;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 93155;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 93596;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 94184;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 94940;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 95528;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 96312;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 97320;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 98076;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 99084;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 100380;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 100821;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 101409;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 102165;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 102753;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 103537;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 104545;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 105301;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 106309;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 107605;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 108046;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 108634;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 109390;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 109978;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 110762;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 111770;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 112526;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 113534;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 114830;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 115271;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 115859;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 116615;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 117203;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 117987;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 118995;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 119751;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 120759;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 122055;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 122496;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 123084;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 123840;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 124428;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 125212;
 Libderiv->deriv_classes[7][5][11] = int_stack + 126220;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 126976;
 Libderiv->deriv_classes[7][6][11] = int_stack + 127732;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 128740;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 129748;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 131044;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 131485;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 132073;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 132829;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 133417;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 134201;
 Libderiv->deriv_classes[7][5][10] = int_stack + 135209;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 135965;
 Libderiv->deriv_classes[7][6][10] = int_stack + 136721;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 137729;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 138737;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 140033;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 140474;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 141062;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 141818;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 142406;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 143190;
 Libderiv->deriv_classes[7][5][9] = int_stack + 144198;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 144954;
 Libderiv->deriv_classes[7][6][9] = int_stack + 145710;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 146718;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 147726;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 149022;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 149463;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 150051;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 150807;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 151395;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 152179;
 Libderiv->deriv_classes[7][5][8] = int_stack + 153187;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 153943;
 Libderiv->deriv_classes[7][6][8] = int_stack + 154699;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 155707;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 156715;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 158011;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 158452;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 159040;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 159796;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 160384;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 161168;
 Libderiv->deriv_classes[7][5][7] = int_stack + 162176;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 162932;
 Libderiv->deriv_classes[7][6][7] = int_stack + 163688;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 164696;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 165704;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 167000;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 167441;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 168029;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 168785;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 169373;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 170157;
 Libderiv->dvrr_classes[7][5] = int_stack + 171165;
 Libderiv->deriv_classes[7][5][6] = int_stack + 171921;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 172677;
 Libderiv->deriv_classes[7][6][6] = int_stack + 173433;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 174441;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 175449;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 176745;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 177186;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 177774;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 178530;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 179118;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 179902;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 180910;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 181666;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 182674;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 183970;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 184411;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 184999;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 185755;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 186343;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 187127;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 188135;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 188891;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 189899;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 191195;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 191636;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 192224;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 192980;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 193568;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 194352;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 195360;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 196116;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 197124;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 198420;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 198861;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 199449;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 200205;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 200793;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 201577;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 202585;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 203341;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 204349;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 205645;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 206086;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 206674;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 207430;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 208018;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 208802;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 209810;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 210566;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 211574;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 212870;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 213311;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 213899;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 214655;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 215243;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 216027;
 Libderiv->deriv_classes[7][5][2] = int_stack + 217035;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 217791;
 Libderiv->deriv_classes[7][6][2] = int_stack + 218547;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 219555;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 220563;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 221859;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 222300;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 222888;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 223644;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 224232;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 225016;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 226024;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 226780;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 227788;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 229084;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 229525;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 230113;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 230869;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 231457;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 232241;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 233249;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 234005;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 235013;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 236309;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 236750;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 237338;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 238094;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 238682;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 239466;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 240474;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 241230;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 242238;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 243534;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 243975;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 244563;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 245319;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 245907;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 246691;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 247699;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 248455;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 249463;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 250759;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 251200;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 251788;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 252544;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 253132;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 253916;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 254924;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 255680;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 256688;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 257984;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 258425;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 259013;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 259769;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 260357;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 261141;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 262149;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 262905;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 263913;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 265209;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 265650;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 266238;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 266994;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 267582;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 268366;
 Libderiv->deriv_classes[7][5][1] = int_stack + 269374;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 270130;
 Libderiv->deriv_classes[7][6][1] = int_stack + 270886;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 271894;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 272902;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 274198;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 274639;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 275227;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 275983;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 276571;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 277355;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 278363;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 279119;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 280127;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 281423;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 281864;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 282452;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 283208;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 283796;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 284580;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 285588;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 286344;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 287352;
 Libderiv->deriv_classes[5][5][11] = int_stack + 288648;
 Libderiv->deriv_classes[5][6][11] = int_stack + 289089;
 Libderiv->deriv_classes[5][7][11] = int_stack + 289677;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 290433;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 290874;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 291462;
 Libderiv->deriv_classes[6][5][11] = int_stack + 292218;
 Libderiv->deriv_classes[6][6][11] = int_stack + 292806;
 Libderiv->deriv_classes[6][7][11] = int_stack + 293590;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 294598;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 295186;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 295970;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 296978;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 297734;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 298742;
 Libderiv->deriv_classes[5][5][10] = int_stack + 300038;
 Libderiv->deriv_classes[5][6][10] = int_stack + 300479;
 Libderiv->deriv_classes[5][7][10] = int_stack + 301067;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 301823;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 302264;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 302852;
 Libderiv->deriv_classes[6][5][10] = int_stack + 303608;
 Libderiv->deriv_classes[6][6][10] = int_stack + 304196;
 Libderiv->deriv_classes[6][7][10] = int_stack + 304980;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 305988;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 306576;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 307360;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 308368;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 309124;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 310132;
 Libderiv->deriv_classes[5][5][9] = int_stack + 311428;
 Libderiv->deriv_classes[5][6][9] = int_stack + 311869;
 Libderiv->deriv_classes[5][7][9] = int_stack + 312457;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 313213;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 313654;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 314242;
 Libderiv->deriv_classes[6][5][9] = int_stack + 314998;
 Libderiv->deriv_classes[6][6][9] = int_stack + 315586;
 Libderiv->deriv_classes[6][7][9] = int_stack + 316370;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 317378;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 317966;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 318750;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 319758;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 320514;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 321522;
 Libderiv->deriv_classes[5][5][8] = int_stack + 322818;
 Libderiv->deriv_classes[5][6][8] = int_stack + 323259;
 Libderiv->deriv_classes[5][7][8] = int_stack + 323847;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 324603;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 325044;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 325632;
 Libderiv->deriv_classes[6][5][8] = int_stack + 326388;
 Libderiv->deriv_classes[6][6][8] = int_stack + 326976;
 Libderiv->deriv_classes[6][7][8] = int_stack + 327760;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 328768;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 329356;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 330140;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 331148;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 331904;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 332912;
 Libderiv->deriv_classes[5][5][7] = int_stack + 334208;
 Libderiv->deriv_classes[5][6][7] = int_stack + 334649;
 Libderiv->deriv_classes[5][7][7] = int_stack + 335237;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 335993;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 336434;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 337022;
 Libderiv->deriv_classes[6][5][7] = int_stack + 337778;
 Libderiv->deriv_classes[6][6][7] = int_stack + 338366;
 Libderiv->deriv_classes[6][7][7] = int_stack + 339150;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 340158;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 340746;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 341530;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 342538;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 343294;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 344302;
 Libderiv->deriv_classes[5][5][6] = int_stack + 345598;
 Libderiv->deriv_classes[5][6][6] = int_stack + 346039;
 Libderiv->deriv_classes[5][7][6] = int_stack + 346627;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 347383;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 347824;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 348412;
 Libderiv->dvrr_classes[6][5] = int_stack + 349168;
 Libderiv->deriv_classes[6][5][6] = int_stack + 349756;
 Libderiv->dvrr_classes[6][6] = int_stack + 350344;
 Libderiv->deriv_classes[6][6][6] = int_stack + 351128;
 Libderiv->deriv_classes[6][7][6] = int_stack + 351912;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 352920;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 353508;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 354292;
 Libderiv->deriv_classes[7][5][0] = int_stack + 355300;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 356056;
 Libderiv->deriv_classes[7][6][0] = int_stack + 356812;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 357820;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 358828;
 Libderiv->deriv_classes[5][5][2] = int_stack + 360124;
 Libderiv->deriv_classes[5][6][2] = int_stack + 360565;
 Libderiv->deriv_classes[5][7][2] = int_stack + 361153;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 361909;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 362350;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 362938;
 Libderiv->deriv_classes[6][5][2] = int_stack + 363694;
 Libderiv->deriv_classes[6][6][2] = int_stack + 364282;
 Libderiv->deriv_classes[6][7][2] = int_stack + 365066;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 366074;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 366662;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 367446;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 368454;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 369210;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 370218;
 Libderiv->deriv_classes[5][5][1] = int_stack + 371514;
 Libderiv->deriv_classes[5][6][1] = int_stack + 371955;
 Libderiv->deriv_classes[5][7][1] = int_stack + 372543;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 373299;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 373740;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 374328;
 Libderiv->deriv_classes[6][5][1] = int_stack + 375084;
 Libderiv->deriv_classes[6][6][1] = int_stack + 375672;
 Libderiv->deriv_classes[6][7][1] = int_stack + 376456;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 377464;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 378052;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 378836;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 379844;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 380600;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 381608;
 Libderiv->dvrr_classes[5][5] = int_stack + 382904;
 Libderiv->dvrr_classes[5][6] = int_stack + 383345;
 Libderiv->dvrr_classes[5][7] = int_stack + 383933;
 Libderiv->deriv_classes[5][5][0] = int_stack + 384689;
 Libderiv->deriv_classes[5][6][0] = int_stack + 385130;
 Libderiv->deriv_classes[5][7][0] = int_stack + 385718;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 386474;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 386915;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 387503;
 Libderiv->deriv_classes[6][5][0] = int_stack + 388259;
 Libderiv->deriv_classes[6][6][0] = int_stack + 388847;
 Libderiv->deriv_classes[6][7][0] = int_stack + 389631;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 390639;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 391227;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 392011;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 393019;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 393775;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 394783;
 memset(int_stack,0,3168632);

 Libderiv->dvrr_stack = int_stack + 1151407;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hdhd(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+396079,int_stack+383345,int_stack+382904,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+289089,int_stack+288648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382904,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+398725,int_stack+289677,int_stack+289089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383345,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+400489,int_stack+398725,int_stack+397402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396079,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+398725,int_stack+350344,int_stack+349168,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+292806,int_stack+292218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349168,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+404899,int_stack+293590,int_stack+292806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+350344,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+407251,int_stack+404899,int_stack+403135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398725,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+410779,int_stack+407251,int_stack+400489,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+404899,int_stack+6480,int_stack+171165,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+418717,int_stack+127732,int_stack+126220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171165,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+420985,int_stack+0,int_stack+127732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+424009,int_stack+420985,int_stack+418717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404899,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+428545,int_stack+424009,int_stack+407251,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+420985,int_stack+300479,int_stack+300038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382904, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+422308,int_stack+301067,int_stack+300479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383345, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+424072,int_stack+422308,int_stack+420985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396079, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+422308,int_stack+304196,int_stack+303608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349168, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+439129,int_stack+304980,int_stack+304196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+350344, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+441481,int_stack+439129,int_stack+422308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398725, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+445009,int_stack+441481,int_stack+424072,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+439129,int_stack+136721,int_stack+135209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171165, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+452947,int_stack+1296,int_stack+136721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+455971,int_stack+452947,int_stack+439129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404899, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+460507,int_stack+455971,int_stack+441481,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+452947,int_stack+311869,int_stack+311428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382904, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+454270,int_stack+312457,int_stack+311869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383345, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+456034,int_stack+454270,int_stack+452947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396079, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+454270,int_stack+315586,int_stack+314998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349168, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+316370,int_stack+315586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+350344, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+471091,int_stack+0,int_stack+454270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398725, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+474619,int_stack+471091,int_stack+456034,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+145710,int_stack+144198, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171165, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+482557,int_stack+2592,int_stack+145710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+485581,int_stack+482557,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404899, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+490117,int_stack+485581,int_stack+471091,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+482557,int_stack+323259,int_stack+322818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+483880,int_stack+323847,int_stack+323259, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+383345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+485644,int_stack+483880,int_stack+482557, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+483880,int_stack+326976,int_stack+326388, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+500701,int_stack+327760,int_stack+326976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+350344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+503053,int_stack+500701,int_stack+483880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+506581,int_stack+503053,int_stack+485644,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+500701,int_stack+154699,int_stack+153187, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+514519,int_stack+3888,int_stack+154699, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+517543,int_stack+514519,int_stack+500701, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+522079,int_stack+517543,int_stack+503053,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+514519,int_stack+334649,int_stack+334208, 0.0, zero_stack, 1.0, int_stack+382904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+515842,int_stack+335237,int_stack+334649, 0.0, zero_stack, 1.0, int_stack+383345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+517606,int_stack+515842,int_stack+514519, 0.0, zero_stack, 1.0, int_stack+396079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+515842,int_stack+338366,int_stack+337778, 0.0, zero_stack, 1.0, int_stack+349168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+339150,int_stack+338366, 0.0, zero_stack, 1.0, int_stack+350344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+532663,int_stack+2268,int_stack+515842, 0.0, zero_stack, 1.0, int_stack+398725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+536191,int_stack+532663,int_stack+517606,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2268,int_stack+163688,int_stack+162176, 0.0, zero_stack, 1.0, int_stack+171165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+544129,int_stack+5184,int_stack+163688, 0.0, zero_stack, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+547153,int_stack+544129,int_stack+2268, 0.0, zero_stack, 1.0, int_stack+404899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+551689,int_stack+547153,int_stack+532663,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+544129,int_stack+346039,int_stack+345598, 1.0, int_stack+382904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+545452,int_stack+346627,int_stack+346039, 1.0, int_stack+383345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+547216,int_stack+545452,int_stack+544129, 1.0, int_stack+396079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+545452,int_stack+351128,int_stack+349756, 1.0, int_stack+349168, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+351912,int_stack+351128, 1.0, int_stack+350344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+564625,int_stack+562273,int_stack+545452, 1.0, int_stack+398725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+568153,int_stack+564625,int_stack+547216,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+562273,int_stack+173433,int_stack+171921, 1.0, int_stack+171165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+576091,int_stack+7488,int_stack+173433, 1.0, int_stack+6480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+579115,int_stack+576091,int_stack+562273, 1.0, int_stack+404899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+583651,int_stack+579115,int_stack+564625,126);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+404899,int_stack+383933,int_stack+383345,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+576091,int_stack+404899,int_stack+396079,21);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+404899,int_stack+11376,int_stack+350344,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+578737,int_stack+404899,int_stack+398725,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+594235,int_stack+578737,int_stack+576091,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+396079,int_stack+360565,int_stack+360124,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+398725,int_stack+361153,int_stack+360565,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+4536,int_stack+398725,int_stack+396079,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+398725,int_stack+364282,int_stack+363694,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+404899,int_stack+365066,int_stack+364282,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+602173,int_stack+404899,int_stack+398725,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+605701,int_stack+602173,int_stack+4536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+404899,int_stack+218547,int_stack+217035,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+613639,int_stack+8784,int_stack+218547,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+616663,int_stack+613639,int_stack+404899,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+621199,int_stack+616663,int_stack+602173, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+613639,int_stack+371955,int_stack+371514,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+614962,int_stack+372543,int_stack+371955,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+616726,int_stack+614962,int_stack+613639,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+614962,int_stack+375672,int_stack+375084,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+376456,int_stack+375672,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+631783,int_stack+7182,int_stack+614962,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+635311,int_stack+631783,int_stack+616726, 0.0, zero_stack, 1.0, int_stack+576091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+270886,int_stack+269374,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+643249,int_stack+10080,int_stack+270886,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+646273,int_stack+643249,int_stack+7182,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+650809,int_stack+646273,int_stack+631783, 0.0, zero_stack, 1.0, int_stack+578737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+643249,int_stack+385130,int_stack+384689,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+644572,int_stack+385718,int_stack+385130,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+646336,int_stack+644572,int_stack+643249,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+644572,int_stack+388847,int_stack+388259,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9450,int_stack+389631,int_stack+388847,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+661393,int_stack+9450,int_stack+644572,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+664921,int_stack+661393,int_stack+646336, 1.0, int_stack+576091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+576091,int_stack+356812,int_stack+355300,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+672859,int_stack+12384,int_stack+356812,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+675883,int_stack+672859,int_stack+576091,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+680419,int_stack+675883,int_stack+661393, 1.0, int_stack+578737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+672859,int_stack+14121,int_stack+13680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+288648,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+674182,int_stack+14709,int_stack+14121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+289089,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+675946,int_stack+674182,int_stack+672859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+397402,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+672859,int_stack+16053,int_stack+15465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+292218,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+578359,int_stack+16837,int_stack+16053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+292806,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+578359,int_stack+672859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+403135,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+691003,int_stack+9450,int_stack+675946,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+672859,int_stack+18601,int_stack+17845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+126220,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+675127,int_stack+19609,int_stack+18601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+127732,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+675127,int_stack+672859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+418717,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+698941,int_stack+578359,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+21346,int_stack+20905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288648, 1.0, int_stack+300038,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+21934,int_stack+21346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289089, 1.0, int_stack+300479,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12537,int_stack+10773,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397402, 1.0, int_stack+420985,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+23278,int_stack+22690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292218, 1.0, int_stack+303608,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15183,int_stack+24062,int_stack+23278, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292806, 1.0, int_stack+304196,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17535,int_stack+15183,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403135, 1.0, int_stack+422308,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+709525,int_stack+17535,int_stack+12537,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+25826,int_stack+25070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126220, 1.0, int_stack+135209,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11718,int_stack+26834,int_stack+25826, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127732, 1.0, int_stack+136721,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+21063,int_stack+11718,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418717, 1.0, int_stack+439129,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+717463,int_stack+21063,int_stack+17535,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+28571,int_stack+28130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+300038, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+29159,int_stack+28571, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+300479, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12537,int_stack+10773,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+420985, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+30503,int_stack+29915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+303608, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15183,int_stack+31287,int_stack+30503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+304196, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17535,int_stack+15183,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+422308, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+21063,int_stack+17535,int_stack+12537,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+33051,int_stack+32295, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+135209, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+11718,int_stack+34059,int_stack+33051, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+136721, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29001,int_stack+11718,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+439129, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+728047,int_stack+29001,int_stack+17535,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+35796,int_stack+35355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288648, 0.0, zero_stack, 1.0, int_stack+311428,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30324,int_stack+36384,int_stack+35796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289089, 0.0, zero_stack, 1.0, int_stack+311869,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32088,int_stack+30324,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397402, 0.0, zero_stack, 1.0, int_stack+452947,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+37728,int_stack+37140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292218, 0.0, zero_stack, 1.0, int_stack+314998,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34734,int_stack+38512,int_stack+37728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292806, 0.0, zero_stack, 1.0, int_stack+315586,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+34734,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403135, 0.0, zero_stack, 1.0, int_stack+454270,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+12978,int_stack+9450,int_stack+32088,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+40276,int_stack+39520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126220, 0.0, zero_stack, 1.0, int_stack+144198,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31269,int_stack+41284,int_stack+40276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127732, 0.0, zero_stack, 1.0, int_stack+145710,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+34293,int_stack+31269,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418717, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+738631,int_stack+34293,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+43021,int_stack+42580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300038, 1.0, int_stack+311428, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+43609,int_stack+43021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300479, 1.0, int_stack+311869, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29001,int_stack+10773,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420985, 1.0, int_stack+452947, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+44953,int_stack+44365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303608, 1.0, int_stack+314998, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31647,int_stack+45737,int_stack+44953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304196, 1.0, int_stack+315586, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+33999,int_stack+31647,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422308, 1.0, int_stack+454270, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+37527,int_stack+33999,int_stack+29001,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+47501,int_stack+46745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135209, 1.0, int_stack+144198, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9450,int_stack+48509,int_stack+47501, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136721, 1.0, int_stack+145710, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+9450,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+439129, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+749215,int_stack+578359,int_stack+33999,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+578359,int_stack+50246,int_stack+49805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+311428, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+579682,int_stack+50834,int_stack+50246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+311869, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29001,int_stack+579682,int_stack+578359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+452947, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+578359,int_stack+52178,int_stack+51590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+314998, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+580123,int_stack+52962,int_stack+52178, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+315586, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+580123,int_stack+578359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+454270, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+45465,int_stack+9450,int_stack+29001,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+54726,int_stack+53970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+144198, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31269,int_stack+55734,int_stack+54726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+145710, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+31269,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+759799,int_stack+578359,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+57471,int_stack+57030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322818,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+58059,int_stack+57471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+323259,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+10773,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397402, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482557,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+59403,int_stack+58815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+326388,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+581005,int_stack+60187,int_stack+59403, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292806, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+326976,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29001,int_stack+581005,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+403135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483880,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+770383,int_stack+29001,int_stack+578359,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+578359,int_stack+61951,int_stack+61195, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+126220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+153187,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+580627,int_stack+62959,int_stack+61951, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+127732, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+154699,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32529,int_stack+580627,int_stack+578359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+418717, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500701,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+53403,int_stack+32529,int_stack+29001,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+64696,int_stack+64255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300038, 0.0, zero_stack, 1.0, int_stack+322818, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30324,int_stack+65284,int_stack+64696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300479, 0.0, zero_stack, 1.0, int_stack+323259, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32088,int_stack+30324,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+420985, 0.0, zero_stack, 1.0, int_stack+482557, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+66628,int_stack+66040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303608, 0.0, zero_stack, 1.0, int_stack+326388, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34734,int_stack+67412,int_stack+66628, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304196, 0.0, zero_stack, 1.0, int_stack+326976, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+34734,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+422308, 0.0, zero_stack, 1.0, int_stack+483880, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+778321,int_stack+9450,int_stack+32088,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+69176,int_stack+68420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+135209, 0.0, zero_stack, 1.0, int_stack+153187, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31269,int_stack+70184,int_stack+69176, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+136721, 0.0, zero_stack, 1.0, int_stack+154699, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+31269,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+439129, 0.0, zero_stack, 1.0, int_stack+500701, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+786259,int_stack+578359,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+71921,int_stack+71480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311428, 1.0, int_stack+322818, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+72509,int_stack+71921, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311869, 1.0, int_stack+323259, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+10773,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452947, 1.0, int_stack+482557, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+73853,int_stack+73265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+314998, 1.0, int_stack+326388, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+581005,int_stack+74637,int_stack+73853, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315586, 1.0, int_stack+326976, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29001,int_stack+581005,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+454270, 1.0, int_stack+483880, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+63987,int_stack+29001,int_stack+578359,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+578359,int_stack+76401,int_stack+75645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+144198, 1.0, int_stack+153187, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+580627,int_stack+77409,int_stack+76401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145710, 1.0, int_stack+154699, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32529,int_stack+580627,int_stack+578359, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+500701, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+796843,int_stack+32529,int_stack+29001,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+79146,int_stack+78705, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+322818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30324,int_stack+79734,int_stack+79146, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+323259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32088,int_stack+30324,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+482557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+81078,int_stack+80490, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+326388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34734,int_stack+81862,int_stack+81078, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+326976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+34734,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+483880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+71925,int_stack+9450,int_stack+32088,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+83626,int_stack+82870, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+153187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31269,int_stack+84634,int_stack+83626, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+154699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+31269,int_stack+29001, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+500701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+807427,int_stack+578359,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+86371,int_stack+85930, 0.0, zero_stack, 1.0, int_stack+288648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334208,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+86959,int_stack+86371, 0.0, zero_stack, 1.0, int_stack+289089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334649,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+10773,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+397402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+514519,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+88303,int_stack+87715, 0.0, zero_stack, 1.0, int_stack+292218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337778,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+581005,int_stack+89087,int_stack+88303, 0.0, zero_stack, 1.0, int_stack+292806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338366,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29001,int_stack+581005,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+403135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515842,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+79863,int_stack+29001,int_stack+578359,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+578359,int_stack+90851,int_stack+90095, 0.0, zero_stack, 1.0, int_stack+126220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162176,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+580627,int_stack+91859,int_stack+90851, 0.0, zero_stack, 1.0, int_stack+127732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163688,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32529,int_stack+580627,int_stack+578359, 0.0, zero_stack, 1.0, int_stack+418717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+818011,int_stack+32529,int_stack+29001,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+93596,int_stack+93155, 0.0, zero_stack, 1.0, int_stack+300038, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334208, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30324,int_stack+94184,int_stack+93596, 0.0, zero_stack, 1.0, int_stack+300479, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334649, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32088,int_stack+30324,int_stack+29001, 0.0, zero_stack, 1.0, int_stack+420985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+514519, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+95528,int_stack+94940, 0.0, zero_stack, 1.0, int_stack+303608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337778, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34734,int_stack+96312,int_stack+95528, 0.0, zero_stack, 1.0, int_stack+304196, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338366, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+34734,int_stack+29001, 0.0, zero_stack, 1.0, int_stack+422308, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+515842, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+87801,int_stack+9450,int_stack+32088,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+98076,int_stack+97320, 0.0, zero_stack, 1.0, int_stack+135209, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+162176, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31269,int_stack+99084,int_stack+98076, 0.0, zero_stack, 1.0, int_stack+136721, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163688, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+31269,int_stack+29001, 0.0, zero_stack, 1.0, int_stack+439129, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+828595,int_stack+578359,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+100821,int_stack+100380, 0.0, zero_stack, 1.0, int_stack+311428, 0.0, zero_stack, 1.0, int_stack+334208, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+101409,int_stack+100821, 0.0, zero_stack, 1.0, int_stack+311869, 0.0, zero_stack, 1.0, int_stack+334649, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+10773,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+452947, 0.0, zero_stack, 1.0, int_stack+514519, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+102753,int_stack+102165, 0.0, zero_stack, 1.0, int_stack+314998, 0.0, zero_stack, 1.0, int_stack+337778, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+581005,int_stack+103537,int_stack+102753, 0.0, zero_stack, 1.0, int_stack+315586, 0.0, zero_stack, 1.0, int_stack+338366, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29001,int_stack+581005,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+454270, 0.0, zero_stack, 1.0, int_stack+515842, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+95739,int_stack+29001,int_stack+578359,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+578359,int_stack+105301,int_stack+104545, 0.0, zero_stack, 1.0, int_stack+144198, 0.0, zero_stack, 1.0, int_stack+162176, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+580627,int_stack+106309,int_stack+105301, 0.0, zero_stack, 1.0, int_stack+145710, 0.0, zero_stack, 1.0, int_stack+163688, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32529,int_stack+580627,int_stack+578359, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+839179,int_stack+32529,int_stack+29001,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+108046,int_stack+107605, 0.0, zero_stack, 1.0, int_stack+322818, 1.0, int_stack+334208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30324,int_stack+108634,int_stack+108046, 0.0, zero_stack, 1.0, int_stack+323259, 1.0, int_stack+334649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32088,int_stack+30324,int_stack+29001, 0.0, zero_stack, 1.0, int_stack+482557, 1.0, int_stack+514519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+109978,int_stack+109390, 0.0, zero_stack, 1.0, int_stack+326388, 1.0, int_stack+337778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34734,int_stack+110762,int_stack+109978, 0.0, zero_stack, 1.0, int_stack+326976, 1.0, int_stack+338366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+34734,int_stack+29001, 0.0, zero_stack, 1.0, int_stack+483880, 1.0, int_stack+515842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+103677,int_stack+9450,int_stack+32088,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+112526,int_stack+111770, 0.0, zero_stack, 1.0, int_stack+153187, 1.0, int_stack+162176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31269,int_stack+113534,int_stack+112526, 0.0, zero_stack, 1.0, int_stack+154699, 1.0, int_stack+163688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+31269,int_stack+29001, 0.0, zero_stack, 1.0, int_stack+500701, 1.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+849763,int_stack+578359,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+115271,int_stack+114830, 0.0, zero_stack, 2.0, int_stack+334208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+115859,int_stack+115271, 0.0, zero_stack, 2.0, int_stack+334649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+10773,int_stack+9450, 0.0, zero_stack, 2.0, int_stack+514519, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+117203,int_stack+116615, 0.0, zero_stack, 2.0, int_stack+337778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+581005,int_stack+117987,int_stack+117203, 0.0, zero_stack, 2.0, int_stack+338366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29001,int_stack+581005,int_stack+9450, 0.0, zero_stack, 2.0, int_stack+515842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+860347,int_stack+29001,int_stack+578359,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+578359,int_stack+119751,int_stack+118995, 0.0, zero_stack, 2.0, int_stack+162176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+580627,int_stack+120759,int_stack+119751, 0.0, zero_stack, 2.0, int_stack+163688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32529,int_stack+580627,int_stack+578359, 0.0, zero_stack, 2.0, int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+868285,int_stack+32529,int_stack+29001,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+122496,int_stack+122055, 1.0, int_stack+288648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345598,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+30324,int_stack+123084,int_stack+122496, 1.0, int_stack+289089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346039,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32088,int_stack+30324,int_stack+29001, 1.0, int_stack+397402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544129,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+124428,int_stack+123840, 1.0, int_stack+292218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349756,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+34734,int_stack+125212,int_stack+124428, 1.0, int_stack+292806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+351128,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+34734,int_stack+29001, 1.0, int_stack+403135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545452,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+111615,int_stack+9450,int_stack+32088,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+29001,int_stack+128740,int_stack+126976, 1.0, int_stack+126220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171921,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+31269,int_stack+129748,int_stack+128740, 1.0, int_stack+127732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173433,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+578359,int_stack+31269,int_stack+29001, 1.0, int_stack+418717, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562273,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+119553,int_stack+578359,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+131485,int_stack+131044, 1.0, int_stack+300038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345598, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+132073,int_stack+131485, 1.0, int_stack+300479, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346039, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+403135,int_stack+397402, 1.0, int_stack+420985, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544129, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+133417,int_stack+132829, 1.0, int_stack+303608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349756, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+578359,int_stack+134201,int_stack+133417, 1.0, int_stack+304196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+351128, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+418717,int_stack+578359,int_stack+403135, 1.0, int_stack+422308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545452, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+29001,int_stack+418717,int_stack+9450,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+137729,int_stack+135965, 1.0, int_stack+135209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171921, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+578359,int_stack+138737,int_stack+137729, 1.0, int_stack+136721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173433, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+130137,int_stack+578359,int_stack+9450, 1.0, int_stack+439129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562273, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+878869,int_stack+130137,int_stack+418717,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+140474,int_stack+140033, 1.0, int_stack+311428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345598, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+141062,int_stack+140474, 1.0, int_stack+311869, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346039, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+418717,int_stack+403135,int_stack+397402, 1.0, int_stack+452947, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544129, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+142406,int_stack+141818, 1.0, int_stack+314998, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+349756, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+439129,int_stack+143190,int_stack+142406, 1.0, int_stack+315586, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+351128, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+439129,int_stack+403135, 1.0, int_stack+454270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+545452, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+130137,int_stack+9450,int_stack+418717,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+418717,int_stack+146718,int_stack+144954, 1.0, int_stack+144198, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+171921, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+420985,int_stack+147726,int_stack+146718, 1.0, int_stack+145710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173433, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+420985,int_stack+418717, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+562273, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+889453,int_stack+138075,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+149463,int_stack+149022, 1.0, int_stack+322818, 0.0, zero_stack, 1.0, int_stack+345598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+150051,int_stack+149463, 1.0, int_stack+323259, 0.0, zero_stack, 1.0, int_stack+346039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+403135,int_stack+397402, 1.0, int_stack+482557, 0.0, zero_stack, 1.0, int_stack+544129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+151395,int_stack+150807, 1.0, int_stack+326388, 0.0, zero_stack, 1.0, int_stack+349756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+439129,int_stack+152179,int_stack+151395, 1.0, int_stack+326976, 0.0, zero_stack, 1.0, int_stack+351128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+439129,int_stack+403135, 1.0, int_stack+483880, 0.0, zero_stack, 1.0, int_stack+545452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+141603,int_stack+138075,int_stack+9450,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+155707,int_stack+153943, 1.0, int_stack+153187, 0.0, zero_stack, 1.0, int_stack+171921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9450,int_stack+156715,int_stack+155707, 1.0, int_stack+154699, 0.0, zero_stack, 1.0, int_stack+173433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+149541,int_stack+9450,int_stack+0, 1.0, int_stack+500701, 0.0, zero_stack, 1.0, int_stack+562273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+900037,int_stack+149541,int_stack+138075,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+158452,int_stack+158011, 1.0, int_stack+334208, 1.0, int_stack+345598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+159040,int_stack+158452, 1.0, int_stack+334649, 1.0, int_stack+346039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+403135,int_stack+397402, 1.0, int_stack+514519, 1.0, int_stack+544129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+160384,int_stack+159796, 1.0, int_stack+337778, 1.0, int_stack+349756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+500701,int_stack+161168,int_stack+160384, 1.0, int_stack+338366, 1.0, int_stack+351128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+500701,int_stack+403135, 1.0, int_stack+515842, 1.0, int_stack+545452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+149541,int_stack+9450,int_stack+138075,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+164696,int_stack+162932, 1.0, int_stack+162176, 1.0, int_stack+171921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+138075,int_stack+165704,int_stack+164696, 1.0, int_stack+163688, 1.0, int_stack+173433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+157479,int_stack+138075,int_stack+0, 1.0, int_stack+2268, 1.0, int_stack+562273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+910621,int_stack+157479,int_stack+9450,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+167441,int_stack+167000, 2.0, int_stack+345598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+168029,int_stack+167441, 2.0, int_stack+346039, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+403135,int_stack+397402, 2.0, int_stack+544129, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+169373,int_stack+168785, 2.0, int_stack+349756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+500701,int_stack+170157,int_stack+169373, 2.0, int_stack+351128, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+500701,int_stack+403135, 2.0, int_stack+545452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+157479,int_stack+138075,int_stack+9450,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+174441,int_stack+172677, 2.0, int_stack+171921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+544129,int_stack+175449,int_stack+174441, 2.0, int_stack+173433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+544129,int_stack+9450, 2.0, int_stack+562273, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+165417,int_stack+0,int_stack+138075,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+177186,int_stack+176745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360124,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+177774,int_stack+177186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360565,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+403135,int_stack+397402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396079,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+179118,int_stack+178530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363694,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+179902,int_stack+179118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364282,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+562273,int_stack+403135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398725,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+921205,int_stack+9450,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+181666,int_stack+180910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217035,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+182674,int_stack+181666, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218547,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+176001,int_stack+0,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404899,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+929143,int_stack+176001,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+184411,int_stack+183970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360124, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+184999,int_stack+184411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360565, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+403135,int_stack+397402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396079, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+186343,int_stack+185755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363694, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+187127,int_stack+186343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364282, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+403135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398725, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+176001,int_stack+138075,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+424072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+188891,int_stack+188135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217035, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+183939,int_stack+189899,int_stack+188891, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218547, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+183939,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404899, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+939727,int_stack+0,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+191636,int_stack+191195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360124, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+192224,int_stack+191636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360565, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+403135,int_stack+397402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396079, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+193568,int_stack+192980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363694, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+194352,int_stack+193568, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364282, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+562273,int_stack+403135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398725, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+183939,int_stack+9450,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+456034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+196116,int_stack+195360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217035, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+197124,int_stack+196116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218547, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+191877,int_stack+0,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404899, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+950311,int_stack+191877,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+471091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+198861,int_stack+198420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+199449,int_stack+198861, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+360565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+403135,int_stack+397402, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+396079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+200793,int_stack+200205, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+201577,int_stack+200793, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+403135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+398725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+191877,int_stack+138075,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+203341,int_stack+202585, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+199815,int_stack+204349,int_stack+203341, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+199815,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+960895,int_stack+0,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+503053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+206086,int_stack+205645, 0.0, zero_stack, 1.0, int_stack+360124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+206674,int_stack+206086, 0.0, zero_stack, 1.0, int_stack+360565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+403135,int_stack+397402, 0.0, zero_stack, 1.0, int_stack+396079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+208018,int_stack+207430, 0.0, zero_stack, 1.0, int_stack+363694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+208802,int_stack+208018, 0.0, zero_stack, 1.0, int_stack+364282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+562273,int_stack+403135, 0.0, zero_stack, 1.0, int_stack+398725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+199815,int_stack+9450,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+210566,int_stack+209810, 0.0, zero_stack, 1.0, int_stack+217035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+211574,int_stack+210566, 0.0, zero_stack, 1.0, int_stack+218547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+207753,int_stack+0,int_stack+138075, 0.0, zero_stack, 1.0, int_stack+404899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+971479,int_stack+207753,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+532663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+397402,int_stack+213311,int_stack+212870, 1.0, int_stack+360124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+403135,int_stack+213899,int_stack+213311, 1.0, int_stack+360565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+403135,int_stack+397402, 1.0, int_stack+396079, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+403135,int_stack+215243,int_stack+214655, 1.0, int_stack+363694, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+216027,int_stack+215243, 1.0, int_stack+364282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+403135, 1.0, int_stack+398725, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+207753,int_stack+138075,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+547216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+219555,int_stack+217791, 1.0, int_stack+217035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+396079,int_stack+220563,int_stack+219555, 1.0, int_stack+218547, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+396079,int_stack+9450, 1.0, int_stack+404899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+982063,int_stack+0,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+564625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+222300,int_stack+221859,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+139398,int_stack+222888,int_stack+222300,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+139398,int_stack+138075,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+224232,int_stack+223644,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+225016,int_stack+224232,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+562273,int_stack+138075,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+215691,int_stack+9450,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+226780,int_stack+226024,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+138075,int_stack+227788,int_stack+226780,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+223629,int_stack+138075,int_stack+0,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+992647,int_stack+223629,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+602173, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+229525,int_stack+229084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371514,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+230113,int_stack+229525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371955,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+223629,int_stack+10773,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613639,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+231457,int_stack+230869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+375084,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+232241,int_stack+231457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+375672,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614962,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1003231,int_stack+138075,int_stack+223629, 0.0, zero_stack, 1.0, int_stack+400489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+223629,int_stack+234005,int_stack+233249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269374,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+225897,int_stack+235013,int_stack+234005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270886,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+225897,int_stack+223629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7182,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+223629,int_stack+0,int_stack+138075, 0.0, zero_stack, 1.0, int_stack+407251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+236750,int_stack+236309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371514, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+139398,int_stack+237338,int_stack+236750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371955, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+139398,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613639, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+238682,int_stack+238094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+375084, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+239466,int_stack+238682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+375672, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+562273,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614962, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1011169,int_stack+9450,int_stack+0, 0.0, zero_stack, 1.0, int_stack+424072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+241230,int_stack+240474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269374, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+138075,int_stack+242238,int_stack+241230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270886, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+138075,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7182, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1019107,int_stack+234213,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+441481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+243975,int_stack+243534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371514, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+244563,int_stack+243975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371955, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+10773,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613639, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+245907,int_stack+245319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+375084, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+246691,int_stack+245907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+375672, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+9450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614962, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+236859,int_stack+138075,int_stack+234213, 0.0, zero_stack, 1.0, int_stack+456034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+248455,int_stack+247699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269374, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9450,int_stack+249463,int_stack+248455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270886, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+9450,int_stack+234213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7182, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1029691,int_stack+0,int_stack+138075, 0.0, zero_stack, 1.0, int_stack+471091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+251200,int_stack+250759, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+139398,int_stack+251788,int_stack+251200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+371955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+139398,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+253132,int_stack+252544, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+375084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+253916,int_stack+253132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+375672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+562273,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+244797,int_stack+9450,int_stack+234213, 0.0, zero_stack, 1.0, int_stack+485644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+255680,int_stack+254924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+138075,int_stack+256688,int_stack+255680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+270886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+138075,int_stack+234213, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1040275,int_stack+0,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+503053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+258425,int_stack+257984, 0.0, zero_stack, 1.0, int_stack+371514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10773,int_stack+259013,int_stack+258425, 0.0, zero_stack, 1.0, int_stack+371955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+10773,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+613639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9450,int_stack+260357,int_stack+259769, 0.0, zero_stack, 1.0, int_stack+375084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+261141,int_stack+260357, 0.0, zero_stack, 1.0, int_stack+375672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+614962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+252735,int_stack+138075,int_stack+234213, 0.0, zero_stack, 1.0, int_stack+517606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+262905,int_stack+262149, 0.0, zero_stack, 1.0, int_stack+269374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+9450,int_stack+263913,int_stack+262905, 0.0, zero_stack, 1.0, int_stack+270886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+9450,int_stack+234213, 0.0, zero_stack, 1.0, int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1050859,int_stack+0,int_stack+138075, 0.0, zero_stack, 1.0, int_stack+532663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+265650,int_stack+265209, 1.0, int_stack+371514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+139398,int_stack+266238,int_stack+265650, 1.0, int_stack+371955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+139398,int_stack+138075, 1.0, int_stack+613639, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+267582,int_stack+266994, 1.0, int_stack+375084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+268366,int_stack+267582, 1.0, int_stack+375672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+562273,int_stack+138075, 1.0, int_stack+614962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+260673,int_stack+9450,int_stack+234213, 0.0, zero_stack, 1.0, int_stack+547216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+271894,int_stack+270130, 1.0, int_stack+269374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+138075,int_stack+272902,int_stack+271894, 1.0, int_stack+270886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+138075,int_stack+234213, 1.0, int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1061443,int_stack+0,int_stack+9450, 0.0, zero_stack, 1.0, int_stack+564625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+274639,int_stack+274198,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+275227,int_stack+274639,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+1323,int_stack+0,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+276571,int_stack+275983,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+277355,int_stack+276571,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+0,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+268611,int_stack+138075,int_stack+234213, 0.0, zero_stack, 1.0, int_stack+4536, 1.0, int_stack+616726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+279119,int_stack+278363,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+280127,int_stack+279119,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+0,int_stack+234213,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1072027,int_stack+7182,int_stack+138075, 0.0, zero_stack, 1.0, int_stack+602173, 1.0, int_stack+631783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+281864,int_stack+281423,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+139398,int_stack+282452,int_stack+281864,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+139398,int_stack+138075,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+283796,int_stack+283208,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+284580,int_stack+283796,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+562273,int_stack+138075,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+276549,int_stack+7182,int_stack+234213, 0.0, zero_stack, 2.0, int_stack+616726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+10710,int_stack+286344,int_stack+285588,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+138075,int_stack+287352,int_stack+286344,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+138075,int_stack+10710,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1082611,int_stack+0,int_stack+7182, 0.0, zero_stack, 2.0, int_stack+631783, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+290874,int_stack+290433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384689,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+291462,int_stack+290874, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385130,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643249,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+295186,int_stack+294598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388259,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+295970,int_stack+295186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388847,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644572,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+284487,int_stack+138075,int_stack+234213, 1.0, int_stack+400489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+297734,int_stack+296978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355300,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+298742,int_stack+297734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356812,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+7182,int_stack+234213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576091,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+396079,int_stack+0,int_stack+138075, 1.0, int_stack+407251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+302264,int_stack+301823, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384689, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+139398,int_stack+302852,int_stack+302264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385130, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+139398,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643249, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+306576,int_stack+305988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388259, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+307360,int_stack+306576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388847, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+562273,int_stack+138075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644572, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+292425,int_stack+0,int_stack+234213, 1.0, int_stack+424072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+309124,int_stack+308368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355300, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+138075,int_stack+310132,int_stack+309124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356812, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+138075,int_stack+234213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576091, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+300363,int_stack+7182,int_stack+0, 1.0, int_stack+441481, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+313654,int_stack+313213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384689, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1323,int_stack+314242,int_stack+313654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385130, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+1323,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643249, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+317966,int_stack+317378, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388259, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+318750,int_stack+317966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388847, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644572, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+310947,int_stack+138075,int_stack+234213, 1.0, int_stack+456034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+320514,int_stack+319758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355300, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+321522,int_stack+320514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356812, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+0,int_stack+234213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576091, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1093195,int_stack+7182,int_stack+138075, 1.0, int_stack+471091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+471091,int_stack+325044,int_stack+324603, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+384689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+472414,int_stack+325632,int_stack+325044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+385130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+472414,int_stack+471091, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+643249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+471091,int_stack+329356,int_stack+328768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+330140,int_stack+329356, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+138075,int_stack+562273,int_stack+471091, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+318885,int_stack+138075,int_stack+234213, 1.0, int_stack+485644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+331904,int_stack+331148, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471091,int_stack+332912,int_stack+331904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+471091,int_stack+234213, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+576091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1103779,int_stack+0,int_stack+138075, 1.0, int_stack+503053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+336434,int_stack+335993, 0.0, zero_stack, 1.0, int_stack+384689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+139398,int_stack+337022,int_stack+336434, 0.0, zero_stack, 1.0, int_stack+385130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+139398,int_stack+138075, 0.0, zero_stack, 1.0, int_stack+643249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+138075,int_stack+340746,int_stack+340158, 0.0, zero_stack, 1.0, int_stack+388259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+341530,int_stack+340746, 0.0, zero_stack, 1.0, int_stack+388847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+471091,int_stack+562273,int_stack+138075, 0.0, zero_stack, 1.0, int_stack+644572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+326823,int_stack+471091,int_stack+234213, 1.0, int_stack+517606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+343294,int_stack+342538, 0.0, zero_stack, 1.0, int_stack+355300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+138075,int_stack+344302,int_stack+343294, 0.0, zero_stack, 1.0, int_stack+356812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+138075,int_stack+234213, 0.0, zero_stack, 1.0, int_stack+576091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+334761,int_stack+0,int_stack+471091, 1.0, int_stack+532663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+532663,int_stack+347824,int_stack+347383, 1.0, int_stack+384689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+533986,int_stack+348412,int_stack+347824, 1.0, int_stack+385130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+533986,int_stack+532663, 1.0, int_stack+643249, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+532663,int_stack+353508,int_stack+352920, 1.0, int_stack+388259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+562273,int_stack+354292,int_stack+353508, 1.0, int_stack+388847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+471091,int_stack+562273,int_stack+532663, 1.0, int_stack+644572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+345345,int_stack+471091,int_stack+234213, 1.0, int_stack+547216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+357820,int_stack+356056, 1.0, int_stack+355300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+532663,int_stack+358828,int_stack+357820, 1.0, int_stack+356812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+532663,int_stack+234213, 1.0, int_stack+576091, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1114363,int_stack+0,int_stack+471091, 1.0, int_stack+564625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+471091,int_stack+362350,int_stack+361909,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+472414,int_stack+362938,int_stack+362350,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+472414,int_stack+471091,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+471091,int_stack+366662,int_stack+366074,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+367446,int_stack+366662,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+532663,int_stack+0,int_stack+471091,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+353283,int_stack+532663,int_stack+234213, 1.0, int_stack+4536, 0.0, zero_stack, 1.0, int_stack+646336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+369210,int_stack+368454,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471091,int_stack+370218,int_stack+369210,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+471091,int_stack+234213,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+361221,int_stack+0,int_stack+532663, 1.0, int_stack+602173, 0.0, zero_stack, 1.0, int_stack+661393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+602173,int_stack+373740,int_stack+373299,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+603496,int_stack+374328,int_stack+373740,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+603496,int_stack+602173,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+602173,int_stack+378052,int_stack+377464,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+532663,int_stack+378836,int_stack+378052,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+471091,int_stack+532663,int_stack+602173,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+471091,int_stack+234213, 1.0, int_stack+616726, 1.0, int_stack+646336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+380600,int_stack+379844,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+602173,int_stack+381608,int_stack+380600,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7938,int_stack+602173,int_stack+234213,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+371805,int_stack+7938,int_stack+471091, 1.0, int_stack+631783, 1.0, int_stack+661393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+631783,int_stack+386915,int_stack+386474,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+633106,int_stack+387503,int_stack+386915,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+234213,int_stack+633106,int_stack+631783,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+631783,int_stack+391227,int_stack+390639,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471091,int_stack+392011,int_stack+391227,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+602173,int_stack+471091,int_stack+631783,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+382389,int_stack+602173,int_stack+234213, 2.0, int_stack+646336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+234213,int_stack+393775,int_stack+393019,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+631783,int_stack+394783,int_stack+393775,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+7938,int_stack+631783,int_stack+234213,36);
 /*--- compute (ip|hd) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1124947,int_stack+7938,int_stack+602173, 2.0, int_stack+661393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1135531,int_stack+428545,int_stack+410779,126);
     Libderiv->ABCD[11] = int_stack + 1135531;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+418717,int_stack+460507,int_stack+445009,126);
     Libderiv->ABCD[10] = int_stack + 418717;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+452947,int_stack+490117,int_stack+474619,126);
     Libderiv->ABCD[9] = int_stack + 452947;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+482557,int_stack+522079,int_stack+506581,126);
     Libderiv->ABCD[8] = int_stack + 482557;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+514519,int_stack+551689,int_stack+536191,126);
     Libderiv->ABCD[7] = int_stack + 514519;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+544129,int_stack+583651,int_stack+568153,126);
     Libderiv->ABCD[6] = int_stack + 544129;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+576091,int_stack+621199,int_stack+605701, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+594235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[2] = int_stack + 576091;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+613639,int_stack+650809,int_stack+635311, 0.0, zero_stack, 1.0, int_stack+594235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[1] = int_stack + 613639;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+643249,int_stack+680419,int_stack+664921, 1.0, int_stack+594235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[0] = int_stack + 643249;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+672859,int_stack+698941,int_stack+691003,126);
     Libderiv->ABCD[155] = int_stack + 672859;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+688735,int_stack+717463,int_stack+709525,126);
     Libderiv->ABCD[143] = int_stack + 688735;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+704611,int_stack+728047,int_stack+21063,126);
     Libderiv->ABCD[142] = int_stack + 704611;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+720487,int_stack+738631,int_stack+12978,126);
     Libderiv->ABCD[131] = int_stack + 720487;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+7938,int_stack+749215,int_stack+37527,126);
     Libderiv->ABCD[130] = int_stack + 7938;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+736363,int_stack+759799,int_stack+45465,126);
     Libderiv->ABCD[129] = int_stack + 736363;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+36939,int_stack+53403,int_stack+770383,126);
     Libderiv->ABCD[119] = int_stack + 36939;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+752239,int_stack+786259,int_stack+778321,126);
     Libderiv->ABCD[118] = int_stack + 752239;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+768115,int_stack+796843,int_stack+63987,126);
     Libderiv->ABCD[117] = int_stack + 768115;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+52815,int_stack+807427,int_stack+71925,126);
     Libderiv->ABCD[116] = int_stack + 52815;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+783991,int_stack+818011,int_stack+79863,126);
     Libderiv->ABCD[107] = int_stack + 783991;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+68691,int_stack+828595,int_stack+87801,126);
     Libderiv->ABCD[106] = int_stack + 68691;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+799867,int_stack+839179,int_stack+95739,126);
     Libderiv->ABCD[105] = int_stack + 799867;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+84567,int_stack+849763,int_stack+103677,126);
     Libderiv->ABCD[104] = int_stack + 84567;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+815743,int_stack+868285,int_stack+860347,126);
     Libderiv->ABCD[103] = int_stack + 815743;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+831619,int_stack+119553,int_stack+111615,126);
     Libderiv->ABCD[95] = int_stack + 831619;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+100443,int_stack+878869,int_stack+29001,126);
     Libderiv->ABCD[94] = int_stack + 100443;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+847495,int_stack+889453,int_stack+130137,126);
     Libderiv->ABCD[93] = int_stack + 847495;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+116319,int_stack+900037,int_stack+141603,126);
     Libderiv->ABCD[92] = int_stack + 116319;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+132195,int_stack+910621,int_stack+149541,126);
     Libderiv->ABCD[91] = int_stack + 132195;
 /*--- compute (hd|hd) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+863371,int_stack+165417,int_stack+157479,126);
     Libderiv->ABCD[90] = int_stack + 863371;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+148071,int_stack+929143,int_stack+921205, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[47] = int_stack + 148071;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+879247,int_stack+939727,int_stack+176001, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[46] = int_stack + 879247;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+163947,int_stack+950311,int_stack+183939, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+474619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[45] = int_stack + 163947;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+895123,int_stack+960895,int_stack+191877, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+506581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[44] = int_stack + 895123;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+179823,int_stack+971479,int_stack+199815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[43] = int_stack + 179823;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+910999,int_stack+982063,int_stack+207753, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+568153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[42] = int_stack + 910999;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+195699,int_stack+992647,int_stack+215691, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+605701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[38] = int_stack + 195699;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+926875,int_stack+223629,int_stack+1003231, 0.0, zero_stack, 1.0, int_stack+410779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[35] = int_stack + 926875;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+211575,int_stack+1019107,int_stack+1011169, 0.0, zero_stack, 1.0, int_stack+445009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[34] = int_stack + 211575;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+942751,int_stack+1029691,int_stack+236859, 0.0, zero_stack, 1.0, int_stack+474619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[33] = int_stack + 942751;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+227451,int_stack+1040275,int_stack+244797, 0.0, zero_stack, 1.0, int_stack+506581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[32] = int_stack + 227451;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+958627,int_stack+1050859,int_stack+252735, 0.0, zero_stack, 1.0, int_stack+536191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[31] = int_stack + 958627;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+243327,int_stack+1061443,int_stack+260673, 0.0, zero_stack, 1.0, int_stack+568153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[30] = int_stack + 243327;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+974503,int_stack+1072027,int_stack+268611, 0.0, zero_stack, 1.0, int_stack+605701, 1.0, int_stack+635311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[26] = int_stack + 974503;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+259203,int_stack+1082611,int_stack+276549, 0.0, zero_stack, 2.0, int_stack+635311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[25] = int_stack + 259203;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+990379,int_stack+396079,int_stack+284487, 1.0, int_stack+410779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[23] = int_stack + 990379;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+390327,int_stack+300363,int_stack+292425, 1.0, int_stack+445009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[22] = int_stack + 390327;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+434593,int_stack+1093195,int_stack+310947, 1.0, int_stack+474619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[21] = int_stack + 434593;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+275079,int_stack+1103779,int_stack+318885, 1.0, int_stack+506581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[20] = int_stack + 275079;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+498433,int_stack+334761,int_stack+326823, 1.0, int_stack+536191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[19] = int_stack + 498433;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+290955,int_stack+1114363,int_stack+345345, 1.0, int_stack+568153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[18] = int_stack + 290955;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+560005,int_stack+361221,int_stack+353283, 1.0, int_stack+605701, 0.0, zero_stack, 1.0, int_stack+664921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[14] = int_stack + 560005;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+591967,int_stack+371805,int_stack+0, 1.0, int_stack+635311, 1.0, int_stack+664921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[13] = int_stack + 591967;
 /*--- compute (hd|hd) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+306831,int_stack+1124947,int_stack+382389, 2.0, int_stack+664921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[12] = int_stack + 306831;

}
