/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hfhg(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hf|hg) integrals */

void d12hrr_order_hfhg(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[8][9][11] = int_stack + 0;
 Libderiv->deriv_classes[8][9][10] = int_stack + 2475;
 Libderiv->deriv_classes[8][9][9] = int_stack + 4950;
 Libderiv->deriv_classes[8][9][8] = int_stack + 7425;
 Libderiv->deriv_classes[8][9][7] = int_stack + 9900;
 Libderiv->dvrr_classes[8][8] = int_stack + 12375;
 Libderiv->deriv_classes[8][9][6] = int_stack + 14400;
 Libderiv->deriv_classes[8][9][2] = int_stack + 16875;
 Libderiv->deriv_classes[8][9][1] = int_stack + 19350;
 Libderiv->dvrr_classes[7][9] = int_stack + 21825;
 Libderiv->deriv_classes[8][9][0] = int_stack + 23805;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 26280;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 26721;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 27309;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 28065;
 Libderiv->deriv2_classes[5][9][143] = int_stack + 29010;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 30165;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 30753;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 31537;
 Libderiv->deriv2_classes[6][8][143] = int_stack + 32545;
 Libderiv->deriv2_classes[6][9][143] = int_stack + 33805;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 35345;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 36101;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 37109;
 Libderiv->deriv2_classes[7][8][143] = int_stack + 38405;
 Libderiv->deriv2_classes[7][9][143] = int_stack + 40025;
 Libderiv->deriv2_classes[8][5][143] = int_stack + 42005;
 Libderiv->deriv2_classes[8][6][143] = int_stack + 42950;
 Libderiv->deriv2_classes[8][7][143] = int_stack + 44210;
 Libderiv->deriv2_classes[8][8][143] = int_stack + 45830;
 Libderiv->deriv2_classes[8][9][143] = int_stack + 47855;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 50330;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 50771;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 51359;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 52115;
 Libderiv->deriv2_classes[5][9][131] = int_stack + 53060;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 54215;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 54803;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 55587;
 Libderiv->deriv2_classes[6][8][131] = int_stack + 56595;
 Libderiv->deriv2_classes[6][9][131] = int_stack + 57855;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 59395;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 60151;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 61159;
 Libderiv->deriv2_classes[7][8][131] = int_stack + 62455;
 Libderiv->deriv2_classes[7][9][131] = int_stack + 64075;
 Libderiv->deriv2_classes[8][5][131] = int_stack + 66055;
 Libderiv->deriv2_classes[8][6][131] = int_stack + 67000;
 Libderiv->deriv2_classes[8][7][131] = int_stack + 68260;
 Libderiv->deriv2_classes[8][8][131] = int_stack + 69880;
 Libderiv->deriv2_classes[8][9][131] = int_stack + 71905;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 74380;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 74821;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 75409;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 76165;
 Libderiv->deriv2_classes[5][9][130] = int_stack + 77110;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 78265;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 78853;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 79637;
 Libderiv->deriv2_classes[6][8][130] = int_stack + 80645;
 Libderiv->deriv2_classes[6][9][130] = int_stack + 81905;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 83445;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 84201;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 85209;
 Libderiv->deriv2_classes[7][8][130] = int_stack + 86505;
 Libderiv->deriv2_classes[7][9][130] = int_stack + 88125;
 Libderiv->deriv2_classes[8][5][130] = int_stack + 90105;
 Libderiv->deriv2_classes[8][6][130] = int_stack + 91050;
 Libderiv->deriv2_classes[8][7][130] = int_stack + 92310;
 Libderiv->deriv2_classes[8][8][130] = int_stack + 93930;
 Libderiv->deriv2_classes[8][9][130] = int_stack + 95955;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 98430;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 98871;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 99459;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 100215;
 Libderiv->deriv2_classes[5][9][119] = int_stack + 101160;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 102315;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 102903;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 103687;
 Libderiv->deriv2_classes[6][8][119] = int_stack + 104695;
 Libderiv->deriv2_classes[6][9][119] = int_stack + 105955;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 107495;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 108251;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 109259;
 Libderiv->deriv2_classes[7][8][119] = int_stack + 110555;
 Libderiv->deriv2_classes[7][9][119] = int_stack + 112175;
 Libderiv->deriv2_classes[8][5][119] = int_stack + 114155;
 Libderiv->deriv2_classes[8][6][119] = int_stack + 115100;
 Libderiv->deriv2_classes[8][7][119] = int_stack + 116360;
 Libderiv->deriv2_classes[8][8][119] = int_stack + 117980;
 Libderiv->deriv2_classes[8][9][119] = int_stack + 120005;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 122480;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 122921;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 123509;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 124265;
 Libderiv->deriv2_classes[5][9][118] = int_stack + 125210;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 126365;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 126953;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 127737;
 Libderiv->deriv2_classes[6][8][118] = int_stack + 128745;
 Libderiv->deriv2_classes[6][9][118] = int_stack + 130005;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 131545;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 132301;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 133309;
 Libderiv->deriv2_classes[7][8][118] = int_stack + 134605;
 Libderiv->deriv2_classes[7][9][118] = int_stack + 136225;
 Libderiv->deriv2_classes[8][5][118] = int_stack + 138205;
 Libderiv->deriv2_classes[8][6][118] = int_stack + 139150;
 Libderiv->deriv2_classes[8][7][118] = int_stack + 140410;
 Libderiv->deriv2_classes[8][8][118] = int_stack + 142030;
 Libderiv->deriv2_classes[8][9][118] = int_stack + 144055;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 146530;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 146971;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 147559;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 148315;
 Libderiv->deriv2_classes[5][9][117] = int_stack + 149260;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 150415;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 151003;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 151787;
 Libderiv->deriv2_classes[6][8][117] = int_stack + 152795;
 Libderiv->deriv2_classes[6][9][117] = int_stack + 154055;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 155595;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 156351;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 157359;
 Libderiv->deriv2_classes[7][8][117] = int_stack + 158655;
 Libderiv->deriv2_classes[7][9][117] = int_stack + 160275;
 Libderiv->deriv2_classes[8][5][117] = int_stack + 162255;
 Libderiv->deriv2_classes[8][6][117] = int_stack + 163200;
 Libderiv->deriv2_classes[8][7][117] = int_stack + 164460;
 Libderiv->deriv2_classes[8][8][117] = int_stack + 166080;
 Libderiv->deriv2_classes[8][9][117] = int_stack + 168105;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 170580;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 171021;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 171609;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 172365;
 Libderiv->deriv2_classes[5][9][107] = int_stack + 173310;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 174465;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 175053;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 175837;
 Libderiv->deriv2_classes[6][8][107] = int_stack + 176845;
 Libderiv->deriv2_classes[6][9][107] = int_stack + 178105;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 179645;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 180401;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 181409;
 Libderiv->deriv2_classes[7][8][107] = int_stack + 182705;
 Libderiv->deriv2_classes[7][9][107] = int_stack + 184325;
 Libderiv->deriv2_classes[8][5][107] = int_stack + 186305;
 Libderiv->deriv2_classes[8][6][107] = int_stack + 187250;
 Libderiv->deriv2_classes[8][7][107] = int_stack + 188510;
 Libderiv->deriv2_classes[8][8][107] = int_stack + 190130;
 Libderiv->deriv2_classes[8][9][107] = int_stack + 192155;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 194630;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 195071;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 195659;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 196415;
 Libderiv->deriv2_classes[5][9][106] = int_stack + 197360;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 198515;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 199103;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 199887;
 Libderiv->deriv2_classes[6][8][106] = int_stack + 200895;
 Libderiv->deriv2_classes[6][9][106] = int_stack + 202155;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 203695;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 204451;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 205459;
 Libderiv->deriv2_classes[7][8][106] = int_stack + 206755;
 Libderiv->deriv2_classes[7][9][106] = int_stack + 208375;
 Libderiv->deriv2_classes[8][5][106] = int_stack + 210355;
 Libderiv->deriv2_classes[8][6][106] = int_stack + 211300;
 Libderiv->deriv2_classes[8][7][106] = int_stack + 212560;
 Libderiv->deriv2_classes[8][8][106] = int_stack + 214180;
 Libderiv->deriv2_classes[8][9][106] = int_stack + 216205;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 218680;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 219121;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 219709;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 220465;
 Libderiv->deriv2_classes[5][9][105] = int_stack + 221410;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 222565;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 223153;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 223937;
 Libderiv->deriv2_classes[6][8][105] = int_stack + 224945;
 Libderiv->deriv2_classes[6][9][105] = int_stack + 226205;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 227745;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 228501;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 229509;
 Libderiv->deriv2_classes[7][8][105] = int_stack + 230805;
 Libderiv->deriv2_classes[7][9][105] = int_stack + 232425;
 Libderiv->deriv2_classes[8][5][105] = int_stack + 234405;
 Libderiv->deriv2_classes[8][6][105] = int_stack + 235350;
 Libderiv->deriv2_classes[8][7][105] = int_stack + 236610;
 Libderiv->deriv2_classes[8][8][105] = int_stack + 238230;
 Libderiv->deriv2_classes[8][9][105] = int_stack + 240255;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 242730;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 243171;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 243759;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 244515;
 Libderiv->deriv2_classes[5][9][104] = int_stack + 245460;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 246615;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 247203;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 247987;
 Libderiv->deriv2_classes[6][8][104] = int_stack + 248995;
 Libderiv->deriv2_classes[6][9][104] = int_stack + 250255;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 251795;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 252551;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 253559;
 Libderiv->deriv2_classes[7][8][104] = int_stack + 254855;
 Libderiv->deriv2_classes[7][9][104] = int_stack + 256475;
 Libderiv->deriv2_classes[8][5][104] = int_stack + 258455;
 Libderiv->deriv2_classes[8][6][104] = int_stack + 259400;
 Libderiv->deriv2_classes[8][7][104] = int_stack + 260660;
 Libderiv->deriv2_classes[8][8][104] = int_stack + 262280;
 Libderiv->deriv2_classes[8][9][104] = int_stack + 264305;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 266780;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 267221;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 267809;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 268565;
 Libderiv->deriv2_classes[5][9][95] = int_stack + 269510;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 270665;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 271253;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 272037;
 Libderiv->deriv2_classes[6][8][95] = int_stack + 273045;
 Libderiv->deriv2_classes[6][9][95] = int_stack + 274305;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 275845;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 276601;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 277609;
 Libderiv->deriv2_classes[7][8][95] = int_stack + 278905;
 Libderiv->deriv2_classes[7][9][95] = int_stack + 280525;
 Libderiv->deriv2_classes[8][5][95] = int_stack + 282505;
 Libderiv->deriv2_classes[8][6][95] = int_stack + 283450;
 Libderiv->deriv2_classes[8][7][95] = int_stack + 284710;
 Libderiv->deriv2_classes[8][8][95] = int_stack + 286330;
 Libderiv->deriv2_classes[8][9][95] = int_stack + 288355;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 290830;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 291271;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 291859;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 292615;
 Libderiv->deriv2_classes[5][9][94] = int_stack + 293560;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 294715;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 295303;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 296087;
 Libderiv->deriv2_classes[6][8][94] = int_stack + 297095;
 Libderiv->deriv2_classes[6][9][94] = int_stack + 298355;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 299895;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 300651;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 301659;
 Libderiv->deriv2_classes[7][8][94] = int_stack + 302955;
 Libderiv->deriv2_classes[7][9][94] = int_stack + 304575;
 Libderiv->deriv2_classes[8][5][94] = int_stack + 306555;
 Libderiv->deriv2_classes[8][6][94] = int_stack + 307500;
 Libderiv->deriv2_classes[8][7][94] = int_stack + 308760;
 Libderiv->deriv2_classes[8][8][94] = int_stack + 310380;
 Libderiv->deriv2_classes[8][9][94] = int_stack + 312405;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 314880;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 315321;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 315909;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 316665;
 Libderiv->deriv2_classes[5][9][93] = int_stack + 317610;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 318765;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 319353;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 320137;
 Libderiv->deriv2_classes[6][8][93] = int_stack + 321145;
 Libderiv->deriv2_classes[6][9][93] = int_stack + 322405;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 323945;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 324701;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 325709;
 Libderiv->deriv2_classes[7][8][93] = int_stack + 327005;
 Libderiv->deriv2_classes[7][9][93] = int_stack + 328625;
 Libderiv->deriv2_classes[8][5][93] = int_stack + 330605;
 Libderiv->deriv2_classes[8][6][93] = int_stack + 331550;
 Libderiv->deriv2_classes[8][7][93] = int_stack + 332810;
 Libderiv->deriv2_classes[8][8][93] = int_stack + 334430;
 Libderiv->deriv2_classes[8][9][93] = int_stack + 336455;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 338930;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 339371;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 339959;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 340715;
 Libderiv->deriv2_classes[5][9][92] = int_stack + 341660;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 342815;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 343403;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 344187;
 Libderiv->deriv2_classes[6][8][92] = int_stack + 345195;
 Libderiv->deriv2_classes[6][9][92] = int_stack + 346455;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 347995;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 348751;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 349759;
 Libderiv->deriv2_classes[7][8][92] = int_stack + 351055;
 Libderiv->deriv2_classes[7][9][92] = int_stack + 352675;
 Libderiv->deriv2_classes[8][5][92] = int_stack + 354655;
 Libderiv->deriv2_classes[8][6][92] = int_stack + 355600;
 Libderiv->deriv2_classes[8][7][92] = int_stack + 356860;
 Libderiv->deriv2_classes[8][8][92] = int_stack + 358480;
 Libderiv->deriv2_classes[8][9][92] = int_stack + 360505;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 362980;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 363421;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 364009;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 364765;
 Libderiv->deriv2_classes[5][9][91] = int_stack + 365710;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 366865;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 367453;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 368237;
 Libderiv->deriv2_classes[6][8][91] = int_stack + 369245;
 Libderiv->deriv2_classes[6][9][91] = int_stack + 370505;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 372045;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 372801;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 373809;
 Libderiv->deriv2_classes[7][8][91] = int_stack + 375105;
 Libderiv->deriv2_classes[7][9][91] = int_stack + 376725;
 Libderiv->deriv2_classes[8][5][91] = int_stack + 378705;
 Libderiv->deriv2_classes[8][6][91] = int_stack + 379650;
 Libderiv->deriv2_classes[8][7][91] = int_stack + 380910;
 Libderiv->deriv2_classes[8][8][91] = int_stack + 382530;
 Libderiv->deriv2_classes[8][9][91] = int_stack + 384555;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 387030;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 387471;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 388059;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 388815;
 Libderiv->deriv2_classes[5][9][83] = int_stack + 389760;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 390915;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 391503;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 392287;
 Libderiv->deriv2_classes[6][8][83] = int_stack + 393295;
 Libderiv->deriv2_classes[6][9][83] = int_stack + 394555;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 396095;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 396851;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 397859;
 Libderiv->deriv2_classes[7][8][83] = int_stack + 399155;
 Libderiv->deriv2_classes[7][9][83] = int_stack + 400775;
 Libderiv->deriv_classes[8][5][11] = int_stack + 402755;
 Libderiv->deriv2_classes[8][5][83] = int_stack + 403700;
 Libderiv->deriv_classes[8][6][11] = int_stack + 404645;
 Libderiv->deriv2_classes[8][6][83] = int_stack + 405905;
 Libderiv->deriv_classes[8][7][11] = int_stack + 407165;
 Libderiv->deriv2_classes[8][7][83] = int_stack + 408785;
 Libderiv->deriv_classes[8][8][11] = int_stack + 410405;
 Libderiv->deriv2_classes[8][8][83] = int_stack + 412430;
 Libderiv->deriv2_classes[8][9][83] = int_stack + 414455;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 416930;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 417371;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 417959;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 418715;
 Libderiv->deriv2_classes[5][9][82] = int_stack + 419660;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 420815;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 421403;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 422187;
 Libderiv->deriv2_classes[6][8][82] = int_stack + 423195;
 Libderiv->deriv2_classes[6][9][82] = int_stack + 424455;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 425995;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 426751;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 427759;
 Libderiv->deriv2_classes[7][8][82] = int_stack + 429055;
 Libderiv->deriv2_classes[7][9][82] = int_stack + 430675;
 Libderiv->deriv_classes[8][5][10] = int_stack + 432655;
 Libderiv->deriv2_classes[8][5][82] = int_stack + 433600;
 Libderiv->deriv_classes[8][6][10] = int_stack + 434545;
 Libderiv->deriv2_classes[8][6][82] = int_stack + 435805;
 Libderiv->deriv_classes[8][7][10] = int_stack + 437065;
 Libderiv->deriv2_classes[8][7][82] = int_stack + 438685;
 Libderiv->deriv_classes[8][8][10] = int_stack + 440305;
 Libderiv->deriv2_classes[8][8][82] = int_stack + 442330;
 Libderiv->deriv2_classes[8][9][82] = int_stack + 444355;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 446830;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 447271;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 447859;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 448615;
 Libderiv->deriv2_classes[5][9][81] = int_stack + 449560;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 450715;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 451303;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 452087;
 Libderiv->deriv2_classes[6][8][81] = int_stack + 453095;
 Libderiv->deriv2_classes[6][9][81] = int_stack + 454355;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 455895;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 456651;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 457659;
 Libderiv->deriv2_classes[7][8][81] = int_stack + 458955;
 Libderiv->deriv2_classes[7][9][81] = int_stack + 460575;
 Libderiv->deriv_classes[8][5][9] = int_stack + 462555;
 Libderiv->deriv2_classes[8][5][81] = int_stack + 463500;
 Libderiv->deriv_classes[8][6][9] = int_stack + 464445;
 Libderiv->deriv2_classes[8][6][81] = int_stack + 465705;
 Libderiv->deriv_classes[8][7][9] = int_stack + 466965;
 Libderiv->deriv2_classes[8][7][81] = int_stack + 468585;
 Libderiv->deriv_classes[8][8][9] = int_stack + 470205;
 Libderiv->deriv2_classes[8][8][81] = int_stack + 472230;
 Libderiv->deriv2_classes[8][9][81] = int_stack + 474255;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 476730;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 477171;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 477759;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 478515;
 Libderiv->deriv2_classes[5][9][80] = int_stack + 479460;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 480615;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 481203;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 481987;
 Libderiv->deriv2_classes[6][8][80] = int_stack + 482995;
 Libderiv->deriv2_classes[6][9][80] = int_stack + 484255;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 485795;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 486551;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 487559;
 Libderiv->deriv2_classes[7][8][80] = int_stack + 488855;
 Libderiv->deriv2_classes[7][9][80] = int_stack + 490475;
 Libderiv->deriv_classes[8][5][8] = int_stack + 492455;
 Libderiv->deriv2_classes[8][5][80] = int_stack + 493400;
 Libderiv->deriv_classes[8][6][8] = int_stack + 494345;
 Libderiv->deriv2_classes[8][6][80] = int_stack + 495605;
 Libderiv->deriv_classes[8][7][8] = int_stack + 496865;
 Libderiv->deriv2_classes[8][7][80] = int_stack + 498485;
 Libderiv->deriv_classes[8][8][8] = int_stack + 500105;
 Libderiv->deriv2_classes[8][8][80] = int_stack + 502130;
 Libderiv->deriv2_classes[8][9][80] = int_stack + 504155;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 506630;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 507071;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 507659;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 508415;
 Libderiv->deriv2_classes[5][9][79] = int_stack + 509360;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 510515;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 511103;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 511887;
 Libderiv->deriv2_classes[6][8][79] = int_stack + 512895;
 Libderiv->deriv2_classes[6][9][79] = int_stack + 514155;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 515695;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 516451;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 517459;
 Libderiv->deriv2_classes[7][8][79] = int_stack + 518755;
 Libderiv->deriv2_classes[7][9][79] = int_stack + 520375;
 Libderiv->deriv_classes[8][5][7] = int_stack + 522355;
 Libderiv->deriv2_classes[8][5][79] = int_stack + 523300;
 Libderiv->deriv_classes[8][6][7] = int_stack + 524245;
 Libderiv->deriv2_classes[8][6][79] = int_stack + 525505;
 Libderiv->deriv_classes[8][7][7] = int_stack + 526765;
 Libderiv->deriv2_classes[8][7][79] = int_stack + 528385;
 Libderiv->deriv_classes[8][8][7] = int_stack + 530005;
 Libderiv->deriv2_classes[8][8][79] = int_stack + 532030;
 Libderiv->deriv2_classes[8][9][79] = int_stack + 534055;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 536530;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 536971;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 537559;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 538315;
 Libderiv->deriv2_classes[5][9][78] = int_stack + 539260;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 540415;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 541003;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 541787;
 Libderiv->deriv2_classes[6][8][78] = int_stack + 542795;
 Libderiv->deriv2_classes[6][9][78] = int_stack + 544055;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 545595;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 546351;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 547359;
 Libderiv->deriv2_classes[7][8][78] = int_stack + 548655;
 Libderiv->deriv2_classes[7][9][78] = int_stack + 550275;
 Libderiv->dvrr_classes[8][5] = int_stack + 552255;
 Libderiv->deriv_classes[8][5][6] = int_stack + 553200;
 Libderiv->deriv2_classes[8][5][78] = int_stack + 554145;
 Libderiv->dvrr_classes[8][6] = int_stack + 555090;
 Libderiv->deriv_classes[8][6][6] = int_stack + 556350;
 Libderiv->deriv2_classes[8][6][78] = int_stack + 557610;
 Libderiv->dvrr_classes[8][7] = int_stack + 558870;
 Libderiv->deriv_classes[8][7][6] = int_stack + 560490;
 Libderiv->deriv2_classes[8][7][78] = int_stack + 562110;
 Libderiv->deriv_classes[8][8][6] = int_stack + 563730;
 Libderiv->deriv2_classes[8][8][78] = int_stack + 565755;
 Libderiv->deriv2_classes[8][9][78] = int_stack + 567780;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 570255;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 570696;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 571284;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 572040;
 Libderiv->deriv2_classes[5][9][35] = int_stack + 572985;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 574140;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 574728;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 575512;
 Libderiv->deriv2_classes[6][8][35] = int_stack + 576520;
 Libderiv->deriv2_classes[6][9][35] = int_stack + 577780;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 579320;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 580076;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 581084;
 Libderiv->deriv2_classes[7][8][35] = int_stack + 582380;
 Libderiv->deriv2_classes[7][9][35] = int_stack + 584000;
 Libderiv->deriv2_classes[8][5][35] = int_stack + 585980;
 Libderiv->deriv2_classes[8][6][35] = int_stack + 586925;
 Libderiv->deriv2_classes[8][7][35] = int_stack + 588185;
 Libderiv->deriv2_classes[8][8][35] = int_stack + 589805;
 Libderiv->deriv2_classes[8][9][35] = int_stack + 591830;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 594305;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 594746;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 595334;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 596090;
 Libderiv->deriv2_classes[5][9][34] = int_stack + 597035;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 598190;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 598778;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 599562;
 Libderiv->deriv2_classes[6][8][34] = int_stack + 600570;
 Libderiv->deriv2_classes[6][9][34] = int_stack + 601830;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 603370;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 604126;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 605134;
 Libderiv->deriv2_classes[7][8][34] = int_stack + 606430;
 Libderiv->deriv2_classes[7][9][34] = int_stack + 608050;
 Libderiv->deriv2_classes[8][5][34] = int_stack + 610030;
 Libderiv->deriv2_classes[8][6][34] = int_stack + 610975;
 Libderiv->deriv2_classes[8][7][34] = int_stack + 612235;
 Libderiv->deriv2_classes[8][8][34] = int_stack + 613855;
 Libderiv->deriv2_classes[8][9][34] = int_stack + 615880;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 618355;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 618796;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 619384;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 620140;
 Libderiv->deriv2_classes[5][9][33] = int_stack + 621085;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 622240;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 622828;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 623612;
 Libderiv->deriv2_classes[6][8][33] = int_stack + 624620;
 Libderiv->deriv2_classes[6][9][33] = int_stack + 625880;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 627420;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 628176;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 629184;
 Libderiv->deriv2_classes[7][8][33] = int_stack + 630480;
 Libderiv->deriv2_classes[7][9][33] = int_stack + 632100;
 Libderiv->deriv2_classes[8][5][33] = int_stack + 634080;
 Libderiv->deriv2_classes[8][6][33] = int_stack + 635025;
 Libderiv->deriv2_classes[8][7][33] = int_stack + 636285;
 Libderiv->deriv2_classes[8][8][33] = int_stack + 637905;
 Libderiv->deriv2_classes[8][9][33] = int_stack + 639930;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 642405;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 642846;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 643434;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 644190;
 Libderiv->deriv2_classes[5][9][32] = int_stack + 645135;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 646290;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 646878;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 647662;
 Libderiv->deriv2_classes[6][8][32] = int_stack + 648670;
 Libderiv->deriv2_classes[6][9][32] = int_stack + 649930;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 651470;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 652226;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 653234;
 Libderiv->deriv2_classes[7][8][32] = int_stack + 654530;
 Libderiv->deriv2_classes[7][9][32] = int_stack + 656150;
 Libderiv->deriv2_classes[8][5][32] = int_stack + 658130;
 Libderiv->deriv2_classes[8][6][32] = int_stack + 659075;
 Libderiv->deriv2_classes[8][7][32] = int_stack + 660335;
 Libderiv->deriv2_classes[8][8][32] = int_stack + 661955;
 Libderiv->deriv2_classes[8][9][32] = int_stack + 663980;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 666455;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 666896;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 667484;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 668240;
 Libderiv->deriv2_classes[5][9][31] = int_stack + 669185;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 670340;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 670928;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 671712;
 Libderiv->deriv2_classes[6][8][31] = int_stack + 672720;
 Libderiv->deriv2_classes[6][9][31] = int_stack + 673980;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 675520;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 676276;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 677284;
 Libderiv->deriv2_classes[7][8][31] = int_stack + 678580;
 Libderiv->deriv2_classes[7][9][31] = int_stack + 680200;
 Libderiv->deriv2_classes[8][5][31] = int_stack + 682180;
 Libderiv->deriv2_classes[8][6][31] = int_stack + 683125;
 Libderiv->deriv2_classes[8][7][31] = int_stack + 684385;
 Libderiv->deriv2_classes[8][8][31] = int_stack + 686005;
 Libderiv->deriv2_classes[8][9][31] = int_stack + 688030;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 690505;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 690946;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 691534;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 692290;
 Libderiv->deriv2_classes[5][9][30] = int_stack + 693235;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 694390;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 694978;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 695762;
 Libderiv->deriv2_classes[6][8][30] = int_stack + 696770;
 Libderiv->deriv2_classes[6][9][30] = int_stack + 698030;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 699570;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 700326;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 701334;
 Libderiv->deriv2_classes[7][8][30] = int_stack + 702630;
 Libderiv->deriv2_classes[7][9][30] = int_stack + 704250;
 Libderiv->deriv_classes[8][5][2] = int_stack + 706230;
 Libderiv->deriv2_classes[8][5][30] = int_stack + 707175;
 Libderiv->deriv_classes[8][6][2] = int_stack + 708120;
 Libderiv->deriv2_classes[8][6][30] = int_stack + 709380;
 Libderiv->deriv_classes[8][7][2] = int_stack + 710640;
 Libderiv->deriv2_classes[8][7][30] = int_stack + 712260;
 Libderiv->deriv_classes[8][8][2] = int_stack + 713880;
 Libderiv->deriv2_classes[8][8][30] = int_stack + 715905;
 Libderiv->deriv2_classes[8][9][30] = int_stack + 717930;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 720405;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 720846;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 721434;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 722190;
 Libderiv->deriv2_classes[5][9][26] = int_stack + 723135;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 724290;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 724878;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 725662;
 Libderiv->deriv2_classes[6][8][26] = int_stack + 726670;
 Libderiv->deriv2_classes[6][9][26] = int_stack + 727930;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 729470;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 730226;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 731234;
 Libderiv->deriv2_classes[7][8][26] = int_stack + 732530;
 Libderiv->deriv2_classes[7][9][26] = int_stack + 734150;
 Libderiv->deriv2_classes[8][5][26] = int_stack + 736130;
 Libderiv->deriv2_classes[8][6][26] = int_stack + 737075;
 Libderiv->deriv2_classes[8][7][26] = int_stack + 738335;
 Libderiv->deriv2_classes[8][8][26] = int_stack + 739955;
 Libderiv->deriv2_classes[8][9][26] = int_stack + 741980;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 744455;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 744896;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 745484;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 746240;
 Libderiv->deriv2_classes[5][9][23] = int_stack + 747185;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 748340;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 748928;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 749712;
 Libderiv->deriv2_classes[6][8][23] = int_stack + 750720;
 Libderiv->deriv2_classes[6][9][23] = int_stack + 751980;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 753520;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 754276;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 755284;
 Libderiv->deriv2_classes[7][8][23] = int_stack + 756580;
 Libderiv->deriv2_classes[7][9][23] = int_stack + 758200;
 Libderiv->deriv2_classes[8][5][23] = int_stack + 760180;
 Libderiv->deriv2_classes[8][6][23] = int_stack + 761125;
 Libderiv->deriv2_classes[8][7][23] = int_stack + 762385;
 Libderiv->deriv2_classes[8][8][23] = int_stack + 764005;
 Libderiv->deriv2_classes[8][9][23] = int_stack + 766030;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 768505;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 768946;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 769534;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 770290;
 Libderiv->deriv2_classes[5][9][22] = int_stack + 771235;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 772390;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 772978;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 773762;
 Libderiv->deriv2_classes[6][8][22] = int_stack + 774770;
 Libderiv->deriv2_classes[6][9][22] = int_stack + 776030;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 777570;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 778326;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 779334;
 Libderiv->deriv2_classes[7][8][22] = int_stack + 780630;
 Libderiv->deriv2_classes[7][9][22] = int_stack + 782250;
 Libderiv->deriv2_classes[8][5][22] = int_stack + 784230;
 Libderiv->deriv2_classes[8][6][22] = int_stack + 785175;
 Libderiv->deriv2_classes[8][7][22] = int_stack + 786435;
 Libderiv->deriv2_classes[8][8][22] = int_stack + 788055;
 Libderiv->deriv2_classes[8][9][22] = int_stack + 790080;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 792555;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 792996;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 793584;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 794340;
 Libderiv->deriv2_classes[5][9][21] = int_stack + 795285;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 796440;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 797028;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 797812;
 Libderiv->deriv2_classes[6][8][21] = int_stack + 798820;
 Libderiv->deriv2_classes[6][9][21] = int_stack + 800080;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 801620;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 802376;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 803384;
 Libderiv->deriv2_classes[7][8][21] = int_stack + 804680;
 Libderiv->deriv2_classes[7][9][21] = int_stack + 806300;
 Libderiv->deriv2_classes[8][5][21] = int_stack + 808280;
 Libderiv->deriv2_classes[8][6][21] = int_stack + 809225;
 Libderiv->deriv2_classes[8][7][21] = int_stack + 810485;
 Libderiv->deriv2_classes[8][8][21] = int_stack + 812105;
 Libderiv->deriv2_classes[8][9][21] = int_stack + 814130;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 816605;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 817046;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 817634;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 818390;
 Libderiv->deriv2_classes[5][9][20] = int_stack + 819335;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 820490;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 821078;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 821862;
 Libderiv->deriv2_classes[6][8][20] = int_stack + 822870;
 Libderiv->deriv2_classes[6][9][20] = int_stack + 824130;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 825670;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 826426;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 827434;
 Libderiv->deriv2_classes[7][8][20] = int_stack + 828730;
 Libderiv->deriv2_classes[7][9][20] = int_stack + 830350;
 Libderiv->deriv2_classes[8][5][20] = int_stack + 832330;
 Libderiv->deriv2_classes[8][6][20] = int_stack + 833275;
 Libderiv->deriv2_classes[8][7][20] = int_stack + 834535;
 Libderiv->deriv2_classes[8][8][20] = int_stack + 836155;
 Libderiv->deriv2_classes[8][9][20] = int_stack + 838180;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 840655;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 841096;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 841684;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 842440;
 Libderiv->deriv2_classes[5][9][19] = int_stack + 843385;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 844540;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 845128;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 845912;
 Libderiv->deriv2_classes[6][8][19] = int_stack + 846920;
 Libderiv->deriv2_classes[6][9][19] = int_stack + 848180;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 849720;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 850476;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 851484;
 Libderiv->deriv2_classes[7][8][19] = int_stack + 852780;
 Libderiv->deriv2_classes[7][9][19] = int_stack + 854400;
 Libderiv->deriv2_classes[8][5][19] = int_stack + 856380;
 Libderiv->deriv2_classes[8][6][19] = int_stack + 857325;
 Libderiv->deriv2_classes[8][7][19] = int_stack + 858585;
 Libderiv->deriv2_classes[8][8][19] = int_stack + 860205;
 Libderiv->deriv2_classes[8][9][19] = int_stack + 862230;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 864705;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 865146;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 865734;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 866490;
 Libderiv->deriv2_classes[5][9][18] = int_stack + 867435;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 868590;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 869178;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 869962;
 Libderiv->deriv2_classes[6][8][18] = int_stack + 870970;
 Libderiv->deriv2_classes[6][9][18] = int_stack + 872230;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 873770;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 874526;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 875534;
 Libderiv->deriv2_classes[7][8][18] = int_stack + 876830;
 Libderiv->deriv2_classes[7][9][18] = int_stack + 878450;
 Libderiv->deriv_classes[8][5][1] = int_stack + 880430;
 Libderiv->deriv2_classes[8][5][18] = int_stack + 881375;
 Libderiv->deriv_classes[8][6][1] = int_stack + 882320;
 Libderiv->deriv2_classes[8][6][18] = int_stack + 883580;
 Libderiv->deriv_classes[8][7][1] = int_stack + 884840;
 Libderiv->deriv2_classes[8][7][18] = int_stack + 886460;
 Libderiv->deriv_classes[8][8][1] = int_stack + 888080;
 Libderiv->deriv2_classes[8][8][18] = int_stack + 890105;
 Libderiv->deriv2_classes[8][9][18] = int_stack + 892130;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 894605;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 895046;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 895634;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 896390;
 Libderiv->deriv2_classes[5][9][14] = int_stack + 897335;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 898490;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 899078;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 899862;
 Libderiv->deriv2_classes[6][8][14] = int_stack + 900870;
 Libderiv->deriv2_classes[6][9][14] = int_stack + 902130;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 903670;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 904426;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 905434;
 Libderiv->deriv2_classes[7][8][14] = int_stack + 906730;
 Libderiv->deriv2_classes[7][9][14] = int_stack + 908350;
 Libderiv->deriv2_classes[8][5][14] = int_stack + 910330;
 Libderiv->deriv2_classes[8][6][14] = int_stack + 911275;
 Libderiv->deriv2_classes[8][7][14] = int_stack + 912535;
 Libderiv->deriv2_classes[8][8][14] = int_stack + 914155;
 Libderiv->deriv2_classes[8][9][14] = int_stack + 916180;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 918655;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 919096;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 919684;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 920440;
 Libderiv->deriv2_classes[5][9][13] = int_stack + 921385;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 922540;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 923128;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 923912;
 Libderiv->deriv2_classes[6][8][13] = int_stack + 924920;
 Libderiv->deriv2_classes[6][9][13] = int_stack + 926180;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 927720;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 928476;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 929484;
 Libderiv->deriv2_classes[7][8][13] = int_stack + 930780;
 Libderiv->deriv2_classes[7][9][13] = int_stack + 932400;
 Libderiv->deriv2_classes[8][5][13] = int_stack + 934380;
 Libderiv->deriv2_classes[8][6][13] = int_stack + 935325;
 Libderiv->deriv2_classes[8][7][13] = int_stack + 936585;
 Libderiv->deriv2_classes[8][8][13] = int_stack + 938205;
 Libderiv->deriv2_classes[8][9][13] = int_stack + 940230;
 Libderiv->deriv_classes[5][5][11] = int_stack + 942705;
 Libderiv->deriv_classes[5][6][11] = int_stack + 943146;
 Libderiv->deriv_classes[5][7][11] = int_stack + 943734;
 Libderiv->deriv_classes[5][8][11] = int_stack + 944490;
 Libderiv->deriv_classes[5][9][11] = int_stack + 945435;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 946590;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 947031;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 947619;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 948375;
 Libderiv->deriv2_classes[5][9][11] = int_stack + 949320;
 Libderiv->deriv_classes[6][5][11] = int_stack + 950475;
 Libderiv->deriv_classes[6][6][11] = int_stack + 951063;
 Libderiv->deriv_classes[6][7][11] = int_stack + 951847;
 Libderiv->deriv_classes[6][8][11] = int_stack + 952855;
 Libderiv->deriv_classes[6][9][11] = int_stack + 954115;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 955655;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 956243;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 957027;
 Libderiv->deriv2_classes[6][8][11] = int_stack + 958035;
 Libderiv->deriv2_classes[6][9][11] = int_stack + 959295;
 Libderiv->deriv_classes[7][5][11] = int_stack + 960835;
 Libderiv->deriv_classes[7][6][11] = int_stack + 961591;
 Libderiv->deriv_classes[7][7][11] = int_stack + 962599;
 Libderiv->deriv_classes[7][8][11] = int_stack + 963895;
 Libderiv->deriv_classes[7][9][11] = int_stack + 965515;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 967495;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 968251;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 969259;
 Libderiv->deriv2_classes[7][8][11] = int_stack + 970555;
 Libderiv->deriv2_classes[7][9][11] = int_stack + 972175;
 Libderiv->deriv2_classes[8][5][11] = int_stack + 974155;
 Libderiv->deriv2_classes[8][6][11] = int_stack + 975100;
 Libderiv->deriv2_classes[8][7][11] = int_stack + 976360;
 Libderiv->deriv2_classes[8][8][11] = int_stack + 977980;
 Libderiv->deriv2_classes[8][9][11] = int_stack + 980005;
 Libderiv->deriv_classes[5][5][10] = int_stack + 982480;
 Libderiv->deriv_classes[5][6][10] = int_stack + 982921;
 Libderiv->deriv_classes[5][7][10] = int_stack + 983509;
 Libderiv->deriv_classes[5][8][10] = int_stack + 984265;
 Libderiv->deriv_classes[5][9][10] = int_stack + 985210;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 986365;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 986806;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 987394;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 988150;
 Libderiv->deriv2_classes[5][9][10] = int_stack + 989095;
 Libderiv->deriv_classes[6][5][10] = int_stack + 990250;
 Libderiv->deriv_classes[6][6][10] = int_stack + 990838;
 Libderiv->deriv_classes[6][7][10] = int_stack + 991622;
 Libderiv->deriv_classes[6][8][10] = int_stack + 992630;
 Libderiv->deriv_classes[6][9][10] = int_stack + 993890;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 995430;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 996018;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 996802;
 Libderiv->deriv2_classes[6][8][10] = int_stack + 997810;
 Libderiv->deriv2_classes[6][9][10] = int_stack + 999070;
 Libderiv->deriv_classes[7][5][10] = int_stack + 1000610;
 Libderiv->deriv_classes[7][6][10] = int_stack + 1001366;
 Libderiv->deriv_classes[7][7][10] = int_stack + 1002374;
 Libderiv->deriv_classes[7][8][10] = int_stack + 1003670;
 Libderiv->deriv_classes[7][9][10] = int_stack + 1005290;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 1007270;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 1008026;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 1009034;
 Libderiv->deriv2_classes[7][8][10] = int_stack + 1010330;
 Libderiv->deriv2_classes[7][9][10] = int_stack + 1011950;
 Libderiv->deriv2_classes[8][5][10] = int_stack + 1013930;
 Libderiv->deriv2_classes[8][6][10] = int_stack + 1014875;
 Libderiv->deriv2_classes[8][7][10] = int_stack + 1016135;
 Libderiv->deriv2_classes[8][8][10] = int_stack + 1017755;
 Libderiv->deriv2_classes[8][9][10] = int_stack + 1019780;
 Libderiv->deriv_classes[5][5][9] = int_stack + 1022255;
 Libderiv->deriv_classes[5][6][9] = int_stack + 1022696;
 Libderiv->deriv_classes[5][7][9] = int_stack + 1023284;
 Libderiv->deriv_classes[5][8][9] = int_stack + 1024040;
 Libderiv->deriv_classes[5][9][9] = int_stack + 1024985;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 1026140;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 1026581;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 1027169;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 1027925;
 Libderiv->deriv2_classes[5][9][9] = int_stack + 1028870;
 Libderiv->deriv_classes[6][5][9] = int_stack + 1030025;
 Libderiv->deriv_classes[6][6][9] = int_stack + 1030613;
 Libderiv->deriv_classes[6][7][9] = int_stack + 1031397;
 Libderiv->deriv_classes[6][8][9] = int_stack + 1032405;
 Libderiv->deriv_classes[6][9][9] = int_stack + 1033665;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 1035205;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 1035793;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 1036577;
 Libderiv->deriv2_classes[6][8][9] = int_stack + 1037585;
 Libderiv->deriv2_classes[6][9][9] = int_stack + 1038845;
 Libderiv->deriv_classes[7][5][9] = int_stack + 1040385;
 Libderiv->deriv_classes[7][6][9] = int_stack + 1041141;
 Libderiv->deriv_classes[7][7][9] = int_stack + 1042149;
 Libderiv->deriv_classes[7][8][9] = int_stack + 1043445;
 Libderiv->deriv_classes[7][9][9] = int_stack + 1045065;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 1047045;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 1047801;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 1048809;
 Libderiv->deriv2_classes[7][8][9] = int_stack + 1050105;
 Libderiv->deriv2_classes[7][9][9] = int_stack + 1051725;
 Libderiv->deriv2_classes[8][5][9] = int_stack + 1053705;
 Libderiv->deriv2_classes[8][6][9] = int_stack + 1054650;
 Libderiv->deriv2_classes[8][7][9] = int_stack + 1055910;
 Libderiv->deriv2_classes[8][8][9] = int_stack + 1057530;
 Libderiv->deriv2_classes[8][9][9] = int_stack + 1059555;
 Libderiv->deriv_classes[5][5][8] = int_stack + 1062030;
 Libderiv->deriv_classes[5][6][8] = int_stack + 1062471;
 Libderiv->deriv_classes[5][7][8] = int_stack + 1063059;
 Libderiv->deriv_classes[5][8][8] = int_stack + 1063815;
 Libderiv->deriv_classes[5][9][8] = int_stack + 1064760;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 1065915;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 1066356;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 1066944;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 1067700;
 Libderiv->deriv2_classes[5][9][8] = int_stack + 1068645;
 Libderiv->deriv_classes[6][5][8] = int_stack + 1069800;
 Libderiv->deriv_classes[6][6][8] = int_stack + 1070388;
 Libderiv->deriv_classes[6][7][8] = int_stack + 1071172;
 Libderiv->deriv_classes[6][8][8] = int_stack + 1072180;
 Libderiv->deriv_classes[6][9][8] = int_stack + 1073440;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 1074980;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 1075568;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 1076352;
 Libderiv->deriv2_classes[6][8][8] = int_stack + 1077360;
 Libderiv->deriv2_classes[6][9][8] = int_stack + 1078620;
 Libderiv->deriv_classes[7][5][8] = int_stack + 1080160;
 Libderiv->deriv_classes[7][6][8] = int_stack + 1080916;
 Libderiv->deriv_classes[7][7][8] = int_stack + 1081924;
 Libderiv->deriv_classes[7][8][8] = int_stack + 1083220;
 Libderiv->deriv_classes[7][9][8] = int_stack + 1084840;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 1086820;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 1087576;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 1088584;
 Libderiv->deriv2_classes[7][8][8] = int_stack + 1089880;
 Libderiv->deriv2_classes[7][9][8] = int_stack + 1091500;
 Libderiv->deriv2_classes[8][5][8] = int_stack + 1093480;
 Libderiv->deriv2_classes[8][6][8] = int_stack + 1094425;
 Libderiv->deriv2_classes[8][7][8] = int_stack + 1095685;
 Libderiv->deriv2_classes[8][8][8] = int_stack + 1097305;
 Libderiv->deriv2_classes[8][9][8] = int_stack + 1099330;
 Libderiv->deriv_classes[5][5][7] = int_stack + 1101805;
 Libderiv->deriv_classes[5][6][7] = int_stack + 1102246;
 Libderiv->deriv_classes[5][7][7] = int_stack + 1102834;
 Libderiv->deriv_classes[5][8][7] = int_stack + 1103590;
 Libderiv->deriv_classes[5][9][7] = int_stack + 1104535;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 1105690;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 1106131;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 1106719;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 1107475;
 Libderiv->deriv2_classes[5][9][7] = int_stack + 1108420;
 Libderiv->deriv_classes[6][5][7] = int_stack + 1109575;
 Libderiv->deriv_classes[6][6][7] = int_stack + 1110163;
 Libderiv->deriv_classes[6][7][7] = int_stack + 1110947;
 Libderiv->deriv_classes[6][8][7] = int_stack + 1111955;
 Libderiv->deriv_classes[6][9][7] = int_stack + 1113215;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 1114755;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 1115343;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 1116127;
 Libderiv->deriv2_classes[6][8][7] = int_stack + 1117135;
 Libderiv->deriv2_classes[6][9][7] = int_stack + 1118395;
 Libderiv->deriv_classes[7][5][7] = int_stack + 1119935;
 Libderiv->deriv_classes[7][6][7] = int_stack + 1120691;
 Libderiv->deriv_classes[7][7][7] = int_stack + 1121699;
 Libderiv->deriv_classes[7][8][7] = int_stack + 1122995;
 Libderiv->deriv_classes[7][9][7] = int_stack + 1124615;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 1126595;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 1127351;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 1128359;
 Libderiv->deriv2_classes[7][8][7] = int_stack + 1129655;
 Libderiv->deriv2_classes[7][9][7] = int_stack + 1131275;
 Libderiv->deriv2_classes[8][5][7] = int_stack + 1133255;
 Libderiv->deriv2_classes[8][6][7] = int_stack + 1134200;
 Libderiv->deriv2_classes[8][7][7] = int_stack + 1135460;
 Libderiv->deriv2_classes[8][8][7] = int_stack + 1137080;
 Libderiv->deriv2_classes[8][9][7] = int_stack + 1139105;
 Libderiv->deriv_classes[5][5][6] = int_stack + 1141580;
 Libderiv->deriv_classes[5][6][6] = int_stack + 1142021;
 Libderiv->deriv_classes[5][7][6] = int_stack + 1142609;
 Libderiv->deriv_classes[5][8][6] = int_stack + 1143365;
 Libderiv->deriv_classes[5][9][6] = int_stack + 1144310;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 1145465;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 1145906;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 1146494;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 1147250;
 Libderiv->deriv2_classes[5][9][6] = int_stack + 1148195;
 Libderiv->deriv_classes[6][5][6] = int_stack + 1149350;
 Libderiv->deriv_classes[6][6][6] = int_stack + 1149938;
 Libderiv->deriv_classes[6][7][6] = int_stack + 1150722;
 Libderiv->deriv_classes[6][8][6] = int_stack + 1151730;
 Libderiv->deriv_classes[6][9][6] = int_stack + 1152990;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 1154530;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 1155118;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 1155902;
 Libderiv->deriv2_classes[6][8][6] = int_stack + 1156910;
 Libderiv->deriv2_classes[6][9][6] = int_stack + 1158170;
 Libderiv->dvrr_classes[7][5] = int_stack + 1159710;
 Libderiv->deriv_classes[7][5][6] = int_stack + 1160466;
 Libderiv->dvrr_classes[7][6] = int_stack + 1161222;
 Libderiv->deriv_classes[7][6][6] = int_stack + 1162230;
 Libderiv->dvrr_classes[7][7] = int_stack + 1163238;
 Libderiv->deriv_classes[7][7][6] = int_stack + 1164534;
 Libderiv->dvrr_classes[7][8] = int_stack + 1165830;
 Libderiv->deriv_classes[7][8][6] = int_stack + 1167450;
 Libderiv->deriv_classes[7][9][6] = int_stack + 1169070;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 1171050;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 1171806;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 1172814;
 Libderiv->deriv2_classes[7][8][6] = int_stack + 1174110;
 Libderiv->deriv2_classes[7][9][6] = int_stack + 1175730;
 Libderiv->deriv_classes[8][5][0] = int_stack + 1177710;
 Libderiv->deriv2_classes[8][5][6] = int_stack + 1178655;
 Libderiv->deriv_classes[8][6][0] = int_stack + 1179600;
 Libderiv->deriv2_classes[8][6][6] = int_stack + 1180860;
 Libderiv->deriv_classes[8][7][0] = int_stack + 1182120;
 Libderiv->deriv2_classes[8][7][6] = int_stack + 1183740;
 Libderiv->deriv_classes[8][8][0] = int_stack + 1185360;
 Libderiv->deriv2_classes[8][8][6] = int_stack + 1187385;
 Libderiv->deriv2_classes[8][9][6] = int_stack + 1189410;
 Libderiv->deriv_classes[5][5][2] = int_stack + 1191885;
 Libderiv->deriv_classes[5][6][2] = int_stack + 1192326;
 Libderiv->deriv_classes[5][7][2] = int_stack + 1192914;
 Libderiv->deriv_classes[5][8][2] = int_stack + 1193670;
 Libderiv->deriv_classes[5][9][2] = int_stack + 1194615;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 1195770;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 1196211;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 1196799;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 1197555;
 Libderiv->deriv2_classes[5][9][2] = int_stack + 1198500;
 Libderiv->deriv_classes[6][5][2] = int_stack + 1199655;
 Libderiv->deriv_classes[6][6][2] = int_stack + 1200243;
 Libderiv->deriv_classes[6][7][2] = int_stack + 1201027;
 Libderiv->deriv_classes[6][8][2] = int_stack + 1202035;
 Libderiv->deriv_classes[6][9][2] = int_stack + 1203295;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 1204835;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 1205423;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 1206207;
 Libderiv->deriv2_classes[6][8][2] = int_stack + 1207215;
 Libderiv->deriv2_classes[6][9][2] = int_stack + 1208475;
 Libderiv->deriv_classes[7][5][2] = int_stack + 1210015;
 Libderiv->deriv_classes[7][6][2] = int_stack + 1210771;
 Libderiv->deriv_classes[7][7][2] = int_stack + 1211779;
 Libderiv->deriv_classes[7][8][2] = int_stack + 1213075;
 Libderiv->deriv_classes[7][9][2] = int_stack + 1214695;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 1216675;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 1217431;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 1218439;
 Libderiv->deriv2_classes[7][8][2] = int_stack + 1219735;
 Libderiv->deriv2_classes[7][9][2] = int_stack + 1221355;
 Libderiv->deriv2_classes[8][5][2] = int_stack + 1223335;
 Libderiv->deriv2_classes[8][6][2] = int_stack + 1224280;
 Libderiv->deriv2_classes[8][7][2] = int_stack + 1225540;
 Libderiv->deriv2_classes[8][8][2] = int_stack + 1227160;
 Libderiv->deriv2_classes[8][9][2] = int_stack + 1229185;
 Libderiv->deriv_classes[5][5][1] = int_stack + 1231660;
 Libderiv->deriv_classes[5][6][1] = int_stack + 1232101;
 Libderiv->deriv_classes[5][7][1] = int_stack + 1232689;
 Libderiv->deriv_classes[5][8][1] = int_stack + 1233445;
 Libderiv->deriv_classes[5][9][1] = int_stack + 1234390;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 1235545;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 1235986;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 1236574;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 1237330;
 Libderiv->deriv2_classes[5][9][1] = int_stack + 1238275;
 Libderiv->deriv_classes[6][5][1] = int_stack + 1239430;
 Libderiv->deriv_classes[6][6][1] = int_stack + 1240018;
 Libderiv->deriv_classes[6][7][1] = int_stack + 1240802;
 Libderiv->deriv_classes[6][8][1] = int_stack + 1241810;
 Libderiv->deriv_classes[6][9][1] = int_stack + 1243070;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 1244610;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 1245198;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 1245982;
 Libderiv->deriv2_classes[6][8][1] = int_stack + 1246990;
 Libderiv->deriv2_classes[6][9][1] = int_stack + 1248250;
 Libderiv->deriv_classes[7][5][1] = int_stack + 1249790;
 Libderiv->deriv_classes[7][6][1] = int_stack + 1250546;
 Libderiv->deriv_classes[7][7][1] = int_stack + 1251554;
 Libderiv->deriv_classes[7][8][1] = int_stack + 1252850;
 Libderiv->deriv_classes[7][9][1] = int_stack + 1254470;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 1256450;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 1257206;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 1258214;
 Libderiv->deriv2_classes[7][8][1] = int_stack + 1259510;
 Libderiv->deriv2_classes[7][9][1] = int_stack + 1261130;
 Libderiv->deriv2_classes[8][5][1] = int_stack + 1263110;
 Libderiv->deriv2_classes[8][6][1] = int_stack + 1264055;
 Libderiv->deriv2_classes[8][7][1] = int_stack + 1265315;
 Libderiv->deriv2_classes[8][8][1] = int_stack + 1266935;
 Libderiv->deriv2_classes[8][9][1] = int_stack + 1268960;
 Libderiv->dvrr_classes[5][5] = int_stack + 1271435;
 Libderiv->dvrr_classes[5][6] = int_stack + 1271876;
 Libderiv->dvrr_classes[5][7] = int_stack + 1272464;
 Libderiv->dvrr_classes[5][8] = int_stack + 1273220;
 Libderiv->dvrr_classes[5][9] = int_stack + 1274165;
 Libderiv->deriv_classes[5][5][0] = int_stack + 1275320;
 Libderiv->deriv_classes[5][6][0] = int_stack + 1275761;
 Libderiv->deriv_classes[5][7][0] = int_stack + 1276349;
 Libderiv->deriv_classes[5][8][0] = int_stack + 1277105;
 Libderiv->deriv_classes[5][9][0] = int_stack + 1278050;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 1279205;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 1279646;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 1280234;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 1280990;
 Libderiv->deriv2_classes[5][9][0] = int_stack + 1281935;
 Libderiv->dvrr_classes[6][5] = int_stack + 1283090;
 Libderiv->dvrr_classes[6][6] = int_stack + 1283678;
 Libderiv->dvrr_classes[6][7] = int_stack + 1284462;
 Libderiv->dvrr_classes[6][8] = int_stack + 1285470;
 Libderiv->dvrr_classes[6][9] = int_stack + 1286730;
 Libderiv->deriv_classes[6][5][0] = int_stack + 1288270;
 Libderiv->deriv_classes[6][6][0] = int_stack + 1288858;
 Libderiv->deriv_classes[6][7][0] = int_stack + 1289642;
 Libderiv->deriv_classes[6][8][0] = int_stack + 1290650;
 Libderiv->deriv_classes[6][9][0] = int_stack + 1291910;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 1293450;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 1294038;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 1294822;
 Libderiv->deriv2_classes[6][8][0] = int_stack + 1295830;
 Libderiv->deriv2_classes[6][9][0] = int_stack + 1297090;
 Libderiv->deriv_classes[7][5][0] = int_stack + 1298630;
 Libderiv->deriv_classes[7][6][0] = int_stack + 1299386;
 Libderiv->deriv_classes[7][7][0] = int_stack + 1300394;
 Libderiv->deriv_classes[7][8][0] = int_stack + 1301690;
 Libderiv->deriv_classes[7][9][0] = int_stack + 1303310;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 1305290;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 1306046;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 1307054;
 Libderiv->deriv2_classes[7][8][0] = int_stack + 1308350;
 Libderiv->deriv2_classes[7][9][0] = int_stack + 1309970;
 Libderiv->deriv2_classes[8][5][0] = int_stack + 1311950;
 Libderiv->deriv2_classes[8][6][0] = int_stack + 1312895;
 Libderiv->deriv2_classes[8][7][0] = int_stack + 1314155;
 Libderiv->deriv2_classes[8][8][0] = int_stack + 1315775;
 Libderiv->deriv2_classes[8][9][0] = int_stack + 1317800;
 memset(int_stack,0,10562200);

 Libderiv->dvrr_stack = int_stack + 6148266;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hfhg(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1320275,int_stack+1271876,int_stack+1271435,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1321598,int_stack+1272464,int_stack+1271876,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1323362,int_stack+1321598,int_stack+1320275,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1326008,int_stack+1273220,int_stack+1272464,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1328276,int_stack+1326008,int_stack+1321598,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1331804,int_stack+1328276,int_stack+1323362,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1336214,int_stack+943146,int_stack+942705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271435,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1337537,int_stack+943734,int_stack+943146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271876,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1339301,int_stack+1337537,int_stack+1336214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1320275,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1341947,int_stack+944490,int_stack+943734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1272464,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1344215,int_stack+1341947,int_stack+1337537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1321598,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1347743,int_stack+1344215,int_stack+1339301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323362,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1352153,int_stack+945435,int_stack+944490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1273220,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1354988,int_stack+1352153,int_stack+1341947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326008,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1359524,int_stack+1354988,int_stack+1344215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328276,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1352153,int_stack+1359524,int_stack+1347743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331804,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1358768,int_stack+1283678,int_stack+1283090,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1360532,int_stack+1284462,int_stack+1283678,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1362884,int_stack+1360532,int_stack+1358768,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1366412,int_stack+1285470,int_stack+1284462,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1369436,int_stack+1366412,int_stack+1360532,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1374140,int_stack+1369436,int_stack+1362884,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1380020,int_stack+951063,int_stack+950475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283090,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1381784,int_stack+951847,int_stack+951063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283678,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1384136,int_stack+1381784,int_stack+1380020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358768,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1387664,int_stack+952855,int_stack+951847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284462,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1390688,int_stack+1387664,int_stack+1381784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1360532,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1395392,int_stack+1390688,int_stack+1384136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1362884,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1401272,int_stack+954115,int_stack+952855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1285470,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1405052,int_stack+1401272,int_stack+1387664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1366412,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1411100,int_stack+1405052,int_stack+1390688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1369436,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1401272,int_stack+1411100,int_stack+1395392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1374140,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1410092,int_stack+1401272,int_stack+1352153,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1429937,int_stack+1161222,int_stack+1159710,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1432205,int_stack+1163238,int_stack+1161222,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1435229,int_stack+1432205,int_stack+1429937,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1439765,int_stack+1165830,int_stack+1163238,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1443653,int_stack+1439765,int_stack+1432205,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1449701,int_stack+1443653,int_stack+1435229,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1457261,int_stack+961591,int_stack+960835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1159710,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1459529,int_stack+962599,int_stack+961591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1161222,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1462553,int_stack+1459529,int_stack+1457261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1429937,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1467089,int_stack+963895,int_stack+962599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1163238,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1470977,int_stack+1467089,int_stack+1459529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432205,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1477025,int_stack+1470977,int_stack+1462553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1435229,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1484585,int_stack+965515,int_stack+963895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1165830,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1489445,int_stack+1484585,int_stack+1467089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1439765,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1497221,int_stack+1489445,int_stack+1470977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1443653,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1484585,int_stack+1497221,int_stack+1477025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449701,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1495925,int_stack+1484585,int_stack+1401272,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1522385,int_stack+1495925,int_stack+1410092,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1562075,int_stack+555090,int_stack+552255,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1564910,int_stack+558870,int_stack+555090,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1568690,int_stack+1564910,int_stack+1562075,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1574360,int_stack+12375,int_stack+558870,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1579220,int_stack+1574360,int_stack+1564910,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1586780,int_stack+1579220,int_stack+1568690,45);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1596230,int_stack+404645,int_stack+402755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552255,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1599065,int_stack+407165,int_stack+404645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555090,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1602845,int_stack+1599065,int_stack+1596230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1562075,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1608515,int_stack+410405,int_stack+407165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558870,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1613375,int_stack+1608515,int_stack+1599065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1564910,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1620935,int_stack+1613375,int_stack+1602845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1568690,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1630385,int_stack+0,int_stack+410405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12375,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1636460,int_stack+1630385,int_stack+1608515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1574360,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1646180,int_stack+1636460,int_stack+1613375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1579220,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1630385,int_stack+1646180,int_stack+1620935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1586780,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1644560,int_stack+1630385,int_stack+1484585,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1678580,int_stack+1644560,int_stack+1495925,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1630385,int_stack+982921,int_stack+982480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271435, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1631708,int_stack+983509,int_stack+982921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271876, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1633472,int_stack+1631708,int_stack+1630385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1320275, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1636118,int_stack+984265,int_stack+983509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1272464, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1638386,int_stack+1636118,int_stack+1631708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1321598, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1641914,int_stack+1638386,int_stack+1633472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323362, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1646324,int_stack+985210,int_stack+984265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1273220, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1649159,int_stack+1646324,int_stack+1636118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326008, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1653695,int_stack+1649159,int_stack+1638386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328276, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1646324,int_stack+1653695,int_stack+1641914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331804, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1652939,int_stack+990838,int_stack+990250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283090, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1654703,int_stack+991622,int_stack+990838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283678, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1657055,int_stack+1654703,int_stack+1652939, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358768, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1660583,int_stack+992630,int_stack+991622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284462, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1663607,int_stack+1660583,int_stack+1654703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1360532, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1668311,int_stack+1663607,int_stack+1657055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1362884, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1674191,int_stack+993890,int_stack+992630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1285470, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1731500,int_stack+1674191,int_stack+1660583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1366412, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1737548,int_stack+1731500,int_stack+1663607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1369436, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1745388,int_stack+1737548,int_stack+1668311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1374140, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1754208,int_stack+1745388,int_stack+1646324,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1731500,int_stack+1001366,int_stack+1000610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1159710, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1733768,int_stack+1002374,int_stack+1001366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1161222, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1736792,int_stack+1733768,int_stack+1731500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1429937, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1741328,int_stack+1003670,int_stack+1002374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1163238, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1774053,int_stack+1741328,int_stack+1733768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432205, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1780101,int_stack+1774053,int_stack+1736792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1435229, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1787661,int_stack+1005290,int_stack+1003670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1165830, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1792521,int_stack+1787661,int_stack+1741328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1439765, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1800297,int_stack+1792521,int_stack+1774053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1443653, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1787661,int_stack+1800297,int_stack+1780101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449701, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1799001,int_stack+1787661,int_stack+1745388,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1825461,int_stack+1799001,int_stack+1754208,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1674191,int_stack+434545,int_stack+432655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552255, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1865151,int_stack+437065,int_stack+434545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555090, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1868931,int_stack+1865151,int_stack+1674191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1874601,int_stack+440305,int_stack+437065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558870, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1879461,int_stack+1874601,int_stack+1865151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1564910, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1887021,int_stack+1879461,int_stack+1868931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1568690, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1896471,int_stack+2475,int_stack+440305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12375, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1902546,int_stack+1896471,int_stack+1874601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1574360, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1912266,int_stack+1902546,int_stack+1879461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1579220, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1896471,int_stack+1912266,int_stack+1887021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1586780, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1910646,int_stack+1896471,int_stack+1787661,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1944666,int_stack+1910646,int_stack+1799001,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1896471,int_stack+1022696,int_stack+1022255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271435, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1897794,int_stack+1023284,int_stack+1022696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271876, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1899558,int_stack+1897794,int_stack+1896471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1902204,int_stack+1024040,int_stack+1023284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1272464, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1904472,int_stack+1902204,int_stack+1897794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1321598, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1908000,int_stack+1904472,int_stack+1899558, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323362, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1912410,int_stack+1024985,int_stack+1024040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1273220, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1915245,int_stack+1912410,int_stack+1902204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326008, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1919781,int_stack+1915245,int_stack+1904472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328276, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1912410,int_stack+1919781,int_stack+1908000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331804, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1919025,int_stack+1030613,int_stack+1030025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283090, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1920789,int_stack+1031397,int_stack+1030613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283678, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1923141,int_stack+1920789,int_stack+1919025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1926669,int_stack+1032405,int_stack+1031397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284462, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1929693,int_stack+1926669,int_stack+1920789, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1360532, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1934397,int_stack+1929693,int_stack+1923141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1362884, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1940277,int_stack+1033665,int_stack+1032405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1285470, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1997586,int_stack+1940277,int_stack+1926669, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1366412, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2003634,int_stack+1997586,int_stack+1929693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1369436, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2011474,int_stack+2003634,int_stack+1934397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1374140, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2020294,int_stack+2011474,int_stack+1912410,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1997586,int_stack+1041141,int_stack+1040385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1999854,int_stack+1042149,int_stack+1041141, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1161222, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2002878,int_stack+1999854,int_stack+1997586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2007414,int_stack+1043445,int_stack+1042149, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1163238, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2040139,int_stack+2007414,int_stack+1999854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432205, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2046187,int_stack+2040139,int_stack+2002878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1435229, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+1045065,int_stack+1043445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1165830, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2053747,int_stack+0,int_stack+2007414, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1439765, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2061523,int_stack+2053747,int_stack+2040139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1443653, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2071603,int_stack+2061523,int_stack+2046187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449701, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2082943,int_stack+2071603,int_stack+2011474,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2109403,int_stack+2082943,int_stack+2020294,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2053747,int_stack+464445,int_stack+462555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552255, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2056582,int_stack+466965,int_stack+464445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555090, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2060362,int_stack+2056582,int_stack+2053747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2066032,int_stack+470205,int_stack+466965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558870, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2149093,int_stack+2066032,int_stack+2056582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1564910, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2156653,int_stack+2149093,int_stack+2060362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1568690, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2166103,int_stack+4950,int_stack+470205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12375, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2172178,int_stack+2166103,int_stack+2066032, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1574360, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2181898,int_stack+2172178,int_stack+2149093, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1579220, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2166103,int_stack+2181898,int_stack+2156653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1586780, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2180278,int_stack+2166103,int_stack+2071603,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2214298,int_stack+2180278,int_stack+2082943,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2166103,int_stack+1062471,int_stack+1062030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2167426,int_stack+1063059,int_stack+1062471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2169190,int_stack+2167426,int_stack+2166103, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2171836,int_stack+1063815,int_stack+1063059, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1272464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2174104,int_stack+2171836,int_stack+2167426, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1321598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2177632,int_stack+2174104,int_stack+2169190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2182042,int_stack+1064760,int_stack+1063815, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1273220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2184877,int_stack+2182042,int_stack+2171836, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1326008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2189413,int_stack+2184877,int_stack+2174104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1328276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2182042,int_stack+2189413,int_stack+2177632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2188657,int_stack+1070388,int_stack+1069800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2190421,int_stack+1071172,int_stack+1070388, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2192773,int_stack+2190421,int_stack+2188657, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2196301,int_stack+1072180,int_stack+1071172, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1284462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2199325,int_stack+2196301,int_stack+2190421, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1360532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2204029,int_stack+2199325,int_stack+2192773, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1362884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2209909,int_stack+1073440,int_stack+1072180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1285470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+0,int_stack+2209909,int_stack+2196301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1366412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+0,int_stack+2199325, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1369436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2275058,int_stack+2267218,int_stack+2204029, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1374140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2283878,int_stack+2275058,int_stack+2182042,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2267218,int_stack+1080916,int_stack+1080160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2269486,int_stack+1081924,int_stack+1080916, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1161222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+2269486,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2209909,int_stack+1083220,int_stack+1081924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1163238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2303723,int_stack+2209909,int_stack+2269486, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1432205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2309771,int_stack+2303723,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1435229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2317331,int_stack+1084840,int_stack+1083220, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1165830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2322191,int_stack+2317331,int_stack+2209909, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1439765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2329967,int_stack+2322191,int_stack+2303723, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1443653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2317331,int_stack+2329967,int_stack+2309771, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1449701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2328671,int_stack+2317331,int_stack+2275058,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2355131,int_stack+2328671,int_stack+2283878,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+4536,int_stack+494345,int_stack+492455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1940277,int_stack+496865,int_stack+494345, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+555090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2394821,int_stack+1940277,int_stack+4536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2400491,int_stack+500105,int_stack+496865, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+558870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2405351,int_stack+2400491,int_stack+1940277, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1564910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2412911,int_stack+2405351,int_stack+2394821, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1568690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2422361,int_stack+7425,int_stack+500105, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2428436,int_stack+2422361,int_stack+2400491, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1574360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2438156,int_stack+2428436,int_stack+2405351, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1579220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2422361,int_stack+2438156,int_stack+2412911, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1586780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2436536,int_stack+2422361,int_stack+2317331,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2470556,int_stack+2436536,int_stack+2328671,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2422361,int_stack+1102246,int_stack+1101805, 0.0, zero_stack, 1.0, int_stack+1271435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2423684,int_stack+1102834,int_stack+1102246, 0.0, zero_stack, 1.0, int_stack+1271876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2425448,int_stack+2423684,int_stack+2422361, 0.0, zero_stack, 1.0, int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2428094,int_stack+1103590,int_stack+1102834, 0.0, zero_stack, 1.0, int_stack+1272464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2430362,int_stack+2428094,int_stack+2423684, 0.0, zero_stack, 1.0, int_stack+1321598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2433890,int_stack+2430362,int_stack+2425448, 0.0, zero_stack, 1.0, int_stack+1323362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2438300,int_stack+1104535,int_stack+1103590, 0.0, zero_stack, 1.0, int_stack+1273220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2441135,int_stack+2438300,int_stack+2428094, 0.0, zero_stack, 1.0, int_stack+1326008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2445671,int_stack+2441135,int_stack+2430362, 0.0, zero_stack, 1.0, int_stack+1328276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2438300,int_stack+2445671,int_stack+2433890, 0.0, zero_stack, 1.0, int_stack+1331804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2444915,int_stack+1110163,int_stack+1109575, 0.0, zero_stack, 1.0, int_stack+1283090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2446679,int_stack+1110947,int_stack+1110163, 0.0, zero_stack, 1.0, int_stack+1283678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2449031,int_stack+2446679,int_stack+2444915, 0.0, zero_stack, 1.0, int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2452559,int_stack+1111955,int_stack+1110947, 0.0, zero_stack, 1.0, int_stack+1284462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2455583,int_stack+2452559,int_stack+2446679, 0.0, zero_stack, 1.0, int_stack+1360532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2460287,int_stack+2455583,int_stack+2449031, 0.0, zero_stack, 1.0, int_stack+1362884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2466167,int_stack+1113215,int_stack+1111955, 0.0, zero_stack, 1.0, int_stack+1285470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2523476,int_stack+2466167,int_stack+2452559, 0.0, zero_stack, 1.0, int_stack+1366412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2529524,int_stack+2523476,int_stack+2455583, 0.0, zero_stack, 1.0, int_stack+1369436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2537364,int_stack+2529524,int_stack+2460287, 0.0, zero_stack, 1.0, int_stack+1374140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2546184,int_stack+2537364,int_stack+2438300,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2523476,int_stack+1120691,int_stack+1119935, 0.0, zero_stack, 1.0, int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2525744,int_stack+1121699,int_stack+1120691, 0.0, zero_stack, 1.0, int_stack+1161222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2528768,int_stack+2525744,int_stack+2523476, 0.0, zero_stack, 1.0, int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2533304,int_stack+1122995,int_stack+1121699, 0.0, zero_stack, 1.0, int_stack+1163238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2566029,int_stack+2533304,int_stack+2525744, 0.0, zero_stack, 1.0, int_stack+1432205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2572077,int_stack+2566029,int_stack+2528768, 0.0, zero_stack, 1.0, int_stack+1435229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2579637,int_stack+1124615,int_stack+1122995, 0.0, zero_stack, 1.0, int_stack+1165830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2584497,int_stack+2579637,int_stack+2533304, 0.0, zero_stack, 1.0, int_stack+1439765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2592273,int_stack+2584497,int_stack+2566029, 0.0, zero_stack, 1.0, int_stack+1443653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2579637,int_stack+2592273,int_stack+2572077, 0.0, zero_stack, 1.0, int_stack+1449701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2590977,int_stack+2579637,int_stack+2537364,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2617437,int_stack+2590977,int_stack+2546184,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2466167,int_stack+524245,int_stack+522355, 0.0, zero_stack, 1.0, int_stack+552255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2657127,int_stack+526765,int_stack+524245, 0.0, zero_stack, 1.0, int_stack+555090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2660907,int_stack+2657127,int_stack+2466167, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2666577,int_stack+530005,int_stack+526765, 0.0, zero_stack, 1.0, int_stack+558870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2671437,int_stack+2666577,int_stack+2657127, 0.0, zero_stack, 1.0, int_stack+1564910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2678997,int_stack+2671437,int_stack+2660907, 0.0, zero_stack, 1.0, int_stack+1568690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2688447,int_stack+9900,int_stack+530005, 0.0, zero_stack, 1.0, int_stack+12375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2694522,int_stack+2688447,int_stack+2666577, 0.0, zero_stack, 1.0, int_stack+1574360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2704242,int_stack+2694522,int_stack+2671437, 0.0, zero_stack, 1.0, int_stack+1579220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2688447,int_stack+2704242,int_stack+2678997, 0.0, zero_stack, 1.0, int_stack+1586780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+2702622,int_stack+2688447,int_stack+2579637,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2736642,int_stack+2702622,int_stack+2590977,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2688447,int_stack+1142021,int_stack+1141580, 1.0, int_stack+1271435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2689770,int_stack+1142609,int_stack+1142021, 1.0, int_stack+1271876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2691534,int_stack+2689770,int_stack+2688447, 1.0, int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2694180,int_stack+1143365,int_stack+1142609, 1.0, int_stack+1272464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2696448,int_stack+2694180,int_stack+2689770, 1.0, int_stack+1321598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2699976,int_stack+2696448,int_stack+2691534, 1.0, int_stack+1323362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1320275,int_stack+1144310,int_stack+1143365, 1.0, int_stack+1273220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2704386,int_stack+1320275,int_stack+2694180, 1.0, int_stack+1326008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2708922,int_stack+2704386,int_stack+2696448, 1.0, int_stack+1328276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2714802,int_stack+2708922,int_stack+2699976, 1.0, int_stack+1331804, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2704386,int_stack+1149938,int_stack+1149350, 1.0, int_stack+1283090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2706150,int_stack+1150722,int_stack+1149938, 1.0, int_stack+1283678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2708502,int_stack+2706150,int_stack+2704386, 1.0, int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320275,int_stack+1151730,int_stack+1150722, 1.0, int_stack+1284462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2721417,int_stack+1320275,int_stack+2706150, 1.0, int_stack+1360532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2726121,int_stack+2721417,int_stack+2708502, 1.0, int_stack+1362884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1358768,int_stack+1152990,int_stack+1151730, 1.0, int_stack+1285470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2789562,int_stack+1358768,int_stack+1320275, 1.0, int_stack+1366412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2795610,int_stack+2789562,int_stack+2721417, 1.0, int_stack+1369436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2803450,int_stack+2795610,int_stack+2726121, 1.0, int_stack+1374140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2812270,int_stack+2803450,int_stack+2714802,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2789562,int_stack+1162230,int_stack+1160466, 1.0, int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2791830,int_stack+1164534,int_stack+1162230, 1.0, int_stack+1161222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2794854,int_stack+2791830,int_stack+2789562, 1.0, int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2799390,int_stack+1167450,int_stack+1164534, 1.0, int_stack+1163238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1358768,int_stack+2799390,int_stack+2791830, 1.0, int_stack+1432205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2832115,int_stack+1358768,int_stack+2794854, 1.0, int_stack+1435229, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1429937,int_stack+1169070,int_stack+1167450, 1.0, int_stack+1165830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2839675,int_stack+1429937,int_stack+2799390, 1.0, int_stack+1439765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2847451,int_stack+2839675,int_stack+1358768, 1.0, int_stack+1443653, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2857531,int_stack+2847451,int_stack+2832115, 1.0, int_stack+1449701, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2868871,int_stack+2857531,int_stack+2803450,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2895331,int_stack+2868871,int_stack+2812270,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2839675,int_stack+556350,int_stack+553200, 1.0, int_stack+552255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2842510,int_stack+560490,int_stack+556350, 1.0, int_stack+555090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2846290,int_stack+2842510,int_stack+2839675, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2851960,int_stack+563730,int_stack+560490, 1.0, int_stack+558870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1429937,int_stack+2851960,int_stack+2842510, 1.0, int_stack+1564910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+1429937,int_stack+2846290, 1.0, int_stack+1568690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1562075,int_stack+14400,int_stack+563730, 1.0, int_stack+12375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2944471,int_stack+1562075,int_stack+2851960, 1.0, int_stack+1574360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1562075,int_stack+2944471,int_stack+1429937, 1.0, int_stack+1579220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2944471,int_stack+1562075,int_stack+2935021, 1.0, int_stack+1586780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1562075,int_stack+2944471,int_stack+2857531,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+2944471,int_stack+1562075,int_stack+2868871,315);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1562075,int_stack+1274165,int_stack+1273220,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1564910,int_stack+1562075,int_stack+1326008,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1569446,int_stack+1564910,int_stack+1328276,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1562075,int_stack+1569446,int_stack+1331804,21);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1568690,int_stack+1286730,int_stack+1285470,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1572470,int_stack+1568690,int_stack+1366412,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1578518,int_stack+1572470,int_stack+1369436,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1568690,int_stack+1578518,int_stack+1374140,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2997391,int_stack+1568690,int_stack+1562075,315);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1577510,int_stack+21825,int_stack+1165830,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1582370,int_stack+1577510,int_stack+1439765,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1364816,int_stack+1582370,int_stack+1443653,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1577510,int_stack+1364816,int_stack+1449701,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3017236,int_stack+1577510,int_stack+1568690,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3043696,int_stack+3017236,int_stack+2997391,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1364816,int_stack+1192326,int_stack+1191885,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1366139,int_stack+1192914,int_stack+1192326,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1367903,int_stack+1366139,int_stack+1364816,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1370549,int_stack+1193670,int_stack+1192914,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1372817,int_stack+1370549,int_stack+1366139,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1588850,int_stack+1372817,int_stack+1367903,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1376345,int_stack+1194615,int_stack+1193670,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1437497,int_stack+1376345,int_stack+1370549,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1442033,int_stack+1437497,int_stack+1372817,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1447913,int_stack+1442033,int_stack+1588850,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1437497,int_stack+1200243,int_stack+1199655,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1439261,int_stack+1201027,int_stack+1200243,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1441613,int_stack+1439261,int_stack+1437497,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1376345,int_stack+1202035,int_stack+1201027,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1283090,int_stack+1376345,int_stack+1439261,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1323299,int_stack+1283090,int_stack+1441613,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1329179,int_stack+1203295,int_stack+1202035,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+7371,int_stack+1329179,int_stack+1376345,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3083386,int_stack+7371,int_stack+1283090,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+7371,int_stack+3083386,int_stack+1323299,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3083386,int_stack+7371,int_stack+1447913, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1329179,int_stack+1210771,int_stack+1210015,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1331447,int_stack+1211779,int_stack+1210771,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2732001,int_stack+1331447,int_stack+1329179,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3103231,int_stack+1213075,int_stack+1211779,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3107119,int_stack+3103231,int_stack+1331447,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3113167,int_stack+3107119,int_stack+2732001,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3120727,int_stack+1214695,int_stack+1213075,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3125587,int_stack+3120727,int_stack+3103231,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3133363,int_stack+3125587,int_stack+3107119,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3120727,int_stack+3133363,int_stack+3113167,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3132067,int_stack+3120727,int_stack+7371, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1568690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3158527,int_stack+3132067,int_stack+3083386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2997391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1593260,int_stack+708120,int_stack+706230,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1271435,int_stack+710640,int_stack+708120,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3198217,int_stack+1271435,int_stack+1593260,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3203887,int_stack+713880,int_stack+710640,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3208747,int_stack+3203887,int_stack+1271435,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3216307,int_stack+3208747,int_stack+3198217,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3225757,int_stack+16875,int_stack+713880,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3231832,int_stack+3225757,int_stack+3203887,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3241552,int_stack+3231832,int_stack+3208747,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3225757,int_stack+3241552,int_stack+3216307,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3239932,int_stack+3225757,int_stack+3120727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1577510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3273952,int_stack+3239932,int_stack+3132067, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3017236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3225757,int_stack+1232101,int_stack+1231660,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3227080,int_stack+1232689,int_stack+1232101,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3228844,int_stack+3227080,int_stack+3225757,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3231490,int_stack+1233445,int_stack+1232689,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3233758,int_stack+3231490,int_stack+3227080,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3237286,int_stack+3233758,int_stack+3228844,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3241696,int_stack+1234390,int_stack+1233445,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3244531,int_stack+3241696,int_stack+3231490,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3249067,int_stack+3244531,int_stack+3233758,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3241696,int_stack+3249067,int_stack+3237286,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3248311,int_stack+1240018,int_stack+1239430,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3250075,int_stack+1240802,int_stack+1240018,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3252427,int_stack+3250075,int_stack+3248311,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3255955,int_stack+1241810,int_stack+1240802,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3258979,int_stack+3255955,int_stack+3250075,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3263683,int_stack+3258979,int_stack+3252427,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3269563,int_stack+1243070,int_stack+1241810,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3326872,int_stack+3269563,int_stack+3255955,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3332920,int_stack+3326872,int_stack+3258979,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3340760,int_stack+3332920,int_stack+3263683,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3349580,int_stack+3340760,int_stack+3241696, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3326872,int_stack+1250546,int_stack+1249790,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3329140,int_stack+1251554,int_stack+1250546,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3332164,int_stack+3329140,int_stack+3326872,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3336700,int_stack+1252850,int_stack+1251554,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3369425,int_stack+3336700,int_stack+3329140,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3375473,int_stack+3369425,int_stack+3332164,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3383033,int_stack+1254470,int_stack+1252850,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3387893,int_stack+3383033,int_stack+3336700,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3395669,int_stack+3387893,int_stack+3369425,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3383033,int_stack+3395669,int_stack+3375473,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3394373,int_stack+3383033,int_stack+3340760, 0.0, zero_stack, 1.0, int_stack+1568690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3420833,int_stack+3394373,int_stack+3349580, 0.0, zero_stack, 1.0, int_stack+2997391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3269563,int_stack+882320,int_stack+880430,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3460523,int_stack+884840,int_stack+882320,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3464303,int_stack+3460523,int_stack+3269563,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3469973,int_stack+888080,int_stack+884840,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3474833,int_stack+3469973,int_stack+3460523,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3482393,int_stack+3474833,int_stack+3464303,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3491843,int_stack+19350,int_stack+888080,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3497918,int_stack+3491843,int_stack+3469973,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3507638,int_stack+3497918,int_stack+3474833,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3491843,int_stack+3507638,int_stack+3482393,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3506018,int_stack+3491843,int_stack+3383033, 0.0, zero_stack, 1.0, int_stack+1577510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3540038,int_stack+3506018,int_stack+3394373, 0.0, zero_stack, 1.0, int_stack+3017236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3491843,int_stack+1275761,int_stack+1275320,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3493166,int_stack+1276349,int_stack+1275761,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3494930,int_stack+3493166,int_stack+3491843,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3497576,int_stack+1277105,int_stack+1276349,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3499844,int_stack+3497576,int_stack+3493166,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3503372,int_stack+3499844,int_stack+3494930,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3507782,int_stack+1278050,int_stack+1277105,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3510617,int_stack+3507782,int_stack+3497576,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3515153,int_stack+3510617,int_stack+3499844,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3507782,int_stack+3515153,int_stack+3503372,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3514397,int_stack+1288858,int_stack+1288270,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3516161,int_stack+1289642,int_stack+1288858,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3518513,int_stack+3516161,int_stack+3514397,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3522041,int_stack+1290650,int_stack+1289642,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3525065,int_stack+3522041,int_stack+3516161,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3529769,int_stack+3525065,int_stack+3518513,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3535649,int_stack+1291910,int_stack+1290650,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+16191,int_stack+3535649,int_stack+3522041,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3592958,int_stack+16191,int_stack+3525065,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3600798,int_stack+3592958,int_stack+3529769,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3609618,int_stack+3600798,int_stack+3507782, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1562075,int_stack+1299386,int_stack+1298630,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1564343,int_stack+1300394,int_stack+1299386,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3592958,int_stack+1564343,int_stack+1562075,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+16191,int_stack+1301690,int_stack+1300394,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3629463,int_stack+16191,int_stack+1564343,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3635511,int_stack+3629463,int_stack+3592958,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3643071,int_stack+1303310,int_stack+1301690,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3647931,int_stack+3643071,int_stack+16191,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3655707,int_stack+3647931,int_stack+3629463,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3643071,int_stack+3655707,int_stack+3635511,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3654411,int_stack+3643071,int_stack+3600798, 1.0, int_stack+1568690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3680871,int_stack+3654411,int_stack+3609618, 1.0, int_stack+2997391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2997391,int_stack+1179600,int_stack+1177710,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3000226,int_stack+1182120,int_stack+1179600,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3004006,int_stack+3000226,int_stack+2997391,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3009676,int_stack+1185360,int_stack+1182120,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1567367,int_stack+3009676,int_stack+3000226,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3720561,int_stack+1567367,int_stack+3004006,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+23805,int_stack+1185360,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3736086,int_stack+3730011,int_stack+3009676,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3745806,int_stack+3736086,int_stack+1567367,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3730011,int_stack+3745806,int_stack+3720561,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3744186,int_stack+3730011,int_stack+3643071, 1.0, int_stack+1577510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3778206,int_stack+3744186,int_stack+3654411, 1.0, int_stack+3017236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+26721,int_stack+26280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+942705,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+27309,int_stack+26721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+943146,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1336214,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+28065,int_stack+27309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+943734,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1337537,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1339301,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+29010,int_stack+28065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+944490,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1341947,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1344215,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1347743,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+30753,int_stack+30165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+950475,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+31537,int_stack+30753, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+951063,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1380020,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+32545,int_stack+31537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+951847,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1381784,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1384136,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+33805,int_stack+32545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+952855,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1387664,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1390688,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1395392,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3014536,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+36101,int_stack+35345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+960835,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+37109,int_stack+36101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+961591,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1457261,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+38405,int_stack+37109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+962599,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1459529,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1462553,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+40025,int_stack+38405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+963895,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1467089,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1470977,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1574927,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1477025,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+1574927,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3831126,int_stack+3730011,int_stack+3014536,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3014536,int_stack+42950,int_stack+42005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+402755,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3017371,int_stack+44210,int_stack+42950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+404645,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3021151,int_stack+3017371,int_stack+3014536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1596230,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3026821,int_stack+45830,int_stack+44210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+407165,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3031681,int_stack+3026821,int_stack+3017371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1599065,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3756471,int_stack+3031681,int_stack+3021151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1602845,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3014536,int_stack+47855,int_stack+45830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+410405,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3765921,int_stack+3014536,int_stack+3026821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1608515,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3014536,int_stack+3765921,int_stack+3031681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1613375,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3027136,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1620935,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3027136,int_stack+1574927,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3904836,int_stack+3870816,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+50771,int_stack+50330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+942705, 1.0, int_stack+982480,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+51359,int_stack+50771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+943146, 1.0, int_stack+982921,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336214, 1.0, int_stack+1630385,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+52115,int_stack+51359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+943734, 1.0, int_stack+983509,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1337537, 1.0, int_stack+1631708,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1339301, 1.0, int_stack+1633472,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+53060,int_stack+52115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+944490, 1.0, int_stack+984265,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1341947, 1.0, int_stack+1636118,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1344215, 1.0, int_stack+1638386,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347743, 1.0, int_stack+1641914,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+54803,int_stack+54215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+950475, 1.0, int_stack+990250,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+55587,int_stack+54803, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951063, 1.0, int_stack+990838,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1380020, 1.0, int_stack+1652939,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+56595,int_stack+55587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951847, 1.0, int_stack+991622,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1381784, 1.0, int_stack+1654703,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1384136, 1.0, int_stack+1657055,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+57855,int_stack+56595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+952855, 1.0, int_stack+992630,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1387664, 1.0, int_stack+1660583,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1390688, 1.0, int_stack+1663607,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1395392, 1.0, int_stack+1668311,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+60151,int_stack+59395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960835, 1.0, int_stack+1000610,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+61159,int_stack+60151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+961591, 1.0, int_stack+1001366,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1457261, 1.0, int_stack+1731500,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+62455,int_stack+61159, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962599, 1.0, int_stack+1002374,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1459529, 1.0, int_stack+1733768,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1462553, 1.0, int_stack+1736792,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+64075,int_stack+62455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963895, 1.0, int_stack+1003670,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1467089, 1.0, int_stack+1741328,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1470977, 1.0, int_stack+1774053,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3890661,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477025, 1.0, int_stack+1780101,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3890661,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+20079,int_stack+3730011,int_stack+3870816,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3902001,int_stack+67000,int_stack+66055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+402755, 1.0, int_stack+432655,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3870816,int_stack+68260,int_stack+67000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404645, 1.0, int_stack+434545,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3874596,int_stack+3870816,int_stack+3902001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1596230, 1.0, int_stack+1674191,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3880266,int_stack+69880,int_stack+68260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407165, 1.0, int_stack+437065,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3880266,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1599065, 1.0, int_stack+1865151,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3874596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1602845, 1.0, int_stack+1868931,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+71905,int_stack+69880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410405, 1.0, int_stack+440305,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1574927,int_stack+3870816,int_stack+3880266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1608515, 1.0, int_stack+1874601,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+1574927,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1613375, 1.0, int_stack+1879461,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3764031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1620935, 1.0, int_stack+1887021,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3014536,int_stack+3890661,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+3991776,int_stack+3957756,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+74821,int_stack+74380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+982480, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+75409,int_stack+74821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+982921, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1630385, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+76165,int_stack+75409, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+983509, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1631708, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1633472, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+77110,int_stack+76165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+984265, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1636118, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1638386, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1641914, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+78853,int_stack+78265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+990250, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+79637,int_stack+78853, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+990838, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1652939, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+80645,int_stack+79637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+991622, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1654703, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1657055, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+81905,int_stack+80645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+992630, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1660583, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1663607, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1668311, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+84201,int_stack+83445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1000610, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+85209,int_stack+84201, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1001366, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1731500, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+86505,int_stack+85209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1002374, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1733768, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1736792, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+88125,int_stack+86505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1003670, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1741328, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1774053, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3977601,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1780101, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3977601,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4044696,int_stack+3730011,int_stack+3957756,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3988941,int_stack+91050,int_stack+90105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+432655, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3957756,int_stack+92310,int_stack+91050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+434545, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3961536,int_stack+3957756,int_stack+3988941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1674191, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3967206,int_stack+93930,int_stack+92310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+437065, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3967206,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1865151, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3961536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1868931, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+95955,int_stack+93930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+440305, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3967206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1874601, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1879461, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3764031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1887021, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3014536,int_stack+3977601,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4084386,int_stack+3870816,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+98871,int_stack+98430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+942705, 0.0, zero_stack, 1.0, int_stack+1022255,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+99459,int_stack+98871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+943146, 0.0, zero_stack, 1.0, int_stack+1022696,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336214, 0.0, zero_stack, 1.0, int_stack+1896471,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+100215,int_stack+99459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+943734, 0.0, zero_stack, 1.0, int_stack+1023284,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1337537, 0.0, zero_stack, 1.0, int_stack+1897794,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1339301, 0.0, zero_stack, 1.0, int_stack+1899558,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+101160,int_stack+100215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+944490, 0.0, zero_stack, 1.0, int_stack+1024040,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1341947, 0.0, zero_stack, 1.0, int_stack+1902204,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1344215, 0.0, zero_stack, 1.0, int_stack+1904472,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347743, 0.0, zero_stack, 1.0, int_stack+1908000,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+102903,int_stack+102315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+950475, 0.0, zero_stack, 1.0, int_stack+1030025,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+103687,int_stack+102903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951063, 0.0, zero_stack, 1.0, int_stack+1030613,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1380020, 0.0, zero_stack, 1.0, int_stack+1919025,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+104695,int_stack+103687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951847, 0.0, zero_stack, 1.0, int_stack+1031397,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1381784, 0.0, zero_stack, 1.0, int_stack+1920789,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1384136, 0.0, zero_stack, 1.0, int_stack+1923141,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+105955,int_stack+104695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+952855, 0.0, zero_stack, 1.0, int_stack+1032405,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1387664, 0.0, zero_stack, 1.0, int_stack+1926669,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1390688, 0.0, zero_stack, 1.0, int_stack+1929693,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1395392, 0.0, zero_stack, 1.0, int_stack+1934397,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+108251,int_stack+107495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960835, 0.0, zero_stack, 1.0, int_stack+1040385,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+109259,int_stack+108251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+961591, 0.0, zero_stack, 1.0, int_stack+1041141,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1457261, 0.0, zero_stack, 1.0, int_stack+1997586,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+110555,int_stack+109259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962599, 0.0, zero_stack, 1.0, int_stack+1042149,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1459529, 0.0, zero_stack, 1.0, int_stack+1999854,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1462553, 0.0, zero_stack, 1.0, int_stack+2002878,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+112175,int_stack+110555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963895, 0.0, zero_stack, 1.0, int_stack+1043445,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1467089, 0.0, zero_stack, 1.0, int_stack+2007414,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1470977, 0.0, zero_stack, 1.0, int_stack+2040139,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3890661,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477025, 0.0, zero_stack, 1.0, int_stack+2046187,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3890661,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+59769,int_stack+3730011,int_stack+3870816,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3902001,int_stack+115100,int_stack+114155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+402755, 0.0, zero_stack, 1.0, int_stack+462555,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3870816,int_stack+116360,int_stack+115100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404645, 0.0, zero_stack, 1.0, int_stack+464445,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3874596,int_stack+3870816,int_stack+3902001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1596230, 0.0, zero_stack, 1.0, int_stack+2053747,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3880266,int_stack+117980,int_stack+116360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407165, 0.0, zero_stack, 1.0, int_stack+466965,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3880266,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1599065, 0.0, zero_stack, 1.0, int_stack+2056582,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3874596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1602845, 0.0, zero_stack, 1.0, int_stack+2060362,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+120005,int_stack+117980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410405, 0.0, zero_stack, 1.0, int_stack+470205,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3880266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1608515, 0.0, zero_stack, 1.0, int_stack+2066032,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1613375, 0.0, zero_stack, 1.0, int_stack+2149093,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3764031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1620935, 0.0, zero_stack, 1.0, int_stack+2156653,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3014536,int_stack+3890661,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4137306,int_stack+3957756,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+122921,int_stack+122480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+982480, 1.0, int_stack+1022255, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+123509,int_stack+122921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+982921, 1.0, int_stack+1022696, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1630385, 1.0, int_stack+1896471, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+124265,int_stack+123509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+983509, 1.0, int_stack+1023284, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1631708, 1.0, int_stack+1897794, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1633472, 1.0, int_stack+1899558, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+125210,int_stack+124265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+984265, 1.0, int_stack+1024040, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1636118, 1.0, int_stack+1902204, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1638386, 1.0, int_stack+1904472, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1641914, 1.0, int_stack+1908000, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+126953,int_stack+126365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+990250, 1.0, int_stack+1030025, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+127737,int_stack+126953, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+990838, 1.0, int_stack+1030613, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1652939, 1.0, int_stack+1919025, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+128745,int_stack+127737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+991622, 1.0, int_stack+1031397, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1654703, 1.0, int_stack+1920789, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1657055, 1.0, int_stack+1923141, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+130005,int_stack+128745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+992630, 1.0, int_stack+1032405, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1660583, 1.0, int_stack+1926669, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1663607, 1.0, int_stack+1929693, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1668311, 1.0, int_stack+1934397, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+132301,int_stack+131545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000610, 1.0, int_stack+1040385, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+133309,int_stack+132301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001366, 1.0, int_stack+1041141, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1731500, 1.0, int_stack+1997586, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+134605,int_stack+133309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1002374, 1.0, int_stack+1042149, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1733768, 1.0, int_stack+1999854, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1736792, 1.0, int_stack+2002878, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+136225,int_stack+134605, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003670, 1.0, int_stack+1043445, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1741328, 1.0, int_stack+2007414, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1774053, 1.0, int_stack+2040139, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3977601,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780101, 1.0, int_stack+2046187, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3977601,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4190226,int_stack+3730011,int_stack+3957756,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3988941,int_stack+139150,int_stack+138205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+432655, 1.0, int_stack+462555, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3957756,int_stack+140410,int_stack+139150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434545, 1.0, int_stack+464445, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3961536,int_stack+3957756,int_stack+3988941, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1674191, 1.0, int_stack+2053747, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3967206,int_stack+142030,int_stack+140410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437065, 1.0, int_stack+466965, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3967206,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1865151, 1.0, int_stack+2056582, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3961536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1868931, 1.0, int_stack+2060362, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+144055,int_stack+142030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440305, 1.0, int_stack+470205, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3967206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1874601, 1.0, int_stack+2066032, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879461, 1.0, int_stack+2149093, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3764031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1887021, 1.0, int_stack+2156653, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3014536,int_stack+3977601,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4229916,int_stack+3870816,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+146971,int_stack+146530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1022255, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+147559,int_stack+146971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1022696, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1896471, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+148315,int_stack+147559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1023284, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1897794, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1899558, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+149260,int_stack+148315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1024040, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1902204, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1904472, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1908000, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+151003,int_stack+150415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1030025, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+151787,int_stack+151003, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1030613, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1919025, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+152795,int_stack+151787, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1031397, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1920789, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1923141, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+154055,int_stack+152795, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1032405, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1926669, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1929693, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1934397, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+156351,int_stack+155595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1040385, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+157359,int_stack+156351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1041141, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1997586, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+158655,int_stack+157359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1042149, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1999854, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2002878, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+160275,int_stack+158655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1043445, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2007414, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2040139, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3890661,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2046187, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3890661,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+99459,int_stack+3730011,int_stack+3870816,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3902001,int_stack+163200,int_stack+162255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+462555, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3870816,int_stack+164460,int_stack+163200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+464445, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3874596,int_stack+3870816,int_stack+3902001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2053747, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3880266,int_stack+166080,int_stack+164460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+466965, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3880266,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2056582, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3874596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2060362, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+168105,int_stack+166080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+470205, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3880266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2066032, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2149093, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3764031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2156653, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3014536,int_stack+3890661,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4282836,int_stack+3957756,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+171021,int_stack+170580, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+942705, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1062030,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+171609,int_stack+171021, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+943146, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1062471,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1336214, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2166103,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+172365,int_stack+171609, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+943734, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063059,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1337537, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2167426,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1339301, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2169190,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+173310,int_stack+172365, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+944490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1063815,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1341947, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2171836,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1344215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2174104,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1347743, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2177632,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+175053,int_stack+174465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+950475, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1069800,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+175837,int_stack+175053, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951063, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1070388,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1380020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2188657,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+176845,int_stack+175837, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+951847, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1071172,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1381784, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2190421,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1384136, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2192773,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+178105,int_stack+176845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+952855, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1072180,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1387664, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2196301,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1390688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2199325,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1395392, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2204029,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+180401,int_stack+179645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+960835, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080160,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+181409,int_stack+180401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+961591, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1080916,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1457261, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2267218,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+182705,int_stack+181409, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+962599, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1081924,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1459529, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2269486,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1462553, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+184325,int_stack+182705, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1083220,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1467089, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2209909,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1470977, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2303723,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3977601,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1477025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2309771,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3977601,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+139149,int_stack+3730011,int_stack+3957756,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3988941,int_stack+187250,int_stack+186305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+402755, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+492455,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3957756,int_stack+188510,int_stack+187250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404645, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494345,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3961536,int_stack+3957756,int_stack+3988941, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1596230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+4536,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3967206,int_stack+190130,int_stack+188510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+407165, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+496865,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3967206,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1599065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1940277,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3961536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1602845, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2394821,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+192155,int_stack+190130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500105,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3967206, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1608515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2400491,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1613375, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2405351,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3764031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1620935, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2412911,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3014536,int_stack+3977601,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4335756,int_stack+3870816,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+195071,int_stack+194630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+982480, 0.0, zero_stack, 1.0, int_stack+1062030, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+195659,int_stack+195071, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+982921, 0.0, zero_stack, 1.0, int_stack+1062471, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1630385, 0.0, zero_stack, 1.0, int_stack+2166103, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+196415,int_stack+195659, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+983509, 0.0, zero_stack, 1.0, int_stack+1063059, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1631708, 0.0, zero_stack, 1.0, int_stack+2167426, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1633472, 0.0, zero_stack, 1.0, int_stack+2169190, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+197360,int_stack+196415, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+984265, 0.0, zero_stack, 1.0, int_stack+1063815, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1636118, 0.0, zero_stack, 1.0, int_stack+2171836, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1638386, 0.0, zero_stack, 1.0, int_stack+2174104, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1641914, 0.0, zero_stack, 1.0, int_stack+2177632, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+199103,int_stack+198515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+990250, 0.0, zero_stack, 1.0, int_stack+1069800, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+199887,int_stack+199103, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+990838, 0.0, zero_stack, 1.0, int_stack+1070388, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1652939, 0.0, zero_stack, 1.0, int_stack+2188657, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+200895,int_stack+199887, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+991622, 0.0, zero_stack, 1.0, int_stack+1071172, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1654703, 0.0, zero_stack, 1.0, int_stack+2190421, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1657055, 0.0, zero_stack, 1.0, int_stack+2192773, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+202155,int_stack+200895, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+992630, 0.0, zero_stack, 1.0, int_stack+1072180, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1660583, 0.0, zero_stack, 1.0, int_stack+2196301, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1663607, 0.0, zero_stack, 1.0, int_stack+2199325, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1668311, 0.0, zero_stack, 1.0, int_stack+2204029, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+204451,int_stack+203695, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1000610, 0.0, zero_stack, 1.0, int_stack+1080160, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+205459,int_stack+204451, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1001366, 0.0, zero_stack, 1.0, int_stack+1080916, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1731500, 0.0, zero_stack, 1.0, int_stack+2267218, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+206755,int_stack+205459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1002374, 0.0, zero_stack, 1.0, int_stack+1081924, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1733768, 0.0, zero_stack, 1.0, int_stack+2269486, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1736792, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+208375,int_stack+206755, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1003670, 0.0, zero_stack, 1.0, int_stack+1083220, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1741328, 0.0, zero_stack, 1.0, int_stack+2209909, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1774053, 0.0, zero_stack, 1.0, int_stack+2303723, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3890661,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1780101, 0.0, zero_stack, 1.0, int_stack+2309771, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3890661,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4388676,int_stack+3730011,int_stack+3870816,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3902001,int_stack+211300,int_stack+210355, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+432655, 0.0, zero_stack, 1.0, int_stack+492455, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3870816,int_stack+212560,int_stack+211300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+434545, 0.0, zero_stack, 1.0, int_stack+494345, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3874596,int_stack+3870816,int_stack+3902001, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1674191, 0.0, zero_stack, 1.0, int_stack+4536, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3880266,int_stack+214180,int_stack+212560, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+437065, 0.0, zero_stack, 1.0, int_stack+496865, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3880266,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1865151, 0.0, zero_stack, 1.0, int_stack+1940277, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3874596, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1868931, 0.0, zero_stack, 1.0, int_stack+2394821, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+216205,int_stack+214180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+440305, 0.0, zero_stack, 1.0, int_stack+500105, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3880266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1874601, 0.0, zero_stack, 1.0, int_stack+2400491, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1879461, 0.0, zero_stack, 1.0, int_stack+2405351, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3764031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1887021, 0.0, zero_stack, 1.0, int_stack+2412911, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3014536,int_stack+3890661,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4428366,int_stack+3957756,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+219121,int_stack+218680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1022255, 1.0, int_stack+1062030, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+219709,int_stack+219121, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1022696, 1.0, int_stack+1062471, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1896471, 1.0, int_stack+2166103, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+220465,int_stack+219709, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1023284, 1.0, int_stack+1063059, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1897794, 1.0, int_stack+2167426, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1899558, 1.0, int_stack+2169190, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+221410,int_stack+220465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1024040, 1.0, int_stack+1063815, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1902204, 1.0, int_stack+2171836, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1904472, 1.0, int_stack+2174104, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1908000, 1.0, int_stack+2177632, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+223153,int_stack+222565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1030025, 1.0, int_stack+1069800, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+223937,int_stack+223153, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1030613, 1.0, int_stack+1070388, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1919025, 1.0, int_stack+2188657, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+224945,int_stack+223937, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1031397, 1.0, int_stack+1071172, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1920789, 1.0, int_stack+2190421, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1923141, 1.0, int_stack+2192773, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+226205,int_stack+224945, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1032405, 1.0, int_stack+1072180, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1926669, 1.0, int_stack+2196301, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1929693, 1.0, int_stack+2199325, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1934397, 1.0, int_stack+2204029, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+228501,int_stack+227745, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1040385, 1.0, int_stack+1080160, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+229509,int_stack+228501, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1041141, 1.0, int_stack+1080916, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1997586, 1.0, int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+230805,int_stack+229509, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1042149, 1.0, int_stack+1081924, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1999854, 1.0, int_stack+2269486, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2002878, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+232425,int_stack+230805, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1043445, 1.0, int_stack+1083220, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2007414, 1.0, int_stack+2209909, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2040139, 1.0, int_stack+2303723, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3977601,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2046187, 1.0, int_stack+2309771, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3977601,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+178839,int_stack+3730011,int_stack+3957756,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3988941,int_stack+235350,int_stack+234405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+462555, 1.0, int_stack+492455, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3957756,int_stack+236610,int_stack+235350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464445, 1.0, int_stack+494345, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3961536,int_stack+3957756,int_stack+3988941, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2053747, 1.0, int_stack+4536, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3967206,int_stack+238230,int_stack+236610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+466965, 1.0, int_stack+496865, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3967206,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2056582, 1.0, int_stack+1940277, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3961536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2060362, 1.0, int_stack+2394821, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+240255,int_stack+238230, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+470205, 1.0, int_stack+500105, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3967206, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2066032, 1.0, int_stack+2400491, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2149093, 1.0, int_stack+2405351, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3764031, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2156653, 1.0, int_stack+2412911, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3014536,int_stack+3977601,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4481286,int_stack+3870816,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+243171,int_stack+242730, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1062030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+243759,int_stack+243171, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1062471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2166103, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+244515,int_stack+243759, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1063059, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2167426, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2169190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+245460,int_stack+244515, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1063815, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2171836, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2174104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2177632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+247203,int_stack+246615, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1069800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+247987,int_stack+247203, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1070388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2188657, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+248995,int_stack+247987, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1071172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2190421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2192773, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+250255,int_stack+248995, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1072180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2196301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2199325, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2204029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+252551,int_stack+251795, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1080160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+253559,int_stack+252551, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1080916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+254855,int_stack+253559, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1081924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2269486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+256475,int_stack+254855, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1083220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2209909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2303723, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3890661,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2309771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3890661,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+218529,int_stack+3730011,int_stack+3870816,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3902001,int_stack+259400,int_stack+258455, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+492455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3870816,int_stack+260660,int_stack+259400, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+494345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3874596,int_stack+3870816,int_stack+3902001, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+4536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3880266,int_stack+262280,int_stack+260660, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+496865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3880266,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1940277, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3874596, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2394821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+264305,int_stack+262280, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+500105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3880266, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2400491, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2405351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3764031, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+2412911, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3014536,int_stack+3890661,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4534206,int_stack+3957756,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+267221,int_stack+266780, 0.0, zero_stack, 1.0, int_stack+942705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1101805,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+267809,int_stack+267221, 0.0, zero_stack, 1.0, int_stack+943146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102246,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+1336214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2422361,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+268565,int_stack+267809, 0.0, zero_stack, 1.0, int_stack+943734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102834,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 1.0, int_stack+1337537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2423684,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 1.0, int_stack+1339301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2425448,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+269510,int_stack+268565, 0.0, zero_stack, 1.0, int_stack+944490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1103590,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 1.0, int_stack+1341947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2428094,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 1.0, int_stack+1344215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2430362,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 1.0, int_stack+1347743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2433890,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+271253,int_stack+270665, 0.0, zero_stack, 1.0, int_stack+950475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1109575,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+272037,int_stack+271253, 0.0, zero_stack, 1.0, int_stack+951063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1110163,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+1380020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2444915,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+273045,int_stack+272037, 0.0, zero_stack, 1.0, int_stack+951847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1110947,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 1.0, int_stack+1381784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2446679,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 1.0, int_stack+1384136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2449031,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+274305,int_stack+273045, 0.0, zero_stack, 1.0, int_stack+952855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1111955,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 1.0, int_stack+1387664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2452559,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 1.0, int_stack+1390688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455583,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 1.0, int_stack+1395392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2460287,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+276601,int_stack+275845, 0.0, zero_stack, 1.0, int_stack+960835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1119935,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+277609,int_stack+276601, 0.0, zero_stack, 1.0, int_stack+961591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1120691,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+1457261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2523476,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+278905,int_stack+277609, 0.0, zero_stack, 1.0, int_stack+962599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1121699,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 1.0, int_stack+1459529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2525744,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 1.0, int_stack+1462553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2528768,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+280525,int_stack+278905, 0.0, zero_stack, 1.0, int_stack+963895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1122995,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 1.0, int_stack+1467089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2533304,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 1.0, int_stack+1470977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2566029,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3977601,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 1.0, int_stack+1477025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2572077,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3977601,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4587126,int_stack+3730011,int_stack+3957756,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3988941,int_stack+283450,int_stack+282505, 0.0, zero_stack, 1.0, int_stack+402755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522355,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3957756,int_stack+284710,int_stack+283450, 0.0, zero_stack, 1.0, int_stack+404645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524245,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3961536,int_stack+3957756,int_stack+3988941, 0.0, zero_stack, 1.0, int_stack+1596230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2466167,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3967206,int_stack+286330,int_stack+284710, 0.0, zero_stack, 1.0, int_stack+407165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+526765,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3967206,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+1599065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2657127,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3961536, 0.0, zero_stack, 1.0, int_stack+1602845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2660907,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+288355,int_stack+286330, 0.0, zero_stack, 1.0, int_stack+410405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530005,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3967206, 0.0, zero_stack, 1.0, int_stack+1608515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2666577,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 1.0, int_stack+1613375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2671437,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3764031, 0.0, zero_stack, 1.0, int_stack+1620935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2678997,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3014536,int_stack+3977601,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4626816,int_stack+3870816,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+291271,int_stack+290830, 0.0, zero_stack, 1.0, int_stack+982480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1101805, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+291859,int_stack+291271, 0.0, zero_stack, 1.0, int_stack+982921, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102246, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+1630385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2422361, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+292615,int_stack+291859, 0.0, zero_stack, 1.0, int_stack+983509, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1102834, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 1.0, int_stack+1631708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2423684, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 1.0, int_stack+1633472, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2425448, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+293560,int_stack+292615, 0.0, zero_stack, 1.0, int_stack+984265, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1103590, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 1.0, int_stack+1636118, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2428094, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 1.0, int_stack+1638386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2430362, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 1.0, int_stack+1641914, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2433890, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+295303,int_stack+294715, 0.0, zero_stack, 1.0, int_stack+990250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1109575, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+296087,int_stack+295303, 0.0, zero_stack, 1.0, int_stack+990838, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1110163, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+1652939, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2444915, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+297095,int_stack+296087, 0.0, zero_stack, 1.0, int_stack+991622, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1110947, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 1.0, int_stack+1654703, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2446679, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 1.0, int_stack+1657055, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2449031, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+298355,int_stack+297095, 0.0, zero_stack, 1.0, int_stack+992630, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1111955, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 1.0, int_stack+1660583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2452559, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 1.0, int_stack+1663607, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2455583, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 1.0, int_stack+1668311, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2460287, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+300651,int_stack+299895, 0.0, zero_stack, 1.0, int_stack+1000610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1119935, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+301659,int_stack+300651, 0.0, zero_stack, 1.0, int_stack+1001366, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1120691, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+1731500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2523476, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+302955,int_stack+301659, 0.0, zero_stack, 1.0, int_stack+1002374, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1121699, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 1.0, int_stack+1733768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2525744, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 1.0, int_stack+1736792, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2528768, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+304575,int_stack+302955, 0.0, zero_stack, 1.0, int_stack+1003670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1122995, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 1.0, int_stack+1741328, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2533304, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 1.0, int_stack+1774053, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2566029, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3890661,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 1.0, int_stack+1780101, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2572077, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3890661,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+258219,int_stack+3730011,int_stack+3870816,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3902001,int_stack+307500,int_stack+306555, 0.0, zero_stack, 1.0, int_stack+432655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+522355, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3870816,int_stack+308760,int_stack+307500, 0.0, zero_stack, 1.0, int_stack+434545, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+524245, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3874596,int_stack+3870816,int_stack+3902001, 0.0, zero_stack, 1.0, int_stack+1674191, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2466167, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3880266,int_stack+310380,int_stack+308760, 0.0, zero_stack, 1.0, int_stack+437065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+526765, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3880266,int_stack+3870816, 0.0, zero_stack, 1.0, int_stack+1865151, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2657127, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3874596, 0.0, zero_stack, 1.0, int_stack+1868931, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2660907, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+312405,int_stack+310380, 0.0, zero_stack, 1.0, int_stack+440305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+530005, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3880266, 0.0, zero_stack, 1.0, int_stack+1874601, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2666577, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 1.0, int_stack+1879461, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2671437, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3764031, 0.0, zero_stack, 1.0, int_stack+1887021, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2678997, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3014536,int_stack+3890661,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4679736,int_stack+3957756,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+315321,int_stack+314880, 0.0, zero_stack, 1.0, int_stack+1022255, 0.0, zero_stack, 1.0, int_stack+1101805, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+315909,int_stack+315321, 0.0, zero_stack, 1.0, int_stack+1022696, 0.0, zero_stack, 1.0, int_stack+1102246, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+1896471, 0.0, zero_stack, 1.0, int_stack+2422361, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+316665,int_stack+315909, 0.0, zero_stack, 1.0, int_stack+1023284, 0.0, zero_stack, 1.0, int_stack+1102834, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 1.0, int_stack+1897794, 0.0, zero_stack, 1.0, int_stack+2423684, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 1.0, int_stack+1899558, 0.0, zero_stack, 1.0, int_stack+2425448, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+317610,int_stack+316665, 0.0, zero_stack, 1.0, int_stack+1024040, 0.0, zero_stack, 1.0, int_stack+1103590, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 1.0, int_stack+1902204, 0.0, zero_stack, 1.0, int_stack+2428094, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 1.0, int_stack+1904472, 0.0, zero_stack, 1.0, int_stack+2430362, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 1.0, int_stack+1908000, 0.0, zero_stack, 1.0, int_stack+2433890, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+319353,int_stack+318765, 0.0, zero_stack, 1.0, int_stack+1030025, 0.0, zero_stack, 1.0, int_stack+1109575, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+320137,int_stack+319353, 0.0, zero_stack, 1.0, int_stack+1030613, 0.0, zero_stack, 1.0, int_stack+1110163, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+1919025, 0.0, zero_stack, 1.0, int_stack+2444915, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+321145,int_stack+320137, 0.0, zero_stack, 1.0, int_stack+1031397, 0.0, zero_stack, 1.0, int_stack+1110947, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 1.0, int_stack+1920789, 0.0, zero_stack, 1.0, int_stack+2446679, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 1.0, int_stack+1923141, 0.0, zero_stack, 1.0, int_stack+2449031, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+322405,int_stack+321145, 0.0, zero_stack, 1.0, int_stack+1032405, 0.0, zero_stack, 1.0, int_stack+1111955, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 1.0, int_stack+1926669, 0.0, zero_stack, 1.0, int_stack+2452559, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 1.0, int_stack+1929693, 0.0, zero_stack, 1.0, int_stack+2455583, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 1.0, int_stack+1934397, 0.0, zero_stack, 1.0, int_stack+2460287, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+324701,int_stack+323945, 0.0, zero_stack, 1.0, int_stack+1040385, 0.0, zero_stack, 1.0, int_stack+1119935, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+325709,int_stack+324701, 0.0, zero_stack, 1.0, int_stack+1041141, 0.0, zero_stack, 1.0, int_stack+1120691, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+1997586, 0.0, zero_stack, 1.0, int_stack+2523476, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+327005,int_stack+325709, 0.0, zero_stack, 1.0, int_stack+1042149, 0.0, zero_stack, 1.0, int_stack+1121699, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 1.0, int_stack+1999854, 0.0, zero_stack, 1.0, int_stack+2525744, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 1.0, int_stack+2002878, 0.0, zero_stack, 1.0, int_stack+2528768, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+328625,int_stack+327005, 0.0, zero_stack, 1.0, int_stack+1043445, 0.0, zero_stack, 1.0, int_stack+1122995, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 1.0, int_stack+2007414, 0.0, zero_stack, 1.0, int_stack+2533304, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 1.0, int_stack+2040139, 0.0, zero_stack, 1.0, int_stack+2566029, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3977601,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 1.0, int_stack+2046187, 0.0, zero_stack, 1.0, int_stack+2572077, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3977601,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4732656,int_stack+3730011,int_stack+3957756,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3988941,int_stack+331550,int_stack+330605, 0.0, zero_stack, 1.0, int_stack+462555, 0.0, zero_stack, 1.0, int_stack+522355, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3957756,int_stack+332810,int_stack+331550, 0.0, zero_stack, 1.0, int_stack+464445, 0.0, zero_stack, 1.0, int_stack+524245, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3961536,int_stack+3957756,int_stack+3988941, 0.0, zero_stack, 1.0, int_stack+2053747, 0.0, zero_stack, 1.0, int_stack+2466167, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3967206,int_stack+334430,int_stack+332810, 0.0, zero_stack, 1.0, int_stack+466965, 0.0, zero_stack, 1.0, int_stack+526765, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3967206,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+2056582, 0.0, zero_stack, 1.0, int_stack+2657127, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3961536, 0.0, zero_stack, 1.0, int_stack+2060362, 0.0, zero_stack, 1.0, int_stack+2660907, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+336455,int_stack+334430, 0.0, zero_stack, 1.0, int_stack+470205, 0.0, zero_stack, 1.0, int_stack+530005, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3967206, 0.0, zero_stack, 1.0, int_stack+2066032, 0.0, zero_stack, 1.0, int_stack+2666577, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 1.0, int_stack+2149093, 0.0, zero_stack, 1.0, int_stack+2671437, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3764031, 0.0, zero_stack, 1.0, int_stack+2156653, 0.0, zero_stack, 1.0, int_stack+2678997, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3014536,int_stack+3977601,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4772346,int_stack+3870816,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+339371,int_stack+338930, 0.0, zero_stack, 1.0, int_stack+1062030, 1.0, int_stack+1101805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+339959,int_stack+339371, 0.0, zero_stack, 1.0, int_stack+1062471, 1.0, int_stack+1102246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+2166103, 1.0, int_stack+2422361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+340715,int_stack+339959, 0.0, zero_stack, 1.0, int_stack+1063059, 1.0, int_stack+1102834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 1.0, int_stack+2167426, 1.0, int_stack+2423684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 1.0, int_stack+2169190, 1.0, int_stack+2425448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+341660,int_stack+340715, 0.0, zero_stack, 1.0, int_stack+1063815, 1.0, int_stack+1103590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 1.0, int_stack+2171836, 1.0, int_stack+2428094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 1.0, int_stack+2174104, 1.0, int_stack+2430362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 1.0, int_stack+2177632, 1.0, int_stack+2433890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+343403,int_stack+342815, 0.0, zero_stack, 1.0, int_stack+1069800, 1.0, int_stack+1109575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+344187,int_stack+343403, 0.0, zero_stack, 1.0, int_stack+1070388, 1.0, int_stack+1110163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+2188657, 1.0, int_stack+2444915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+345195,int_stack+344187, 0.0, zero_stack, 1.0, int_stack+1071172, 1.0, int_stack+1110947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 1.0, int_stack+2190421, 1.0, int_stack+2446679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 1.0, int_stack+2192773, 1.0, int_stack+2449031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+346455,int_stack+345195, 0.0, zero_stack, 1.0, int_stack+1072180, 1.0, int_stack+1111955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 1.0, int_stack+2196301, 1.0, int_stack+2452559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 1.0, int_stack+2199325, 1.0, int_stack+2455583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 1.0, int_stack+2204029, 1.0, int_stack+2460287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+348751,int_stack+347995, 0.0, zero_stack, 1.0, int_stack+1080160, 1.0, int_stack+1119935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+349759,int_stack+348751, 0.0, zero_stack, 1.0, int_stack+1080916, 1.0, int_stack+1120691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 1.0, int_stack+2267218, 1.0, int_stack+2523476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+351055,int_stack+349759, 0.0, zero_stack, 1.0, int_stack+1081924, 1.0, int_stack+1121699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 1.0, int_stack+2269486, 1.0, int_stack+2525744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+2528768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+352675,int_stack+351055, 0.0, zero_stack, 1.0, int_stack+1083220, 1.0, int_stack+1122995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 1.0, int_stack+2209909, 1.0, int_stack+2533304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 1.0, int_stack+2303723, 1.0, int_stack+2566029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3890661,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 1.0, int_stack+2309771, 1.0, int_stack+2572077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3890661,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+297909,int_stack+3730011,int_stack+3870816,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3902001,int_stack+355600,int_stack+354655, 0.0, zero_stack, 1.0, int_stack+492455, 1.0, int_stack+522355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3870816,int_stack+356860,int_stack+355600, 0.0, zero_stack, 1.0, int_stack+494345, 1.0, int_stack+524245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3874596,int_stack+3870816,int_stack+3902001, 0.0, zero_stack, 1.0, int_stack+4536, 1.0, int_stack+2466167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3880266,int_stack+358480,int_stack+356860, 0.0, zero_stack, 1.0, int_stack+496865, 1.0, int_stack+526765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3880266,int_stack+3870816, 0.0, zero_stack, 1.0, int_stack+1940277, 1.0, int_stack+2657127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3874596, 0.0, zero_stack, 1.0, int_stack+2394821, 1.0, int_stack+2660907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+360505,int_stack+358480, 0.0, zero_stack, 1.0, int_stack+500105, 1.0, int_stack+530005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3880266, 0.0, zero_stack, 1.0, int_stack+2400491, 1.0, int_stack+2666577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 1.0, int_stack+2405351, 1.0, int_stack+2671437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3764031, 0.0, zero_stack, 1.0, int_stack+2412911, 1.0, int_stack+2678997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3014536,int_stack+3890661,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4825266,int_stack+3957756,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+363421,int_stack+362980, 0.0, zero_stack, 2.0, int_stack+1101805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+364009,int_stack+363421, 0.0, zero_stack, 2.0, int_stack+1102246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 0.0, zero_stack, 2.0, int_stack+2422361, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+364765,int_stack+364009, 0.0, zero_stack, 2.0, int_stack+1102834, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 0.0, zero_stack, 2.0, int_stack+2423684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 0.0, zero_stack, 2.0, int_stack+2425448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+365710,int_stack+364765, 0.0, zero_stack, 2.0, int_stack+1103590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 0.0, zero_stack, 2.0, int_stack+2428094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 0.0, zero_stack, 2.0, int_stack+2430362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 0.0, zero_stack, 2.0, int_stack+2433890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+367453,int_stack+366865, 0.0, zero_stack, 2.0, int_stack+1109575, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+368237,int_stack+367453, 0.0, zero_stack, 2.0, int_stack+1110163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 0.0, zero_stack, 2.0, int_stack+2444915, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+369245,int_stack+368237, 0.0, zero_stack, 2.0, int_stack+1110947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 0.0, zero_stack, 2.0, int_stack+2446679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 0.0, zero_stack, 2.0, int_stack+2449031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+370505,int_stack+369245, 0.0, zero_stack, 2.0, int_stack+1111955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 0.0, zero_stack, 2.0, int_stack+2452559, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 0.0, zero_stack, 2.0, int_stack+2455583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 0.0, zero_stack, 2.0, int_stack+2460287, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+372801,int_stack+372045, 0.0, zero_stack, 2.0, int_stack+1119935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+373809,int_stack+372801, 0.0, zero_stack, 2.0, int_stack+1120691, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 0.0, zero_stack, 2.0, int_stack+2523476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+375105,int_stack+373809, 0.0, zero_stack, 2.0, int_stack+1121699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 0.0, zero_stack, 2.0, int_stack+2525744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 0.0, zero_stack, 2.0, int_stack+2528768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+376725,int_stack+375105, 0.0, zero_stack, 2.0, int_stack+1122995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 0.0, zero_stack, 2.0, int_stack+2533304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 0.0, zero_stack, 2.0, int_stack+2566029, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3977601,int_stack+3730011,int_stack+3749775, 0.0, zero_stack, 2.0, int_stack+2572077, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3977601,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+337599,int_stack+3730011,int_stack+3957756,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3988941,int_stack+379650,int_stack+378705, 0.0, zero_stack, 2.0, int_stack+522355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3957756,int_stack+380910,int_stack+379650, 0.0, zero_stack, 2.0, int_stack+524245, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3961536,int_stack+3957756,int_stack+3988941, 0.0, zero_stack, 2.0, int_stack+2466167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3967206,int_stack+382530,int_stack+380910, 0.0, zero_stack, 2.0, int_stack+526765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3967206,int_stack+3957756, 0.0, zero_stack, 2.0, int_stack+2657127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3961536, 0.0, zero_stack, 2.0, int_stack+2660907, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+384555,int_stack+382530, 0.0, zero_stack, 2.0, int_stack+530005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3967206, 0.0, zero_stack, 2.0, int_stack+2666577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3014536,int_stack+3756471, 0.0, zero_stack, 2.0, int_stack+2671437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3957756,int_stack+3764031, 0.0, zero_stack, 2.0, int_stack+2678997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3014536,int_stack+3977601,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4878186,int_stack+3870816,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+387471,int_stack+387030, 1.0, int_stack+942705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1141580,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+388059,int_stack+387471, 1.0, int_stack+943146, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1142021,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 1.0, int_stack+1336214, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2688447,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+388815,int_stack+388059, 1.0, int_stack+943734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1142609,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 1.0, int_stack+1337537, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2689770,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 1.0, int_stack+1339301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2691534,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+389760,int_stack+388815, 1.0, int_stack+944490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1143365,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 1.0, int_stack+1341947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2694180,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 1.0, int_stack+1344215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2696448,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 1.0, int_stack+1347743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2699976,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+391503,int_stack+390915, 1.0, int_stack+950475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149350,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+392287,int_stack+391503, 1.0, int_stack+951063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149938,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 1.0, int_stack+1380020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2704386,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+393295,int_stack+392287, 1.0, int_stack+951847, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150722,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 1.0, int_stack+1381784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2706150,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 1.0, int_stack+1384136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2708502,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+394555,int_stack+393295, 1.0, int_stack+952855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1151730,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3737655, 1.0, int_stack+1387664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1320275,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3758445,int_stack+3740679, 1.0, int_stack+1390688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2721417,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3758445,int_stack+3730011,int_stack+3752565, 1.0, int_stack+1395392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2726121,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3758445,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+396851,int_stack+396095, 1.0, int_stack+960835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1160466,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732279,int_stack+397859,int_stack+396851, 1.0, int_stack+961591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1162230,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3735303,int_stack+3732279,int_stack+3730011, 1.0, int_stack+1457261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2789562,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3739839,int_stack+399155,int_stack+397859, 1.0, int_stack+962599, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1164534,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3743727,int_stack+3739839,int_stack+3732279, 1.0, int_stack+1459529, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2791830,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3749775,int_stack+3743727,int_stack+3735303, 1.0, int_stack+1462553, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2794854,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+400775,int_stack+399155, 1.0, int_stack+963895, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1167450,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3767265,int_stack+3730011,int_stack+3739839, 1.0, int_stack+1467089, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2799390,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3767265,int_stack+3743727, 1.0, int_stack+1470977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358768,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3890661,int_stack+3730011,int_stack+3749775, 1.0, int_stack+1477025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2832115,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3730011,int_stack+3890661,int_stack+3758445,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+4931106,int_stack+3730011,int_stack+3870816,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3902001,int_stack+405905,int_stack+403700, 1.0, int_stack+402755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+553200,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3870816,int_stack+408785,int_stack+405905, 1.0, int_stack+404645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556350,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3874596,int_stack+3870816,int_stack+3902001, 1.0, int_stack+1596230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2839675,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3880266,int_stack+412430,int_stack+408785, 1.0, int_stack+407165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560490,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3756471,int_stack+3880266,int_stack+3870816, 1.0, int_stack+1599065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2842510,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3764031,int_stack+3756471,int_stack+3874596, 1.0, int_stack+1602845, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2846290,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+414455,int_stack+412430, 1.0, int_stack+410405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+563730,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3880266, 1.0, int_stack+1608515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2851960,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3014536,int_stack+3756471, 1.0, int_stack+1613375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1429937,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+3870816,int_stack+3764031, 1.0, int_stack+1620935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2935021,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3014536,int_stack+3890661,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+4970796,int_stack+3957756,int_stack+3730011,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+417371,int_stack+416930, 1.0, int_stack+982480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1141580, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731334,int_stack+417959,int_stack+417371, 1.0, int_stack+982921, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1142021, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3733098,int_stack+3731334,int_stack+3730011, 1.0, int_stack+1630385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2688447, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3735744,int_stack+418715,int_stack+417959, 1.0, int_stack+983509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1142609, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3738012,int_stack+3735744,int_stack+3731334, 1.0, int_stack+1631708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2689770, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3741540,int_stack+3738012,int_stack+3733098, 1.0, int_stack+1633472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2691534, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3730011,int_stack+419660,int_stack+418715, 1.0, int_stack+984265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1143365, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3735744, 1.0, int_stack+1636118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2694180, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3730011,int_stack+3745950,int_stack+3738012, 1.0, int_stack+1638386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2696448, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3745950,int_stack+3730011,int_stack+3741540, 1.0, int_stack+1641914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2699976, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+421403,int_stack+420815, 1.0, int_stack+990250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149350, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3731775,int_stack+422187,int_stack+421403, 1.0, int_stack+990838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149938, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3734127,int_stack+3731775,int_stack+3730011, 1.0, int_stack+1652939, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2704386, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3737655,int_stack+423195,int_stack+422187, 1.0, int_stack+991622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150722, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3740679,int_stack+3737655,int_stack+3731775, 1.0, int_stack+1654703, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2706150, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3752565,int_stack+3740679,int_stack+3734127, 1.0, int_stack+1657055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2708502, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1652939,int_stack+424455,int_stack+423195, 1.0, int_stack+992630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1151730, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3730011,int_stack+1652939,int_stack+3737655, 1.0, int_stack+1660583, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1320275, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1652939,int_stack+3730011,int_stack+3740679, 1.0, int_stack+1663607, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2721417, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3730011,int_stack+1652939,int_stack+3752565, 1.0, int_stack+1668311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2726121, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+3752565,int_stack+3730011,int_stack+3745950,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3772410,int_stack+426751,int_stack+425995, 1.0, int_stack+1000610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1160466, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3774678,int_stack+427759,int_stack+426751, 1.0, int_stack+1001366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1162230, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1652939,int_stack+3774678,int_stack+3772410, 1.0, int_stack+1731500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2789562, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1657475,int_stack+429055,int_stack+427759, 1.0, int_stack+1002374, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1164534, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1661363,int_stack+1657475,int_stack+3774678, 1.0, int_stack+1733768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2791830, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3738831,int_stack+1661363,int_stack+1652939, 1.0, int_stack+1736792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2794854, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1731500,int_stack+430675,int_stack+429055, 1.0, int_stack+1003670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1167450, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3957756,int_stack+1731500,int_stack+1657475, 1.0, int_stack+1741328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2799390, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1731500,int_stack+3957756,int_stack+1661363, 1.0, int_stack+1774053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358768, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+1731500,int_stack+3738831, 1.0, int_stack+1780101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2832115, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3014536,int_stack+3957756,int_stack+3730011,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+377289,int_stack+3014536,int_stack+3752565,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3730011,int_stack+435805,int_stack+433600, 1.0, int_stack+432655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+553200, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3732846,int_stack+438685,int_stack+435805, 1.0, int_stack+434545, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556350, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3736626,int_stack+3732846,int_stack+3730011, 1.0, int_stack+1674191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2839675, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3742296,int_stack+442330,int_stack+438685, 1.0, int_stack+437065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560490, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3747156,int_stack+3742296,int_stack+3732846, 1.0, int_stack+1865151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2842510, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3754716,int_stack+3747156,int_stack+3736626, 1.0, int_stack+1868931, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2846290, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1865151,int_stack+444355,int_stack+442330, 1.0, int_stack+440305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+563730, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3730011,int_stack+1865151,int_stack+3742296, 1.0, int_stack+1874601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2851960, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1865151,int_stack+3730011,int_stack+3747156, 1.0, int_stack+1879461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1429937, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3730011,int_stack+1865151,int_stack+3754716, 1.0, int_stack+1887021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2935021, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3744186,int_stack+3730011,int_stack+3957756,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5023716,int_stack+3744186,int_stack+3014536,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3014536,int_stack+447271,int_stack+446830, 1.0, int_stack+1022255, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1141580, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3015859,int_stack+447859,int_stack+447271, 1.0, int_stack+1022696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1142021, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3017623,int_stack+3015859,int_stack+3014536, 1.0, int_stack+1896471, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2688447, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3020269,int_stack+448615,int_stack+447859, 1.0, int_stack+1023284, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1142609, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3022537,int_stack+3020269,int_stack+3015859, 1.0, int_stack+1897794, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2689770, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3026065,int_stack+3022537,int_stack+3017623, 1.0, int_stack+1899558, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2691534, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3014536,int_stack+449560,int_stack+448615, 1.0, int_stack+1024040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1143365, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3030475,int_stack+3014536,int_stack+3020269, 1.0, int_stack+1902204, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2694180, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3014536,int_stack+3030475,int_stack+3022537, 1.0, int_stack+1904472, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2696448, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3030475,int_stack+3014536,int_stack+3026065, 1.0, int_stack+1908000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2699976, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3014536,int_stack+451303,int_stack+450715, 1.0, int_stack+1030025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149350, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3016300,int_stack+452087,int_stack+451303, 1.0, int_stack+1030613, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1149938, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3018652,int_stack+3016300,int_stack+3014536, 1.0, int_stack+1919025, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2704386, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3022180,int_stack+453095,int_stack+452087, 1.0, int_stack+1031397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1150722, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3025204,int_stack+3022180,int_stack+3016300, 1.0, int_stack+1920789, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2706150, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3037090,int_stack+3025204,int_stack+3018652, 1.0, int_stack+1923141, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2708502, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1919025,int_stack+454355,int_stack+453095, 1.0, int_stack+1032405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1151730, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3014536,int_stack+1919025,int_stack+3022180, 1.0, int_stack+1926669, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1919025,int_stack+3014536,int_stack+3025204, 1.0, int_stack+1929693, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2721417, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3014536,int_stack+1919025,int_stack+3037090, 1.0, int_stack+1934397, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2726121, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1919025,int_stack+3014536,int_stack+3030475,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3023356,int_stack+456651,int_stack+455895, 1.0, int_stack+1040385, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1160466, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3025624,int_stack+457659,int_stack+456651, 1.0, int_stack+1041141, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1162230, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3028648,int_stack+3025624,int_stack+3023356, 1.0, int_stack+1997586, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2789562, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3033184,int_stack+458955,int_stack+457659, 1.0, int_stack+1042149, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1164534, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3037072,int_stack+3033184,int_stack+3025624, 1.0, int_stack+1999854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2791830, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+3037072,int_stack+3028648, 1.0, int_stack+2002878, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2794854, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1997586,int_stack+460575,int_stack+458955, 1.0, int_stack+1043445, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1167450, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3023356,int_stack+1997586,int_stack+3033184, 1.0, int_stack+2007414, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2799390, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1997586,int_stack+3023356,int_stack+3037072, 1.0, int_stack+2040139, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3023356,int_stack+1997586,int_stack+3957756, 1.0, int_stack+2046187, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2832115, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+3957756,int_stack+3023356,int_stack+3014536,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+3730011,int_stack+3957756,int_stack+1919025,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1919025,int_stack+465705,int_stack+463500, 1.0, int_stack+462555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+553200, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1921860,int_stack+468585,int_stack+465705, 1.0, int_stack+464445, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556350, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1925640,int_stack+1921860,int_stack+1919025, 1.0, int_stack+2053747, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2839675, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1931310,int_stack+472230,int_stack+468585, 1.0, int_stack+466965, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+560490, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3984216,int_stack+1931310,int_stack+1921860, 1.0, int_stack+2056582, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2842510, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1997586,int_stack+3984216,int_stack+1925640, 1.0, int_stack+2060362, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2846290, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1919025,int_stack+474255,int_stack+472230, 1.0, int_stack+470205, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+563730, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2040139,int_stack+1919025,int_stack+1931310, 1.0, int_stack+2066032, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2851960, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1919025,int_stack+2040139,int_stack+3984216, 1.0, int_stack+2149093, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2040139,int_stack+1919025,int_stack+1997586, 1.0, int_stack+2156653, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+2040139,int_stack+3023356,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+416979,int_stack+3870816,int_stack+3957756,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+477171,int_stack+476730, 1.0, int_stack+1062030, 0.0, zero_stack, 1.0, int_stack+1141580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3959079,int_stack+477759,int_stack+477171, 1.0, int_stack+1062471, 0.0, zero_stack, 1.0, int_stack+1142021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3960843,int_stack+3959079,int_stack+3957756, 1.0, int_stack+2166103, 0.0, zero_stack, 1.0, int_stack+2688447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3963489,int_stack+478515,int_stack+477759, 1.0, int_stack+1063059, 0.0, zero_stack, 1.0, int_stack+1142609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3965757,int_stack+3963489,int_stack+3959079, 1.0, int_stack+2167426, 0.0, zero_stack, 1.0, int_stack+2689770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3969285,int_stack+3965757,int_stack+3960843, 1.0, int_stack+2169190, 0.0, zero_stack, 1.0, int_stack+2691534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+479460,int_stack+478515, 1.0, int_stack+1063815, 0.0, zero_stack, 1.0, int_stack+1143365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3973695,int_stack+3957756,int_stack+3963489, 1.0, int_stack+2171836, 0.0, zero_stack, 1.0, int_stack+2694180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3973695,int_stack+3965757, 1.0, int_stack+2174104, 0.0, zero_stack, 1.0, int_stack+2696448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3973695,int_stack+3957756,int_stack+3969285, 1.0, int_stack+2177632, 0.0, zero_stack, 1.0, int_stack+2699976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+481203,int_stack+480615, 1.0, int_stack+1069800, 0.0, zero_stack, 1.0, int_stack+1149350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3959520,int_stack+481987,int_stack+481203, 1.0, int_stack+1070388, 0.0, zero_stack, 1.0, int_stack+1149938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3961872,int_stack+3959520,int_stack+3957756, 1.0, int_stack+2188657, 0.0, zero_stack, 1.0, int_stack+2704386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3965400,int_stack+482995,int_stack+481987, 1.0, int_stack+1071172, 0.0, zero_stack, 1.0, int_stack+1150722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3968424,int_stack+3965400,int_stack+3959520, 1.0, int_stack+2190421, 0.0, zero_stack, 1.0, int_stack+2706150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3980310,int_stack+3968424,int_stack+3961872, 1.0, int_stack+2192773, 0.0, zero_stack, 1.0, int_stack+2708502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2188657,int_stack+484255,int_stack+482995, 1.0, int_stack+1072180, 0.0, zero_stack, 1.0, int_stack+1151730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3957756,int_stack+2188657,int_stack+3965400, 1.0, int_stack+2196301, 0.0, zero_stack, 1.0, int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2188657,int_stack+3957756,int_stack+3968424, 1.0, int_stack+2199325, 0.0, zero_stack, 1.0, int_stack+2721417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+2188657,int_stack+3980310, 1.0, int_stack+2204029, 0.0, zero_stack, 1.0, int_stack+2726121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2188657,int_stack+3957756,int_stack+3973695,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3966576,int_stack+486551,int_stack+485795, 1.0, int_stack+1080160, 0.0, zero_stack, 1.0, int_stack+1160466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3968844,int_stack+487559,int_stack+486551, 1.0, int_stack+1080916, 0.0, zero_stack, 1.0, int_stack+1162230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3971868,int_stack+3968844,int_stack+3966576, 1.0, int_stack+2267218, 0.0, zero_stack, 1.0, int_stack+2789562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3976404,int_stack+488855,int_stack+487559, 1.0, int_stack+1081924, 0.0, zero_stack, 1.0, int_stack+1164534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3980292,int_stack+3976404,int_stack+3968844, 1.0, int_stack+2269486, 0.0, zero_stack, 1.0, int_stack+2791830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2267218,int_stack+3980292,int_stack+3971868, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+2794854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3966576,int_stack+490475,int_stack+488855, 1.0, int_stack+1083220, 0.0, zero_stack, 1.0, int_stack+1167450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3870816,int_stack+3966576,int_stack+3976404, 1.0, int_stack+2209909, 0.0, zero_stack, 1.0, int_stack+2799390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3966576,int_stack+3870816,int_stack+3980292, 1.0, int_stack+2303723, 0.0, zero_stack, 1.0, int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3870816,int_stack+3966576,int_stack+2267218, 1.0, int_stack+2309771, 0.0, zero_stack, 1.0, int_stack+2832115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+2040139,int_stack+3870816,int_stack+3957756,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1865151,int_stack+2040139,int_stack+2188657,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2188657,int_stack+495605,int_stack+493400, 1.0, int_stack+492455, 0.0, zero_stack, 1.0, int_stack+553200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2191492,int_stack+498485,int_stack+495605, 1.0, int_stack+494345, 0.0, zero_stack, 1.0, int_stack+556350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2195272,int_stack+2191492,int_stack+2188657, 1.0, int_stack+4536, 0.0, zero_stack, 1.0, int_stack+2839675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2200942,int_stack+502130,int_stack+498485, 1.0, int_stack+496865, 0.0, zero_stack, 1.0, int_stack+560490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2205802,int_stack+2200942,int_stack+2191492, 1.0, int_stack+1940277, 0.0, zero_stack, 1.0, int_stack+2842510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+2205802,int_stack+2195272, 1.0, int_stack+2394821, 0.0, zero_stack, 1.0, int_stack+2846290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2188657,int_stack+504155,int_stack+502130, 1.0, int_stack+500105, 0.0, zero_stack, 1.0, int_stack+563730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3967206,int_stack+2188657,int_stack+2200942, 1.0, int_stack+2400491, 0.0, zero_stack, 1.0, int_stack+2851960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2188657,int_stack+3967206,int_stack+2205802, 1.0, int_stack+2405351, 0.0, zero_stack, 1.0, int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3967206,int_stack+2188657,int_stack+3957756, 1.0, int_stack+2412911, 0.0, zero_stack, 1.0, int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+469899,int_stack+3967206,int_stack+3870816,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5076636,int_stack+469899,int_stack+2040139,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2040139,int_stack+507071,int_stack+506630, 1.0, int_stack+1101805, 1.0, int_stack+1141580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2041462,int_stack+507659,int_stack+507071, 1.0, int_stack+1102246, 1.0, int_stack+1142021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2043226,int_stack+2041462,int_stack+2040139, 1.0, int_stack+2422361, 1.0, int_stack+2688447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2045872,int_stack+508415,int_stack+507659, 1.0, int_stack+1102834, 1.0, int_stack+1142609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2048140,int_stack+2045872,int_stack+2041462, 1.0, int_stack+2423684, 1.0, int_stack+2689770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2051668,int_stack+2048140,int_stack+2043226, 1.0, int_stack+2425448, 1.0, int_stack+2691534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2040139,int_stack+509360,int_stack+508415, 1.0, int_stack+1103590, 1.0, int_stack+1143365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2056078,int_stack+2040139,int_stack+2045872, 1.0, int_stack+2428094, 1.0, int_stack+2694180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2040139,int_stack+2056078,int_stack+2048140, 1.0, int_stack+2430362, 1.0, int_stack+2696448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2056078,int_stack+2040139,int_stack+2051668, 1.0, int_stack+2433890, 1.0, int_stack+2699976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2040139,int_stack+511103,int_stack+510515, 1.0, int_stack+1109575, 1.0, int_stack+1149350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2041903,int_stack+511887,int_stack+511103, 1.0, int_stack+1110163, 1.0, int_stack+1149938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2044255,int_stack+2041903,int_stack+2040139, 1.0, int_stack+2444915, 1.0, int_stack+2704386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2047783,int_stack+512895,int_stack+511887, 1.0, int_stack+1110947, 1.0, int_stack+1150722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2050807,int_stack+2047783,int_stack+2041903, 1.0, int_stack+2446679, 1.0, int_stack+2706150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2062693,int_stack+2050807,int_stack+2044255, 1.0, int_stack+2449031, 1.0, int_stack+2708502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2444915,int_stack+514155,int_stack+512895, 1.0, int_stack+1111955, 1.0, int_stack+1151730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2040139,int_stack+2444915,int_stack+2047783, 1.0, int_stack+2452559, 1.0, int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+2040139,int_stack+2050807, 1.0, int_stack+2455583, 1.0, int_stack+2721417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2040139,int_stack+2267218,int_stack+2062693, 1.0, int_stack+2460287, 1.0, int_stack+2726121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+2444915,int_stack+2040139,int_stack+2056078,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2267218,int_stack+516451,int_stack+515695, 1.0, int_stack+1119935, 1.0, int_stack+1160466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2269486,int_stack+517459,int_stack+516451, 1.0, int_stack+1120691, 1.0, int_stack+1162230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2048959,int_stack+2269486,int_stack+2267218, 1.0, int_stack+2523476, 1.0, int_stack+2789562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2053495,int_stack+518755,int_stack+517459, 1.0, int_stack+1121699, 1.0, int_stack+1164534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2057383,int_stack+2053495,int_stack+2269486, 1.0, int_stack+2525744, 1.0, int_stack+2791830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2267218,int_stack+2057383,int_stack+2048959, 1.0, int_stack+2528768, 1.0, int_stack+2794854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2523476,int_stack+520375,int_stack+518755, 1.0, int_stack+1122995, 1.0, int_stack+1167450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2063431,int_stack+2523476,int_stack+2053495, 1.0, int_stack+2533304, 1.0, int_stack+2799390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2523476,int_stack+2063431,int_stack+2057383, 1.0, int_stack+2566029, 1.0, int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2048959,int_stack+2523476,int_stack+2267218, 1.0, int_stack+2572077, 1.0, int_stack+2832115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+2048959,int_stack+2040139,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2394821,int_stack+469899,int_stack+2444915,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2444915,int_stack+525505,int_stack+523300, 1.0, int_stack+522355, 1.0, int_stack+553200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2447750,int_stack+528385,int_stack+525505, 1.0, int_stack+524245, 1.0, int_stack+556350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2451530,int_stack+2447750,int_stack+2444915, 1.0, int_stack+2466167, 1.0, int_stack+2839675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2457200,int_stack+532030,int_stack+528385, 1.0, int_stack+526765, 1.0, int_stack+560490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2462060,int_stack+2457200,int_stack+2447750, 1.0, int_stack+2657127, 1.0, int_stack+2842510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2523476,int_stack+2462060,int_stack+2451530, 1.0, int_stack+2660907, 1.0, int_stack+2846290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2657127,int_stack+534055,int_stack+532030, 1.0, int_stack+530005, 1.0, int_stack+563730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2444915,int_stack+2657127,int_stack+2457200, 1.0, int_stack+2666577, 1.0, int_stack+2851960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2657127,int_stack+2444915,int_stack+2462060, 1.0, int_stack+2671437, 1.0, int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2444915,int_stack+2657127,int_stack+2523476, 1.0, int_stack+2678997, 1.0, int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+2444915,int_stack+2048959,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+5129556,int_stack+3870816,int_stack+469899,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+536971,int_stack+536530, 2.0, int_stack+1141580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+537559,int_stack+536971, 2.0, int_stack+1142021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 2.0, int_stack+2688447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+538315,int_stack+537559, 2.0, int_stack+1142609, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 2.0, int_stack+2689770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 2.0, int_stack+2691534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+539260,int_stack+538315, 2.0, int_stack+1143365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 2.0, int_stack+2694180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 2.0, int_stack+2696448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 2.0, int_stack+2699976, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+541003,int_stack+540415, 2.0, int_stack+1149350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+541787,int_stack+541003, 2.0, int_stack+1149938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 2.0, int_stack+2704386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+542795,int_stack+541787, 2.0, int_stack+1150722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 2.0, int_stack+2706150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+492453,int_stack+480567,int_stack+474015, 2.0, int_stack+2708502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+544055,int_stack+542795, 2.0, int_stack+1151730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+498333,int_stack+469899,int_stack+477543, 2.0, int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+498333,int_stack+480567, 2.0, int_stack+2721417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+498333,int_stack+2267218,int_stack+492453, 2.0, int_stack+2726121, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+507153,int_stack+498333,int_stack+485838,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2267218,int_stack+546351,int_stack+545595, 2.0, int_stack+1160466, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1320275,int_stack+547359,int_stack+546351, 2.0, int_stack+1162230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2269486,int_stack+1320275,int_stack+2267218, 2.0, int_stack+2789562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2721417,int_stack+548655,int_stack+547359, 2.0, int_stack+1164534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2725305,int_stack+2721417,int_stack+1320275, 2.0, int_stack+2791830, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+526998,int_stack+2725305,int_stack+2269486, 2.0, int_stack+2794854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2789562,int_stack+550275,int_stack+548655, 2.0, int_stack+1167450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2267218,int_stack+2789562,int_stack+2721417, 2.0, int_stack+2799390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2789562,int_stack+2267218,int_stack+2725305, 2.0, int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+2789562,int_stack+526998, 2.0, int_stack+2832115, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+498333,315);
 /*--- compute (hd|hg) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+2657127,int_stack+469899,int_stack+507153,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2832115,int_stack+557610,int_stack+554145, 2.0, int_stack+553200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2834950,int_stack+562110,int_stack+557610, 2.0, int_stack+556350, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2789562,int_stack+2834950,int_stack+2832115, 2.0, int_stack+2839675, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2795232,int_stack+565755,int_stack+562110, 2.0, int_stack+560490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2267218,int_stack+2795232,int_stack+2834950, 2.0, int_stack+2842510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2832115,int_stack+2267218,int_stack+2789562, 2.0, int_stack+2846290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2841565,int_stack+567780,int_stack+565755, 2.0, int_stack+563730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2721417,int_stack+2841565,int_stack+2795232, 2.0, int_stack+2851960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2841565,int_stack+2721417,int_stack+2267218, 2.0, int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+496359,int_stack+2841565,int_stack+2832115, 2.0, int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+496359,int_stack+1159710,315);
 /*--- compute (id|hg) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+496359,int_stack+3870816,int_stack+469899,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+570696,int_stack+570255, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191885,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+571284,int_stack+570696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1192326,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1364816,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+572040,int_stack+571284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1192914,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1366139,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1367903,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+572985,int_stack+572040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1193670,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1370549,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1372817,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1588850,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+574728,int_stack+574140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1199655,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+575512,int_stack+574728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1200243,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1437497,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320275,int_stack+576520,int_stack+575512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1201027,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477543,int_stack+1320275,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1439261,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3870816,int_stack+477543,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1441613,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+577780,int_stack+576520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1202035,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1358768,int_stack+469899,int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1376345,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+1358768,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283090,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323299,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+469899,int_stack+485838, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1352153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3890661,int_stack+580076,int_stack+579320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1210015,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1320275,int_stack+581084,int_stack+580076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1210771,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3892929,int_stack+1320275,int_stack+3890661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1329179,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3897465,int_stack+582380,int_stack+581084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1211779,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1358768,int_stack+3897465,int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331447,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1429937,int_stack+1358768,int_stack+3892929, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2732001,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3890661,int_stack+584000,int_stack+582380, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1213075,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2267218,int_stack+3890661,int_stack+3897465, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3103231,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3890661,int_stack+2267218,int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3107119,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+3890661,int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3113167,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+549279,int_stack+1159710,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1401272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1596095,int_stack+549279,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1410092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+586925,int_stack+585980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+706230,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873651,int_stack+588185,int_stack+586925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708120,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3877431,int_stack+3873651,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1593260,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3883101,int_stack+589805,int_stack+588185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+710640,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1429937,int_stack+3883101,int_stack+3873651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271435,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+1429937,int_stack+3877431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3198217,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+591830,int_stack+589805, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713880,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3887961,int_stack+3870816,int_stack+3883101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3203887,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3887961,int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3208747,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3883416,int_stack+3870816,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3216307,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3883416,int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1484585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5182476,int_stack+3957756,int_stack+549279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1495925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+549279,int_stack+594746,int_stack+594305, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191885, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+550602,int_stack+595334,int_stack+594746, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1192326, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+552366,int_stack+550602,int_stack+549279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1364816, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+555012,int_stack+596090,int_stack+595334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1192914, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+557280,int_stack+555012,int_stack+550602, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1366139, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+560808,int_stack+557280,int_stack+552366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1367903, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+549279,int_stack+597035,int_stack+596090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1193670, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+565218,int_stack+549279,int_stack+555012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1370549, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+549279,int_stack+565218,int_stack+557280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1372817, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+565218,int_stack+549279,int_stack+560808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1588850, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+549279,int_stack+598778,int_stack+598190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1199655, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+551043,int_stack+599562,int_stack+598778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1200243, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+553395,int_stack+551043,int_stack+549279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1437497, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320275,int_stack+600570,int_stack+599562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1201027, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+556923,int_stack+1320275,int_stack+551043, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1439261, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+571833,int_stack+556923,int_stack+553395, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1441613, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+549279,int_stack+601830,int_stack+600570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1202035, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1358768,int_stack+549279,int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1376345, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+1358768,int_stack+556923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283090, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+549279,int_stack+2267218,int_stack+571833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323299, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+571833,int_stack+549279,int_stack+565218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1646324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+591678,int_stack+604126,int_stack+603370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1210015, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1320275,int_stack+605134,int_stack+604126, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1210771, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+593946,int_stack+1320275,int_stack+591678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1329179, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+598482,int_stack+606430,int_stack+605134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1211779, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1358768,int_stack+598482,int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331447, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1429937,int_stack+1358768,int_stack+593946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2732001, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+591678,int_stack+608050,int_stack+606430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1213075, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2267218,int_stack+591678,int_stack+598482, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3103231, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+591678,int_stack+2267218,int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3107119, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+591678,int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3113167, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+549279, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1745388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5235396,int_stack+469899,int_stack+571833, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1754208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+549279,int_stack+610975,int_stack+610030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+706230, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+552114,int_stack+612235,int_stack+610975, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708120, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+555894,int_stack+552114,int_stack+549279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1593260, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+561564,int_stack+613855,int_stack+612235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+710640, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1429937,int_stack+561564,int_stack+552114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271435, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+1429937,int_stack+555894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3198217, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+549279,int_stack+615880,int_stack+613855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713880, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+566424,int_stack+549279,int_stack+561564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3203887, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+549279,int_stack+566424,int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3208747, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+561879,int_stack+549279,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3216307, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+561879,int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1787661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+549279,int_stack+3957756,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1799001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+618796,int_stack+618355, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191885, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+619384,int_stack+618796, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1192326, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1364816, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+620140,int_stack+619384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1192914, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1366139, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1367903, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+621085,int_stack+620140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1193670, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1370549, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1372817, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1588850, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+622828,int_stack+622240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1199655, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+623612,int_stack+622828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1200243, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1437497, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320275,int_stack+624620,int_stack+623612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1201027, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477543,int_stack+1320275,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1439261, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+477543,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1441613, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+625880,int_stack+624620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1202035, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1358768,int_stack+469899,int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1376345, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+1358768,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283090, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323299, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+469899,int_stack+485838, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1912410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3977601,int_stack+628176,int_stack+627420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1210015, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1320275,int_stack+629184,int_stack+628176, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1210771, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3979869,int_stack+1320275,int_stack+3977601, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1329179, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3984405,int_stack+630480,int_stack+629184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1211779, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1358768,int_stack+3984405,int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331447, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1429937,int_stack+1358768,int_stack+3979869, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2732001, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3977601,int_stack+632100,int_stack+630480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1213075, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2267218,int_stack+3977601,int_stack+3984405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3103231, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3977601,int_stack+2267218,int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3107119, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+3977601,int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3113167, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+602199,int_stack+1159710,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2011474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5275086,int_stack+602199,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2020294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+635025,int_stack+634080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+706230, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960591,int_stack+636285,int_stack+635025, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708120, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3964371,int_stack+3960591,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1593260, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3970041,int_stack+637905,int_stack+636285, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+710640, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1429937,int_stack+3970041,int_stack+3960591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271435, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+1429937,int_stack+3964371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3198217, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+639930,int_stack+637905, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713880, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3974901,int_stack+3957756,int_stack+3970041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3203887, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3974901,int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3208747, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3970356,int_stack+3957756,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3216307, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3970356,int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2071603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5314776,int_stack+3870816,int_stack+602199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2082943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+602199,int_stack+642846,int_stack+642405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+603522,int_stack+643434,int_stack+642846, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1192326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+605286,int_stack+603522,int_stack+602199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1364816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+607932,int_stack+644190,int_stack+643434, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1192914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+610200,int_stack+607932,int_stack+603522, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1366139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+613728,int_stack+610200,int_stack+605286, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1367903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+602199,int_stack+645135,int_stack+644190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1193670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+618138,int_stack+602199,int_stack+607932, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1370549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+602199,int_stack+618138,int_stack+610200, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1372817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+618138,int_stack+602199,int_stack+613728, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1588850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+602199,int_stack+646878,int_stack+646290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1199655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+603963,int_stack+647662,int_stack+646878, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1200243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+606315,int_stack+603963,int_stack+602199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1437497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320275,int_stack+648670,int_stack+647662, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1201027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+609843,int_stack+1320275,int_stack+603963, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1439261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+624753,int_stack+609843,int_stack+606315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1441613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+602199,int_stack+649930,int_stack+648670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1202035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1358768,int_stack+602199,int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1376345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+1358768,int_stack+609843, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1283090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+602199,int_stack+2267218,int_stack+624753, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1323299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+624753,int_stack+602199,int_stack+618138, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2182042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+644598,int_stack+652226,int_stack+651470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1210015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1320275,int_stack+653234,int_stack+652226, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1210771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+646866,int_stack+1320275,int_stack+644598, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1329179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+2267218,int_stack+654530,int_stack+653234, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1211779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1358768,int_stack+2267218,int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1331447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1429937,int_stack+1358768,int_stack+646866, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2732001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+644598,int_stack+656150,int_stack+654530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1213075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+649458,int_stack+644598,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3103231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+611019,int_stack+649458,int_stack+1358768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3107119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+611019,int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3113167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+602199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2275058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5367696,int_stack+469899,int_stack+624753, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2283878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+602199,int_stack+659075,int_stack+658130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+706230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+605034,int_stack+660335,int_stack+659075, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+708120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+608814,int_stack+605034,int_stack+602199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1593260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+614484,int_stack+661955,int_stack+660335, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+710640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1429937,int_stack+614484,int_stack+605034, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1271435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+1429937,int_stack+608814, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3198217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+602199,int_stack+663980,int_stack+661955, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+619344,int_stack+602199,int_stack+614484, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3203887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+602199,int_stack+619344,int_stack+1429937, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3208747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+614799,int_stack+602199,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3216307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+614799,int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2317331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+602199,int_stack+3870816,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2328671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+666896,int_stack+666455, 0.0, zero_stack, 1.0, int_stack+1191885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+667484,int_stack+666896, 0.0, zero_stack, 1.0, int_stack+1192326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+1364816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+668240,int_stack+667484, 0.0, zero_stack, 1.0, int_stack+1192914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 1.0, int_stack+1366139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 1.0, int_stack+1367903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+669185,int_stack+668240, 0.0, zero_stack, 1.0, int_stack+1193670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 1.0, int_stack+1370549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 1.0, int_stack+1372817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 1.0, int_stack+1588850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+670928,int_stack+670340, 0.0, zero_stack, 1.0, int_stack+1199655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+671712,int_stack+670928, 0.0, zero_stack, 1.0, int_stack+1200243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+1437497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320275,int_stack+672720,int_stack+671712, 0.0, zero_stack, 1.0, int_stack+1201027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477543,int_stack+1320275,int_stack+471663, 0.0, zero_stack, 1.0, int_stack+1439261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3870816,int_stack+477543,int_stack+474015, 0.0, zero_stack, 1.0, int_stack+1441613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+673980,int_stack+672720, 0.0, zero_stack, 1.0, int_stack+1202035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1358768,int_stack+469899,int_stack+1320275, 0.0, zero_stack, 1.0, int_stack+1376345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+1358768,int_stack+477543, 0.0, zero_stack, 1.0, int_stack+1283090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3870816, 0.0, zero_stack, 1.0, int_stack+1323299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+469899,int_stack+485838, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2438300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3890661,int_stack+676276,int_stack+675520, 0.0, zero_stack, 1.0, int_stack+1210015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1320275,int_stack+677284,int_stack+676276, 0.0, zero_stack, 1.0, int_stack+1210771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3892929,int_stack+1320275,int_stack+3890661, 0.0, zero_stack, 1.0, int_stack+1329179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3897465,int_stack+678580,int_stack+677284, 0.0, zero_stack, 1.0, int_stack+1211779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1358768,int_stack+3897465,int_stack+1320275, 0.0, zero_stack, 1.0, int_stack+1331447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1429937,int_stack+1358768,int_stack+3892929, 0.0, zero_stack, 1.0, int_stack+2732001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3890661,int_stack+680200,int_stack+678580, 0.0, zero_stack, 1.0, int_stack+1213075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2267218,int_stack+3890661,int_stack+3897465, 0.0, zero_stack, 1.0, int_stack+3103231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3890661,int_stack+2267218,int_stack+1358768, 0.0, zero_stack, 1.0, int_stack+3107119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+3890661,int_stack+1429937, 0.0, zero_stack, 1.0, int_stack+3113167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+655119,int_stack+1159710,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2537364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5407386,int_stack+655119,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2546184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+683125,int_stack+682180, 0.0, zero_stack, 1.0, int_stack+706230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873651,int_stack+684385,int_stack+683125, 0.0, zero_stack, 1.0, int_stack+708120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3877431,int_stack+3873651,int_stack+3870816, 0.0, zero_stack, 1.0, int_stack+1593260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3883101,int_stack+686005,int_stack+684385, 0.0, zero_stack, 1.0, int_stack+710640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1429937,int_stack+3883101,int_stack+3873651, 0.0, zero_stack, 1.0, int_stack+1271435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+1429937,int_stack+3877431, 0.0, zero_stack, 1.0, int_stack+3198217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+688030,int_stack+686005, 0.0, zero_stack, 1.0, int_stack+713880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3887961,int_stack+3870816,int_stack+3883101, 0.0, zero_stack, 1.0, int_stack+3203887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3887961,int_stack+1429937, 0.0, zero_stack, 1.0, int_stack+3208747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3883416,int_stack+3870816,int_stack+2935021, 0.0, zero_stack, 1.0, int_stack+3216307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3883416,int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2579637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5447076,int_stack+3957756,int_stack+655119, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2590977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+655119,int_stack+690946,int_stack+690505, 1.0, int_stack+1191885, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+656442,int_stack+691534,int_stack+690946, 1.0, int_stack+1192326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+658206,int_stack+656442,int_stack+655119, 1.0, int_stack+1364816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+660852,int_stack+692290,int_stack+691534, 1.0, int_stack+1192914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+663120,int_stack+660852,int_stack+656442, 1.0, int_stack+1366139, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+666648,int_stack+663120,int_stack+658206, 1.0, int_stack+1367903, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+655119,int_stack+693235,int_stack+692290, 1.0, int_stack+1193670, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+671058,int_stack+655119,int_stack+660852, 1.0, int_stack+1370549, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+655119,int_stack+671058,int_stack+663120, 1.0, int_stack+1372817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+671058,int_stack+655119,int_stack+666648, 1.0, int_stack+1588850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+655119,int_stack+694978,int_stack+694390, 1.0, int_stack+1199655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+656883,int_stack+695762,int_stack+694978, 1.0, int_stack+1200243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+659235,int_stack+656883,int_stack+655119, 1.0, int_stack+1437497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1320275,int_stack+696770,int_stack+695762, 1.0, int_stack+1201027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+662763,int_stack+1320275,int_stack+656883, 1.0, int_stack+1439261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+677673,int_stack+662763,int_stack+659235, 1.0, int_stack+1441613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+655119,int_stack+698030,int_stack+696770, 1.0, int_stack+1202035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+683553,int_stack+655119,int_stack+1320275, 1.0, int_stack+1376345, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+683553,int_stack+662763, 1.0, int_stack+1283090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+683553,int_stack+2267218,int_stack+677673, 1.0, int_stack+1323299, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+683553,int_stack+671058, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2714802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+2267218,int_stack+700326,int_stack+699570, 1.0, int_stack+1210015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2269486,int_stack+701334,int_stack+700326, 1.0, int_stack+1210771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1283090,int_stack+2269486,int_stack+2267218, 1.0, int_stack+1329179, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+692373,int_stack+702630,int_stack+701334, 1.0, int_stack+1211779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+696261,int_stack+692373,int_stack+2269486, 1.0, int_stack+1331447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2267218,int_stack+696261,int_stack+1283090, 1.0, int_stack+2732001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1283090,int_stack+704250,int_stack+702630, 1.0, int_stack+1213075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1320275,int_stack+1283090,int_stack+692373, 1.0, int_stack+3103231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+1328051,int_stack+1320275,int_stack+696261, 1.0, int_stack+3107119, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+1328051,int_stack+2267218, 1.0, int_stack+3113167, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+683553, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2803450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+655119,int_stack+469899,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2812270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+709380,int_stack+707175, 1.0, int_stack+706230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960591,int_stack+712260,int_stack+709380, 1.0, int_stack+708120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3964371,int_stack+3960591,int_stack+3957756, 1.0, int_stack+1593260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3970041,int_stack+715905,int_stack+712260, 1.0, int_stack+710640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3974901,int_stack+3970041,int_stack+3960591, 1.0, int_stack+1271435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+3974901,int_stack+3964371, 1.0, int_stack+3198217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+717930,int_stack+715905, 1.0, int_stack+713880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1320275,int_stack+3957756,int_stack+3970041, 1.0, int_stack+3203887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+1320275,int_stack+3974901, 1.0, int_stack+3208747, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1320275,int_stack+3957756,int_stack+2935021, 1.0, int_stack+3216307, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+1320275,int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2857531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5499996,int_stack+3957756,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2868871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+720846,int_stack+720405,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+721434,int_stack+720846,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+722190,int_stack+721434,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+723135,int_stack+722190,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+724878,int_stack+724290,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+725662,int_stack+724878,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+726670,int_stack+725662,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+480567,int_stack+474015,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+727930,int_stack+726670,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3963636,int_stack+469899,int_stack+477543,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3963636,int_stack+480567,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3963636,int_stack+2267218,int_stack+3957756,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1320275,int_stack+3963636,int_stack+485838, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1447913, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+730226,int_stack+729470,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3960024,int_stack+731234,int_stack+730226,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3960024,int_stack+3957756,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3972456,int_stack+732530,int_stack+731234,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3976344,int_stack+3972456,int_stack+3960024,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3982392,int_stack+3976344,int_stack+2267218,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+734150,int_stack+732530,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3972456,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3976344,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3982392,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3963636, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+7371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+694809,int_stack+469899,int_stack+1320275, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3083386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1320275,int_stack+737075,int_stack+736130,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1323110,int_stack+738335,int_stack+737075,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1326890,int_stack+1323110,int_stack+1320275,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1332560,int_stack+739955,int_stack+738335,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1337420,int_stack+1332560,int_stack+1323110,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+1337420,int_stack+1326890,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1320275,int_stack+741980,int_stack+739955,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3957756,int_stack+1320275,int_stack+1332560,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1320275,int_stack+3957756,int_stack+1337420,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+1320275,int_stack+2935021,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3957756,int_stack+1159710, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3120727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5552916,int_stack+3870816,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3132067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+744896,int_stack+744455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1231660,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+745484,int_stack+744896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232101,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3225757,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+746240,int_stack+745484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232689,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3227080,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3228844,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+747185,int_stack+746240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233445,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3231490,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3233758,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3237286,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+748928,int_stack+748340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1239430,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+749712,int_stack+748928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240018,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3248311,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+750720,int_stack+749712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240802,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3250075,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3870816,int_stack+480567,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3252427,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+751980,int_stack+750720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1241810,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3876696,int_stack+469899,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3255955,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3876696,int_stack+480567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3258979,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3876696,int_stack+2267218,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3263683,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3876696,int_stack+485838, 0.0, zero_stack, 1.0, int_stack+1352153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+754276,int_stack+753520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249790,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873084,int_stack+755284,int_stack+754276, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1250546,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3873084,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3326872,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3885516,int_stack+756580,int_stack+755284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1251554,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3889404,int_stack+3885516,int_stack+3873084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3329140,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3895452,int_stack+3889404,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3332164,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+758200,int_stack+756580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1252850,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3885516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3336700,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3889404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3369425,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3895452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3375473,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3876696, 0.0, zero_stack, 1.0, int_stack+1401272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1358768,int_stack+469899,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+1410092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+761125,int_stack+760180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880430,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960591,int_stack+762385,int_stack+761125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+882320,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3964371,int_stack+3960591,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3269563,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3970041,int_stack+764005,int_stack+762385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+884840,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3974901,int_stack+3970041,int_stack+3960591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3460523,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+3974901,int_stack+3964371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3464303,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+766030,int_stack+764005, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888080,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3870816,int_stack+3957756,int_stack+3970041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3469973,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3870816,int_stack+3974901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3474833,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3870816,int_stack+3957756,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3482393,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3870816,int_stack+1159710, 0.0, zero_stack, 1.0, int_stack+1484585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5605836,int_stack+3957756,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+1495925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+768946,int_stack+768505, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1231660, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+769534,int_stack+768946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232101, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3225757, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+770290,int_stack+769534, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232689, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3227080, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3228844, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+771235,int_stack+770290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233445, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3231490, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3233758, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3237286, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+772978,int_stack+772390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1239430, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+773762,int_stack+772978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240018, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3248311, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+774770,int_stack+773762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240802, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3250075, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+480567,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3252427, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+776030,int_stack+774770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1241810, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3963636,int_stack+469899,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3255955, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3963636,int_stack+480567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3258979, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3963636,int_stack+2267218,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3263683, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3963636,int_stack+485838, 0.0, zero_stack, 1.0, int_stack+1646324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+778326,int_stack+777570, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249790, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960024,int_stack+779334,int_stack+778326, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1250546, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3960024,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3326872, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3972456,int_stack+780630,int_stack+779334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1251554, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3976344,int_stack+3972456,int_stack+3960024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3329140, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3982392,int_stack+3976344,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3332164, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+782250,int_stack+780630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1252850, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3972456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3336700, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3976344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3369425, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3982392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3375473, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3963636, 0.0, zero_stack, 1.0, int_stack+1745388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+734499,int_stack+469899,int_stack+3870816, 0.0, zero_stack, 1.0, int_stack+1754208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+785175,int_stack+784230, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880430, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873651,int_stack+786435,int_stack+785175, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+882320, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3877431,int_stack+3873651,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3269563, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3883101,int_stack+788055,int_stack+786435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+884840, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3887961,int_stack+3883101,int_stack+3873651, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3460523, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+3887961,int_stack+3877431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3464303, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+790080,int_stack+788055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888080, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3957756,int_stack+3870816,int_stack+3883101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3469973, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3957756,int_stack+3887961, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3474833, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+3870816,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3482393, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3957756,int_stack+1159710, 0.0, zero_stack, 1.0, int_stack+1787661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5658756,int_stack+3870816,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+1799001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+792996,int_stack+792555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1231660, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+793584,int_stack+792996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232101, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3225757, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+794340,int_stack+793584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232689, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3227080, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3228844, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+795285,int_stack+794340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233445, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3231490, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3233758, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3237286, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+797028,int_stack+796440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1239430, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+797812,int_stack+797028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240018, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3248311, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+798820,int_stack+797812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240802, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3250075, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3870816,int_stack+480567,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3252427, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+800080,int_stack+798820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1241810, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3876696,int_stack+469899,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3255955, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3876696,int_stack+480567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3258979, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3876696,int_stack+2267218,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3263683, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3876696,int_stack+485838, 0.0, zero_stack, 1.0, int_stack+1912410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+802376,int_stack+801620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249790, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873084,int_stack+803384,int_stack+802376, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1250546, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3873084,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3326872, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3885516,int_stack+804680,int_stack+803384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1251554, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3889404,int_stack+3885516,int_stack+3873084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3329140, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3895452,int_stack+3889404,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3332164, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+806300,int_stack+804680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1252850, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3885516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3336700, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3889404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3369425, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3895452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3375473, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3876696, 0.0, zero_stack, 1.0, int_stack+2011474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5711676,int_stack+469899,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+2020294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+809225,int_stack+808280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880430, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960591,int_stack+810485,int_stack+809225, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+882320, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3964371,int_stack+3960591,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3269563, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3970041,int_stack+812105,int_stack+810485, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+884840, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3974901,int_stack+3970041,int_stack+3960591, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3460523, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+3974901,int_stack+3964371, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3464303, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+814130,int_stack+812105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888080, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3870816,int_stack+3957756,int_stack+3970041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3469973, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3870816,int_stack+3974901, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3474833, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3870816,int_stack+3957756,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3482393, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3870816,int_stack+1159710, 0.0, zero_stack, 1.0, int_stack+2071603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5751366,int_stack+3957756,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+2082943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+817046,int_stack+816605, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1231660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+817634,int_stack+817046, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3225757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+818390,int_stack+817634, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1232689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3227080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3228844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+819335,int_stack+818390, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1233445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3231490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3233758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3237286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+821078,int_stack+820490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1239430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+821862,int_stack+821078, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3248311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+822870,int_stack+821862, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1240802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3250075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+480567,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3252427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+824130,int_stack+822870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1241810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3963636,int_stack+469899,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3255955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3963636,int_stack+480567, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3258979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3963636,int_stack+2267218,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3263683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3870816,int_stack+3963636,int_stack+485838, 0.0, zero_stack, 1.0, int_stack+2182042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+826426,int_stack+825670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1249790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960024,int_stack+827434,int_stack+826426, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1250546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3960024,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3326872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3972456,int_stack+828730,int_stack+827434, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1251554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3976344,int_stack+3972456,int_stack+3960024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3329140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3982392,int_stack+3976344,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3332164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+830350,int_stack+828730, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1252850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3972456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3336700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3976344, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3369425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3982392, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3375473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3963636, 0.0, zero_stack, 1.0, int_stack+2275058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+774189,int_stack+469899,int_stack+3870816, 0.0, zero_stack, 1.0, int_stack+2283878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+833275,int_stack+832330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873651,int_stack+834535,int_stack+833275, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+882320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3877431,int_stack+3873651,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3269563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3883101,int_stack+836155,int_stack+834535, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+884840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3887961,int_stack+3883101,int_stack+3873651, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3460523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+3887961,int_stack+3877431, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3464303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+838180,int_stack+836155, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3957756,int_stack+3870816,int_stack+3883101, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3469973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3957756,int_stack+3887961, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3474833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+3870816,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3482393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3957756,int_stack+1159710, 0.0, zero_stack, 1.0, int_stack+2317331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5804286,int_stack+3870816,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+2328671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+841096,int_stack+840655, 0.0, zero_stack, 1.0, int_stack+1231660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+841684,int_stack+841096, 0.0, zero_stack, 1.0, int_stack+1232101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+3225757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+842440,int_stack+841684, 0.0, zero_stack, 1.0, int_stack+1232689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 1.0, int_stack+3227080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 1.0, int_stack+3228844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+843385,int_stack+842440, 0.0, zero_stack, 1.0, int_stack+1233445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 1.0, int_stack+3231490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 1.0, int_stack+3233758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 1.0, int_stack+3237286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+845128,int_stack+844540, 0.0, zero_stack, 1.0, int_stack+1239430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+845912,int_stack+845128, 0.0, zero_stack, 1.0, int_stack+1240018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+3248311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+846920,int_stack+845912, 0.0, zero_stack, 1.0, int_stack+1240802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 1.0, int_stack+3250075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3870816,int_stack+480567,int_stack+474015, 0.0, zero_stack, 1.0, int_stack+3252427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+848180,int_stack+846920, 0.0, zero_stack, 1.0, int_stack+1241810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3876696,int_stack+469899,int_stack+477543, 0.0, zero_stack, 1.0, int_stack+3255955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3876696,int_stack+480567, 0.0, zero_stack, 1.0, int_stack+3258979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3876696,int_stack+2267218,int_stack+3870816, 0.0, zero_stack, 1.0, int_stack+3263683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+3876696,int_stack+485838, 0.0, zero_stack, 1.0, int_stack+2438300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+850476,int_stack+849720, 0.0, zero_stack, 1.0, int_stack+1249790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873084,int_stack+851484,int_stack+850476, 0.0, zero_stack, 1.0, int_stack+1250546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3873084,int_stack+3870816, 0.0, zero_stack, 1.0, int_stack+3326872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3885516,int_stack+852780,int_stack+851484, 0.0, zero_stack, 1.0, int_stack+1251554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3889404,int_stack+3885516,int_stack+3873084, 0.0, zero_stack, 1.0, int_stack+3329140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3895452,int_stack+3889404,int_stack+2267218, 0.0, zero_stack, 1.0, int_stack+3332164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+854400,int_stack+852780, 0.0, zero_stack, 1.0, int_stack+1252850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3885516, 0.0, zero_stack, 1.0, int_stack+3336700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3889404, 0.0, zero_stack, 1.0, int_stack+3369425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3895452, 0.0, zero_stack, 1.0, int_stack+3375473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3876696, 0.0, zero_stack, 1.0, int_stack+2537364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+813879,int_stack+469899,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+2546184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+857325,int_stack+856380, 0.0, zero_stack, 1.0, int_stack+880430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960591,int_stack+858585,int_stack+857325, 0.0, zero_stack, 1.0, int_stack+882320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3964371,int_stack+3960591,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+3269563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3970041,int_stack+860205,int_stack+858585, 0.0, zero_stack, 1.0, int_stack+884840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3974901,int_stack+3970041,int_stack+3960591, 0.0, zero_stack, 1.0, int_stack+3460523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+3974901,int_stack+3964371, 0.0, zero_stack, 1.0, int_stack+3464303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+862230,int_stack+860205, 0.0, zero_stack, 1.0, int_stack+888080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3870816,int_stack+3957756,int_stack+3970041, 0.0, zero_stack, 1.0, int_stack+3469973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3870816,int_stack+3974901, 0.0, zero_stack, 1.0, int_stack+3474833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3870816,int_stack+3957756,int_stack+2935021, 0.0, zero_stack, 1.0, int_stack+3482393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3870816,int_stack+1159710, 0.0, zero_stack, 1.0, int_stack+2579637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5857206,int_stack+3957756,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+2590977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+865146,int_stack+864705, 1.0, int_stack+1231660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+865734,int_stack+865146, 1.0, int_stack+1232101, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 1.0, int_stack+3225757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+866490,int_stack+865734, 1.0, int_stack+1232689, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 1.0, int_stack+3227080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 1.0, int_stack+3228844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+867435,int_stack+866490, 1.0, int_stack+1233445, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 1.0, int_stack+3231490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 1.0, int_stack+3233758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 1.0, int_stack+3237286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+869178,int_stack+868590, 1.0, int_stack+1239430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+869962,int_stack+869178, 1.0, int_stack+1240018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 1.0, int_stack+3248311, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+870970,int_stack+869962, 1.0, int_stack+1240802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 1.0, int_stack+3250075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+480567,int_stack+474015, 1.0, int_stack+3252427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3248311,int_stack+872230,int_stack+870970, 1.0, int_stack+1241810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+3248311,int_stack+477543, 1.0, int_stack+3255955, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+469899,int_stack+480567, 1.0, int_stack+3258979, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3957756, 1.0, int_stack+3263683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+3957756,int_stack+469899,int_stack+485838, 0.0, zero_stack, 1.0, int_stack+2714802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3977601,int_stack+874526,int_stack+873770, 1.0, int_stack+1249790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3979869,int_stack+875534,int_stack+874526, 1.0, int_stack+1250546, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3982893,int_stack+3979869,int_stack+3977601, 1.0, int_stack+3326872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3987429,int_stack+876830,int_stack+875534, 1.0, int_stack+1251554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2267218,int_stack+3987429,int_stack+3979869, 1.0, int_stack+3329140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+478719,int_stack+2267218,int_stack+3982893, 1.0, int_stack+3332164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3326872,int_stack+878450,int_stack+876830, 1.0, int_stack+1252850, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3977601,int_stack+3326872,int_stack+3987429, 1.0, int_stack+3336700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+486279,int_stack+3977601,int_stack+2267218, 1.0, int_stack+3369425, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+486279,int_stack+478719, 1.0, int_stack+3375473, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3870816,int_stack+1159710,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+2803450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3198217,int_stack+3870816,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+2812270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+883580,int_stack+881375, 1.0, int_stack+880430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960591,int_stack+886460,int_stack+883580, 1.0, int_stack+882320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3964371,int_stack+3960591,int_stack+3957756, 1.0, int_stack+3269563, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3970041,int_stack+890105,int_stack+886460, 1.0, int_stack+884840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3897276,int_stack+3970041,int_stack+3960591, 1.0, int_stack+3460523, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+3897276,int_stack+3964371, 1.0, int_stack+3464303, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3460523,int_stack+892130,int_stack+890105, 1.0, int_stack+888080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3957756,int_stack+3460523,int_stack+3970041, 1.0, int_stack+3469973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3460523,int_stack+3957756,int_stack+3897276, 1.0, int_stack+3474833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+3460523,int_stack+2935021, 1.0, int_stack+3482393, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+853569,int_stack+3957756,int_stack+1159710, 0.0, zero_stack, 1.0, int_stack+2857531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+5910126,int_stack+853569,int_stack+3870816, 0.0, zero_stack, 1.0, int_stack+2868871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+895046,int_stack+894605,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3872139,int_stack+895634,int_stack+895046,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3873903,int_stack+3872139,int_stack+3870816,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3876549,int_stack+896390,int_stack+895634,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3878817,int_stack+3876549,int_stack+3872139,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3882345,int_stack+3878817,int_stack+3873903,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+897335,int_stack+896390,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3886755,int_stack+3870816,int_stack+3876549,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+3886755,int_stack+3878817,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3886755,int_stack+3870816,int_stack+3882345,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+899078,int_stack+898490,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3872580,int_stack+899862,int_stack+899078,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3874932,int_stack+3872580,int_stack+3870816,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3878460,int_stack+900870,int_stack+899862,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3881484,int_stack+3878460,int_stack+3872580,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3893370,int_stack+3881484,int_stack+3874932,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3870816,int_stack+902130,int_stack+900870,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+853569,int_stack+3870816,int_stack+3878460,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+853569,int_stack+3881484,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+853569,int_stack+2267218,int_stack+3893370,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+862389,int_stack+853569,int_stack+3886755, 0.0, zero_stack, 1.0, int_stack+1447913, 1.0, int_stack+3241696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2267218,int_stack+904426,int_stack+903670,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+2269486,int_stack+905434,int_stack+904426,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+882234,int_stack+2269486,int_stack+2267218,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+886770,int_stack+906730,int_stack+905434,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+890658,int_stack+886770,int_stack+2269486,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2267218,int_stack+890658,int_stack+882234,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+896706,int_stack+908350,int_stack+906730,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+901566,int_stack+896706,int_stack+886770,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3870816,int_stack+901566,int_stack+890658,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+3870816,int_stack+2267218,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+853569, 0.0, zero_stack, 1.0, int_stack+7371, 1.0, int_stack+3340760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+5963046,int_stack+469899,int_stack+862389, 0.0, zero_stack, 1.0, int_stack+3083386, 1.0, int_stack+3349580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+853569,int_stack+911275,int_stack+910330,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+856404,int_stack+912535,int_stack+911275,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+860184,int_stack+856404,int_stack+853569,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+865854,int_stack+914155,int_stack+912535,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+870714,int_stack+865854,int_stack+856404,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+870714,int_stack+860184,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+853569,int_stack+916180,int_stack+914155,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+878274,int_stack+853569,int_stack+865854,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+853569,int_stack+878274,int_stack+870714,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+866169,int_stack+853569,int_stack+2935021,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+866169,int_stack+1159710, 0.0, zero_stack, 1.0, int_stack+3120727, 1.0, int_stack+3383033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+853569,int_stack+3870816,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+3132067, 1.0, int_stack+3394373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+919096,int_stack+918655,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+919684,int_stack+919096,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+920440,int_stack+919684,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+921385,int_stack+920440,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+923128,int_stack+922540,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+923912,int_stack+923128,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+924920,int_stack+923912,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3870816,int_stack+480567,int_stack+474015,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+926180,int_stack+924920,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3876696,int_stack+469899,int_stack+477543,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3876696,int_stack+480567,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3876696,int_stack+2267218,int_stack+3870816,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+3876696,int_stack+485838, 0.0, zero_stack, 2.0, int_stack+3241696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+928476,int_stack+927720,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3873084,int_stack+929484,int_stack+928476,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3873084,int_stack+3870816,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3885516,int_stack+930780,int_stack+929484,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3889404,int_stack+3885516,int_stack+3873084,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3895452,int_stack+3889404,int_stack+2267218,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+932400,int_stack+930780,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3885516,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3889404,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3895452,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3876696, 0.0, zero_stack, 2.0, int_stack+3340760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+6002736,int_stack+469899,int_stack+906489, 0.0, zero_stack, 2.0, int_stack+3349580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+906489,int_stack+935325,int_stack+934380,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+909324,int_stack+936585,int_stack+935325,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+913104,int_stack+909324,int_stack+906489,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+918774,int_stack+938205,int_stack+936585,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+923634,int_stack+918774,int_stack+909324,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+923634,int_stack+913104,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+906489,int_stack+940230,int_stack+938205,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+931194,int_stack+906489,int_stack+918774,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+906489,int_stack+931194,int_stack+923634,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+919089,int_stack+906489,int_stack+2935021,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+919089,int_stack+1159710, 0.0, zero_stack, 2.0, int_stack+3383033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+6042426,int_stack+3870816,int_stack+469899, 0.0, zero_stack, 2.0, int_stack+3394373, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+947031,int_stack+946590, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1275320,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+947619,int_stack+947031, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1275761,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3491843,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+948375,int_stack+947619, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1276349,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3493166,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3494930,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+949320,int_stack+948375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1277105,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3497576,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3499844,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3503372,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+956243,int_stack+955655, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288270,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+957027,int_stack+956243, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288858,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3514397,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+958035,int_stack+957027, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1289642,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3516161,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3870816,int_stack+480567,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3518513,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+959295,int_stack+958035, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1290650,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3876696,int_stack+469899,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3522041,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3876696,int_stack+480567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3525065,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3876696,int_stack+2267218,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3529769,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+3876696,int_stack+485838, 1.0, int_stack+1352153, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+968251,int_stack+967495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1298630,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873084,int_stack+969259,int_stack+968251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299386,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3873084,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1562075,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3885516,int_stack+970555,int_stack+969259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1300394,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3889404,int_stack+3885516,int_stack+3873084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1564343,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3895452,int_stack+3889404,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3592958,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+972175,int_stack+970555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1301690,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3885516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16191,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3889404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3629463,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3895452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3635511,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3876696, 1.0, int_stack+1401272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+926334,int_stack+469899,int_stack+906489, 1.0, int_stack+1410092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+906489,int_stack+975100,int_stack+974155, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1177710,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+909324,int_stack+976360,int_stack+975100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1179600,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+913104,int_stack+909324,int_stack+906489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2997391,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+918774,int_stack+977980,int_stack+976360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1182120,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2267218,int_stack+918774,int_stack+909324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3000226,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+2267218,int_stack+913104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3004006,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+906489,int_stack+980005,int_stack+977980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1185360,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3870816,int_stack+906489,int_stack+918774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3009676,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+906489,int_stack+3870816,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1567367,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3870816,int_stack+906489,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3720561,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3870816,int_stack+1159710, 1.0, int_stack+1484585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+6095346,int_stack+3957756,int_stack+469899, 1.0, int_stack+1495925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+986806,int_stack+986365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1275320, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+987394,int_stack+986806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1275761, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3491843, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+988150,int_stack+987394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1276349, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3493166, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3494930, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+989095,int_stack+988150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1277105, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3497576, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3499844, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3503372, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+996018,int_stack+995430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288270, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+996802,int_stack+996018, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288858, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3514397, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+997810,int_stack+996802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1289642, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3516161, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+480567,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3518513, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+999070,int_stack+997810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1290650, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3963636,int_stack+469899,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3522041, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3963636,int_stack+480567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3525065, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3963636,int_stack+2267218,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3529769, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+3963636,int_stack+485838, 1.0, int_stack+1646324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+1008026,int_stack+1007270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1298630, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960024,int_stack+1009034,int_stack+1008026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299386, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3960024,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3972456,int_stack+1010330,int_stack+1009034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1300394, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3976344,int_stack+3972456,int_stack+3960024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1564343, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3982392,int_stack+3976344,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3592958, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+1011950,int_stack+1010330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1301690, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3972456, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16191, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3976344, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3629463, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3982392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3635511, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3963636, 1.0, int_stack+1745388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+966024,int_stack+469899,int_stack+906489, 1.0, int_stack+1754208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+906489,int_stack+1014875,int_stack+1013930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1177710, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+909324,int_stack+1016135,int_stack+1014875, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1179600, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+913104,int_stack+909324,int_stack+906489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2997391, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+918774,int_stack+1017755,int_stack+1016135, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1182120, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2267218,int_stack+918774,int_stack+909324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3000226, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+2267218,int_stack+913104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3004006, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+906489,int_stack+1019780,int_stack+1017755, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1185360, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3957756,int_stack+906489,int_stack+918774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3009676, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+906489,int_stack+3957756,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1567367, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+906489,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3720561, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3957756,int_stack+1159710, 1.0, int_stack+1787661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1731500,int_stack+3870816,int_stack+469899, 1.0, int_stack+1799001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1026581,int_stack+1026140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1275320, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+1027169,int_stack+1026581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1275761, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3491843, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+1027925,int_stack+1027169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1276349, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3493166, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3494930, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1028870,int_stack+1027925, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1277105, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3497576, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3499844, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3503372, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1035793,int_stack+1035205, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288270, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+1036577,int_stack+1035793, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288858, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3514397, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+1037585,int_stack+1036577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1289642, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3516161, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3870816,int_stack+480567,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3518513, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1038845,int_stack+1037585, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1290650, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3876696,int_stack+469899,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3522041, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3876696,int_stack+480567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3525065, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3876696,int_stack+2267218,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3529769, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+3876696,int_stack+485838, 1.0, int_stack+1912410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+1047801,int_stack+1047045, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1298630, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873084,int_stack+1048809,int_stack+1047801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299386, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3873084,int_stack+3870816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3885516,int_stack+1050105,int_stack+1048809, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1300394, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3889404,int_stack+3885516,int_stack+3873084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1564343, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3895452,int_stack+3889404,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3592958, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+1051725,int_stack+1050105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1301690, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3885516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16191, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3889404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3629463, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3895452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3635511, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3876696, 1.0, int_stack+2011474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1005714,int_stack+469899,int_stack+906489, 1.0, int_stack+2020294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+906489,int_stack+1054650,int_stack+1053705, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1177710, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+909324,int_stack+1055910,int_stack+1054650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1179600, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+913104,int_stack+909324,int_stack+906489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2997391, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+918774,int_stack+1057530,int_stack+1055910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1182120, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2267218,int_stack+918774,int_stack+909324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3000226, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+2267218,int_stack+913104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3004006, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+906489,int_stack+1059555,int_stack+1057530, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1185360, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3870816,int_stack+906489,int_stack+918774, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3009676, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+906489,int_stack+3870816,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1567367, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3870816,int_stack+906489,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3720561, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3870816,int_stack+1159710, 1.0, int_stack+2071603, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1997586,int_stack+3957756,int_stack+469899, 1.0, int_stack+2082943, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1066356,int_stack+1065915, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1275320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+1066944,int_stack+1066356, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1275761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3491843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+1067700,int_stack+1066944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1276349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3493166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3494930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1068645,int_stack+1067700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1277105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3497576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3499844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3503372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1075568,int_stack+1074980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+1076352,int_stack+1075568, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1288858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3514397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+1077360,int_stack+1076352, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1289642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3516161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+480567,int_stack+474015, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3518513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1078620,int_stack+1077360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1290650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3963636,int_stack+469899,int_stack+477543, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3522041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2267218,int_stack+3963636,int_stack+480567, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3525065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3963636,int_stack+2267218,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3529769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+3963636,int_stack+485838, 1.0, int_stack+2182042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+1087576,int_stack+1086820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1298630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960024,int_stack+1088584,int_stack+1087576, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1299386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+2267218,int_stack+3960024,int_stack+3957756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3972456,int_stack+1089880,int_stack+1088584, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1300394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3976344,int_stack+3972456,int_stack+3960024, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1564343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3982392,int_stack+3976344,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3592958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2267218,int_stack+1091500,int_stack+1089880, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1301690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+2267218,int_stack+3972456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3976344, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3629463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+477675,int_stack+3982392, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3635511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3963636, 1.0, int_stack+2275058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1045404,int_stack+469899,int_stack+906489, 1.0, int_stack+2283878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+906489,int_stack+1094425,int_stack+1093480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1177710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+909324,int_stack+1095685,int_stack+1094425, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1179600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+913104,int_stack+909324,int_stack+906489, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2997391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+918774,int_stack+1097305,int_stack+1095685, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1182120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2267218,int_stack+918774,int_stack+909324, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3000226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+2267218,int_stack+913104, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3004006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+906489,int_stack+1099330,int_stack+1097305, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1185360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+2274778,int_stack+906489,int_stack+918774, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3009676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+906489,int_stack+2274778,int_stack+2267218, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1567367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+2267218,int_stack+906489,int_stack+2935021, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3720561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+2267218,int_stack+1159710, 1.0, int_stack+2317331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2267218,int_stack+3957756,int_stack+469899, 1.0, int_stack+2328671, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1106131,int_stack+1105690, 0.0, zero_stack, 1.0, int_stack+1275320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+1106719,int_stack+1106131, 0.0, zero_stack, 1.0, int_stack+1275761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+3491843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+1107475,int_stack+1106719, 0.0, zero_stack, 1.0, int_stack+1276349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 0.0, zero_stack, 1.0, int_stack+3493166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 0.0, zero_stack, 1.0, int_stack+3494930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1108420,int_stack+1107475, 0.0, zero_stack, 1.0, int_stack+1277105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 0.0, zero_stack, 1.0, int_stack+3497576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 0.0, zero_stack, 1.0, int_stack+3499844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 0.0, zero_stack, 1.0, int_stack+3503372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1115343,int_stack+1114755, 0.0, zero_stack, 1.0, int_stack+1288270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+1116127,int_stack+1115343, 0.0, zero_stack, 1.0, int_stack+1288858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+3514397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+1117135,int_stack+1116127, 0.0, zero_stack, 1.0, int_stack+1289642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 0.0, zero_stack, 1.0, int_stack+3516161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3957756,int_stack+480567,int_stack+474015, 0.0, zero_stack, 1.0, int_stack+3518513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1118395,int_stack+1117135, 0.0, zero_stack, 1.0, int_stack+1290650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3963636,int_stack+469899,int_stack+477543, 0.0, zero_stack, 1.0, int_stack+3522041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+3963636,int_stack+480567, 0.0, zero_stack, 1.0, int_stack+3525065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3963636,int_stack+469899,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+3529769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+3963636,int_stack+485838, 1.0, int_stack+2438300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+1127351,int_stack+1126595, 0.0, zero_stack, 1.0, int_stack+1298630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3960024,int_stack+1128359,int_stack+1127351, 0.0, zero_stack, 1.0, int_stack+1299386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+469899,int_stack+3960024,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+474435,int_stack+1129655,int_stack+1128359, 0.0, zero_stack, 1.0, int_stack+1300394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+478323,int_stack+474435,int_stack+3960024, 0.0, zero_stack, 1.0, int_stack+1564343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+484371,int_stack+478323,int_stack+469899, 0.0, zero_stack, 1.0, int_stack+3592958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+1131275,int_stack+1129655, 0.0, zero_stack, 1.0, int_stack+1301690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3972456,int_stack+3957756,int_stack+474435, 0.0, zero_stack, 1.0, int_stack+16191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3980232,int_stack+3972456,int_stack+478323, 0.0, zero_stack, 1.0, int_stack+3629463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+1159710,int_stack+3980232,int_stack+484371, 0.0, zero_stack, 1.0, int_stack+3635511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1159710,int_stack+3963636, 1.0, int_stack+2537364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1085094,int_stack+469899,int_stack+906489, 1.0, int_stack+2546184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+906489,int_stack+1134200,int_stack+1133255, 0.0, zero_stack, 1.0, int_stack+1177710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+909324,int_stack+1135460,int_stack+1134200, 0.0, zero_stack, 1.0, int_stack+1179600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+913104,int_stack+909324,int_stack+906489, 0.0, zero_stack, 1.0, int_stack+2997391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+918774,int_stack+1137080,int_stack+1135460, 0.0, zero_stack, 1.0, int_stack+1182120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3957756,int_stack+918774,int_stack+909324, 0.0, zero_stack, 1.0, int_stack+3000226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+3957756,int_stack+913104, 0.0, zero_stack, 1.0, int_stack+3004006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+906489,int_stack+1139105,int_stack+1137080, 0.0, zero_stack, 1.0, int_stack+1185360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3965316,int_stack+906489,int_stack+918774, 0.0, zero_stack, 1.0, int_stack+3009676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+906489,int_stack+3965316,int_stack+3957756, 0.0, zero_stack, 1.0, int_stack+1567367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+906489,int_stack+2935021, 0.0, zero_stack, 1.0, int_stack+3720561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3870816,int_stack+3957756,int_stack+1159710, 1.0, int_stack+2579637, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2523476,int_stack+3870816,int_stack+469899, 1.0, int_stack+2590977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1145906,int_stack+1145465, 1.0, int_stack+1275320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+1146494,int_stack+1145906, 1.0, int_stack+1275761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899, 1.0, int_stack+3491843, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+1147250,int_stack+1146494, 1.0, int_stack+1276349, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222, 1.0, int_stack+3493166, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986, 1.0, int_stack+3494930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1148195,int_stack+1147250, 1.0, int_stack+1277105, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632, 1.0, int_stack+3497576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900, 1.0, int_stack+3499844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+481428, 1.0, int_stack+3503372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1155118,int_stack+1154530, 1.0, int_stack+1288270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+1155902,int_stack+1155118, 1.0, int_stack+1288858, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899, 1.0, int_stack+3514397, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+1156910,int_stack+1155902, 1.0, int_stack+1289642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663, 1.0, int_stack+3516161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3870816,int_stack+480567,int_stack+474015, 1.0, int_stack+3518513, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3514397,int_stack+1158170,int_stack+1156910, 1.0, int_stack+1290650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+3514397,int_stack+477543, 1.0, int_stack+3522041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3514397,int_stack+469899,int_stack+480567, 1.0, int_stack+3525065, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+469899,int_stack+3514397,int_stack+3870816, 1.0, int_stack+3529769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+469899,int_stack+485838, 1.0, int_stack+2714802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3870816,int_stack+1171806,int_stack+1171050, 1.0, int_stack+1298630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3873084,int_stack+1172814,int_stack+1171806, 1.0, int_stack+1299386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3876108,int_stack+3873084,int_stack+3870816, 1.0, int_stack+1562075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3880644,int_stack+1174110,int_stack+1172814, 1.0, int_stack+1300394, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3884532,int_stack+3880644,int_stack+3873084, 1.0, int_stack+1564343, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+3890580,int_stack+3884532,int_stack+3876108, 1.0, int_stack+3592958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+3592958,int_stack+1175730,int_stack+1174110, 1.0, int_stack+1301690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+3870816,int_stack+3592958,int_stack+3880644, 1.0, int_stack+16191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+3514397,int_stack+3870816,int_stack+3884532, 1.0, int_stack+3629463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+3870816,int_stack+3514397,int_stack+3890580, 1.0, int_stack+3635511, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+3957756,int_stack+3870816,int_stack+469899, 1.0, int_stack+2803450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1124784,int_stack+3957756,int_stack+906489, 1.0, int_stack+2812270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+906489,int_stack+1180860,int_stack+1178655, 1.0, int_stack+1177710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+909324,int_stack+1183740,int_stack+1180860, 1.0, int_stack+1179600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+913104,int_stack+909324,int_stack+906489, 1.0, int_stack+2997391, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+918774,int_stack+1187385,int_stack+1183740, 1.0, int_stack+1182120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3984216,int_stack+918774,int_stack+909324, 1.0, int_stack+3000226, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+2935021,int_stack+3984216,int_stack+913104, 1.0, int_stack+3004006, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+2997391,int_stack+1189410,int_stack+1187385, 1.0, int_stack+1185360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+906489,int_stack+2997391,int_stack+918774, 1.0, int_stack+3009676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+2997391,int_stack+906489,int_stack+3984216, 1.0, int_stack+1567367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+906489,int_stack+2997391,int_stack+2935021, 1.0, int_stack+3720561, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1562075,int_stack+906489,int_stack+3870816, 1.0, int_stack+2857531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+2789562,int_stack+1562075,int_stack+3957756, 1.0, int_stack+2868871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+1196211,int_stack+1195770,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3959079,int_stack+1196799,int_stack+1196211,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3960843,int_stack+3959079,int_stack+3957756,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3963489,int_stack+1197555,int_stack+1196799,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3965757,int_stack+3963489,int_stack+3959079,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3969285,int_stack+3965757,int_stack+3960843,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+1198500,int_stack+1197555,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3973695,int_stack+3957756,int_stack+3963489,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+3973695,int_stack+3965757,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3973695,int_stack+3957756,int_stack+3969285,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3957756,int_stack+1205423,int_stack+1204835,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3959520,int_stack+1206207,int_stack+1205423,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3961872,int_stack+3959520,int_stack+3957756,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3965400,int_stack+1207215,int_stack+1206207,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3968424,int_stack+3965400,int_stack+3959520,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3980310,int_stack+3968424,int_stack+3961872,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3957756,int_stack+1208475,int_stack+1207215,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1562075,int_stack+3957756,int_stack+3965400,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3592958,int_stack+1562075,int_stack+3968424,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1562075,int_stack+3592958,int_stack+3980310,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+1562075,int_stack+3973695, 1.0, int_stack+1447913, 0.0, zero_stack, 1.0, int_stack+3507782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3592958,int_stack+1217431,int_stack+1216675,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3595226,int_stack+1218439,int_stack+1217431,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1570895,int_stack+3595226,int_stack+3592958,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+16191,int_stack+1219735,int_stack+1218439,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1575431,int_stack+16191,int_stack+3595226,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3592958,int_stack+1575431,int_stack+1570895,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+1581479,int_stack+1221355,int_stack+1219735,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1586339,int_stack+1581479,int_stack+16191,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3957756,int_stack+1586339,int_stack+1575431,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1570895,int_stack+3957756,int_stack+3592958,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+1570895,int_stack+1562075, 1.0, int_stack+7371, 0.0, zero_stack, 1.0, int_stack+3600798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+2997391,int_stack+469899,int_stack+906489, 1.0, int_stack+3083386, 0.0, zero_stack, 1.0, int_stack+3609618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3083386,int_stack+1224280,int_stack+1223335,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3086221,int_stack+1225540,int_stack+1224280,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3090001,int_stack+3086221,int_stack+3083386,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3095671,int_stack+1227160,int_stack+1225540,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3100531,int_stack+3095671,int_stack+3086221,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3720561,int_stack+3100531,int_stack+3090001,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3083386,int_stack+1229185,int_stack+1227160,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3108091,int_stack+3083386,int_stack+3095671,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3083386,int_stack+3108091,int_stack+3100531,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3095986,int_stack+3083386,int_stack+3720561,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+3095986,int_stack+1570895, 1.0, int_stack+3120727, 0.0, zero_stack, 1.0, int_stack+3643071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1164474,int_stack+3957756,int_stack+469899, 1.0, int_stack+3132067, 0.0, zero_stack, 1.0, int_stack+3654411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1235986,int_stack+1235545,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+1236574,int_stack+1235986,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+1237330,int_stack+1236574,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1238275,int_stack+1237330,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3037081,int_stack+469899,int_stack+481428,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1245198,int_stack+1244610,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+1245982,int_stack+1245198,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+1246990,int_stack+1245982,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+485271,int_stack+480567,int_stack+474015,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1248250,int_stack+1246990,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3957756,int_stack+469899,int_stack+477543,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3592958,int_stack+3957756,int_stack+480567,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+3592958,int_stack+485271,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+3957756,int_stack+3037081, 1.0, int_stack+3241696, 1.0, int_stack+3507782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3037081,int_stack+1257206,int_stack+1256450,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3039349,int_stack+1258214,int_stack+1257206,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3592958,int_stack+3039349,int_stack+3037081,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3966576,int_stack+1259510,int_stack+1258214,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3970464,int_stack+3966576,int_stack+3039349,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3976512,int_stack+3970464,int_stack+3592958,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3592958,int_stack+1261130,int_stack+1259510,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+3592958,int_stack+3966576,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+3970464,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3083386,int_stack+477675,int_stack+3976512,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+3083386,int_stack+3957756, 1.0, int_stack+3340760, 1.0, int_stack+3600798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+3094726,int_stack+469899,int_stack+906489, 1.0, int_stack+3349580, 1.0, int_stack+3609618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+906489,int_stack+1264055,int_stack+1263110,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+909324,int_stack+1265315,int_stack+1264055,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+913104,int_stack+909324,int_stack+906489,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+918774,int_stack+1266935,int_stack+1265315,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3957756,int_stack+918774,int_stack+909324,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3720561,int_stack+3957756,int_stack+913104,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+906489,int_stack+1268960,int_stack+1266935,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3965316,int_stack+906489,int_stack+918774,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+906489,int_stack+3965316,int_stack+3957756,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3957756,int_stack+906489,int_stack+3720561,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1562075,int_stack+3957756,int_stack+3083386, 1.0, int_stack+3383033, 1.0, int_stack+3643071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1217394,int_stack+1562075,int_stack+469899, 1.0, int_stack+3394373, 1.0, int_stack+3654411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1279646,int_stack+1279205,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471222,int_stack+1280234,int_stack+1279646,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+472986,int_stack+471222,int_stack+469899,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+475632,int_stack+1280990,int_stack+1280234,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+477900,int_stack+475632,int_stack+471222,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+481428,int_stack+477900,int_stack+472986,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1281935,int_stack+1280990,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+485838,int_stack+469899,int_stack+475632,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+469899,int_stack+485838,int_stack+477900,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3037081,int_stack+469899,int_stack+481428,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+469899,int_stack+1294038,int_stack+1293450,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+471663,int_stack+1294822,int_stack+1294038,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+474015,int_stack+471663,int_stack+469899,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+477543,int_stack+1295830,int_stack+1294822,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+480567,int_stack+477543,int_stack+471663,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+485271,int_stack+480567,int_stack+474015,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+469899,int_stack+1297090,int_stack+1295830,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1562075,int_stack+469899,int_stack+477543,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+3592958,int_stack+1562075,int_stack+480567,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1562075,int_stack+3592958,int_stack+485271,28);
 /*--- compute (hp|hg) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+906489,int_stack+1562075,int_stack+3037081, 2.0, int_stack+3507782, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+3037081,int_stack+1306046,int_stack+1305290,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+3039349,int_stack+1307054,int_stack+1306046,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3592958,int_stack+3039349,int_stack+3037081,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1570895,int_stack+1308350,int_stack+1307054,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1574783,int_stack+1570895,int_stack+3039349,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1580831,int_stack+1574783,int_stack+3592958,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+3592958,int_stack+1309970,int_stack+1308350,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+469899,int_stack+3592958,int_stack+1570895,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+477675,int_stack+469899,int_stack+1574783,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+3083386,int_stack+477675,int_stack+1580831,36);
 /*--- compute (ip|hg) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+469899,int_stack+3083386,int_stack+1562075, 2.0, int_stack+3600798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hd|hg) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1270314,int_stack+469899,int_stack+906489, 2.0, int_stack+3609618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (l0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+906489,int_stack+1312895,int_stack+1311950,45);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+909324,int_stack+1314155,int_stack+1312895,45);
 /*--- compute (l0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+913104,int_stack+909324,int_stack+906489,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+918774,int_stack+1315775,int_stack+1314155,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1562075,int_stack+918774,int_stack+909324,45);
 /*--- compute (l0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+3720561,int_stack+1562075,int_stack+913104,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+906489,int_stack+1317800,int_stack+1315775,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1569635,int_stack+906489,int_stack+918774,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+906489,int_stack+1569635,int_stack+1562075,45);
 /*--- compute (l0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+1562075,int_stack+906489,int_stack+3720561,45);
 /*--- compute (kp|hg) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+3957756,int_stack+1562075,int_stack+3083386, 2.0, int_stack+3643071, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (id|hg) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+3592958,int_stack+3957756,int_stack+469899, 2.0, int_stack+3654411, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3460523,int_stack+1678580,int_stack+1522385,315);
     Libderiv->ABCD[11] = int_stack + 3460523;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3326872,int_stack+1944666,int_stack+1825461,315);
     Libderiv->ABCD[10] = int_stack + 3326872;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1398458,int_stack+2214298,int_stack+2109403,315);
     Libderiv->ABCD[9] = int_stack + 1398458;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2149093,int_stack+2470556,int_stack+2355131,315);
     Libderiv->ABCD[8] = int_stack + 2149093;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2434511,int_stack+2736642,int_stack+2617437,315);
     Libderiv->ABCD[7] = int_stack + 2434511;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+2696817,int_stack+2944471,int_stack+2895331,315);
     Libderiv->ABCD[6] = int_stack + 2696817;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1904841,int_stack+3273952,int_stack+3158527, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3043696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[2] = int_stack + 1904841;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3237907,int_stack+3540038,int_stack+3420833, 0.0, zero_stack, 1.0, int_stack+3043696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[1] = int_stack + 3237907;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3526673,int_stack+3778206,int_stack+3680871, 1.0, int_stack+3043696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[0] = int_stack + 3526673;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+1635785,int_stack+3904836,int_stack+3831126,315);
     Libderiv->ABCD[155] = int_stack + 1635785;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3769701,int_stack+3991776,int_stack+20079,315);
     Libderiv->ABCD[143] = int_stack + 3769701;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3835851,int_stack+4084386,int_stack+4044696,315);
     Libderiv->ABCD[142] = int_stack + 3835851;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3902001,int_stack+4137306,int_stack+59769,315);
     Libderiv->ABCD[131] = int_stack + 3902001;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+0,int_stack+4229916,int_stack+4190226,315);
     Libderiv->ABCD[130] = int_stack + 0;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+3968151,int_stack+4282836,int_stack+99459,315);
     Libderiv->ABCD[129] = int_stack + 3968151;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+66150,int_stack+4335756,int_stack+139149,315);
     Libderiv->ABCD[119] = int_stack + 66150;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4034301,int_stack+4428366,int_stack+4388676,315);
     Libderiv->ABCD[118] = int_stack + 4034301;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4100451,int_stack+4481286,int_stack+178839,315);
     Libderiv->ABCD[117] = int_stack + 4100451;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+132300,int_stack+4534206,int_stack+218529,315);
     Libderiv->ABCD[116] = int_stack + 132300;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4166601,int_stack+4626816,int_stack+4587126,315);
     Libderiv->ABCD[107] = int_stack + 4166601;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4232751,int_stack+4679736,int_stack+258219,315);
     Libderiv->ABCD[106] = int_stack + 4232751;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+198450,int_stack+4772346,int_stack+4732656,315);
     Libderiv->ABCD[105] = int_stack + 198450;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4298901,int_stack+4825266,int_stack+297909,315);
     Libderiv->ABCD[104] = int_stack + 4298901;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+264600,int_stack+4878186,int_stack+337599,315);
     Libderiv->ABCD[103] = int_stack + 264600;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4365051,int_stack+4970796,int_stack+4931106,315);
     Libderiv->ABCD[95] = int_stack + 4365051;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4431201,int_stack+5023716,int_stack+377289,315);
     Libderiv->ABCD[94] = int_stack + 4431201;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+330750,int_stack+416979,int_stack+3730011,315);
     Libderiv->ABCD[93] = int_stack + 330750;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+396900,int_stack+5076636,int_stack+1865151,315);
     Libderiv->ABCD[92] = int_stack + 396900;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4497351,int_stack+5129556,int_stack+2394821,315);
     Libderiv->ABCD[91] = int_stack + 4497351;
 /*--- compute (hf|hg) ---*/
   hrr1_build_hf(Libderiv->AB,int_stack+4563501,int_stack+496359,int_stack+2657127,315);
     Libderiv->ABCD[90] = int_stack + 4563501;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+463050,int_stack+5182476,int_stack+1596095, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1522385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[47] = int_stack + 463050;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1562075,int_stack+549279,int_stack+5235396, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1825461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[46] = int_stack + 1562075;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+529200,int_stack+5314776,int_stack+5275086, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2109403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[45] = int_stack + 529200;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4629651,int_stack+602199,int_stack+5367696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2355131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[44] = int_stack + 4629651;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4695801,int_stack+5447076,int_stack+5407386, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2617437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[43] = int_stack + 4695801;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4761951,int_stack+5499996,int_stack+655119, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2895331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[42] = int_stack + 4761951;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+595350,int_stack+5552916,int_stack+694809, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3158527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[38] = int_stack + 595350;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+661500,int_stack+5605836,int_stack+1358768, 0.0, zero_stack, 1.0, int_stack+1522385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[35] = int_stack + 661500;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1310004,int_stack+5658756,int_stack+734499, 0.0, zero_stack, 1.0, int_stack+1825461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[34] = int_stack + 1310004;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4828101,int_stack+5751366,int_stack+5711676, 0.0, zero_stack, 1.0, int_stack+2109403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[33] = int_stack + 4828101;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4894251,int_stack+5804286,int_stack+774189, 0.0, zero_stack, 1.0, int_stack+2355131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[32] = int_stack + 4894251;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+727650,int_stack+5857206,int_stack+813879, 0.0, zero_stack, 1.0, int_stack+2617437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[31] = int_stack + 727650;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+4960401,int_stack+5910126,int_stack+3198217, 0.0, zero_stack, 1.0, int_stack+2895331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[30] = int_stack + 4960401;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5026551,int_stack+853569,int_stack+5963046, 0.0, zero_stack, 1.0, int_stack+3158527, 1.0, int_stack+3420833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[26] = int_stack + 5026551;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+793800,int_stack+6042426,int_stack+6002736, 0.0, zero_stack, 2.0, int_stack+3420833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[25] = int_stack + 793800;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+859950,int_stack+6095346,int_stack+926334, 1.0, int_stack+1522385, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[23] = int_stack + 859950;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+1464608,int_stack+1731500,int_stack+966024, 1.0, int_stack+1825461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[22] = int_stack + 1464608;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+926100,int_stack+1997586,int_stack+1005714, 1.0, int_stack+2109403, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[21] = int_stack + 926100;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+5092701,int_stack+2267218,int_stack+1045404, 1.0, int_stack+2355131, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[20] = int_stack + 5092701;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+992250,int_stack+2523476,int_stack+1085094, 1.0, int_stack+2617437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[19] = int_stack + 992250;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2500661,int_stack+2789562,int_stack+1124784, 1.0, int_stack+2895331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[18] = int_stack + 2500661;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+2762967,int_stack+1164474,int_stack+2997391, 1.0, int_stack+3158527, 0.0, zero_stack, 1.0, int_stack+3680871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[14] = int_stack + 2762967;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3134416,int_stack+1217394,int_stack+3094726, 1.0, int_stack+3420833, 1.0, int_stack+3680871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[13] = int_stack + 3134416;
 /*--- compute (hf|hg) ---*/
   d1hrr1_build_hf(Libderiv->AB,int_stack+3393022,int_stack+3592958,int_stack+1270314, 2.0, int_stack+3680871, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,315);
     Libderiv->ABCD[12] = int_stack + 3393022;

}
