/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (pp|hg) integrals */

void d12vrr_order_pphg(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+3, dvrr_stack+0, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12, dvrr_stack+3, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+0, dvrr_stack+21, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+30, dvrr_stack+6, dvrr_stack+24, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+15, dvrr_stack+6, dvrr_stack+12, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+50, dvrr_stack+40, dvrr_stack+30, dvrr_stack+15, dvrr_stack+6, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+68, dvrr_stack+21, dvrr_stack+65, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+74, dvrr_stack+24, dvrr_stack+68, dvrr_stack+0, dvrr_stack+21, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+84, dvrr_stack+30, dvrr_stack+74, dvrr_stack+6, dvrr_stack+24, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+99, dvrr_stack+50, dvrr_stack+84, dvrr_stack+40, dvrr_stack+30, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+120, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+123, dvrr_stack+120, dvrr_stack+12, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+129, dvrr_stack+123, dvrr_stack+15, dvrr_stack+120, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+139, dvrr_stack+129, dvrr_stack+40, dvrr_stack+123, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+154, dvrr_stack+139, dvrr_stack+50, dvrr_stack+129, dvrr_stack+40, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+175, dvrr_stack+154, dvrr_stack+99, NULL, NULL, dvrr_stack+50);
 tmp = dvrr_stack + 175;
 target_ptr = Libderiv->dvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+120, dvrr_stack+65, dvrr_stack+12, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+238, dvrr_stack+68, dvrr_stack+120, dvrr_stack+21, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+248, dvrr_stack+74, dvrr_stack+238, dvrr_stack+24, dvrr_stack+68, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+263, dvrr_stack+84, dvrr_stack+248, dvrr_stack+30, dvrr_stack+74, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+284, dvrr_stack+99, dvrr_stack+263, dvrr_stack+50, dvrr_stack+84, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+312, dvrr_stack+154, dvrr_stack+99, dvrr_stack+139, dvrr_stack+50, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+340, dvrr_stack+312, dvrr_stack+284, NULL, NULL, dvrr_stack+99);
 tmp = dvrr_stack + 340;
 target_ptr = Libderiv->dvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+424,dvrr_stack+340,dvrr_stack+175,3);


 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+126, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+613, dvrr_stack+12, dvrr_stack+126, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+619, dvrr_stack+120, dvrr_stack+613, dvrr_stack+65, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+629, dvrr_stack+238, dvrr_stack+619, dvrr_stack+68, dvrr_stack+120, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+644, dvrr_stack+248, dvrr_stack+629, dvrr_stack+74, dvrr_stack+238, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+665, dvrr_stack+263, dvrr_stack+644, dvrr_stack+84, dvrr_stack+248, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+693, dvrr_stack+284, dvrr_stack+665, dvrr_stack+99, dvrr_stack+263, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+729, dvrr_stack+312, dvrr_stack+284, dvrr_stack+154, dvrr_stack+99, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+765, dvrr_stack+729, dvrr_stack+693, NULL, NULL, dvrr_stack+284);
 tmp = dvrr_stack + 765;
 target_ptr = Libderiv->dvrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+873,dvrr_stack+765,dvrr_stack+340,3);


 /* compute (1 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+1125,dvrr_stack+873,dvrr_stack+424,3);


 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,63,dvrr_stack+1503, dvrr_stack+1125, dvrr_stack+175);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1692, dvrr_stack+126, dvrr_stack+65, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1698, dvrr_stack+613, dvrr_stack+1692, dvrr_stack+12, dvrr_stack+126, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1708, dvrr_stack+619, dvrr_stack+1698, dvrr_stack+120, dvrr_stack+613, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1723, dvrr_stack+629, dvrr_stack+1708, dvrr_stack+238, dvrr_stack+619, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1744, dvrr_stack+644, dvrr_stack+1723, dvrr_stack+248, dvrr_stack+629, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1772, dvrr_stack+665, dvrr_stack+1744, dvrr_stack+263, dvrr_stack+644, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1808, dvrr_stack+693, dvrr_stack+1772, dvrr_stack+284, dvrr_stack+665, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1853, dvrr_stack+729, dvrr_stack+693, dvrr_stack+312, dvrr_stack+284, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1898, dvrr_stack+1853, dvrr_stack+1808, NULL, NULL, dvrr_stack+693);
 tmp = dvrr_stack + 1898;
 target_ptr = Libderiv->dvrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+2033,dvrr_stack+1898,dvrr_stack+765,3);


 /* compute (1 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+2357,dvrr_stack+2033,dvrr_stack+873,3);


 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,84,dvrr_stack+2861, dvrr_stack+2357, dvrr_stack+340);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+120, dvrr_stack+65, dvrr_stack+12, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3113, dvrr_stack+1692, dvrr_stack+120, dvrr_stack+126, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+3123, dvrr_stack+1698, dvrr_stack+3113, dvrr_stack+613, dvrr_stack+1692, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3138, dvrr_stack+1708, dvrr_stack+3123, dvrr_stack+619, dvrr_stack+1698, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3159, dvrr_stack+1723, dvrr_stack+3138, dvrr_stack+629, dvrr_stack+1708, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3187, dvrr_stack+1744, dvrr_stack+3159, dvrr_stack+644, dvrr_stack+1723, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3223, dvrr_stack+1772, dvrr_stack+3187, dvrr_stack+665, dvrr_stack+1744, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3268, dvrr_stack+1808, dvrr_stack+3223, dvrr_stack+693, dvrr_stack+1772, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3323, dvrr_stack+1853, dvrr_stack+1808, dvrr_stack+729, dvrr_stack+693, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3378, dvrr_stack+3323, dvrr_stack+3268, NULL, NULL, dvrr_stack+1808);
 tmp = dvrr_stack + 3378;
 target_ptr = Libderiv->dvrr_classes[1][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+3543,dvrr_stack+3378,dvrr_stack+1898,3);


 /* compute (1 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+3948,dvrr_stack+3543,dvrr_stack+2033,3);


 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,108,dvrr_stack+4596, dvrr_stack+3948, dvrr_stack+765);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+126, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+613, dvrr_stack+12, dvrr_stack+126, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+619, dvrr_stack+120, dvrr_stack+613, dvrr_stack+65, dvrr_stack+12, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+4920, dvrr_stack+3113, dvrr_stack+619, dvrr_stack+1692, dvrr_stack+120, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+4935, dvrr_stack+3123, dvrr_stack+4920, dvrr_stack+1698, dvrr_stack+3113, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4956, dvrr_stack+3138, dvrr_stack+4935, dvrr_stack+1708, dvrr_stack+3123, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4984, dvrr_stack+3159, dvrr_stack+4956, dvrr_stack+1723, dvrr_stack+3138, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5020, dvrr_stack+3187, dvrr_stack+4984, dvrr_stack+1744, dvrr_stack+3159, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+5065, dvrr_stack+3223, dvrr_stack+5020, dvrr_stack+1772, dvrr_stack+3187, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5120, dvrr_stack+3268, dvrr_stack+5065, dvrr_stack+1808, dvrr_stack+3223, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5186, dvrr_stack+3323, dvrr_stack+3268, dvrr_stack+1853, dvrr_stack+1808, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+5252, dvrr_stack+5186, dvrr_stack+5120, NULL, NULL, dvrr_stack+3268);

 /* compute (1 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+5450,dvrr_stack+5252,dvrr_stack+3378,3);


 /* compute (1 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+5945,dvrr_stack+5450,dvrr_stack+3543,3);


 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,135,dvrr_stack+6755, dvrr_stack+5945, dvrr_stack+1898);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+65, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1692, dvrr_stack+126, dvrr_stack+65, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1698, dvrr_stack+613, dvrr_stack+1692, dvrr_stack+12, dvrr_stack+126, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1708, dvrr_stack+619, dvrr_stack+1698, dvrr_stack+120, dvrr_stack+613, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+7160, dvrr_stack+4920, dvrr_stack+1708, dvrr_stack+3113, dvrr_stack+619, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+7181, dvrr_stack+4935, dvrr_stack+7160, dvrr_stack+3123, dvrr_stack+4920, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7209, dvrr_stack+4956, dvrr_stack+7181, dvrr_stack+3138, dvrr_stack+4935, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3113, dvrr_stack+4984, dvrr_stack+7209, dvrr_stack+3159, dvrr_stack+4956, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7245, dvrr_stack+5020, dvrr_stack+3113, dvrr_stack+3187, dvrr_stack+4984, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+7300, dvrr_stack+5065, dvrr_stack+7245, dvrr_stack+3223, dvrr_stack+5020, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+7366, dvrr_stack+5120, dvrr_stack+7300, dvrr_stack+3268, dvrr_stack+5065, NULL);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+7444, dvrr_stack+5186, dvrr_stack+5120, dvrr_stack+3323, dvrr_stack+3268, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+7522, dvrr_stack+7444, dvrr_stack+7366, NULL, NULL, dvrr_stack+5120);

 /* compute (1 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+7756,dvrr_stack+7522,dvrr_stack+5252,3);


 /* compute (1 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+8350,dvrr_stack+7756,dvrr_stack+5450,3);


 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,165,dvrr_stack+9340, dvrr_stack+8350, dvrr_stack+3378);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+9835, dvrr_stack+50, dvrr_stack+84, NULL, NULL, dvrr_stack+30);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+9880, dvrr_stack+99, dvrr_stack+263, NULL, NULL, dvrr_stack+84);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+9943, dvrr_stack+175, dvrr_stack+9880, dvrr_stack+154, dvrr_stack+99, dvrr_stack+9835);
 tmp = dvrr_stack + 9943;
 target_ptr = Libderiv->dvrr_classes[2][5];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+10069, dvrr_stack+284, dvrr_stack+665, NULL, NULL, dvrr_stack+263);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+10153, dvrr_stack+340, dvrr_stack+10069, dvrr_stack+312, dvrr_stack+284, dvrr_stack+9880);
 tmp = dvrr_stack + 10153;
 target_ptr = Libderiv->dvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+10321,dvrr_stack+10153,dvrr_stack+9943,6);


 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10699, dvrr_stack+693, dvrr_stack+1772, NULL, NULL, dvrr_stack+665);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+10807, dvrr_stack+765, dvrr_stack+10699, dvrr_stack+729, dvrr_stack+693, dvrr_stack+10069);
 tmp = dvrr_stack + 10807;
 target_ptr = Libderiv->dvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+11023,dvrr_stack+10807,dvrr_stack+10153,6);


 /* compute (2 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+11527,dvrr_stack+11023,dvrr_stack+10321,6);


 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,126,dvrr_stack+12283, dvrr_stack+11527, dvrr_stack+9943);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12661, dvrr_stack+1808, dvrr_stack+3223, NULL, NULL, dvrr_stack+1772);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12796, dvrr_stack+1898, dvrr_stack+12661, dvrr_stack+1853, dvrr_stack+1808, dvrr_stack+10699);
 tmp = dvrr_stack + 12796;
 target_ptr = Libderiv->dvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+13066,dvrr_stack+12796,dvrr_stack+10807,6);


 /* compute (2 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+13714,dvrr_stack+13066,dvrr_stack+11023,6);


 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,168,dvrr_stack+14722, dvrr_stack+13714, dvrr_stack+10153);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15226, dvrr_stack+3268, dvrr_stack+5065, NULL, NULL, dvrr_stack+3223);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+15391, dvrr_stack+3378, dvrr_stack+15226, dvrr_stack+3323, dvrr_stack+3268, dvrr_stack+12661);

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+15721,dvrr_stack+15391,dvrr_stack+12796,6);


 /* compute (2 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+16531,dvrr_stack+15721,dvrr_stack+13066,6);


 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,216,dvrr_stack+17827, dvrr_stack+16531, dvrr_stack+10807);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18475, dvrr_stack+5120, dvrr_stack+7300, NULL, NULL, dvrr_stack+5065);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18673, dvrr_stack+5252, dvrr_stack+18475, dvrr_stack+5186, dvrr_stack+5120, dvrr_stack+15226);

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+19069,dvrr_stack+18673,dvrr_stack+15391,6);


 /* compute (2 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+20059,dvrr_stack+19069,dvrr_stack+15721,6);


 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,270,dvrr_stack+21679, dvrr_stack+20059, dvrr_stack+12796);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+120, dvrr_stack+65, dvrr_stack+12, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+22489, dvrr_stack+1692, dvrr_stack+120, dvrr_stack+126, dvrr_stack+65, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+22499, dvrr_stack+1698, dvrr_stack+22489, dvrr_stack+613, dvrr_stack+1692, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+22514, dvrr_stack+1708, dvrr_stack+22499, dvrr_stack+619, dvrr_stack+1698, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+22535, dvrr_stack+7160, dvrr_stack+22514, dvrr_stack+4920, dvrr_stack+1708, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+22489, dvrr_stack+7181, dvrr_stack+22535, dvrr_stack+4935, dvrr_stack+7160, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+22525, dvrr_stack+7209, dvrr_stack+22489, dvrr_stack+4956, dvrr_stack+7181, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4920, dvrr_stack+3113, dvrr_stack+22525, dvrr_stack+4984, dvrr_stack+7209, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22489, dvrr_stack+7245, dvrr_stack+4920, dvrr_stack+5020, dvrr_stack+3113, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22555, dvrr_stack+7300, dvrr_stack+22489, dvrr_stack+5065, dvrr_stack+7245, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22633, dvrr_stack+7366, dvrr_stack+22555, NULL, NULL, dvrr_stack+7300);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22867, dvrr_stack+7522, dvrr_stack+22633, dvrr_stack+7444, dvrr_stack+7366, dvrr_stack+18475);

 /* compute (2 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+23335,dvrr_stack+22867,dvrr_stack+18673,6);


 /* compute (2 0 | 9 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_md(Libderiv->CD,dvrr_stack+24523,dvrr_stack+23335,dvrr_stack+19069,6);


 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,330,dvrr_stack+26503, dvrr_stack+24523, dvrr_stack+15391);

 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,63,dvrr_stack+22555, dvrr_stack+1125, dvrr_stack+175);

 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,84,dvrr_stack+27493, dvrr_stack+2357, dvrr_stack+340);

 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,108,dvrr_stack+27745, dvrr_stack+3948, dvrr_stack+765);

 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,135,dvrr_stack+28069, dvrr_stack+5945, dvrr_stack+1898);

 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,165,dvrr_stack+28474, dvrr_stack+8350, dvrr_stack+3378);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,126,dvrr_stack+28969, dvrr_stack+11527, dvrr_stack+9943);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,168,dvrr_stack+29347, dvrr_stack+13714, dvrr_stack+10153);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,216,dvrr_stack+29851, dvrr_stack+16531, dvrr_stack+10807);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,270,dvrr_stack+30499, dvrr_stack+20059, dvrr_stack+12796);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,330,dvrr_stack+31309, dvrr_stack+24523, dvrr_stack+15391);

 /* compute (1 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,63,dvrr_stack+32299, dvrr_stack+1125, dvrr_stack+175);

 /* compute (1 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,84,dvrr_stack+1125, dvrr_stack+2357, dvrr_stack+340);

 /* compute (1 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,108,dvrr_stack+2357, dvrr_stack+3948, dvrr_stack+765);

 /* compute (1 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,135,dvrr_stack+3948, dvrr_stack+5945, dvrr_stack+1898);

 /* compute (1 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,165,dvrr_stack+5945, dvrr_stack+8350, dvrr_stack+3378);

 /* compute (2 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,126,dvrr_stack+8350, dvrr_stack+11527, dvrr_stack+9943);

 /* compute (2 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,168,dvrr_stack+11527, dvrr_stack+13714, dvrr_stack+10153);

 /* compute (2 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,216,dvrr_stack+13714, dvrr_stack+16531, dvrr_stack+10807);

 /* compute (2 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,270,dvrr_stack+16531, dvrr_stack+20059, dvrr_stack+12796);

 /* compute (2 0 | 9 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,330,dvrr_stack+20059, dvrr_stack+24523, dvrr_stack+15391);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+24523, dvrr_stack+139, dvrr_stack+50, NULL, NULL, dvrr_stack+40);

 /* compute (1 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+24568,dvrr_stack+175,dvrr_stack+24523,3);


 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+24703, dvrr_stack+24568, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+24748, dvrr_stack+873, NULL);
 tmp = dvrr_stack + 24748;
 target_ptr = Libderiv->deriv_classes[1][6][11];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+24832, dvrr_stack+424, NULL);
 tmp = dvrr_stack + 24832;
 target_ptr = Libderiv->deriv_classes[1][5][11];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+24895, dvrr_stack+2033, NULL);
 tmp = dvrr_stack + 24895;
 target_ptr = Libderiv->deriv_classes[1][7][11];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+25003, dvrr_stack+3543, NULL);
 tmp = dvrr_stack + 25003;
 target_ptr = Libderiv->deriv_classes[1][8][11];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,165,dvrr_stack+25138, dvrr_stack+5450, NULL);
 tmp = dvrr_stack + 25138;
 target_ptr = Libderiv->deriv_classes[1][9][11];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,198,dvrr_stack+25303, dvrr_stack+7756, NULL);

 /* compute (1 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+25501, dvrr_stack+40, dvrr_stack+30, NULL, NULL, dvrr_stack+6);

 /* compute (2 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+25531, dvrr_stack+24523, dvrr_stack+9835, dvrr_stack+139, dvrr_stack+50, dvrr_stack+25501);

 /* compute (2 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+25621,dvrr_stack+9943,dvrr_stack+25531,6);


 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,90,dvrr_stack+25891, dvrr_stack+25621, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+25981, dvrr_stack+11023, NULL);
 tmp = dvrr_stack + 25981;
 target_ptr = Libderiv->deriv_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,126,dvrr_stack+1377, dvrr_stack+10321, NULL);
 tmp = dvrr_stack + 1377;
 target_ptr = Libderiv->deriv_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+26149, dvrr_stack+13066, NULL);
 tmp = dvrr_stack + 26149;
 target_ptr = Libderiv->deriv_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+21049, dvrr_stack+15721, NULL);
 tmp = dvrr_stack + 21049;
 target_ptr = Libderiv->deriv_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+21319, dvrr_stack+19069, NULL);
 tmp = dvrr_stack + 21319;
 target_ptr = Libderiv->deriv_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,396,dvrr_stack+17341, dvrr_stack+23335, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+26365, dvrr_stack+24568, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+26410, dvrr_stack+873, NULL);
 tmp = dvrr_stack + 26410;
 target_ptr = Libderiv->deriv_classes[1][6][10];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+17737, dvrr_stack+424, NULL);
 tmp = dvrr_stack + 17737;
 target_ptr = Libderiv->deriv_classes[1][5][10];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+14362, dvrr_stack+2033, NULL);
 tmp = dvrr_stack + 14362;
 target_ptr = Libderiv->deriv_classes[1][7][10];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+14470, dvrr_stack+3543, NULL);
 tmp = dvrr_stack + 14470;
 target_ptr = Libderiv->deriv_classes[1][8][10];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+12031, dvrr_stack+5450, NULL);
 tmp = dvrr_stack + 12031;
 target_ptr = Libderiv->deriv_classes[1][9][10];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,198,dvrr_stack+8728, dvrr_stack+7756, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,90,dvrr_stack+14605, dvrr_stack+25621, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+8926, dvrr_stack+11023, NULL);
 tmp = dvrr_stack + 8926;
 target_ptr = Libderiv->deriv_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+9094, dvrr_stack+10321, NULL);
 tmp = dvrr_stack + 9094;
 target_ptr = Libderiv->deriv_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+6440, dvrr_stack+13066, NULL);
 tmp = dvrr_stack + 6440;
 target_ptr = Libderiv->deriv_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+32488, dvrr_stack+15721, NULL);
 tmp = dvrr_stack + 32488;
 target_ptr = Libderiv->deriv_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+32758, dvrr_stack+19069, NULL);
 tmp = dvrr_stack + 32758;
 target_ptr = Libderiv->deriv_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,396,dvrr_stack+33088, dvrr_stack+23335, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+12196, dvrr_stack+24568, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+24568, dvrr_stack+873, NULL);
 tmp = dvrr_stack + 24568;
 target_ptr = Libderiv->deriv_classes[1][6][9];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+873, dvrr_stack+424, NULL);
 tmp = dvrr_stack + 873;
 target_ptr = Libderiv->deriv_classes[1][5][9];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+424, dvrr_stack+2033, NULL);
 tmp = dvrr_stack + 424;
 target_ptr = Libderiv->deriv_classes[1][7][9];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+2033, dvrr_stack+3543, NULL);
 tmp = dvrr_stack + 2033;
 target_ptr = Libderiv->deriv_classes[1][8][9];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+3543, dvrr_stack+5450, NULL);
 tmp = dvrr_stack + 3543;
 target_ptr = Libderiv->deriv_classes[1][9][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+5450, dvrr_stack+7756, NULL);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,90,dvrr_stack+7756, dvrr_stack+25621, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+25621, dvrr_stack+11023, NULL);
 tmp = dvrr_stack + 25621;
 target_ptr = Libderiv->deriv_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+11023, dvrr_stack+10321, NULL);
 tmp = dvrr_stack + 11023;
 target_ptr = Libderiv->deriv_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+10321, dvrr_stack+13066, NULL);
 tmp = dvrr_stack + 10321;
 target_ptr = Libderiv->deriv_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+13066, dvrr_stack+15721, NULL);
 tmp = dvrr_stack + 13066;
 target_ptr = Libderiv->deriv_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+15721, dvrr_stack+19069, NULL);
 tmp = dvrr_stack + 15721;
 target_ptr = Libderiv->deriv_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+19069, dvrr_stack+23335, NULL);

 /* compute (1 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+21649, dvrr_stack+129, dvrr_stack+40, NULL, NULL, dvrr_stack+15);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,3,1,dvrr_stack+23335, dvrr_stack+175, dvrr_stack+21649);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+23380, dvrr_stack+765, dvrr_stack+175);
 tmp = dvrr_stack + 23380;
 target_ptr = Libderiv->deriv_classes[1][6][8];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+23464, dvrr_stack+340, dvrr_stack+24523);
 tmp = dvrr_stack + 23464;
 target_ptr = Libderiv->deriv_classes[1][5][8];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+23527, dvrr_stack+1898, dvrr_stack+340);
 tmp = dvrr_stack + 23527;
 target_ptr = Libderiv->deriv_classes[1][7][8];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+23635, dvrr_stack+3378, dvrr_stack+765);
 tmp = dvrr_stack + 23635;
 target_ptr = Libderiv->deriv_classes[1][8][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+23770, dvrr_stack+5252, dvrr_stack+1898);
 tmp = dvrr_stack + 23770;
 target_ptr = Libderiv->deriv_classes[1][9][8];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+23935, dvrr_stack+7522, dvrr_stack+3378);

 /* compute (1 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+24133, dvrr_stack+15, dvrr_stack+6, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+24151, dvrr_stack+21649, dvrr_stack+25501, dvrr_stack+129, dvrr_stack+40, dvrr_stack+24133);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,6,1,dvrr_stack+24211, dvrr_stack+9943, dvrr_stack+24151);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+24301, dvrr_stack+10807, dvrr_stack+9943);
 tmp = dvrr_stack + 24301;
 target_ptr = Libderiv->deriv_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+19465, dvrr_stack+10153, dvrr_stack+25531);
 tmp = dvrr_stack + 19465;
 target_ptr = Libderiv->deriv_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+19591, dvrr_stack+12796, dvrr_stack+10153);
 tmp = dvrr_stack + 19591;
 target_ptr = Libderiv->deriv_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+16051, dvrr_stack+15391, dvrr_stack+10807);
 tmp = dvrr_stack + 16051;
 target_ptr = Libderiv->deriv_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+13336, dvrr_stack+18673, dvrr_stack+12796);
 tmp = dvrr_stack + 13336;
 target_ptr = Libderiv->deriv_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+7846, dvrr_stack+22867, dvrr_stack+15391);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,3,1,dvrr_stack+24469, dvrr_stack+175, dvrr_stack+21649);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+19807, dvrr_stack+765, dvrr_stack+175);
 tmp = dvrr_stack + 19807;
 target_ptr = Libderiv->deriv_classes[1][6][7];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+19891, dvrr_stack+340, dvrr_stack+24523);
 tmp = dvrr_stack + 19891;
 target_ptr = Libderiv->deriv_classes[1][5][7];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+8242, dvrr_stack+1898, dvrr_stack+340);
 tmp = dvrr_stack + 8242;
 target_ptr = Libderiv->deriv_classes[1][7][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+16321, dvrr_stack+3378, dvrr_stack+765);
 tmp = dvrr_stack + 16321;
 target_ptr = Libderiv->deriv_classes[1][8][7];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+11149, dvrr_stack+5252, dvrr_stack+1898);
 tmp = dvrr_stack + 11149;
 target_ptr = Libderiv->deriv_classes[1][9][7];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+11314, dvrr_stack+7522, dvrr_stack+3378);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,6,1,dvrr_stack+19954, dvrr_stack+9943, dvrr_stack+24151);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+5648, dvrr_stack+10807, dvrr_stack+9943);
 tmp = dvrr_stack + 5648;
 target_ptr = Libderiv->deriv_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+10537, dvrr_stack+10153, dvrr_stack+25531);
 tmp = dvrr_stack + 10537;
 target_ptr = Libderiv->deriv_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+3708, dvrr_stack+12796, dvrr_stack+10153);
 tmp = dvrr_stack + 3708;
 target_ptr = Libderiv->deriv_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+33484, dvrr_stack+15391, dvrr_stack+10807);
 tmp = dvrr_stack + 33484;
 target_ptr = Libderiv->deriv_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+33754, dvrr_stack+18673, dvrr_stack+12796);
 tmp = dvrr_stack + 33754;
 target_ptr = Libderiv->deriv_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+34084, dvrr_stack+22867, dvrr_stack+15391);

 /* compute (1 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,3,1,dvrr_stack+16456, dvrr_stack+175, dvrr_stack+21649);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+25789, dvrr_stack+765, dvrr_stack+175);
 tmp = dvrr_stack + 25789;
 target_ptr = Libderiv->deriv_classes[1][6][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+5816, dvrr_stack+340, dvrr_stack+24523);
 tmp = dvrr_stack + 5816;
 target_ptr = Libderiv->deriv_classes[1][5][6];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+2168, dvrr_stack+1898, dvrr_stack+340);
 tmp = dvrr_stack + 2168;
 target_ptr = Libderiv->deriv_classes[1][7][6];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+936, dvrr_stack+3378, dvrr_stack+765);
 tmp = dvrr_stack + 936;
 target_ptr = Libderiv->deriv_classes[1][8][6];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+4353, dvrr_stack+5252, dvrr_stack+1898);
 tmp = dvrr_stack + 4353;
 target_ptr = Libderiv->deriv_classes[1][9][6];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+34480, dvrr_stack+7522, dvrr_stack+3378);

 /* compute (2 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,6,1,dvrr_stack+532, dvrr_stack+9943, dvrr_stack+24151);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+2681, dvrr_stack+10807, dvrr_stack+9943);
 tmp = dvrr_stack + 2681;
 target_ptr = Libderiv->deriv_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+7366, dvrr_stack+10153, dvrr_stack+25531);
 tmp = dvrr_stack + 7366;
 target_ptr = Libderiv->deriv_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+7492, dvrr_stack+12796, dvrr_stack+10153);
 tmp = dvrr_stack + 7492;
 target_ptr = Libderiv->deriv_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+34678, dvrr_stack+15391, dvrr_stack+10807);
 tmp = dvrr_stack + 34678;
 target_ptr = Libderiv->deriv_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+34948, dvrr_stack+18673, dvrr_stack+12796);
 tmp = dvrr_stack + 34948;
 target_ptr = Libderiv->deriv_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+35278, dvrr_stack+22867, dvrr_stack+15391);

 /* compute (0 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+24133,dvrr_stack+312,dvrr_stack+154,1);


 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,21,dvrr_stack+21649, dvrr_stack+24133, NULL);

 /* compute (0 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+9220,dvrr_stack+729,dvrr_stack+312,1);


 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,28,dvrr_stack+16501, dvrr_stack+9220, NULL);

 /* compute (0 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+22744,dvrr_stack+1853,dvrr_stack+729,1);


 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,36,dvrr_stack+10663, dvrr_stack+22744, NULL);

 /* compute (0 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+22852,dvrr_stack+3323,dvrr_stack+1853,1);


 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+13666, dvrr_stack+22852, NULL);

 /* compute (0 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+22987,dvrr_stack+5186,dvrr_stack+3323,1);


 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,55,dvrr_stack+5879, dvrr_stack+22987, NULL);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+2276, dvrr_stack+30, dvrr_stack+74, NULL, NULL, dvrr_stack+24);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+2306, dvrr_stack+84, dvrr_stack+248, NULL, NULL, dvrr_stack+74);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+6656, dvrr_stack+9835, dvrr_stack+2306, dvrr_stack+50, dvrr_stack+84, dvrr_stack+2276);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+4518, dvrr_stack+263, dvrr_stack+644, NULL, NULL, dvrr_stack+248);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+23152, dvrr_stack+9880, dvrr_stack+4518, dvrr_stack+99, dvrr_stack+263, dvrr_stack+2306);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+35674, dvrr_stack+9943, dvrr_stack+23152, dvrr_stack+175, dvrr_stack+9880, dvrr_stack+6656);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+35884, dvrr_stack+665, dvrr_stack+1744, NULL, NULL, dvrr_stack+644);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+35968, dvrr_stack+10069, dvrr_stack+35884, dvrr_stack+284, dvrr_stack+665, dvrr_stack+4518);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+36136, dvrr_stack+10153, dvrr_stack+35968, dvrr_stack+340, dvrr_stack+10069, dvrr_stack+23152);

 /* compute (3 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+36416,dvrr_stack+36136,dvrr_stack+35674,10);


 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,210,dvrr_stack+37046, dvrr_stack+36416, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+37256, dvrr_stack+1772, dvrr_stack+3187, NULL, NULL, dvrr_stack+1744);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+37364, dvrr_stack+10699, dvrr_stack+37256, dvrr_stack+693, dvrr_stack+1772, dvrr_stack+35884);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+37580, dvrr_stack+10807, dvrr_stack+37364, dvrr_stack+765, dvrr_stack+10699, dvrr_stack+35968);

 /* compute (3 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+37940,dvrr_stack+37580,dvrr_stack+36136,10);


 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,280,dvrr_stack+38780, dvrr_stack+37940, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+39060, dvrr_stack+3223, dvrr_stack+5020, NULL, NULL, dvrr_stack+3187);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+39195, dvrr_stack+12661, dvrr_stack+39060, dvrr_stack+1808, dvrr_stack+3223, dvrr_stack+37256);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+39465, dvrr_stack+12796, dvrr_stack+39195, dvrr_stack+1898, dvrr_stack+12661, dvrr_stack+37364);

 /* compute (3 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+39915,dvrr_stack+39465,dvrr_stack+37580,10);


 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,360,dvrr_stack+40995, dvrr_stack+39915, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+41355, dvrr_stack+5065, dvrr_stack+7245, NULL, NULL, dvrr_stack+5020);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+41520, dvrr_stack+15226, dvrr_stack+41355, dvrr_stack+3268, dvrr_stack+5065, dvrr_stack+39060);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+41850, dvrr_stack+15391, dvrr_stack+41520, dvrr_stack+3378, dvrr_stack+15226, dvrr_stack+39195);

 /* compute (3 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+42400,dvrr_stack+41850,dvrr_stack+39465,10);


 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,450,dvrr_stack+43750, dvrr_stack+42400, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+44200, dvrr_stack+7300, dvrr_stack+22489, NULL, NULL, dvrr_stack+7245);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+44398, dvrr_stack+18475, dvrr_stack+44200, dvrr_stack+5120, dvrr_stack+7300, dvrr_stack+41355);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+44794, dvrr_stack+18673, dvrr_stack+44398, dvrr_stack+5252, dvrr_stack+18475, dvrr_stack+41520);

 /* compute (3 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+45454,dvrr_stack+44794,dvrr_stack+41850,10);


 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,550,dvrr_stack+18475, dvrr_stack+45454, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,21,dvrr_stack+19025, dvrr_stack+24133, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,28,dvrr_stack+284, dvrr_stack+9220, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,36,dvrr_stack+693, dvrr_stack+22744, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+1808, dvrr_stack+22852, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,55,dvrr_stack+3268, dvrr_stack+22987, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,210,dvrr_stack+44200, dvrr_stack+36416, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,280,dvrr_stack+44410, dvrr_stack+37940, NULL);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,360,dvrr_stack+47104, dvrr_stack+39915, NULL);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,450,dvrr_stack+47464, dvrr_stack+42400, NULL);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,550,dvrr_stack+47914, dvrr_stack+45454, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+19046, dvrr_stack+24133, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+24133, dvrr_stack+9220, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+9220, dvrr_stack+22744, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+22744, dvrr_stack+22852, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,55,dvrr_stack+22789, dvrr_stack+22987, NULL);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,210,dvrr_stack+22844, dvrr_stack+36416, NULL);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,280,dvrr_stack+36416, dvrr_stack+37940, NULL);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,360,dvrr_stack+37940, dvrr_stack+39915, NULL);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,450,dvrr_stack+39915, dvrr_stack+42400, NULL);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,550,dvrr_stack+42400, dvrr_stack+45454, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+45454, dvrr_stack+312, dvrr_stack+139);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+45475, dvrr_stack+729, dvrr_stack+154);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+45503, dvrr_stack+1853, dvrr_stack+312);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+45539, dvrr_stack+3323, dvrr_stack+729);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+45584, dvrr_stack+5186, dvrr_stack+1853);

 /* compute (1 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+50, dvrr_stack+6, dvrr_stack+24, NULL, NULL, dvrr_stack+0);

 /* compute (2 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+45639, dvrr_stack+25501, dvrr_stack+2276, dvrr_stack+40, dvrr_stack+30, dvrr_stack+50);

 /* compute (3 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+45699, dvrr_stack+25531, dvrr_stack+6656, dvrr_stack+24523, dvrr_stack+9835, dvrr_stack+45639);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,10,1,dvrr_stack+45849, dvrr_stack+36136, dvrr_stack+45699);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,10,1,dvrr_stack+46059, dvrr_stack+37580, dvrr_stack+35674);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,10,1,dvrr_stack+46339, dvrr_stack+39465, dvrr_stack+36136);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,10,1,dvrr_stack+42950, dvrr_stack+41850, dvrr_stack+37580);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,10,1,dvrr_stack+40365, dvrr_stack+44794, dvrr_stack+39465);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+0, dvrr_stack+312, dvrr_stack+139);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+40, dvrr_stack+729, dvrr_stack+154);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+45639, dvrr_stack+1853, dvrr_stack+312);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+25501, dvrr_stack+3323, dvrr_stack+729);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+25546, dvrr_stack+5186, dvrr_stack+1853);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,10,1,dvrr_stack+46699, dvrr_stack+36136, dvrr_stack+45699);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,10,1,dvrr_stack+43400, dvrr_stack+37580, dvrr_stack+35674);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,10,1,dvrr_stack+38300, dvrr_stack+39465, dvrr_stack+36136);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,10,1,dvrr_stack+48464, dvrr_stack+41850, dvrr_stack+37580);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,10,1,dvrr_stack+48914, dvrr_stack+44794, dvrr_stack+39465);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+45675, dvrr_stack+312, dvrr_stack+139);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+46909, dvrr_stack+729, dvrr_stack+154);

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+46937, dvrr_stack+1853, dvrr_stack+312);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+46973, dvrr_stack+3323, dvrr_stack+729);

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+99, dvrr_stack+5186, dvrr_stack+1853);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,10,1,dvrr_stack+36696, dvrr_stack+36136, dvrr_stack+45699);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,10,1,dvrr_stack+5120, dvrr_stack+37580, dvrr_stack+35674);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,10,1,dvrr_stack+49464, dvrr_stack+39465, dvrr_stack+36136);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,10,1,dvrr_stack+49824, dvrr_stack+41850, dvrr_stack+37580);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,10,1,dvrr_stack+50274, dvrr_stack+44794, dvrr_stack+39465);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+45696, dvrr_stack+175, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+45717, dvrr_stack+35674, dvrr_stack+175);
 tmp = dvrr_stack + 45717;
 target_ptr = Libderiv->deriv_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+47018, dvrr_stack+340, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+44690, dvrr_stack+36136, dvrr_stack+340);
 tmp = dvrr_stack + 44690;
 target_ptr = Libderiv->deriv_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+47046, dvrr_stack+765, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+44858, dvrr_stack+37580, dvrr_stack+765);
 tmp = dvrr_stack + 44858;
 target_ptr = Libderiv->deriv_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+43680, dvrr_stack+1898, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+45074, dvrr_stack+39465, dvrr_stack+1898);
 tmp = dvrr_stack + 45074;
 target_ptr = Libderiv->deriv_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,55,dvrr_stack+40915, dvrr_stack+3378, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+50824, dvrr_stack+41850, dvrr_stack+3378);
 tmp = dvrr_stack + 50824;
 target_ptr = Libderiv->deriv_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+38660, dvrr_stack+9943, dvrr_stack+154);
 tmp = dvrr_stack + 38660;
 target_ptr = Libderiv->deriv_classes[1][5][2];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+25873, dvrr_stack+24, dvrr_stack+68, NULL, NULL, dvrr_stack+21);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+38723, dvrr_stack+74, dvrr_stack+238, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+36906, dvrr_stack+2276, dvrr_stack+38723, dvrr_stack+30, dvrr_stack+74, dvrr_stack+25873);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+36966, dvrr_stack+248, dvrr_stack+629, NULL, NULL, dvrr_stack+238);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+23054, dvrr_stack+2306, dvrr_stack+36966, dvrr_stack+84, dvrr_stack+248, dvrr_stack+38723);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+51154, dvrr_stack+6656, dvrr_stack+23054, dvrr_stack+9835, dvrr_stack+2306, dvrr_stack+36906);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+6656, dvrr_stack+644, dvrr_stack+1723, NULL, NULL, dvrr_stack+629);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+51304, dvrr_stack+4518, dvrr_stack+6656, dvrr_stack+263, dvrr_stack+644, dvrr_stack+36966);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+51430, dvrr_stack+23152, dvrr_stack+51304, dvrr_stack+9880, dvrr_stack+4518, dvrr_stack+23054);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+51640, dvrr_stack+35674, dvrr_stack+51430, dvrr_stack+9943, dvrr_stack+23152, dvrr_stack+51154);

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,21,dvrr_stack+23054, dvrr_stack+51640, dvrr_stack+9943);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+9256, dvrr_stack+10153, dvrr_stack+312);
 tmp = dvrr_stack + 9256;
 target_ptr = Libderiv->deriv_classes[1][6][2];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+51154, dvrr_stack+1744, dvrr_stack+3159, NULL, NULL, dvrr_stack+1723);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+51955, dvrr_stack+35884, dvrr_stack+51154, dvrr_stack+665, dvrr_stack+1744, dvrr_stack+6656);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+52123, dvrr_stack+35968, dvrr_stack+51955, dvrr_stack+10069, dvrr_stack+35884, dvrr_stack+51304);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+52403, dvrr_stack+36136, dvrr_stack+52123, dvrr_stack+10153, dvrr_stack+35968, dvrr_stack+51430);

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,28,dvrr_stack+51238, dvrr_stack+52403, dvrr_stack+10153);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+9835, dvrr_stack+10807, dvrr_stack+729);
 tmp = dvrr_stack + 9835;
 target_ptr = Libderiv->deriv_classes[1][7][2];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+35884, dvrr_stack+3187, dvrr_stack+4984, NULL, NULL, dvrr_stack+3159);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+52823, dvrr_stack+37256, dvrr_stack+35884, dvrr_stack+1772, dvrr_stack+3187, dvrr_stack+51154);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+53039, dvrr_stack+37364, dvrr_stack+52823, dvrr_stack+10699, dvrr_stack+37256, dvrr_stack+51955);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+53399, dvrr_stack+37580, dvrr_stack+53039, dvrr_stack+10807, dvrr_stack+37364, dvrr_stack+52123);

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,36,dvrr_stack+51955, dvrr_stack+53399, dvrr_stack+10807);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+37256, dvrr_stack+12796, dvrr_stack+1853);
 tmp = dvrr_stack + 37256;
 target_ptr = Libderiv->deriv_classes[1][8][2];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+37391, dvrr_stack+5020, dvrr_stack+3113, NULL, NULL, dvrr_stack+4984);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+53939, dvrr_stack+39060, dvrr_stack+37391, dvrr_stack+3223, dvrr_stack+5020, dvrr_stack+35884);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+54209, dvrr_stack+39195, dvrr_stack+53939, dvrr_stack+12661, dvrr_stack+39060, dvrr_stack+52823);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+54659, dvrr_stack+39465, dvrr_stack+54209, dvrr_stack+12796, dvrr_stack+39195, dvrr_stack+53039);

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,45,dvrr_stack+52823, dvrr_stack+54659, dvrr_stack+12796);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+39060, dvrr_stack+15391, dvrr_stack+3323);
 tmp = dvrr_stack + 39060;
 target_ptr = Libderiv->deriv_classes[1][9][2];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+39225, dvrr_stack+7245, dvrr_stack+4920, NULL, NULL, dvrr_stack+3113);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+55334, dvrr_stack+41355, dvrr_stack+39225, dvrr_stack+5065, dvrr_stack+7245, dvrr_stack+37391);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+55664, dvrr_stack+41520, dvrr_stack+55334, dvrr_stack+15226, dvrr_stack+41355, dvrr_stack+53939);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+56214, dvrr_stack+41850, dvrr_stack+55664, dvrr_stack+15391, dvrr_stack+41520, dvrr_stack+54209);

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_f(Data,55,dvrr_stack+53939, dvrr_stack+56214, dvrr_stack+15391);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+54489, dvrr_stack+175, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+53273, dvrr_stack+35674, dvrr_stack+175);
 tmp = dvrr_stack + 53273;
 target_ptr = Libderiv->deriv_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+54510, dvrr_stack+340, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+41355, dvrr_stack+36136, dvrr_stack+340);
 tmp = dvrr_stack + 41355;
 target_ptr = Libderiv->deriv_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+54538, dvrr_stack+765, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+41523, dvrr_stack+37580, dvrr_stack+765);
 tmp = dvrr_stack + 41523;
 target_ptr = Libderiv->deriv_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+54574, dvrr_stack+1898, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+55334, dvrr_stack+39465, dvrr_stack+1898);
 tmp = dvrr_stack + 55334;
 target_ptr = Libderiv->deriv_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,55,dvrr_stack+41739, dvrr_stack+3378, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+55604, dvrr_stack+41850, dvrr_stack+3378);
 tmp = dvrr_stack + 55604;
 target_ptr = Libderiv->deriv_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+15226, dvrr_stack+9943, dvrr_stack+154);
 tmp = dvrr_stack + 15226;
 target_ptr = Libderiv->deriv_classes[1][5][1];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,21,dvrr_stack+55934, dvrr_stack+51640, dvrr_stack+9943);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+51154, dvrr_stack+10153, dvrr_stack+312);
 tmp = dvrr_stack + 51154;
 target_ptr = Libderiv->deriv_classes[1][6][1];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,28,dvrr_stack+57039, dvrr_stack+52403, dvrr_stack+10153);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+10699, dvrr_stack+10807, dvrr_stack+729);
 tmp = dvrr_stack + 10699;
 target_ptr = Libderiv->deriv_classes[1][7][1];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,36,dvrr_stack+57319, dvrr_stack+53399, dvrr_stack+10807);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+12661, dvrr_stack+12796, dvrr_stack+1853);
 tmp = dvrr_stack + 12661;
 target_ptr = Libderiv->deriv_classes[1][8][1];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,45,dvrr_stack+57679, dvrr_stack+54659, dvrr_stack+12796);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+37391, dvrr_stack+15391, dvrr_stack+3323);
 tmp = dvrr_stack + 37391;
 target_ptr = Libderiv->deriv_classes[1][9][1];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_f(Data,55,dvrr_stack+58129, dvrr_stack+56214, dvrr_stack+15391);

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+54619, dvrr_stack+175, NULL);

 /* compute (2 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+39225, dvrr_stack+35674, dvrr_stack+175);
 tmp = dvrr_stack + 39225;
 target_ptr = Libderiv->deriv_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+175, dvrr_stack+340, NULL);

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+35674, dvrr_stack+36136, dvrr_stack+340);
 tmp = dvrr_stack + 35674;
 target_ptr = Libderiv->deriv_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+340, dvrr_stack+765, NULL);

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+35842, dvrr_stack+37580, dvrr_stack+765);
 tmp = dvrr_stack + 35842;
 target_ptr = Libderiv->deriv_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+765, dvrr_stack+1898, NULL);

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+36058, dvrr_stack+39465, dvrr_stack+1898);
 tmp = dvrr_stack + 36058;
 target_ptr = Libderiv->deriv_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,55,dvrr_stack+1898, dvrr_stack+3378, NULL);

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+37556, dvrr_stack+41850, dvrr_stack+3378);
 tmp = dvrr_stack + 37556;
 target_ptr = Libderiv->deriv_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+810, dvrr_stack+9943, dvrr_stack+154);
 tmp = dvrr_stack + 810;
 target_ptr = Libderiv->deriv_classes[1][5][0];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,21,dvrr_stack+41794, dvrr_stack+51640, dvrr_stack+9943);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+9943, dvrr_stack+10153, dvrr_stack+312);
 tmp = dvrr_stack + 9943;
 target_ptr = Libderiv->deriv_classes[1][6][0];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,28,dvrr_stack+42004, dvrr_stack+52403, dvrr_stack+10153);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+10027, dvrr_stack+10807, dvrr_stack+729);
 tmp = dvrr_stack + 10027;
 target_ptr = Libderiv->deriv_classes[1][7][0];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,36,dvrr_stack+39351, dvrr_stack+53399, dvrr_stack+10807);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+10807, dvrr_stack+12796, dvrr_stack+1853);
 tmp = dvrr_stack + 10807;
 target_ptr = Libderiv->deriv_classes[1][8][0];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,45,dvrr_stack+53399, dvrr_stack+54659, dvrr_stack+12796);

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+3378, dvrr_stack+15391, dvrr_stack+3323);
 tmp = dvrr_stack + 3378;
 target_ptr = Libderiv->deriv_classes[1][9][0];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (3 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_f(Data,55,dvrr_stack+54640, dvrr_stack+56214, dvrr_stack+15391);

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,63,dvrr_stack+12796, dvrr_stack+1503, NULL);
 tmp = dvrr_stack + 12796;
 target_ptr = Libderiv->deriv2_classes[1][5][143];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,84,dvrr_stack+12859, dvrr_stack+2861, NULL);
 tmp = dvrr_stack + 12859;
 target_ptr = Libderiv->deriv2_classes[1][6][143];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,108,dvrr_stack+12943, dvrr_stack+4596, NULL);
 tmp = dvrr_stack + 12943;
 target_ptr = Libderiv->deriv2_classes[1][7][143];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,135,dvrr_stack+10135, dvrr_stack+6755, NULL);
 tmp = dvrr_stack + 10135;
 target_ptr = Libderiv->deriv2_classes[1][8][143];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,165,dvrr_stack+15289, dvrr_stack+9340, NULL);
 tmp = dvrr_stack + 15289;
 target_ptr = Libderiv->deriv2_classes[1][9][143];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,126,dvrr_stack+55190, dvrr_stack+12283, NULL);
 tmp = dvrr_stack + 55190;
 target_ptr = Libderiv->deriv2_classes[2][5][143];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,168,dvrr_stack+15454, dvrr_stack+14722, NULL);
 tmp = dvrr_stack + 15454;
 target_ptr = Libderiv->deriv2_classes[2][6][143];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,216,dvrr_stack+56144, dvrr_stack+17827, NULL);
 tmp = dvrr_stack + 56144;
 target_ptr = Libderiv->deriv2_classes[2][7][143];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,270,dvrr_stack+56360, dvrr_stack+21679, NULL);
 tmp = dvrr_stack + 56360;
 target_ptr = Libderiv->deriv2_classes[2][8][143];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,330,dvrr_stack+56630, dvrr_stack+26503, NULL);
 tmp = dvrr_stack + 56630;
 target_ptr = Libderiv->deriv2_classes[2][9][143];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,63,dvrr_stack+10942, dvrr_stack+1503, NULL);
 tmp = dvrr_stack + 10942;
 target_ptr = Libderiv->deriv2_classes[1][5][131];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,84,dvrr_stack+53849, dvrr_stack+2861, NULL);
 tmp = dvrr_stack + 53849;
 target_ptr = Libderiv->deriv2_classes[1][6][131];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,108,dvrr_stack+42284, dvrr_stack+4596, NULL);
 tmp = dvrr_stack + 42284;
 target_ptr = Libderiv->deriv2_classes[1][7][131];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,135,dvrr_stack+39711, dvrr_stack+6755, NULL);
 tmp = dvrr_stack + 39711;
 target_ptr = Libderiv->deriv2_classes[1][8][131];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,165,dvrr_stack+4920, dvrr_stack+9340, NULL);
 tmp = dvrr_stack + 4920;
 target_ptr = Libderiv->deriv2_classes[1][9][131];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,126,dvrr_stack+3113, dvrr_stack+12283, NULL);
 tmp = dvrr_stack + 3113;
 target_ptr = Libderiv->deriv2_classes[2][5][131];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,168,dvrr_stack+52315, dvrr_stack+14722, NULL);
 tmp = dvrr_stack + 52315;
 target_ptr = Libderiv->deriv2_classes[2][6][131];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,216,dvrr_stack+52483, dvrr_stack+17827, NULL);
 tmp = dvrr_stack + 52483;
 target_ptr = Libderiv->deriv2_classes[2][7][131];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,270,dvrr_stack+51518, dvrr_stack+21679, NULL);
 tmp = dvrr_stack + 51518;
 target_ptr = Libderiv->deriv2_classes[2][8][131];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,330,dvrr_stack+58679, dvrr_stack+26503, NULL);
 tmp = dvrr_stack + 58679;
 target_ptr = Libderiv->deriv2_classes[2][9][131];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+1953, dvrr_stack+22555, NULL);
 tmp = dvrr_stack + 1953;
 target_ptr = Libderiv->deriv2_classes[1][5][130];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+36328, dvrr_stack+27493, NULL);
 tmp = dvrr_stack + 36328;
 target_ptr = Libderiv->deriv2_classes[1][6][130];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+52699, dvrr_stack+27745, NULL);
 tmp = dvrr_stack + 52699;
 target_ptr = Libderiv->deriv2_classes[1][7][130];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+51788, dvrr_stack+28069, NULL);
 tmp = dvrr_stack + 51788;
 target_ptr = Libderiv->deriv2_classes[1][8][130];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+59009, dvrr_stack+28474, NULL);
 tmp = dvrr_stack + 59009;
 target_ptr = Libderiv->deriv2_classes[1][9][130];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,126,dvrr_stack+36906, dvrr_stack+28969, NULL);
 tmp = dvrr_stack + 36906;
 target_ptr = Libderiv->deriv2_classes[2][5][130];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+59174, dvrr_stack+29347, NULL);
 tmp = dvrr_stack + 59174;
 target_ptr = Libderiv->deriv2_classes[2][6][130];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+59342, dvrr_stack+29851, NULL);
 tmp = dvrr_stack + 59342;
 target_ptr = Libderiv->deriv2_classes[2][7][130];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+59558, dvrr_stack+30499, NULL);
 tmp = dvrr_stack + 59558;
 target_ptr = Libderiv->deriv2_classes[2][8][130];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+59828, dvrr_stack+31309, NULL);
 tmp = dvrr_stack + 59828;
 target_ptr = Libderiv->deriv2_classes[2][9][130];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,63,dvrr_stack+203, dvrr_stack+1503, NULL);
 tmp = dvrr_stack + 203;
 target_ptr = Libderiv->deriv2_classes[1][5][119];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,84,dvrr_stack+1503, dvrr_stack+2861, NULL);
 tmp = dvrr_stack + 1503;
 target_ptr = Libderiv->deriv2_classes[1][6][119];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,108,dvrr_stack+1587, dvrr_stack+4596, NULL);
 tmp = dvrr_stack + 1587;
 target_ptr = Libderiv->deriv2_classes[1][7][119];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,135,dvrr_stack+4518, dvrr_stack+6755, NULL);
 tmp = dvrr_stack + 4518;
 target_ptr = Libderiv->deriv2_classes[1][8][119];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,165,dvrr_stack+6656, dvrr_stack+9340, NULL);
 tmp = dvrr_stack + 6656;
 target_ptr = Libderiv->deriv2_classes[1][9][119];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,126,dvrr_stack+9340, dvrr_stack+12283, NULL);
 tmp = dvrr_stack + 9340;
 target_ptr = Libderiv->deriv2_classes[2][5][119];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,168,dvrr_stack+9466, dvrr_stack+14722, NULL);
 tmp = dvrr_stack + 9466;
 target_ptr = Libderiv->deriv2_classes[2][6][119];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,216,dvrr_stack+6821, dvrr_stack+17827, NULL);
 tmp = dvrr_stack + 6821;
 target_ptr = Libderiv->deriv2_classes[2][7][119];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,270,dvrr_stack+7037, dvrr_stack+21679, NULL);
 tmp = dvrr_stack + 7037;
 target_ptr = Libderiv->deriv2_classes[2][8][119];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,330,dvrr_stack+21670, dvrr_stack+26503, NULL);
 tmp = dvrr_stack + 21670;
 target_ptr = Libderiv->deriv2_classes[2][9][119];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+9634, dvrr_stack+22555, NULL);
 tmp = dvrr_stack + 9634;
 target_ptr = Libderiv->deriv2_classes[1][5][118];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+9697, dvrr_stack+27493, NULL);
 tmp = dvrr_stack + 9697;
 target_ptr = Libderiv->deriv2_classes[1][6][118];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+1695, dvrr_stack+27745, NULL);
 tmp = dvrr_stack + 1695;
 target_ptr = Libderiv->deriv2_classes[1][7][118];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+4653, dvrr_stack+28069, NULL);
 tmp = dvrr_stack + 4653;
 target_ptr = Libderiv->deriv2_classes[1][8][118];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+22000, dvrr_stack+28474, NULL);
 tmp = dvrr_stack + 22000;
 target_ptr = Libderiv->deriv2_classes[1][9][118];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+4788, dvrr_stack+28969, NULL);
 tmp = dvrr_stack + 4788;
 target_ptr = Libderiv->deriv2_classes[2][5][118];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+22165, dvrr_stack+29347, NULL);
 tmp = dvrr_stack + 22165;
 target_ptr = Libderiv->deriv2_classes[2][6][118];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+22333, dvrr_stack+29851, NULL);
 tmp = dvrr_stack + 22333;
 target_ptr = Libderiv->deriv2_classes[2][7][118];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+26494, dvrr_stack+30499, NULL);
 tmp = dvrr_stack + 26494;
 target_ptr = Libderiv->deriv2_classes[2][8][118];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+26764, dvrr_stack+31309, NULL);
 tmp = dvrr_stack + 26764;
 target_ptr = Libderiv->deriv2_classes[2][9][118];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+15622, dvrr_stack+32299, NULL);
 tmp = dvrr_stack + 15622;
 target_ptr = Libderiv->deriv2_classes[1][5][117];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+45344, dvrr_stack+1125, NULL);
 tmp = dvrr_stack + 45344;
 target_ptr = Libderiv->deriv2_classes[1][6][117];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+22549, dvrr_stack+2357, NULL);
 tmp = dvrr_stack + 22549;
 target_ptr = Libderiv->deriv2_classes[1][7][117];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+2276, dvrr_stack+3948, NULL);
 tmp = dvrr_stack + 2276;
 target_ptr = Libderiv->deriv2_classes[1][8][117];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+2411, dvrr_stack+5945, NULL);
 tmp = dvrr_stack + 2411;
 target_ptr = Libderiv->deriv2_classes[1][9][117];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,126,dvrr_stack+5934, dvrr_stack+8350, NULL);
 tmp = dvrr_stack + 5934;
 target_ptr = Libderiv->deriv2_classes[2][5][117];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+8350, dvrr_stack+11527, NULL);
 tmp = dvrr_stack + 8350;
 target_ptr = Libderiv->deriv2_classes[2][6][117];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+11512, dvrr_stack+13714, NULL);
 tmp = dvrr_stack + 11512;
 target_ptr = Libderiv->deriv2_classes[2][7][117];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+13711, dvrr_stack+16531, NULL);
 tmp = dvrr_stack + 13711;
 target_ptr = Libderiv->deriv2_classes[2][8][117];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+16529, dvrr_stack+20059, NULL);
 tmp = dvrr_stack + 16529;
 target_ptr = Libderiv->deriv2_classes[2][9][117];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+8518, dvrr_stack+24748, dvrr_stack+24703);
 tmp = dvrr_stack + 8518;
 target_ptr = Libderiv->deriv2_classes[1][5][107];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+8581, dvrr_stack+24895, dvrr_stack+24832);
 tmp = dvrr_stack + 8581;
 target_ptr = Libderiv->deriv2_classes[1][6][107];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+20044, dvrr_stack+25003, dvrr_stack+24748);
 tmp = dvrr_stack + 20044;
 target_ptr = Libderiv->deriv2_classes[1][7][107];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+20152, dvrr_stack+25138, dvrr_stack+24895);
 tmp = dvrr_stack + 20152;
 target_ptr = Libderiv->deriv2_classes[1][8][107];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+20287, dvrr_stack+25303, dvrr_stack+25003);
 tmp = dvrr_stack + 20287;
 target_ptr = Libderiv->deriv2_classes[1][9][107];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+20452, dvrr_stack+25981, dvrr_stack+25891);
 tmp = dvrr_stack + 20452;
 target_ptr = Libderiv->deriv2_classes[2][5][107];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+20578, dvrr_stack+26149, dvrr_stack+1377);
 tmp = dvrr_stack + 20578;
 target_ptr = Libderiv->deriv2_classes[2][6][107];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+20746, dvrr_stack+21049, dvrr_stack+25981);
 tmp = dvrr_stack + 20746;
 target_ptr = Libderiv->deriv2_classes[2][7][107];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+16859, dvrr_stack+21319, dvrr_stack+26149);
 tmp = dvrr_stack + 16859;
 target_ptr = Libderiv->deriv2_classes[2][8][107];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+13981, dvrr_stack+17341, dvrr_stack+21049);
 tmp = dvrr_stack + 13981;
 target_ptr = Libderiv->deriv2_classes[2][9][107];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+8665, dvrr_stack+26410, dvrr_stack+26365);
 tmp = dvrr_stack + 8665;
 target_ptr = Libderiv->deriv2_classes[1][5][106];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+2576, dvrr_stack+14362, dvrr_stack+17737);
 tmp = dvrr_stack + 2576;
 target_ptr = Libderiv->deriv2_classes[1][6][106];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+17129, dvrr_stack+14470, dvrr_stack+26410);
 tmp = dvrr_stack + 17129;
 target_ptr = Libderiv->deriv2_classes[1][7][106];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+11728, dvrr_stack+12031, dvrr_stack+14362);
 tmp = dvrr_stack + 11728;
 target_ptr = Libderiv->deriv2_classes[1][8][106];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+11863, dvrr_stack+8728, dvrr_stack+14470);
 tmp = dvrr_stack + 11863;
 target_ptr = Libderiv->deriv2_classes[1][9][106];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+6060, dvrr_stack+8926, dvrr_stack+14605);
 tmp = dvrr_stack + 6060;
 target_ptr = Libderiv->deriv2_classes[2][5][106];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+6186, dvrr_stack+6440, dvrr_stack+9094);
 tmp = dvrr_stack + 6186;
 target_ptr = Libderiv->deriv2_classes[2][6][106];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+3924, dvrr_stack+32488, dvrr_stack+8926);
 tmp = dvrr_stack + 3924;
 target_ptr = Libderiv->deriv2_classes[2][7][106];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+1071, dvrr_stack+32758, dvrr_stack+6440);
 tmp = dvrr_stack + 1071;
 target_ptr = Libderiv->deriv2_classes[2][8][106];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+27094, dvrr_stack+33088, dvrr_stack+32488);
 tmp = dvrr_stack + 27094;
 target_ptr = Libderiv->deriv2_classes[2][9][106];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+56960, dvrr_stack+24568, dvrr_stack+12196);
 tmp = dvrr_stack + 56960;
 target_ptr = Libderiv->deriv2_classes[1][5][105];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+22657, dvrr_stack+424, dvrr_stack+873);
 tmp = dvrr_stack + 22657;
 target_ptr = Libderiv->deriv2_classes[1][6][105];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+4140, dvrr_stack+2033, dvrr_stack+24568);
 tmp = dvrr_stack + 4140;
 target_ptr = Libderiv->deriv2_classes[1][7][105];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+27424, dvrr_stack+3543, dvrr_stack+424);
 tmp = dvrr_stack + 27424;
 target_ptr = Libderiv->deriv2_classes[1][8][105];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+27559, dvrr_stack+5450, dvrr_stack+2033);
 tmp = dvrr_stack + 27559;
 target_ptr = Libderiv->deriv2_classes[1][9][105];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+27724, dvrr_stack+25621, dvrr_stack+7756);
 tmp = dvrr_stack + 27724;
 target_ptr = Libderiv->deriv2_classes[2][5][105];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+27850, dvrr_stack+10321, dvrr_stack+11023);
 tmp = dvrr_stack + 27850;
 target_ptr = Libderiv->deriv2_classes[2][6][105];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+28018, dvrr_stack+13066, dvrr_stack+25621);
 tmp = dvrr_stack + 28018;
 target_ptr = Libderiv->deriv2_classes[2][7][105];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+28234, dvrr_stack+15721, dvrr_stack+10321);
 tmp = dvrr_stack + 28234;
 target_ptr = Libderiv->deriv2_classes[2][8][105];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+28504, dvrr_stack+19069, dvrr_stack+13066);
 tmp = dvrr_stack + 28504;
 target_ptr = Libderiv->deriv2_classes[2][9][105];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+39846, dvrr_stack+23380, dvrr_stack+23335);
 tmp = dvrr_stack + 39846;
 target_ptr = Libderiv->deriv2_classes[1][5][104];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+20962, dvrr_stack+23527, dvrr_stack+23464);
 tmp = dvrr_stack + 20962;
 target_ptr = Libderiv->deriv2_classes[1][6][104];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+28834, dvrr_stack+23635, dvrr_stack+23380);
 tmp = dvrr_stack + 28834;
 target_ptr = Libderiv->deriv2_classes[1][7][104];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+28942, dvrr_stack+23770, dvrr_stack+23527);
 tmp = dvrr_stack + 28942;
 target_ptr = Libderiv->deriv2_classes[1][8][104];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+29077, dvrr_stack+23935, dvrr_stack+23635);
 tmp = dvrr_stack + 29077;
 target_ptr = Libderiv->deriv2_classes[1][9][104];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,6,1,dvrr_stack+29242, dvrr_stack+24301, dvrr_stack+24211);
 tmp = dvrr_stack + 29242;
 target_ptr = Libderiv->deriv2_classes[2][5][104];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+29368, dvrr_stack+19591, dvrr_stack+19465);
 tmp = dvrr_stack + 29368;
 target_ptr = Libderiv->deriv2_classes[2][6][104];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+29536, dvrr_stack+16051, dvrr_stack+24301);
 tmp = dvrr_stack + 29536;
 target_ptr = Libderiv->deriv2_classes[2][7][104];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+29752, dvrr_stack+13336, dvrr_stack+19591);
 tmp = dvrr_stack + 29752;
 target_ptr = Libderiv->deriv2_classes[2][8][104];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+30022, dvrr_stack+7846, dvrr_stack+16051);
 tmp = dvrr_stack + 30022;
 target_ptr = Libderiv->deriv2_classes[2][9][104];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+23264, dvrr_stack+24748, dvrr_stack+24703);
 tmp = dvrr_stack + 23264;
 target_ptr = Libderiv->deriv2_classes[1][5][95];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+17237, dvrr_stack+24895, dvrr_stack+24832);
 tmp = dvrr_stack + 17237;
 target_ptr = Libderiv->deriv2_classes[1][6][95];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+30352, dvrr_stack+25003, dvrr_stack+24748);
 tmp = dvrr_stack + 30352;
 target_ptr = Libderiv->deriv2_classes[1][7][95];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+30460, dvrr_stack+25138, dvrr_stack+24895);
 tmp = dvrr_stack + 30460;
 target_ptr = Libderiv->deriv2_classes[1][8][95];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+30595, dvrr_stack+25303, dvrr_stack+25003);
 tmp = dvrr_stack + 30595;
 target_ptr = Libderiv->deriv2_classes[1][9][95];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+30760, dvrr_stack+25981, dvrr_stack+25891);
 tmp = dvrr_stack + 30760;
 target_ptr = Libderiv->deriv2_classes[2][5][95];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+30886, dvrr_stack+26149, dvrr_stack+1377);
 tmp = dvrr_stack + 30886;
 target_ptr = Libderiv->deriv2_classes[2][6][95];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+31054, dvrr_stack+21049, dvrr_stack+25981);
 tmp = dvrr_stack + 31054;
 target_ptr = Libderiv->deriv2_classes[2][7][95];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+31270, dvrr_stack+21319, dvrr_stack+26149);
 tmp = dvrr_stack + 31270;
 target_ptr = Libderiv->deriv2_classes[2][8][95];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+31540, dvrr_stack+17341, dvrr_stack+21049);
 tmp = dvrr_stack + 31540;
 target_ptr = Libderiv->deriv2_classes[2][9][95];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+6354, dvrr_stack+26410, dvrr_stack+26365);
 tmp = dvrr_stack + 6354;
 target_ptr = Libderiv->deriv2_classes[1][5][94];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+4248, dvrr_stack+14362, dvrr_stack+17737);
 tmp = dvrr_stack + 4248;
 target_ptr = Libderiv->deriv2_classes[1][6][94];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+31870, dvrr_stack+14470, dvrr_stack+26410);
 tmp = dvrr_stack + 31870;
 target_ptr = Libderiv->deriv2_classes[1][7][94];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+31978, dvrr_stack+12031, dvrr_stack+14362);
 tmp = dvrr_stack + 31978;
 target_ptr = Libderiv->deriv2_classes[1][8][94];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+32113, dvrr_stack+8728, dvrr_stack+14470);
 tmp = dvrr_stack + 32113;
 target_ptr = Libderiv->deriv2_classes[1][9][94];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+32278, dvrr_stack+8926, dvrr_stack+14605);
 tmp = dvrr_stack + 32278;
 target_ptr = Libderiv->deriv2_classes[2][5][94];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+17800, dvrr_stack+6440, dvrr_stack+9094);
 tmp = dvrr_stack + 17800;
 target_ptr = Libderiv->deriv2_classes[2][6][94];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+17968, dvrr_stack+32488, dvrr_stack+8926);
 tmp = dvrr_stack + 17968;
 target_ptr = Libderiv->deriv2_classes[2][7][94];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+18184, dvrr_stack+32758, dvrr_stack+6440);
 tmp = dvrr_stack + 18184;
 target_ptr = Libderiv->deriv2_classes[2][8][94];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+14695, dvrr_stack+33088, dvrr_stack+32488);
 tmp = dvrr_stack + 14695;
 target_ptr = Libderiv->deriv2_classes[2][9][94];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+622, dvrr_stack+24568, dvrr_stack+12196);
 tmp = dvrr_stack + 622;
 target_ptr = Libderiv->deriv2_classes[1][5][93];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+32404, dvrr_stack+424, dvrr_stack+873);
 tmp = dvrr_stack + 32404;
 target_ptr = Libderiv->deriv2_classes[1][6][93];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+15025, dvrr_stack+2033, dvrr_stack+24568);
 tmp = dvrr_stack + 15025;
 target_ptr = Libderiv->deriv2_classes[1][7][93];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+12241, dvrr_stack+3543, dvrr_stack+424);
 tmp = dvrr_stack + 12241;
 target_ptr = Libderiv->deriv2_classes[1][8][93];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+12376, dvrr_stack+5450, dvrr_stack+2033);
 tmp = dvrr_stack + 12376;
 target_ptr = Libderiv->deriv2_classes[1][9][93];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+2849, dvrr_stack+25621, dvrr_stack+7756);
 tmp = dvrr_stack + 2849;
 target_ptr = Libderiv->deriv2_classes[2][5][93];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+60158, dvrr_stack+10321, dvrr_stack+11023);
 tmp = dvrr_stack + 60158;
 target_ptr = Libderiv->deriv2_classes[2][6][93];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+60326, dvrr_stack+13066, dvrr_stack+25621);
 tmp = dvrr_stack + 60326;
 target_ptr = Libderiv->deriv2_classes[2][7][93];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+60542, dvrr_stack+15721, dvrr_stack+10321);
 tmp = dvrr_stack + 60542;
 target_ptr = Libderiv->deriv2_classes[2][8][93];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+60812, dvrr_stack+19069, dvrr_stack+13066);
 tmp = dvrr_stack + 60812;
 target_ptr = Libderiv->deriv2_classes[2][9][93];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+15133, dvrr_stack+23380, dvrr_stack+23335);
 tmp = dvrr_stack + 15133;
 target_ptr = Libderiv->deriv2_classes[1][5][92];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+12541, dvrr_stack+23527, dvrr_stack+23464);
 tmp = dvrr_stack + 12541;
 target_ptr = Libderiv->deriv2_classes[1][6][92];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+2975, dvrr_stack+23635, dvrr_stack+23380);
 tmp = dvrr_stack + 2975;
 target_ptr = Libderiv->deriv2_classes[1][7][92];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+61142, dvrr_stack+23770, dvrr_stack+23527);
 tmp = dvrr_stack + 61142;
 target_ptr = Libderiv->deriv2_classes[1][8][92];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+61277, dvrr_stack+23935, dvrr_stack+23635);
 tmp = dvrr_stack + 61277;
 target_ptr = Libderiv->deriv2_classes[1][9][92];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+61442, dvrr_stack+24301, dvrr_stack+24211);
 tmp = dvrr_stack + 61442;
 target_ptr = Libderiv->deriv2_classes[2][5][92];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+61568, dvrr_stack+19591, dvrr_stack+19465);
 tmp = dvrr_stack + 61568;
 target_ptr = Libderiv->deriv2_classes[2][6][92];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+61736, dvrr_stack+16051, dvrr_stack+24301);
 tmp = dvrr_stack + 61736;
 target_ptr = Libderiv->deriv2_classes[2][7][92];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+61952, dvrr_stack+13336, dvrr_stack+19591);
 tmp = dvrr_stack + 61952;
 target_ptr = Libderiv->deriv2_classes[2][8][92];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+62222, dvrr_stack+7846, dvrr_stack+16051);
 tmp = dvrr_stack + 62222;
 target_ptr = Libderiv->deriv2_classes[2][9][92];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+62552, dvrr_stack+19807, dvrr_stack+24469);
 tmp = dvrr_stack + 62552;
 target_ptr = Libderiv->deriv2_classes[1][5][91];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+62615, dvrr_stack+8242, dvrr_stack+19891);
 tmp = dvrr_stack + 62615;
 target_ptr = Libderiv->deriv2_classes[1][6][91];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+62699, dvrr_stack+16321, dvrr_stack+19807);
 tmp = dvrr_stack + 62699;
 target_ptr = Libderiv->deriv2_classes[1][7][91];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+62807, dvrr_stack+11149, dvrr_stack+8242);
 tmp = dvrr_stack + 62807;
 target_ptr = Libderiv->deriv2_classes[1][8][91];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+62942, dvrr_stack+11314, dvrr_stack+16321);
 tmp = dvrr_stack + 62942;
 target_ptr = Libderiv->deriv2_classes[1][9][91];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,6,1,dvrr_stack+63107, dvrr_stack+5648, dvrr_stack+19954);
 tmp = dvrr_stack + 63107;
 target_ptr = Libderiv->deriv2_classes[2][5][91];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+63233, dvrr_stack+3708, dvrr_stack+10537);
 tmp = dvrr_stack + 63233;
 target_ptr = Libderiv->deriv2_classes[2][6][91];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+63401, dvrr_stack+33484, dvrr_stack+5648);
 tmp = dvrr_stack + 63401;
 target_ptr = Libderiv->deriv2_classes[2][7][91];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+63617, dvrr_stack+33754, dvrr_stack+3708);
 tmp = dvrr_stack + 63617;
 target_ptr = Libderiv->deriv2_classes[2][8][91];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+63887, dvrr_stack+34084, dvrr_stack+33484);
 tmp = dvrr_stack + 63887;
 target_ptr = Libderiv->deriv2_classes[2][9][91];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+64217, dvrr_stack+24748, dvrr_stack+24703);
 tmp = dvrr_stack + 64217;
 target_ptr = Libderiv->deriv2_classes[1][5][83];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+24652, dvrr_stack+24895, dvrr_stack+24832);
 tmp = dvrr_stack + 24652;
 target_ptr = Libderiv->deriv2_classes[1][6][83];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+64280, dvrr_stack+25003, dvrr_stack+24748);
 tmp = dvrr_stack + 64280;
 target_ptr = Libderiv->deriv2_classes[1][7][83];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+64388, dvrr_stack+25138, dvrr_stack+24895);
 tmp = dvrr_stack + 64388;
 target_ptr = Libderiv->deriv2_classes[1][8][83];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+64523, dvrr_stack+25303, dvrr_stack+25003);
 tmp = dvrr_stack + 64523;
 target_ptr = Libderiv->deriv2_classes[1][9][83];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+25303, dvrr_stack+25981, dvrr_stack+25891);
 tmp = dvrr_stack + 25303;
 target_ptr = Libderiv->deriv2_classes[2][5][83];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+64688, dvrr_stack+26149, dvrr_stack+1377);
 tmp = dvrr_stack + 64688;
 target_ptr = Libderiv->deriv2_classes[2][6][83];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+64856, dvrr_stack+21049, dvrr_stack+25981);
 tmp = dvrr_stack + 64856;
 target_ptr = Libderiv->deriv2_classes[2][7][83];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+65072, dvrr_stack+21319, dvrr_stack+26149);
 tmp = dvrr_stack + 65072;
 target_ptr = Libderiv->deriv2_classes[2][8][83];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+65342, dvrr_stack+17341, dvrr_stack+21049);
 tmp = dvrr_stack + 65342;
 target_ptr = Libderiv->deriv2_classes[2][9][83];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+25429, dvrr_stack+26410, dvrr_stack+26365);
 tmp = dvrr_stack + 25429;
 target_ptr = Libderiv->deriv2_classes[1][5][82];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+25873, dvrr_stack+14362, dvrr_stack+17737);
 tmp = dvrr_stack + 25873;
 target_ptr = Libderiv->deriv2_classes[1][6][82];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+17321, dvrr_stack+14470, dvrr_stack+26410);
 tmp = dvrr_stack + 17321;
 target_ptr = Libderiv->deriv2_classes[1][7][82];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+17429, dvrr_stack+12031, dvrr_stack+14362);
 tmp = dvrr_stack + 17429;
 target_ptr = Libderiv->deriv2_classes[1][8][82];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+17564, dvrr_stack+8728, dvrr_stack+14470);
 tmp = dvrr_stack + 17564;
 target_ptr = Libderiv->deriv2_classes[1][9][82];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+8728, dvrr_stack+8926, dvrr_stack+14605);
 tmp = dvrr_stack + 8728;
 target_ptr = Libderiv->deriv2_classes[2][5][82];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+65672, dvrr_stack+6440, dvrr_stack+9094);
 tmp = dvrr_stack + 65672;
 target_ptr = Libderiv->deriv2_classes[2][6][82];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+65840, dvrr_stack+32488, dvrr_stack+8926);
 tmp = dvrr_stack + 65840;
 target_ptr = Libderiv->deriv2_classes[2][7][82];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+66056, dvrr_stack+32758, dvrr_stack+6440);
 tmp = dvrr_stack + 66056;
 target_ptr = Libderiv->deriv2_classes[2][8][82];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+66326, dvrr_stack+33088, dvrr_stack+32488);
 tmp = dvrr_stack + 66326;
 target_ptr = Libderiv->deriv2_classes[2][9][82];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+33088, dvrr_stack+24568, dvrr_stack+12196);
 tmp = dvrr_stack + 33088;
 target_ptr = Libderiv->deriv2_classes[1][5][81];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+33151, dvrr_stack+424, dvrr_stack+873);
 tmp = dvrr_stack + 33151;
 target_ptr = Libderiv->deriv2_classes[1][6][81];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+33235, dvrr_stack+2033, dvrr_stack+24568);
 tmp = dvrr_stack + 33235;
 target_ptr = Libderiv->deriv2_classes[1][7][81];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+33343, dvrr_stack+3543, dvrr_stack+424);
 tmp = dvrr_stack + 33343;
 target_ptr = Libderiv->deriv2_classes[1][8][81];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+66656, dvrr_stack+5450, dvrr_stack+2033);
 tmp = dvrr_stack + 66656;
 target_ptr = Libderiv->deriv2_classes[1][9][81];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+5400, dvrr_stack+25621, dvrr_stack+7756);
 tmp = dvrr_stack + 5400;
 target_ptr = Libderiv->deriv2_classes[2][5][81];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+66821, dvrr_stack+10321, dvrr_stack+11023);
 tmp = dvrr_stack + 66821;
 target_ptr = Libderiv->deriv2_classes[2][6][81];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+66989, dvrr_stack+13066, dvrr_stack+25621);
 tmp = dvrr_stack + 66989;
 target_ptr = Libderiv->deriv2_classes[2][7][81];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+67205, dvrr_stack+15721, dvrr_stack+10321);
 tmp = dvrr_stack + 67205;
 target_ptr = Libderiv->deriv2_classes[2][8][81];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+67475, dvrr_stack+19069, dvrr_stack+13066);
 tmp = dvrr_stack + 67475;
 target_ptr = Libderiv->deriv2_classes[2][9][81];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+14605, dvrr_stack+23380, dvrr_stack+23335);
 tmp = dvrr_stack + 14605;
 target_ptr = Libderiv->deriv2_classes[1][5][80];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+19067, dvrr_stack+23527, dvrr_stack+23464);
 tmp = dvrr_stack + 19067;
 target_ptr = Libderiv->deriv2_classes[1][6][80];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+19151, dvrr_stack+23635, dvrr_stack+23380);
 tmp = dvrr_stack + 19151;
 target_ptr = Libderiv->deriv2_classes[1][7][80];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+19259, dvrr_stack+23770, dvrr_stack+23527);
 tmp = dvrr_stack + 19259;
 target_ptr = Libderiv->deriv2_classes[1][8][80];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+67805, dvrr_stack+23935, dvrr_stack+23635);
 tmp = dvrr_stack + 67805;
 target_ptr = Libderiv->deriv2_classes[1][9][80];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+23935, dvrr_stack+24301, dvrr_stack+24211);
 tmp = dvrr_stack + 23935;
 target_ptr = Libderiv->deriv2_classes[2][5][80];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+67970, dvrr_stack+19591, dvrr_stack+19465);
 tmp = dvrr_stack + 67970;
 target_ptr = Libderiv->deriv2_classes[2][6][80];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+68138, dvrr_stack+16051, dvrr_stack+24301);
 tmp = dvrr_stack + 68138;
 target_ptr = Libderiv->deriv2_classes[2][7][80];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+68354, dvrr_stack+13336, dvrr_stack+19591);
 tmp = dvrr_stack + 68354;
 target_ptr = Libderiv->deriv2_classes[2][8][80];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+68624, dvrr_stack+7846, dvrr_stack+16051);
 tmp = dvrr_stack + 68624;
 target_ptr = Libderiv->deriv2_classes[2][9][80];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+24061, dvrr_stack+19807, dvrr_stack+24469);
 tmp = dvrr_stack + 24061;
 target_ptr = Libderiv->deriv2_classes[1][5][79];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+24469, dvrr_stack+8242, dvrr_stack+19891);
 tmp = dvrr_stack + 24469;
 target_ptr = Libderiv->deriv2_classes[1][6][79];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+24161, dvrr_stack+16321, dvrr_stack+19807);
 tmp = dvrr_stack + 24161;
 target_ptr = Libderiv->deriv2_classes[1][7][79];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+7708, dvrr_stack+11149, dvrr_stack+8242);
 tmp = dvrr_stack + 7708;
 target_ptr = Libderiv->deriv2_classes[1][8][79];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+7843, dvrr_stack+11314, dvrr_stack+16321);
 tmp = dvrr_stack + 7843;
 target_ptr = Libderiv->deriv2_classes[1][9][79];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+11314, dvrr_stack+5648, dvrr_stack+19954);
 tmp = dvrr_stack + 11314;
 target_ptr = Libderiv->deriv2_classes[2][5][79];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+8008, dvrr_stack+3708, dvrr_stack+10537);
 tmp = dvrr_stack + 8008;
 target_ptr = Libderiv->deriv2_classes[2][6][79];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+68954, dvrr_stack+33484, dvrr_stack+5648);
 tmp = dvrr_stack + 68954;
 target_ptr = Libderiv->deriv2_classes[2][7][79];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+69170, dvrr_stack+33754, dvrr_stack+3708);
 tmp = dvrr_stack + 69170;
 target_ptr = Libderiv->deriv2_classes[2][8][79];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+69440, dvrr_stack+34084, dvrr_stack+33484);
 tmp = dvrr_stack + 69440;
 target_ptr = Libderiv->deriv2_classes[2][9][79];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+34084, dvrr_stack+25789, dvrr_stack+16456);
 tmp = dvrr_stack + 34084;
 target_ptr = Libderiv->deriv2_classes[1][5][78];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+34147, dvrr_stack+2168, dvrr_stack+5816);
 tmp = dvrr_stack + 34147;
 target_ptr = Libderiv->deriv2_classes[1][6][78];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+34231, dvrr_stack+936, dvrr_stack+25789);
 tmp = dvrr_stack + 34231;
 target_ptr = Libderiv->deriv2_classes[1][7][78];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+34339, dvrr_stack+4353, dvrr_stack+2168);
 tmp = dvrr_stack + 34339;
 target_ptr = Libderiv->deriv2_classes[1][8][78];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+69770, dvrr_stack+34480, dvrr_stack+936);
 tmp = dvrr_stack + 69770;
 target_ptr = Libderiv->deriv2_classes[1][9][78];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,6,1,dvrr_stack+34474, dvrr_stack+2681, dvrr_stack+532);
 tmp = dvrr_stack + 34474;
 target_ptr = Libderiv->deriv2_classes[2][5][78];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+69935, dvrr_stack+7492, dvrr_stack+7366);
 tmp = dvrr_stack + 69935;
 target_ptr = Libderiv->deriv2_classes[2][6][78];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+70103, dvrr_stack+34678, dvrr_stack+2681);
 tmp = dvrr_stack + 70103;
 target_ptr = Libderiv->deriv2_classes[2][7][78];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+70319, dvrr_stack+34948, dvrr_stack+7492);
 tmp = dvrr_stack + 70319;
 target_ptr = Libderiv->deriv2_classes[2][8][78];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+70589, dvrr_stack+35278, dvrr_stack+34678);
 tmp = dvrr_stack + 70589;
 target_ptr = Libderiv->deriv2_classes[2][9][78];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,21,dvrr_stack+35278, dvrr_stack+1377, dvrr_stack+21649);
 tmp = dvrr_stack + 35278;
 target_ptr = Libderiv->deriv2_classes[1][5][35];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,28,dvrr_stack+35341, dvrr_stack+25981, dvrr_stack+16501);
 tmp = dvrr_stack + 35341;
 target_ptr = Libderiv->deriv2_classes[1][6][35];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,36,dvrr_stack+35425, dvrr_stack+26149, dvrr_stack+10663);
 tmp = dvrr_stack + 35425;
 target_ptr = Libderiv->deriv2_classes[1][7][35];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,45,dvrr_stack+35533, dvrr_stack+21049, dvrr_stack+13666);
 tmp = dvrr_stack + 35533;
 target_ptr = Libderiv->deriv2_classes[1][8][35];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_p(Data,55,dvrr_stack+70919, dvrr_stack+21319, dvrr_stack+5879);
 tmp = dvrr_stack + 70919;
 target_ptr = Libderiv->deriv2_classes[1][9][35];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,21,dvrr_stack+71084, dvrr_stack+37046, dvrr_stack+24832);
 tmp = dvrr_stack + 71084;
 target_ptr = Libderiv->deriv2_classes[2][5][35];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,28,dvrr_stack+71210, dvrr_stack+38780, dvrr_stack+24748);
 tmp = dvrr_stack + 71210;
 target_ptr = Libderiv->deriv2_classes[2][6][35];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,36,dvrr_stack+71378, dvrr_stack+40995, dvrr_stack+24895);
 tmp = dvrr_stack + 71378;
 target_ptr = Libderiv->deriv2_classes[2][7][35];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,45,dvrr_stack+71594, dvrr_stack+43750, dvrr_stack+25003);
 tmp = dvrr_stack + 71594;
 target_ptr = Libderiv->deriv2_classes[2][8][35];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_d(Data,55,dvrr_stack+71864, dvrr_stack+18475, dvrr_stack+25138);
 tmp = dvrr_stack + 71864;
 target_ptr = Libderiv->deriv2_classes[2][9][35];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+532, dvrr_stack+9094, dvrr_stack+19025);
 tmp = dvrr_stack + 532;
 target_ptr = Libderiv->deriv2_classes[1][5][34];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+19954, dvrr_stack+8926, dvrr_stack+284);
 tmp = dvrr_stack + 19954;
 target_ptr = Libderiv->deriv2_classes[1][6][34];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+5526, dvrr_stack+6440, dvrr_stack+693);
 tmp = dvrr_stack + 5526;
 target_ptr = Libderiv->deriv2_classes[1][7][34];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+72194, dvrr_stack+32488, dvrr_stack+1808);
 tmp = dvrr_stack + 72194;
 target_ptr = Libderiv->deriv2_classes[1][8][34];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+72329, dvrr_stack+32758, dvrr_stack+3268);
 tmp = dvrr_stack + 72329;
 target_ptr = Libderiv->deriv2_classes[1][9][34];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+72494, dvrr_stack+44200, dvrr_stack+17737);
 tmp = dvrr_stack + 72494;
 target_ptr = Libderiv->deriv2_classes[2][5][34];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+72620, dvrr_stack+44410, dvrr_stack+26410);
 tmp = dvrr_stack + 72620;
 target_ptr = Libderiv->deriv2_classes[2][6][34];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+72788, dvrr_stack+47104, dvrr_stack+14362);
 tmp = dvrr_stack + 72788;
 target_ptr = Libderiv->deriv2_classes[2][7][34];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+73004, dvrr_stack+47464, dvrr_stack+14470);
 tmp = dvrr_stack + 73004;
 target_ptr = Libderiv->deriv2_classes[2][8][34];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+73274, dvrr_stack+47914, dvrr_stack+12031);
 tmp = dvrr_stack + 73274;
 target_ptr = Libderiv->deriv2_classes[2][9][34];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+34600, dvrr_stack+11023, dvrr_stack+19046);
 tmp = dvrr_stack + 34600;
 target_ptr = Libderiv->deriv2_classes[1][5][33];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+73604, dvrr_stack+25621, dvrr_stack+24133);
 tmp = dvrr_stack + 73604;
 target_ptr = Libderiv->deriv2_classes[1][6][33];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+73688, dvrr_stack+10321, dvrr_stack+9220);
 tmp = dvrr_stack + 73688;
 target_ptr = Libderiv->deriv2_classes[1][7][33];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+73796, dvrr_stack+13066, dvrr_stack+22744);
 tmp = dvrr_stack + 73796;
 target_ptr = Libderiv->deriv2_classes[1][8][33];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+73931, dvrr_stack+15721, dvrr_stack+22789);
 tmp = dvrr_stack + 73931;
 target_ptr = Libderiv->deriv2_classes[1][9][33];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+74096, dvrr_stack+22844, dvrr_stack+873);
 tmp = dvrr_stack + 74096;
 target_ptr = Libderiv->deriv2_classes[2][5][33];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+74222, dvrr_stack+36416, dvrr_stack+24568);
 tmp = dvrr_stack + 74222;
 target_ptr = Libderiv->deriv2_classes[2][6][33];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+74390, dvrr_stack+37940, dvrr_stack+424);
 tmp = dvrr_stack + 74390;
 target_ptr = Libderiv->deriv2_classes[2][7][33];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+74606, dvrr_stack+39915, dvrr_stack+2033);
 tmp = dvrr_stack + 74606;
 target_ptr = Libderiv->deriv2_classes[2][8][33];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+74876, dvrr_stack+42400, dvrr_stack+3543);
 tmp = dvrr_stack + 74876;
 target_ptr = Libderiv->deriv2_classes[2][9][33];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+11440, dvrr_stack+19465, dvrr_stack+45454);
 tmp = dvrr_stack + 11440;
 target_ptr = Libderiv->deriv2_classes[1][5][32];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+75206, dvrr_stack+24301, dvrr_stack+45475);
 tmp = dvrr_stack + 75206;
 target_ptr = Libderiv->deriv2_classes[1][6][32];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+75290, dvrr_stack+19591, dvrr_stack+45503);
 tmp = dvrr_stack + 75290;
 target_ptr = Libderiv->deriv2_classes[1][7][32];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+75398, dvrr_stack+16051, dvrr_stack+45539);
 tmp = dvrr_stack + 75398;
 target_ptr = Libderiv->deriv2_classes[1][8][32];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+75533, dvrr_stack+13336, dvrr_stack+45584);
 tmp = dvrr_stack + 75533;
 target_ptr = Libderiv->deriv2_classes[1][9][32];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+75698, dvrr_stack+45849, dvrr_stack+23464);
 tmp = dvrr_stack + 75698;
 target_ptr = Libderiv->deriv2_classes[2][5][32];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+75824, dvrr_stack+46059, dvrr_stack+23380);
 tmp = dvrr_stack + 75824;
 target_ptr = Libderiv->deriv2_classes[2][6][32];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+75992, dvrr_stack+46339, dvrr_stack+23527);
 tmp = dvrr_stack + 75992;
 target_ptr = Libderiv->deriv2_classes[2][7][32];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+76208, dvrr_stack+42950, dvrr_stack+23635);
 tmp = dvrr_stack + 76208;
 target_ptr = Libderiv->deriv2_classes[2][8][32];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+76478, dvrr_stack+40365, dvrr_stack+23770);
 tmp = dvrr_stack + 76478;
 target_ptr = Libderiv->deriv2_classes[2][9][32];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+8854, dvrr_stack+10537, dvrr_stack+0);
 tmp = dvrr_stack + 8854;
 target_ptr = Libderiv->deriv2_classes[1][5][31];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+76808, dvrr_stack+5648, dvrr_stack+40);
 tmp = dvrr_stack + 76808;
 target_ptr = Libderiv->deriv2_classes[1][6][31];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+76892, dvrr_stack+3708, dvrr_stack+45639);
 tmp = dvrr_stack + 76892;
 target_ptr = Libderiv->deriv2_classes[1][7][31];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+77000, dvrr_stack+33484, dvrr_stack+25501);
 tmp = dvrr_stack + 77000;
 target_ptr = Libderiv->deriv2_classes[1][8][31];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+77135, dvrr_stack+33754, dvrr_stack+25546);
 tmp = dvrr_stack + 77135;
 target_ptr = Libderiv->deriv2_classes[1][9][31];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+77300, dvrr_stack+46699, dvrr_stack+19891);
 tmp = dvrr_stack + 77300;
 target_ptr = Libderiv->deriv2_classes[2][5][31];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+77426, dvrr_stack+43400, dvrr_stack+19807);
 tmp = dvrr_stack + 77426;
 target_ptr = Libderiv->deriv2_classes[2][6][31];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+77594, dvrr_stack+38300, dvrr_stack+8242);
 tmp = dvrr_stack + 77594;
 target_ptr = Libderiv->deriv2_classes[2][7][31];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+77810, dvrr_stack+48464, dvrr_stack+16321);
 tmp = dvrr_stack + 77810;
 target_ptr = Libderiv->deriv2_classes[2][8][31];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+78080, dvrr_stack+48914, dvrr_stack+11149);
 tmp = dvrr_stack + 78080;
 target_ptr = Libderiv->deriv2_classes[2][9][31];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+19394, dvrr_stack+7366, dvrr_stack+45675);
 tmp = dvrr_stack + 19394;
 target_ptr = Libderiv->deriv2_classes[1][5][30];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+78410, dvrr_stack+2681, dvrr_stack+46909);
 tmp = dvrr_stack + 78410;
 target_ptr = Libderiv->deriv2_classes[1][6][30];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+78494, dvrr_stack+7492, dvrr_stack+46937);
 tmp = dvrr_stack + 78494;
 target_ptr = Libderiv->deriv2_classes[1][7][30];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+78602, dvrr_stack+34678, dvrr_stack+46973);
 tmp = dvrr_stack + 78602;
 target_ptr = Libderiv->deriv2_classes[1][8][30];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+78737, dvrr_stack+34948, dvrr_stack+99);
 tmp = dvrr_stack + 78737;
 target_ptr = Libderiv->deriv2_classes[1][9][30];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+78902, dvrr_stack+36696, dvrr_stack+5816);
 tmp = dvrr_stack + 78902;
 target_ptr = Libderiv->deriv2_classes[2][5][30];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+79028, dvrr_stack+5120, dvrr_stack+25789);
 tmp = dvrr_stack + 79028;
 target_ptr = Libderiv->deriv2_classes[2][6][30];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+79196, dvrr_stack+49464, dvrr_stack+2168);
 tmp = dvrr_stack + 79196;
 target_ptr = Libderiv->deriv2_classes[2][7][30];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+79412, dvrr_stack+49824, dvrr_stack+936);
 tmp = dvrr_stack + 79412;
 target_ptr = Libderiv->deriv2_classes[2][8][30];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+79682, dvrr_stack+50274, dvrr_stack+4353);
 tmp = dvrr_stack + 79682;
 target_ptr = Libderiv->deriv2_classes[2][9][30];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+8176, dvrr_stack+45717, dvrr_stack+45696);
 tmp = dvrr_stack + 8176;
 target_ptr = Libderiv->deriv2_classes[1][5][26];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+80012, dvrr_stack+44690, dvrr_stack+47018);
 tmp = dvrr_stack + 80012;
 target_ptr = Libderiv->deriv2_classes[1][6][26];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+80096, dvrr_stack+44858, dvrr_stack+47046);
 tmp = dvrr_stack + 80096;
 target_ptr = Libderiv->deriv2_classes[1][7][26];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+80204, dvrr_stack+45074, dvrr_stack+43680);
 tmp = dvrr_stack + 80204;
 target_ptr = Libderiv->deriv2_classes[1][8][26];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+80339, dvrr_stack+50824, dvrr_stack+40915);
 tmp = dvrr_stack + 80339;
 target_ptr = Libderiv->deriv2_classes[1][9][26];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,21,dvrr_stack+80504, dvrr_stack+23054, dvrr_stack+38660);
 tmp = dvrr_stack + 80504;
 target_ptr = Libderiv->deriv2_classes[2][5][26];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+80630, dvrr_stack+51238, dvrr_stack+9256);
 tmp = dvrr_stack + 80630;
 target_ptr = Libderiv->deriv2_classes[2][6][26];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+80798, dvrr_stack+51955, dvrr_stack+9835);
 tmp = dvrr_stack + 80798;
 target_ptr = Libderiv->deriv2_classes[2][7][26];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+81014, dvrr_stack+52823, dvrr_stack+37256);
 tmp = dvrr_stack + 81014;
 target_ptr = Libderiv->deriv2_classes[2][8][26];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+81284, dvrr_stack+53939, dvrr_stack+39060);
 tmp = dvrr_stack + 81284;
 target_ptr = Libderiv->deriv2_classes[2][9][26];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,21,dvrr_stack+81614, dvrr_stack+1377, dvrr_stack+21649);
 tmp = dvrr_stack + 81614;
 target_ptr = Libderiv->deriv2_classes[1][5][23];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,28,dvrr_stack+81677, dvrr_stack+25981, dvrr_stack+16501);
 tmp = dvrr_stack + 81677;
 target_ptr = Libderiv->deriv2_classes[1][6][23];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,36,dvrr_stack+81761, dvrr_stack+26149, dvrr_stack+10663);
 tmp = dvrr_stack + 81761;
 target_ptr = Libderiv->deriv2_classes[1][7][23];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,45,dvrr_stack+81869, dvrr_stack+21049, dvrr_stack+13666);
 tmp = dvrr_stack + 81869;
 target_ptr = Libderiv->deriv2_classes[1][8][23];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_p(Data,55,dvrr_stack+82004, dvrr_stack+21319, dvrr_stack+5879);
 tmp = dvrr_stack + 82004;
 target_ptr = Libderiv->deriv2_classes[1][9][23];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,21,dvrr_stack+82169, dvrr_stack+37046, dvrr_stack+24832);
 tmp = dvrr_stack + 82169;
 target_ptr = Libderiv->deriv2_classes[2][5][23];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,28,dvrr_stack+82295, dvrr_stack+38780, dvrr_stack+24748);
 tmp = dvrr_stack + 82295;
 target_ptr = Libderiv->deriv2_classes[2][6][23];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,36,dvrr_stack+82463, dvrr_stack+40995, dvrr_stack+24895);
 tmp = dvrr_stack + 82463;
 target_ptr = Libderiv->deriv2_classes[2][7][23];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,45,dvrr_stack+82679, dvrr_stack+43750, dvrr_stack+25003);
 tmp = dvrr_stack + 82679;
 target_ptr = Libderiv->deriv2_classes[2][8][23];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_d(Data,55,dvrr_stack+82949, dvrr_stack+18475, dvrr_stack+25138);
 tmp = dvrr_stack + 82949;
 target_ptr = Libderiv->deriv2_classes[2][9][23];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+83279, dvrr_stack+9094, dvrr_stack+19025);
 tmp = dvrr_stack + 83279;
 target_ptr = Libderiv->deriv2_classes[1][5][22];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+83342, dvrr_stack+8926, dvrr_stack+284);
 tmp = dvrr_stack + 83342;
 target_ptr = Libderiv->deriv2_classes[1][6][22];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+83426, dvrr_stack+6440, dvrr_stack+693);
 tmp = dvrr_stack + 83426;
 target_ptr = Libderiv->deriv2_classes[1][7][22];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+83534, dvrr_stack+32488, dvrr_stack+1808);
 tmp = dvrr_stack + 83534;
 target_ptr = Libderiv->deriv2_classes[1][8][22];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+83669, dvrr_stack+32758, dvrr_stack+3268);
 tmp = dvrr_stack + 83669;
 target_ptr = Libderiv->deriv2_classes[1][9][22];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+83834, dvrr_stack+44200, dvrr_stack+17737);
 tmp = dvrr_stack + 83834;
 target_ptr = Libderiv->deriv2_classes[2][5][22];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+83960, dvrr_stack+44410, dvrr_stack+26410);
 tmp = dvrr_stack + 83960;
 target_ptr = Libderiv->deriv2_classes[2][6][22];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+84128, dvrr_stack+47104, dvrr_stack+14362);
 tmp = dvrr_stack + 84128;
 target_ptr = Libderiv->deriv2_classes[2][7][22];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+84344, dvrr_stack+47464, dvrr_stack+14470);
 tmp = dvrr_stack + 84344;
 target_ptr = Libderiv->deriv2_classes[2][8][22];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+84614, dvrr_stack+47914, dvrr_stack+12031);
 tmp = dvrr_stack + 84614;
 target_ptr = Libderiv->deriv2_classes[2][9][22];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+84944, dvrr_stack+11023, dvrr_stack+19046);
 tmp = dvrr_stack + 84944;
 target_ptr = Libderiv->deriv2_classes[1][5][21];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+85007, dvrr_stack+25621, dvrr_stack+24133);
 tmp = dvrr_stack + 85007;
 target_ptr = Libderiv->deriv2_classes[1][6][21];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+85091, dvrr_stack+10321, dvrr_stack+9220);
 tmp = dvrr_stack + 85091;
 target_ptr = Libderiv->deriv2_classes[1][7][21];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+85199, dvrr_stack+13066, dvrr_stack+22744);
 tmp = dvrr_stack + 85199;
 target_ptr = Libderiv->deriv2_classes[1][8][21];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+85334, dvrr_stack+15721, dvrr_stack+22789);
 tmp = dvrr_stack + 85334;
 target_ptr = Libderiv->deriv2_classes[1][9][21];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+85499, dvrr_stack+22844, dvrr_stack+873);
 tmp = dvrr_stack + 85499;
 target_ptr = Libderiv->deriv2_classes[2][5][21];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+85625, dvrr_stack+36416, dvrr_stack+24568);
 tmp = dvrr_stack + 85625;
 target_ptr = Libderiv->deriv2_classes[2][6][21];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+85793, dvrr_stack+37940, dvrr_stack+424);
 tmp = dvrr_stack + 85793;
 target_ptr = Libderiv->deriv2_classes[2][7][21];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+86009, dvrr_stack+39915, dvrr_stack+2033);
 tmp = dvrr_stack + 86009;
 target_ptr = Libderiv->deriv2_classes[2][8][21];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+86279, dvrr_stack+42400, dvrr_stack+3543);
 tmp = dvrr_stack + 86279;
 target_ptr = Libderiv->deriv2_classes[2][9][21];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+86609, dvrr_stack+19465, dvrr_stack+45454);
 tmp = dvrr_stack + 86609;
 target_ptr = Libderiv->deriv2_classes[1][5][20];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+86672, dvrr_stack+24301, dvrr_stack+45475);
 tmp = dvrr_stack + 86672;
 target_ptr = Libderiv->deriv2_classes[1][6][20];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+86756, dvrr_stack+19591, dvrr_stack+45503);
 tmp = dvrr_stack + 86756;
 target_ptr = Libderiv->deriv2_classes[1][7][20];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+86864, dvrr_stack+16051, dvrr_stack+45539);
 tmp = dvrr_stack + 86864;
 target_ptr = Libderiv->deriv2_classes[1][8][20];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+86999, dvrr_stack+13336, dvrr_stack+45584);
 tmp = dvrr_stack + 86999;
 target_ptr = Libderiv->deriv2_classes[1][9][20];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+87164, dvrr_stack+45849, dvrr_stack+23464);
 tmp = dvrr_stack + 87164;
 target_ptr = Libderiv->deriv2_classes[2][5][20];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+87290, dvrr_stack+46059, dvrr_stack+23380);
 tmp = dvrr_stack + 87290;
 target_ptr = Libderiv->deriv2_classes[2][6][20];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+87458, dvrr_stack+46339, dvrr_stack+23527);
 tmp = dvrr_stack + 87458;
 target_ptr = Libderiv->deriv2_classes[2][7][20];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+87674, dvrr_stack+42950, dvrr_stack+23635);
 tmp = dvrr_stack + 87674;
 target_ptr = Libderiv->deriv2_classes[2][8][20];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+87944, dvrr_stack+40365, dvrr_stack+23770);
 tmp = dvrr_stack + 87944;
 target_ptr = Libderiv->deriv2_classes[2][9][20];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+88274, dvrr_stack+10537, dvrr_stack+0);
 tmp = dvrr_stack + 88274;
 target_ptr = Libderiv->deriv2_classes[1][5][19];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+88337, dvrr_stack+5648, dvrr_stack+40);
 tmp = dvrr_stack + 88337;
 target_ptr = Libderiv->deriv2_classes[1][6][19];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+88421, dvrr_stack+3708, dvrr_stack+45639);
 tmp = dvrr_stack + 88421;
 target_ptr = Libderiv->deriv2_classes[1][7][19];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+88529, dvrr_stack+33484, dvrr_stack+25501);
 tmp = dvrr_stack + 88529;
 target_ptr = Libderiv->deriv2_classes[1][8][19];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+88664, dvrr_stack+33754, dvrr_stack+25546);
 tmp = dvrr_stack + 88664;
 target_ptr = Libderiv->deriv2_classes[1][9][19];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+88829, dvrr_stack+46699, dvrr_stack+19891);
 tmp = dvrr_stack + 88829;
 target_ptr = Libderiv->deriv2_classes[2][5][19];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+88955, dvrr_stack+43400, dvrr_stack+19807);
 tmp = dvrr_stack + 88955;
 target_ptr = Libderiv->deriv2_classes[2][6][19];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+89123, dvrr_stack+38300, dvrr_stack+8242);
 tmp = dvrr_stack + 89123;
 target_ptr = Libderiv->deriv2_classes[2][7][19];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+89339, dvrr_stack+48464, dvrr_stack+16321);
 tmp = dvrr_stack + 89339;
 target_ptr = Libderiv->deriv2_classes[2][8][19];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+89609, dvrr_stack+48914, dvrr_stack+11149);
 tmp = dvrr_stack + 89609;
 target_ptr = Libderiv->deriv2_classes[2][9][19];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+89939, dvrr_stack+7366, dvrr_stack+45675);
 tmp = dvrr_stack + 89939;
 target_ptr = Libderiv->deriv2_classes[1][5][18];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+90002, dvrr_stack+2681, dvrr_stack+46909);
 tmp = dvrr_stack + 90002;
 target_ptr = Libderiv->deriv2_classes[1][6][18];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+90086, dvrr_stack+7492, dvrr_stack+46937);
 tmp = dvrr_stack + 90086;
 target_ptr = Libderiv->deriv2_classes[1][7][18];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+90194, dvrr_stack+34678, dvrr_stack+46973);
 tmp = dvrr_stack + 90194;
 target_ptr = Libderiv->deriv2_classes[1][8][18];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+90329, dvrr_stack+34948, dvrr_stack+99);
 tmp = dvrr_stack + 90329;
 target_ptr = Libderiv->deriv2_classes[1][9][18];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+90494, dvrr_stack+36696, dvrr_stack+5816);
 tmp = dvrr_stack + 90494;
 target_ptr = Libderiv->deriv2_classes[2][5][18];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+90620, dvrr_stack+5120, dvrr_stack+25789);
 tmp = dvrr_stack + 90620;
 target_ptr = Libderiv->deriv2_classes[2][6][18];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+90788, dvrr_stack+49464, dvrr_stack+2168);
 tmp = dvrr_stack + 90788;
 target_ptr = Libderiv->deriv2_classes[2][7][18];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+91004, dvrr_stack+49824, dvrr_stack+936);
 tmp = dvrr_stack + 91004;
 target_ptr = Libderiv->deriv2_classes[2][8][18];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+91274, dvrr_stack+50274, dvrr_stack+4353);
 tmp = dvrr_stack + 91274;
 target_ptr = Libderiv->deriv2_classes[2][9][18];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+91604, dvrr_stack+45717, dvrr_stack+45696);
 tmp = dvrr_stack + 91604;
 target_ptr = Libderiv->deriv2_classes[1][5][14];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+91667, dvrr_stack+44690, dvrr_stack+47018);
 tmp = dvrr_stack + 91667;
 target_ptr = Libderiv->deriv2_classes[1][6][14];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+91751, dvrr_stack+44858, dvrr_stack+47046);
 tmp = dvrr_stack + 91751;
 target_ptr = Libderiv->deriv2_classes[1][7][14];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+91859, dvrr_stack+45074, dvrr_stack+43680);
 tmp = dvrr_stack + 91859;
 target_ptr = Libderiv->deriv2_classes[1][8][14];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+91994, dvrr_stack+50824, dvrr_stack+40915);
 tmp = dvrr_stack + 91994;
 target_ptr = Libderiv->deriv2_classes[1][9][14];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+92159, dvrr_stack+23054, dvrr_stack+38660);
 tmp = dvrr_stack + 92159;
 target_ptr = Libderiv->deriv2_classes[2][5][14];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+92285, dvrr_stack+51238, dvrr_stack+9256);
 tmp = dvrr_stack + 92285;
 target_ptr = Libderiv->deriv2_classes[2][6][14];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+92453, dvrr_stack+51955, dvrr_stack+9835);
 tmp = dvrr_stack + 92453;
 target_ptr = Libderiv->deriv2_classes[2][7][14];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+92669, dvrr_stack+52823, dvrr_stack+37256);
 tmp = dvrr_stack + 92669;
 target_ptr = Libderiv->deriv2_classes[2][8][14];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+92939, dvrr_stack+53939, dvrr_stack+39060);
 tmp = dvrr_stack + 92939;
 target_ptr = Libderiv->deriv2_classes[2][9][14];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+93269, dvrr_stack+53273, dvrr_stack+54489);
 tmp = dvrr_stack + 93269;
 target_ptr = Libderiv->deriv2_classes[1][5][13];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+93332, dvrr_stack+41355, dvrr_stack+54510);
 tmp = dvrr_stack + 93332;
 target_ptr = Libderiv->deriv2_classes[1][6][13];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+93416, dvrr_stack+41523, dvrr_stack+54538);
 tmp = dvrr_stack + 93416;
 target_ptr = Libderiv->deriv2_classes[1][7][13];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+93524, dvrr_stack+55334, dvrr_stack+54574);
 tmp = dvrr_stack + 93524;
 target_ptr = Libderiv->deriv2_classes[1][8][13];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+93659, dvrr_stack+55604, dvrr_stack+41739);
 tmp = dvrr_stack + 93659;
 target_ptr = Libderiv->deriv2_classes[1][9][13];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,21,dvrr_stack+93824, dvrr_stack+55934, dvrr_stack+15226);
 tmp = dvrr_stack + 93824;
 target_ptr = Libderiv->deriv2_classes[2][5][13];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+93950, dvrr_stack+57039, dvrr_stack+51154);
 tmp = dvrr_stack + 93950;
 target_ptr = Libderiv->deriv2_classes[2][6][13];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+94118, dvrr_stack+57319, dvrr_stack+10699);
 tmp = dvrr_stack + 94118;
 target_ptr = Libderiv->deriv2_classes[2][7][13];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+94334, dvrr_stack+57679, dvrr_stack+12661);
 tmp = dvrr_stack + 94334;
 target_ptr = Libderiv->deriv2_classes[2][8][13];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+94604, dvrr_stack+58129, dvrr_stack+37391);
 tmp = dvrr_stack + 94604;
 target_ptr = Libderiv->deriv2_classes[2][9][13];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,21,dvrr_stack+94934, dvrr_stack+1377, dvrr_stack+21649);
 tmp = dvrr_stack + 94934;
 target_ptr = Libderiv->deriv2_classes[1][5][11];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,28,dvrr_stack+1341, dvrr_stack+25981, dvrr_stack+16501);
 tmp = dvrr_stack + 1341;
 target_ptr = Libderiv->deriv2_classes[1][6][11];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,36,dvrr_stack+25957, dvrr_stack+26149, dvrr_stack+10663);
 tmp = dvrr_stack + 25957;
 target_ptr = Libderiv->deriv2_classes[1][7][11];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,45,dvrr_stack+26065, dvrr_stack+21049, dvrr_stack+13666);
 tmp = dvrr_stack + 26065;
 target_ptr = Libderiv->deriv2_classes[1][8][11];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_p(Data,55,dvrr_stack+26200, dvrr_stack+21319, dvrr_stack+5879);
 tmp = dvrr_stack + 26200;
 target_ptr = Libderiv->deriv2_classes[1][9][11];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,21,dvrr_stack+21046, dvrr_stack+37046, dvrr_stack+24832);
 tmp = dvrr_stack + 21046;
 target_ptr = Libderiv->deriv2_classes[2][5][11];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,28,dvrr_stack+37032, dvrr_stack+38780, dvrr_stack+24748);
 tmp = dvrr_stack + 37032;
 target_ptr = Libderiv->deriv2_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,36,dvrr_stack+38723, dvrr_stack+40995, dvrr_stack+24895);
 tmp = dvrr_stack + 38723;
 target_ptr = Libderiv->deriv2_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,45,dvrr_stack+40970, dvrr_stack+43750, dvrr_stack+25003);
 tmp = dvrr_stack + 40970;
 target_ptr = Libderiv->deriv2_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_d(Data,55,dvrr_stack+43725, dvrr_stack+18475, dvrr_stack+25138);
 tmp = dvrr_stack + 43725;
 target_ptr = Libderiv->deriv2_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+16456, dvrr_stack+9094, dvrr_stack+19025);
 tmp = dvrr_stack + 16456;
 target_ptr = Libderiv->deriv2_classes[1][5][10];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+9094, dvrr_stack+8926, dvrr_stack+284);
 tmp = dvrr_stack + 9094;
 target_ptr = Libderiv->deriv2_classes[1][6][10];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+8917, dvrr_stack+6440, dvrr_stack+693);
 tmp = dvrr_stack + 8917;
 target_ptr = Libderiv->deriv2_classes[1][7][10];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+44055, dvrr_stack+32488, dvrr_stack+1808);
 tmp = dvrr_stack + 44055;
 target_ptr = Libderiv->deriv2_classes[1][8][10];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+32488, dvrr_stack+32758, dvrr_stack+3268);
 tmp = dvrr_stack + 32488;
 target_ptr = Libderiv->deriv2_classes[1][9][10];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+32653, dvrr_stack+44200, dvrr_stack+17737);
 tmp = dvrr_stack + 32653;
 target_ptr = Libderiv->deriv2_classes[2][5][10];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+32779, dvrr_stack+44410, dvrr_stack+26410);
 tmp = dvrr_stack + 32779;
 target_ptr = Libderiv->deriv2_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+44190, dvrr_stack+47104, dvrr_stack+14362);
 tmp = dvrr_stack + 44190;
 target_ptr = Libderiv->deriv2_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+47082, dvrr_stack+47464, dvrr_stack+14470);
 tmp = dvrr_stack + 47082;
 target_ptr = Libderiv->deriv2_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+47352, dvrr_stack+47914, dvrr_stack+12031);
 tmp = dvrr_stack + 47352;
 target_ptr = Libderiv->deriv2_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+32947, dvrr_stack+11023, dvrr_stack+19046);
 tmp = dvrr_stack + 32947;
 target_ptr = Libderiv->deriv2_classes[1][5][9];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+1803, dvrr_stack+25621, dvrr_stack+24133);
 tmp = dvrr_stack + 1803;
 target_ptr = Libderiv->deriv2_classes[1][6][9];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+11005, dvrr_stack+10321, dvrr_stack+9220);
 tmp = dvrr_stack + 11005;
 target_ptr = Libderiv->deriv2_classes[1][7][9];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+10270, dvrr_stack+13066, dvrr_stack+22744);
 tmp = dvrr_stack + 10270;
 target_ptr = Libderiv->deriv2_classes[1][8][9];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+13051, dvrr_stack+15721, dvrr_stack+22789);
 tmp = dvrr_stack + 13051;
 target_ptr = Libderiv->deriv2_classes[1][9][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+10405, dvrr_stack+22844, dvrr_stack+873);
 tmp = dvrr_stack + 10405;
 target_ptr = Libderiv->deriv2_classes[2][5][9];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+15685, dvrr_stack+36416, dvrr_stack+24568);
 tmp = dvrr_stack + 15685;
 target_ptr = Libderiv->deriv2_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+36412, dvrr_stack+37940, dvrr_stack+424);
 tmp = dvrr_stack + 36412;
 target_ptr = Libderiv->deriv2_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+37886, dvrr_stack+39915, dvrr_stack+2033);
 tmp = dvrr_stack + 37886;
 target_ptr = Libderiv->deriv2_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+39909, dvrr_stack+42400, dvrr_stack+3543);
 tmp = dvrr_stack + 39909;
 target_ptr = Libderiv->deriv2_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+873, dvrr_stack+19465, dvrr_stack+45454);
 tmp = dvrr_stack + 873;
 target_ptr = Libderiv->deriv2_classes[1][5][8];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+3543, dvrr_stack+24301, dvrr_stack+45475);
 tmp = dvrr_stack + 3543;
 target_ptr = Libderiv->deriv2_classes[1][6][8];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+13216, dvrr_stack+19591, dvrr_stack+45503);
 tmp = dvrr_stack + 13216;
 target_ptr = Libderiv->deriv2_classes[1][7][8];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+2016, dvrr_stack+16051, dvrr_stack+45539);
 tmp = dvrr_stack + 2016;
 target_ptr = Libderiv->deriv2_classes[1][8][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+42392, dvrr_stack+13336, dvrr_stack+45584);
 tmp = dvrr_stack + 42392;
 target_ptr = Libderiv->deriv2_classes[1][9][8];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+40239, dvrr_stack+45849, dvrr_stack+23464);
 tmp = dvrr_stack + 40239;
 target_ptr = Libderiv->deriv2_classes[2][5][8];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+13324, dvrr_stack+46059, dvrr_stack+23380);
 tmp = dvrr_stack + 13324;
 target_ptr = Libderiv->deriv2_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+13492, dvrr_stack+46339, dvrr_stack+23527);
 tmp = dvrr_stack + 13492;
 target_ptr = Libderiv->deriv2_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+42557, dvrr_stack+42950, dvrr_stack+23635);
 tmp = dvrr_stack + 42557;
 target_ptr = Libderiv->deriv2_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+42827, dvrr_stack+40365, dvrr_stack+23770);
 tmp = dvrr_stack + 42827;
 target_ptr = Libderiv->deriv2_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+40365, dvrr_stack+10537, dvrr_stack+0);
 tmp = dvrr_stack + 40365;
 target_ptr = Libderiv->deriv2_classes[1][5][7];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+40428, dvrr_stack+5648, dvrr_stack+40);
 tmp = dvrr_stack + 40428;
 target_ptr = Libderiv->deriv2_classes[1][6][7];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+40512, dvrr_stack+3708, dvrr_stack+45639);
 tmp = dvrr_stack + 40512;
 target_ptr = Libderiv->deriv2_classes[1][7][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+40620, dvrr_stack+33484, dvrr_stack+25501);
 tmp = dvrr_stack + 40620;
 target_ptr = Libderiv->deriv2_classes[1][8][7];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+3627, dvrr_stack+33754, dvrr_stack+25546);
 tmp = dvrr_stack + 3627;
 target_ptr = Libderiv->deriv2_classes[1][9][7];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+40755, dvrr_stack+46699, dvrr_stack+19891);
 tmp = dvrr_stack + 40755;
 target_ptr = Libderiv->deriv2_classes[2][5][7];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+10531, dvrr_stack+43400, dvrr_stack+19807);
 tmp = dvrr_stack + 10531;
 target_ptr = Libderiv->deriv2_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+33478, dvrr_stack+38300, dvrr_stack+8242);
 tmp = dvrr_stack + 33478;
 target_ptr = Libderiv->deriv2_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+33694, dvrr_stack+48464, dvrr_stack+16321);
 tmp = dvrr_stack + 33694;
 target_ptr = Libderiv->deriv2_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+43157, dvrr_stack+48914, dvrr_stack+11149);
 tmp = dvrr_stack + 43157;
 target_ptr = Libderiv->deriv2_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+0, dvrr_stack+7366, dvrr_stack+45675);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[1][5][6];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+3792, dvrr_stack+2681, dvrr_stack+46909);
 tmp = dvrr_stack + 3792;
 target_ptr = Libderiv->deriv2_classes[1][6][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+33964, dvrr_stack+7492, dvrr_stack+46937);
 tmp = dvrr_stack + 33964;
 target_ptr = Libderiv->deriv2_classes[1][7][6];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+25492, dvrr_stack+34678, dvrr_stack+46973);
 tmp = dvrr_stack + 25492;
 target_ptr = Libderiv->deriv2_classes[1][8][6];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+34663, dvrr_stack+34948, dvrr_stack+99);
 tmp = dvrr_stack + 34663;
 target_ptr = Libderiv->deriv2_classes[1][9][6];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+34828, dvrr_stack+36696, dvrr_stack+5816);
 tmp = dvrr_stack + 34828;
 target_ptr = Libderiv->deriv2_classes[2][5][6];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+34954, dvrr_stack+5120, dvrr_stack+25789);
 tmp = dvrr_stack + 34954;
 target_ptr = Libderiv->deriv2_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+25627, dvrr_stack+49464, dvrr_stack+2168);
 tmp = dvrr_stack + 25627;
 target_ptr = Libderiv->deriv2_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+36628, dvrr_stack+49824, dvrr_stack+936);
 tmp = dvrr_stack + 36628;
 target_ptr = Libderiv->deriv2_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+15853, dvrr_stack+50274, dvrr_stack+4353);
 tmp = dvrr_stack + 15853;
 target_ptr = Libderiv->deriv2_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+936, dvrr_stack+45717, dvrr_stack+45696);
 tmp = dvrr_stack + 936;
 target_ptr = Libderiv->deriv2_classes[1][5][2];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+63, dvrr_stack+44690, dvrr_stack+47018);
 tmp = dvrr_stack + 63;
 target_ptr = Libderiv->deriv2_classes[1][6][2];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+35122, dvrr_stack+44858, dvrr_stack+47046);
 tmp = dvrr_stack + 35122;
 target_ptr = Libderiv->deriv2_classes[1][7][2];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+11113, dvrr_stack+45074, dvrr_stack+43680);
 tmp = dvrr_stack + 11113;
 target_ptr = Libderiv->deriv2_classes[1][8][2];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+43487, dvrr_stack+50824, dvrr_stack+40915);
 tmp = dvrr_stack + 43487;
 target_ptr = Libderiv->deriv2_classes[1][9][2];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+376, dvrr_stack+23054, dvrr_stack+38660);
 tmp = dvrr_stack + 376;
 target_ptr = Libderiv->deriv2_classes[2][5][2];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+16183, dvrr_stack+51238, dvrr_stack+9256);
 tmp = dvrr_stack + 16183;
 target_ptr = Libderiv->deriv2_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+51238, dvrr_stack+51955, dvrr_stack+9835);
 tmp = dvrr_stack + 51238;
 target_ptr = Libderiv->deriv2_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+38156, dvrr_stack+52823, dvrr_stack+37256);
 tmp = dvrr_stack + 38156;
 target_ptr = Libderiv->deriv2_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+52807, dvrr_stack+53939, dvrr_stack+39060);
 tmp = dvrr_stack + 52807;
 target_ptr = Libderiv->deriv2_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+51454, dvrr_stack+53273, dvrr_stack+54489);
 tmp = dvrr_stack + 51454;
 target_ptr = Libderiv->deriv2_classes[1][5][1];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+40881, dvrr_stack+41355, dvrr_stack+54510);
 tmp = dvrr_stack + 40881;
 target_ptr = Libderiv->deriv2_classes[1][6][1];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+9178, dvrr_stack+41523, dvrr_stack+54538);
 tmp = dvrr_stack + 9178;
 target_ptr = Libderiv->deriv2_classes[1][7][1];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+9781, dvrr_stack+55334, dvrr_stack+54574);
 tmp = dvrr_stack + 9781;
 target_ptr = Libderiv->deriv2_classes[1][8][1];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+53933, dvrr_stack+55604, dvrr_stack+41739);
 tmp = dvrr_stack + 53933;
 target_ptr = Libderiv->deriv2_classes[1][9][1];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+54098, dvrr_stack+55934, dvrr_stack+15226);
 tmp = dvrr_stack + 54098;
 target_ptr = Libderiv->deriv2_classes[2][5][1];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+54224, dvrr_stack+57039, dvrr_stack+51154);
 tmp = dvrr_stack + 54224;
 target_ptr = Libderiv->deriv2_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+54392, dvrr_stack+57319, dvrr_stack+10699);
 tmp = dvrr_stack + 54392;
 target_ptr = Libderiv->deriv2_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+55316, dvrr_stack+57679, dvrr_stack+12661);
 tmp = dvrr_stack + 55316;
 target_ptr = Libderiv->deriv2_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+55586, dvrr_stack+58129, dvrr_stack+37391);
 tmp = dvrr_stack + 55586;
 target_ptr = Libderiv->deriv2_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+10699, dvrr_stack+39225, dvrr_stack+54619);
 tmp = dvrr_stack + 10699;
 target_ptr = Libderiv->deriv2_classes[1][5][0];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+24553, dvrr_stack+35674, dvrr_stack+175);
 tmp = dvrr_stack + 24553;
 target_ptr = Libderiv->deriv2_classes[1][6][0];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+35668, dvrr_stack+35842, dvrr_stack+340);
 tmp = dvrr_stack + 35668;
 target_ptr = Libderiv->deriv2_classes[1][7][0];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+35776, dvrr_stack+36058, dvrr_stack+765);
 tmp = dvrr_stack + 35776;
 target_ptr = Libderiv->deriv2_classes[1][8][0];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+35911, dvrr_stack+37556, dvrr_stack+1898);
 tmp = dvrr_stack + 35911;
 target_ptr = Libderiv->deriv2_classes[1][9][0];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,21,dvrr_stack+36076, dvrr_stack+41794, dvrr_stack+810);
 tmp = dvrr_stack + 36076;
 target_ptr = Libderiv->deriv2_classes[2][5][0];
 for(i=0;i<126;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+55916, dvrr_stack+42004, dvrr_stack+9943);
 tmp = dvrr_stack + 55916;
 target_ptr = Libderiv->deriv2_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+57023, dvrr_stack+39351, dvrr_stack+10027);
 tmp = dvrr_stack + 57023;
 target_ptr = Libderiv->deriv2_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+57239, dvrr_stack+53399, dvrr_stack+10807);
 tmp = dvrr_stack + 57239;
 target_ptr = Libderiv->deriv2_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+57509, dvrr_stack+54640, dvrr_stack+3378);
 tmp = dvrr_stack + 57509;
 target_ptr = Libderiv->deriv2_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];


}

